Class: Aws::IoT::Types::AssetPropertyValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AssetPropertyValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
An asset property value entry containing the following information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#quality ⇒ String
Optional.
-
#timestamp ⇒ Types::AssetPropertyTimestamp
The asset property value timestamp.
-
#value ⇒ Types::AssetPropertyVariant
The value of the asset property.
Instance Attribute Details
#quality ⇒ String
Optional. A string that describes the quality of the value. Accepts
substitution templates. Must be GOOD, BAD, or UNCERTAIN.
456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-iot/types.rb', line 456 class AssetPropertyValue < Struct.new( :value, :timestamp, :quality) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Types::AssetPropertyTimestamp
The asset property value timestamp.
456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-iot/types.rb', line 456 class AssetPropertyValue < Struct.new( :value, :timestamp, :quality) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Types::AssetPropertyVariant
The value of the asset property.
456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-iot/types.rb', line 456 class AssetPropertyValue < Struct.new( :value, :timestamp, :quality) SENSITIVE = [] include Aws::Structure end |