Class: Aws::IoT::Types::AssetPropertyVariant
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AssetPropertyVariant
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass AssetPropertyVariant data as a hash:
{
string_value: "AssetPropertyStringValue",
integer_value: "AssetPropertyIntegerValue",
double_value: "AssetPropertyDoubleValue",
boolean_value: "AssetPropertyBooleanValue",
}
Contains an asset property value (of a single type).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#boolean_value ⇒ String
Optional.
-
#double_value ⇒ String
Optional.
-
#integer_value ⇒ String
Optional.
-
#string_value ⇒ String
Optional.
Instance Attribute Details
#boolean_value ⇒ String
Optional. A string that contains the boolean value (`true` or `false`) of the value entry. Accepts substitution templates.
783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-iot/types.rb', line 783 class AssetPropertyVariant < Struct.new( :string_value, :integer_value, :double_value, :boolean_value) SENSITIVE = [] include Aws::Structure end |
#double_value ⇒ String
Optional. A string that contains the double value of the value entry. Accepts substitution templates.
783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-iot/types.rb', line 783 class AssetPropertyVariant < Struct.new( :string_value, :integer_value, :double_value, :boolean_value) SENSITIVE = [] include Aws::Structure end |
#integer_value ⇒ String
Optional. A string that contains the integer value of the value entry. Accepts substitution templates.
783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-iot/types.rb', line 783 class AssetPropertyVariant < Struct.new( :string_value, :integer_value, :double_value, :boolean_value) SENSITIVE = [] include Aws::Structure end |
#string_value ⇒ String
Optional. The string value of the value entry. Accepts substitution templates.
783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-iot/types.rb', line 783 class AssetPropertyVariant < Struct.new( :string_value, :integer_value, :double_value, :boolean_value) SENSITIVE = [] include Aws::Structure end |