Class: Aws::IoT::Types::AssociateSbomWithPackageVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#package_nameString

The name of the new software package.



545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-iot/types.rb', line 545

class AssociateSbomWithPackageVersionResponse < Struct.new(
  :package_name,
  :version_name,
  :sbom,
  :sbom_validation_status)
  SENSITIVE = []
  include Aws::Structure
end

#sbomTypes::Sbom

A specific software bill of matrerials associated with a software package version.



545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-iot/types.rb', line 545

class AssociateSbomWithPackageVersionResponse < Struct.new(
  :package_name,
  :version_name,
  :sbom,
  :sbom_validation_status)
  SENSITIVE = []
  include Aws::Structure
end

#sbom_validation_statusString

The status of the initial validation for the software bill of materials against the Software Package Data Exchange (SPDX) and CycloneDX industry standard formats.



545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-iot/types.rb', line 545

class AssociateSbomWithPackageVersionResponse < Struct.new(
  :package_name,
  :version_name,
  :sbom,
  :sbom_validation_status)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The name of the new package version.



545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-iot/types.rb', line 545

class AssociateSbomWithPackageVersionResponse < Struct.new(
  :package_name,
  :version_name,
  :sbom,
  :sbom_validation_status)
  SENSITIVE = []
  include Aws::Structure
end