Class: Aws::IoT::Types::AssociateTargetsWithJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commentString

An optional comment string describing why the job was associated with the targets.

Returns:

  • (String)


517
518
519
520
521
522
523
524
# File 'lib/aws-sdk-iot/types.rb', line 517

class AssociateTargetsWithJobRequest < Struct.new(
  :targets,
  :job_id,
  :comment,
  :namespace_id)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier you assigned to this job when it was created.

Returns:

  • (String)


517
518
519
520
521
522
523
524
# File 'lib/aws-sdk-iot/types.rb', line 517

class AssociateTargetsWithJobRequest < Struct.new(
  :targets,
  :job_id,
  :comment,
  :namespace_id)
  SENSITIVE = []
  include Aws::Structure
end

#namespace_idString

The namespace used to indicate that a job is a customer-managed job.

When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.

‘$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`

<note markdown=“1”> The namespaceId feature is in public preview.

</note>

Returns:

  • (String)


517
518
519
520
521
522
523
524
# File 'lib/aws-sdk-iot/types.rb', line 517

class AssociateTargetsWithJobRequest < Struct.new(
  :targets,
  :job_id,
  :comment,
  :namespace_id)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<String>

A list of thing group ARNs that define the targets of the job.

Returns:

  • (Array<String>)


517
518
519
520
521
522
523
524
# File 'lib/aws-sdk-iot/types.rb', line 517

class AssociateTargetsWithJobRequest < Struct.new(
  :targets,
  :job_id,
  :comment,
  :namespace_id)
  SENSITIVE = []
  include Aws::Structure
end