Class: Aws::IoT::Types::AttributePayload

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass AttributePayload data as a hash:

{
  attributes: {
    "AttributeName" => "AttributeValue",
  },
  merge: false,
}

The attribute payload.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

A JSON string containing up to three key-value pair in JSON format. For example:

`“attributes”:{“string1”:“string2”}`

Returns:

  • (Hash<String,String>)


984
985
986
987
988
989
# File 'lib/aws-sdk-iot/types.rb', line 984

class AttributePayload < Struct.new(
  :attributes,
  :merge)
  SENSITIVE = []
  include Aws::Structure
end

#mergeBoolean

Specifies whether the list of attributes provided in the `AttributePayload` is merged with the attributes stored in the registry, instead of overwriting them.

To remove an attribute, call `UpdateThing` with an empty attribute value.

<note markdown=“1”> The `merge` attribute is only valid when calling `UpdateThing` or `UpdateThingGroup`.

</note>

Returns:

  • (Boolean)


984
985
986
987
988
989
# File 'lib/aws-sdk-iot/types.rb', line 984

class AttributePayload < Struct.new(
  :attributes,
  :merge)
  SENSITIVE = []
  include Aws::Structure
end