Class: Aws::IoT::Types::AuditCheckConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuditCheckConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Which audit checks are enabled and disabled for this account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Hash<String,String>
A structure containing the configName and corresponding configValue for configuring audit checks.
-
#enabled ⇒ Boolean
True if this audit check is enabled for this account.
Instance Attribute Details
#configuration ⇒ Hash<String,String>
A structure containing the configName and corresponding configValue for configuring audit checks.
753 754 755 756 757 758 |
# File 'lib/aws-sdk-iot/types.rb', line 753 class AuditCheckConfiguration < Struct.new( :enabled, :configuration) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
True if this audit check is enabled for this account.
753 754 755 756 757 758 |
# File 'lib/aws-sdk-iot/types.rb', line 753 class AuditCheckConfiguration < Struct.new( :enabled, :configuration) SENSITIVE = [] include Aws::Structure end |