Class: Aws::IoT::Types::AuditFinding
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuditFinding
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The findings (results) of the audit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#check_name ⇒ String
The audit check that generated this result.
-
#finding_id ⇒ String
A unique identifier for this set of audit findings.
-
#finding_time ⇒ Time
The time the result (finding) was discovered.
-
#is_suppressed ⇒ Boolean
Indicates whether the audit finding was suppressed or not during reporting.
-
#non_compliant_resource ⇒ Types::NonCompliantResource
The resource that was found to be noncompliant with the audit check.
-
#reason_for_non_compliance ⇒ String
The reason the resource was noncompliant.
-
#reason_for_non_compliance_code ⇒ String
A code that indicates the reason that the resource was noncompliant.
-
#related_resources ⇒ Array<Types::RelatedResource>
The list of related resources.
-
#severity ⇒ String
The severity of the result (finding).
-
#task_id ⇒ String
The ID of the audit that generated this result (finding).
-
#task_start_time ⇒ Time
The time the audit started.
Instance Attribute Details
#check_name ⇒ String
The audit check that generated this result.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#finding_id ⇒ String
A unique identifier for this set of audit findings. This identifier is used to apply mitigation tasks to one or more sets of findings.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#finding_time ⇒ Time
The time the result (finding) was discovered.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#is_suppressed ⇒ Boolean
Indicates whether the audit finding was suppressed or not during reporting.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#non_compliant_resource ⇒ Types::NonCompliantResource
The resource that was found to be noncompliant with the audit check.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#reason_for_non_compliance ⇒ String
The reason the resource was noncompliant.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#reason_for_non_compliance_code ⇒ String
A code that indicates the reason that the resource was noncompliant.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#related_resources ⇒ Array<Types::RelatedResource>
The list of related resources.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity of the result (finding).
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The ID of the audit that generated this result (finding).
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |
#task_start_time ⇒ Time
The time the audit started.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/aws-sdk-iot/types.rb', line 764 class AuditFinding < Struct.new( :finding_id, :task_id, :check_name, :task_start_time, :finding_time, :severity, :non_compliant_resource, :related_resources, :reason_for_non_compliance, :reason_for_non_compliance_code, :is_suppressed) SENSITIVE = [] include Aws::Structure end |