Class: Aws::IoT::Types::AuditMitigationActionExecutionMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuditMitigationActionExecutionMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Returned by ListAuditMitigationActionsTask, this object contains information that describes a mitigation action that has been started.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_id ⇒ String
The unique identifier for the mitigation action being applied by the task.
-
#action_name ⇒ String
The friendly name of the mitigation action being applied by the task.
-
#end_time ⇒ Time
The date and time when the task was completed or canceled.
-
#error_code ⇒ String
If an error occurred, the code that indicates which type of error occurred.
-
#finding_id ⇒ String
The unique identifier for the findings to which the task and associated mitigation action are applied.
-
#message ⇒ String
If an error occurred, a message that describes the error.
-
#start_time ⇒ Time
The date and time when the task was started.
-
#status ⇒ String
The current status of the task being executed.
-
#task_id ⇒ String
The unique identifier for the task that applies the mitigation action.
Instance Attribute Details
#action_id ⇒ String
The unique identifier for the mitigation action being applied by the task.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#action_name ⇒ String
The friendly name of the mitigation action being applied by the task.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time when the task was completed or canceled. Blank if the task is still running.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#error_code ⇒ String
If an error occurred, the code that indicates which type of error occurred.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#finding_id ⇒ String
The unique identifier for the findings to which the task and associated mitigation action are applied.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
If an error occurred, a message that describes the error.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time when the task was started.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the task being executed.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier for the task that applies the mitigation action.
825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/aws-sdk-iot/types.rb', line 825 class AuditMitigationActionExecutionMetadata < Struct.new( :task_id, :finding_id, :action_name, :action_id, :status, :start_time, :end_time, :error_code, :message) SENSITIVE = [] include Aws::Structure end |