Class: Aws::IoT::Types::AuditMitigationActionsTaskMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuditMitigationActionsTaskMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Information about an audit mitigation actions task that is returned by `ListAuditMitigationActionsTasks`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#start_time ⇒ Time
The time at which the audit mitigation actions task was started.
-
#task_id ⇒ String
The unique identifier for the task.
-
#task_status ⇒ String
The current state of the audit mitigation actions task.
Instance Attribute Details
#start_time ⇒ Time
The time at which the audit mitigation actions task was started.
1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/aws-sdk-iot/types.rb', line 1228 class AuditMitigationActionsTaskMetadata < Struct.new( :task_id, :start_time, :task_status) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier for the task.
1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/aws-sdk-iot/types.rb', line 1228 class AuditMitigationActionsTaskMetadata < Struct.new( :task_id, :start_time, :task_status) SENSITIVE = [] include Aws::Structure end |
#task_status ⇒ String
The current state of the audit mitigation actions task.
1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/aws-sdk-iot/types.rb', line 1228 class AuditMitigationActionsTaskMetadata < Struct.new( :task_id, :start_time, :task_status) SENSITIVE = [] include Aws::Structure end |