Class: Aws::IoT::Types::AuditMitigationActionsTaskTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Used in MitigationActionParams, this information identifies the target findings to which the mitigation actions are applied. Only one entry appears.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audit_check_to_reason_code_filterHash<String,Array<String>>

Specifies a filter in the form of an audit check and set of reason codes that identify the findings from the audit to which the audit mitigation actions task apply.



976
977
978
979
980
981
982
# File 'lib/aws-sdk-iot/types.rb', line 976

class AuditMitigationActionsTaskTarget < Struct.new(
  :audit_task_id,
  :finding_ids,
  :audit_check_to_reason_code_filter)
  SENSITIVE = []
  include Aws::Structure
end

#audit_task_idString

If the task will apply a mitigation action to findings from a specific audit, this value uniquely identifies the audit.



976
977
978
979
980
981
982
# File 'lib/aws-sdk-iot/types.rb', line 976

class AuditMitigationActionsTaskTarget < Struct.new(
  :audit_task_id,
  :finding_ids,
  :audit_check_to_reason_code_filter)
  SENSITIVE = []
  include Aws::Structure
end

#finding_idsArray<String>

If the task will apply a mitigation action to one or more listed findings, this value uniquely identifies those findings.



976
977
978
979
980
981
982
# File 'lib/aws-sdk-iot/types.rb', line 976

class AuditMitigationActionsTaskTarget < Struct.new(
  :audit_task_id,
  :finding_ids,
  :audit_check_to_reason_code_filter)
  SENSITIVE = []
  include Aws::Structure
end