Class: Aws::IoT::Types::AuditNotificationTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass AuditNotificationTarget data as a hash:

{
  target_arn: "TargetArn",
  role_arn: "RoleArn",
  enabled: false,
}

Information about the targets to which audit notifications are sent.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

True if notifications to the target are enabled.

Returns:

  • (Boolean)


1300
1301
1302
1303
1304
1305
1306
# File 'lib/aws-sdk-iot/types.rb', line 1300

class AuditNotificationTarget < Struct.new(
  :target_arn,
  :role_arn,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the role that grants permission to send notifications to the target.

Returns:

  • (String)


1300
1301
1302
1303
1304
1305
1306
# File 'lib/aws-sdk-iot/types.rb', line 1300

class AuditNotificationTarget < Struct.new(
  :target_arn,
  :role_arn,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The ARN of the target (SNS topic) to which audit notifications are sent.

Returns:

  • (String)


1300
1301
1302
1303
1304
1305
1306
# File 'lib/aws-sdk-iot/types.rb', line 1300

class AuditNotificationTarget < Struct.new(
  :target_arn,
  :role_arn,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end