Class: Aws::IoT::Types::AuthInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuthInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass AuthInfo data as a hash:
{
action_type: "PUBLISH", # accepts PUBLISH, SUBSCRIBE, RECEIVE, CONNECT
resources: ["Resource"], # required
}
A collection of authorization information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_type ⇒ String
The type of action for which the principal is being authorized.
-
#resources ⇒ Array<String>
The resources for which the principal is being authorized to perform the specified action.