Class: Aws::IoT::Types::AuthResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The authorizer result.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowedTypes::Allowed

The policies and statements that allowed the specified action.



1112
1113
1114
1115
1116
1117
1118
1119
1120
# File 'lib/aws-sdk-iot/types.rb', line 1112

class AuthResult < Struct.new(
  :auth_info,
  :allowed,
  :denied,
  :auth_decision,
  :missing_context_values)
  SENSITIVE = []
  include Aws::Structure
end

#auth_decisionString

The final authorization decision of this scenario. Multiple statements are taken into account when determining the authorization decision. An explicit deny statement can override multiple allow statements.



1112
1113
1114
1115
1116
1117
1118
1119
1120
# File 'lib/aws-sdk-iot/types.rb', line 1112

class AuthResult < Struct.new(
  :auth_info,
  :allowed,
  :denied,
  :auth_decision,
  :missing_context_values)
  SENSITIVE = []
  include Aws::Structure
end

#auth_infoTypes::AuthInfo

Authorization information.



1112
1113
1114
1115
1116
1117
1118
1119
1120
# File 'lib/aws-sdk-iot/types.rb', line 1112

class AuthResult < Struct.new(
  :auth_info,
  :allowed,
  :denied,
  :auth_decision,
  :missing_context_values)
  SENSITIVE = []
  include Aws::Structure
end

#deniedTypes::Denied

The policies and statements that denied the specified action.



1112
1113
1114
1115
1116
1117
1118
1119
1120
# File 'lib/aws-sdk-iot/types.rb', line 1112

class AuthResult < Struct.new(
  :auth_info,
  :allowed,
  :denied,
  :auth_decision,
  :missing_context_values)
  SENSITIVE = []
  include Aws::Structure
end

#missing_context_valuesArray<String>

Contains any missing context values found while evaluating policy.



1112
1113
1114
1115
1116
1117
1118
1119
1120
# File 'lib/aws-sdk-iot/types.rb', line 1112

class AuthResult < Struct.new(
  :auth_info,
  :allowed,
  :denied,
  :auth_decision,
  :missing_context_values)
  SENSITIVE = []
  include Aws::Structure
end