Class: Aws::IoT::Types::AwsJobAbortConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AwsJobAbortConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass AwsJobAbortConfig data as a hash:
{
abort_criteria_list: [ # required
{
failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
action: "CANCEL", # required, accepts CANCEL
threshold_percentage: 1.0, # required
min_number_of_executed_things: 1, # required
},
],
}
The criteria that determine when and how a job abort takes place.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_criteria_list ⇒ Array<Types::AwsJobAbortCriteria>
The list of criteria that determine when and how to abort the job.
Instance Attribute Details
#abort_criteria_list ⇒ Array<Types::AwsJobAbortCriteria>
The list of criteria that determine when and how to abort the job.
1554 1555 1556 1557 1558 |
# File 'lib/aws-sdk-iot/types.rb', line 1554 class AwsJobAbortConfig < Struct.new( :abort_criteria_list) SENSITIVE = [] include Aws::Structure end |