Class: Aws::IoT::Types::AwsJobAbortCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AwsJobAbortCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The criteria that determine when and how a job abort takes place.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The type of job action to take to initiate the job abort.
-
#failure_type ⇒ String
The type of job execution failures that can initiate a job abort.
-
#min_number_of_executed_things ⇒ Integer
The minimum number of things which must receive job execution notifications before the job can be aborted.
-
#threshold_percentage ⇒ Float
The minimum percentage of job execution failures that must occur to initiate the job abort.
Instance Attribute Details
#action ⇒ String
The type of job action to take to initiate the job abort.
1253 1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/aws-sdk-iot/types.rb', line 1253 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#failure_type ⇒ String
The type of job execution failures that can initiate a job abort.
1253 1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/aws-sdk-iot/types.rb', line 1253 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#min_number_of_executed_things ⇒ Integer
The minimum number of things which must receive job execution notifications before the job can be aborted.
1253 1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/aws-sdk-iot/types.rb', line 1253 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#threshold_percentage ⇒ Float
The minimum percentage of job execution failures that must occur to initiate the job abort.
Amazon Web Services IoT Core supports up to two digits after the decimal (for example, 10.9 and 10.99, but not 10.999).
1253 1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/aws-sdk-iot/types.rb', line 1253 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |