Class: Aws::IoT::Types::BatchConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Configuration settings for batching.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_across_topicsBoolean

Whether to allow batching messages from different MQTT topics into a single HTTP request. By default, only messages from the same topic are batched together. The default value is ‘false`.

<note markdown=“1”> When ‘batchAcrossTopics` is enabled, the error payload format changes: the `topic` field moves from the top level to inside each entry in the `payloadsWithMetadata` array, since each message in the batch may originate from a different topic.

</note>

<note markdown=“1”> Messages are always batched within the scope of the same account, rule name, target HTTP endpoint URL, and billing group. Messages that differ in any of these attributes are never combined into the same batch, regardless of the ‘batchAcrossTopics` setting.

</note>

Returns:

  • (Boolean)


1414
1415
1416
1417
1418
1419
1420
1421
# File 'lib/aws-sdk-iot/types.rb', line 1414

class BatchConfig < Struct.new(
  :max_batch_open_ms,
  :max_batch_size,
  :max_batch_size_bytes,
  :batch_across_topics)
  SENSITIVE = []
  include Aws::Structure
end

#max_batch_open_msInteger

The maximum amount of time (in milliseconds) that an outgoing call waits for other calls with which it batches messages of the same type. The higher the setting, the longer the latency of the batched HTTP Action will be.

Returns:

  • (Integer)


1414
1415
1416
1417
1418
1419
1420
1421
# File 'lib/aws-sdk-iot/types.rb', line 1414

class BatchConfig < Struct.new(
  :max_batch_open_ms,
  :max_batch_size,
  :max_batch_size_bytes,
  :batch_across_topics)
  SENSITIVE = []
  include Aws::Structure
end

#max_batch_sizeInteger

The maximum number of messages that are batched together in a single action execution.

Returns:

  • (Integer)


1414
1415
1416
1417
1418
1419
1420
1421
# File 'lib/aws-sdk-iot/types.rb', line 1414

class BatchConfig < Struct.new(
  :max_batch_open_ms,
  :max_batch_size,
  :max_batch_size_bytes,
  :batch_across_topics)
  SENSITIVE = []
  include Aws::Structure
end

#max_batch_size_bytesInteger

Maximum size of a message batch, in bytes.

Returns:

  • (Integer)


1414
1415
1416
1417
1418
1419
1420
1421
# File 'lib/aws-sdk-iot/types.rb', line 1414

class BatchConfig < Struct.new(
  :max_batch_open_ms,
  :max_batch_size,
  :max_batch_size_bytes,
  :batch_across_topics)
  SENSITIVE = []
  include Aws::Structure
end