Class: Aws::IoT::Types::BehaviorCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::BehaviorCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The criteria by which the behavior is determined to be normal.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The operator that relates the thing measured (
metric) to the criteria (containing avalueorstatisticalThreshold). -
#consecutive_datapoints_to_alarm ⇒ Integer
If a device is in violation of the behavior for the specified number of consecutive datapoints, an alarm occurs.
-
#consecutive_datapoints_to_clear ⇒ Integer
If an alarm has occurred and the offending device is no longer in violation of the behavior for the specified number of consecutive datapoints, the alarm is cleared.
-
#duration_seconds ⇒ Integer
Use this to specify the time duration over which the behavior is evaluated, for those criteria that have a time dimension (for example,
NUM_MESSAGES_SENT). -
#ml_detection_config ⇒ Types::MachineLearningDetectionConfig
The configuration of an ML Detect.
-
#statistical_threshold ⇒ Types::StatisticalThreshold
A statistical ranking (percentile)that indicates a threshold value by which a behavior is determined to be in compliance or in violation of the behavior.
-
#value ⇒ Types::MetricValue
The value to be compared with the
metric.
Instance Attribute Details
#comparison_operator ⇒ String
The operator that relates the thing measured (metric) to the
criteria (containing a value or statisticalThreshold). Valid
operators include:
-
string-list:in-setandnot-in-set -
number-list:in-setandnot-in-set -
ip-address-list:in-cidr-setandnot-in-cidr-set -
number:less-than,less-than-equals,greater-than, andgreater-than-equals
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-iot/types.rb', line 1531 class BehaviorCriteria < Struct.new( :comparison_operator, :value, :duration_seconds, :consecutive_datapoints_to_alarm, :consecutive_datapoints_to_clear, :statistical_threshold, :ml_detection_config) SENSITIVE = [] include Aws::Structure end |
#consecutive_datapoints_to_alarm ⇒ Integer
If a device is in violation of the behavior for the specified number of consecutive datapoints, an alarm occurs. If not specified, the default is 1.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-iot/types.rb', line 1531 class BehaviorCriteria < Struct.new( :comparison_operator, :value, :duration_seconds, :consecutive_datapoints_to_alarm, :consecutive_datapoints_to_clear, :statistical_threshold, :ml_detection_config) SENSITIVE = [] include Aws::Structure end |
#consecutive_datapoints_to_clear ⇒ Integer
If an alarm has occurred and the offending device is no longer in violation of the behavior for the specified number of consecutive datapoints, the alarm is cleared. If not specified, the default is 1.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-iot/types.rb', line 1531 class BehaviorCriteria < Struct.new( :comparison_operator, :value, :duration_seconds, :consecutive_datapoints_to_alarm, :consecutive_datapoints_to_clear, :statistical_threshold, :ml_detection_config) SENSITIVE = [] include Aws::Structure end |
#duration_seconds ⇒ Integer
Use this to specify the time duration over which the behavior is
evaluated, for those criteria that have a time dimension (for
example, NUM_MESSAGES_SENT). For a statisticalThreshhold metric
comparison, measurements from all devices are accumulated over this
time duration before being used to calculate percentiles, and later,
measurements from an individual device are also accumulated over
this time duration before being given a percentile rank. Cannot be
used with list-based metric datatypes.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-iot/types.rb', line 1531 class BehaviorCriteria < Struct.new( :comparison_operator, :value, :duration_seconds, :consecutive_datapoints_to_alarm, :consecutive_datapoints_to_clear, :statistical_threshold, :ml_detection_config) SENSITIVE = [] include Aws::Structure end |
#ml_detection_config ⇒ Types::MachineLearningDetectionConfig
The configuration of an ML Detect
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-iot/types.rb', line 1531 class BehaviorCriteria < Struct.new( :comparison_operator, :value, :duration_seconds, :consecutive_datapoints_to_alarm, :consecutive_datapoints_to_clear, :statistical_threshold, :ml_detection_config) SENSITIVE = [] include Aws::Structure end |
#statistical_threshold ⇒ Types::StatisticalThreshold
A statistical ranking (percentile)that indicates a threshold value by which a behavior is determined to be in compliance or in violation of the behavior.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-iot/types.rb', line 1531 class BehaviorCriteria < Struct.new( :comparison_operator, :value, :duration_seconds, :consecutive_datapoints_to_alarm, :consecutive_datapoints_to_clear, :statistical_threshold, :ml_detection_config) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Types::MetricValue
The value to be compared with the metric.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'lib/aws-sdk-iot/types.rb', line 1531 class BehaviorCriteria < Struct.new( :comparison_operator, :value, :duration_seconds, :consecutive_datapoints_to_alarm, :consecutive_datapoints_to_clear, :statistical_threshold, :ml_detection_config) SENSITIVE = [] include Aws::Structure end |