Class: Aws::IoT::Types::CancelJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CancelJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A short text description of the job.
-
#job_arn ⇒ String
The job ARN.
-
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
Instance Attribute Details
#description ⇒ String
A short text description of the job.
2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-iot/types.rb', line 2280 class CancelJobResponse < Struct.new( :job_arn, :job_id, :description) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The job ARN.
2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-iot/types.rb', line 2280 class CancelJobResponse < Struct.new( :job_arn, :job_id, :description) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-iot/types.rb', line 2280 class CancelJobResponse < Struct.new( :job_arn, :job_id, :description) SENSITIVE = [] include Aws::Structure end |