Class: Aws::IoT::Types::Certificate
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::Certificate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Information about a certificate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The ARN of the certificate.
-
#certificate_id ⇒ String
The ID of the certificate.
-
#certificate_mode ⇒ String
The mode of the certificate.
-
#creation_date ⇒ Time
The date and time the certificate was created.
-
#status ⇒ String
The status of the certificate.
Instance Attribute Details
#certificate_arn ⇒ String
The ARN of the certificate.
1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-iot/types.rb', line 1769 class Certificate < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_mode, :creation_date) SENSITIVE = [] include Aws::Structure end |
#certificate_id ⇒ String
The ID of the certificate. (The last part of the certificate ARN contains the certificate ID.)
1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-iot/types.rb', line 1769 class Certificate < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_mode, :creation_date) SENSITIVE = [] include Aws::Structure end |
#certificate_mode ⇒ String
The mode of the certificate.
‘DEFAULT`: A certificate in `DEFAULT` mode is either generated by Amazon Web Services IoT Core or registered with an issuer certificate authority (CA) in `DEFAULT` mode. Devices with certificates in `DEFAULT` mode aren’t required to send the Server Name Indication (SNI) extension when connecting to Amazon Web Services IoT Core. However, to use features such as custom domains and VPC endpoints, we recommend that you use the SNI extension when connecting to Amazon Web Services IoT Core.
‘SNI_ONLY`: A certificate in `SNI_ONLY` mode is registered without an issuer CA. Devices with certificates in `SNI_ONLY` mode must send the SNI extension when connecting to Amazon Web Services IoT Core.
1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-iot/types.rb', line 1769 class Certificate < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_mode, :creation_date) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time the certificate was created.
1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-iot/types.rb', line 1769 class Certificate < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_mode, :creation_date) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the certificate.
The status value REGISTER_INACTIVE is deprecated and should not be used.
1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-iot/types.rb', line 1769 class Certificate < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_mode, :creation_date) SENSITIVE = [] include Aws::Structure end |