Class: Aws::IoT::Types::CertificateConflictException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Unable to verify the CA certificate used to sign the device certificate you are attempting to register. This is happens when you have registered more than one CA certificate that has the same subject field and public key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The message for the exception.

Returns:

  • (String)


1932
1933
1934
1935
1936
# File 'lib/aws-sdk-iot/types.rb', line 1932

class CertificateConflictException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end