Class: Aws::IoT::Types::CertificateDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CertificateDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes a certificate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ca_certificate_id ⇒ String
The certificate ID of the CA certificate used to sign this certificate.
-
#certificate_arn ⇒ String
The ARN of the certificate.
-
#certificate_id ⇒ String
The ID of the certificate.
-
#certificate_mode ⇒ String
The mode of the certificate.
-
#certificate_pem ⇒ String
The certificate data, in PEM format.
-
#creation_date ⇒ Time
The date and time the certificate was created.
-
#customer_version ⇒ Integer
The customer version of the certificate.
-
#generation_id ⇒ String
The generation ID of the certificate.
-
#last_modified_date ⇒ Time
The date and time the certificate was last modified.
-
#owned_by ⇒ String
The ID of the Amazon Web Services account that owns the certificate.
-
#previous_owned_by ⇒ String
The ID of the Amazon Web Services account of the previous owner of the certificate.
-
#status ⇒ String
The status of the certificate.
-
#transfer_data ⇒ Types::TransferData
The transfer data.
-
#validity ⇒ Types::CertificateValidity
When the certificate is valid.
Instance Attribute Details
#ca_certificate_id ⇒ String
The certificate ID of the CA certificate used to sign this certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The ARN of the certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_id ⇒ String
The ID of the certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_mode ⇒ String
The mode of the certificate.
‘DEFAULT`: A certificate in `DEFAULT` mode is either generated by Amazon Web Services IoT Core or registered with an issuer certificate authority (CA) in `DEFAULT` mode. Devices with certificates in `DEFAULT` mode aren’t required to send the Server Name Indication (SNI) extension when connecting to Amazon Web Services IoT Core. However, to use features such as custom domains and VPC endpoints, we recommend that you use the SNI extension when connecting to Amazon Web Services IoT Core.
‘SNI_ONLY`: A certificate in `SNI_ONLY` mode is registered without an issuer CA. Devices with certificates in `SNI_ONLY` mode must send the SNI extension when connecting to Amazon Web Services IoT Core.
For more information about the value for SNI extension, see [Transport security in IoT].
[1]: docs.aws.amazon.com/iot/latest/developerguide/transport-security.html
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_pem ⇒ String
The certificate data, in PEM format.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time the certificate was created.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#customer_version ⇒ Integer
The customer version of the certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#generation_id ⇒ String
The generation ID of the certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time the certificate was last modified.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#owned_by ⇒ String
The ID of the Amazon Web Services account that owns the certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#previous_owned_by ⇒ String
The ID of the Amazon Web Services account of the previous owner of the certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the certificate.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#transfer_data ⇒ Types::TransferData
The transfer data.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#validity ⇒ Types::CertificateValidity
When the certificate is valid.
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-iot/types.rb', line 2032 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |