Class: Aws::IoT::Types::CloudwatchLogsAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CloudwatchLogsAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass CloudwatchLogsAction data as a hash:
{
role_arn: "AwsArn", # required
log_group_name: "LogGroupName", # required
}
Describes an action that sends data to CloudWatch Logs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_name ⇒ String
The CloudWatch log group to which the action sends data.
-
#role_arn ⇒ String
The IAM role that allows access to the CloudWatch log.
Instance Attribute Details
#log_group_name ⇒ String
The CloudWatch log group to which the action sends data.
2597 2598 2599 2600 2601 2602 |
# File 'lib/aws-sdk-iot/types.rb', line 2597 class CloudwatchLogsAction < Struct.new( :role_arn, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role that allows access to the CloudWatch log.
2597 2598 2599 2600 2601 2602 |
# File 'lib/aws-sdk-iot/types.rb', line 2597 class CloudwatchLogsAction < Struct.new( :role_arn, :log_group_name) SENSITIVE = [] include Aws::Structure end |