Class: Aws::IoT::Types::CommandParameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

A map of key-value pairs that describe the command.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_valueTypes::CommandParameterValue

The default value used to describe the command. This is the value assumed by the parameter if no other value is assigned to it.



2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
# File 'lib/aws-sdk-iot/types.rb', line 2387

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the command parameter.

Returns:

  • (String)


2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
# File 'lib/aws-sdk-iot/types.rb', line 2387

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of a specific parameter used in a command and command execution.

Returns:

  • (String)


2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
# File 'lib/aws-sdk-iot/types.rb', line 2387

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the command parameter.

Returns:

  • (String)


2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
# File 'lib/aws-sdk-iot/types.rb', line 2387

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#valueTypes::CommandParameterValue

Parameter value that overrides the default value, if set.



2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
# File 'lib/aws-sdk-iot/types.rb', line 2387

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#value_conditionsArray<Types::CommandParameterValueCondition>

The list of conditions that a command parameter value must satisfy to create a command execution.



2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
# File 'lib/aws-sdk-iot/types.rb', line 2387

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end