Class: Aws::IoT::Types::CommandParameterValueComparisonOperand
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CommandParameterValueComparisonOperand
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The comparison operand used to compare the defined value against the value supplied in request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#number ⇒ String
An operand of number value type, defined as a string.
-
#number_range ⇒ Types::CommandParameterValueNumberRange
An operand of numerical range value type.
-
#numbers ⇒ Array<String>
A List of operands of numerical value type, defined as strings.
-
#string ⇒ String
An operand of string value type.
-
#strings ⇒ Array<String>
A List of operands of string value type.
Instance Attribute Details
#number ⇒ String
An operand of number value type, defined as a string.
2460 2461 2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-iot/types.rb', line 2460 class CommandParameterValueComparisonOperand < Struct.new( :number, :numbers, :string, :strings, :number_range) SENSITIVE = [] include Aws::Structure end |
#number_range ⇒ Types::CommandParameterValueNumberRange
An operand of numerical range value type.
2460 2461 2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-iot/types.rb', line 2460 class CommandParameterValueComparisonOperand < Struct.new( :number, :numbers, :string, :strings, :number_range) SENSITIVE = [] include Aws::Structure end |
#numbers ⇒ Array<String>
A List of operands of numerical value type, defined as strings.
2460 2461 2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-iot/types.rb', line 2460 class CommandParameterValueComparisonOperand < Struct.new( :number, :numbers, :string, :strings, :number_range) SENSITIVE = [] include Aws::Structure end |
#string ⇒ String
An operand of string value type.
2460 2461 2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-iot/types.rb', line 2460 class CommandParameterValueComparisonOperand < Struct.new( :number, :numbers, :string, :strings, :number_range) SENSITIVE = [] include Aws::Structure end |
#strings ⇒ Array<String>
A List of operands of string value type.
2460 2461 2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/aws-sdk-iot/types.rb', line 2460 class CommandParameterValueComparisonOperand < Struct.new( :number, :numbers, :string, :strings, :number_range) SENSITIVE = [] include Aws::Structure end |