Class: Aws::IoT::Types::CommandParameterValueCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

A condition for the command parameter that must be evaluated to true for successful creation of a command execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#comparison_operatorString

The comparison operator for the command parameter.

IN_RANGE, and NOT_IN_RANGE operators include boundary values.

Returns:

  • (String)


2504
2505
2506
2507
2508
2509
# File 'lib/aws-sdk-iot/types.rb', line 2504

class CommandParameterValueCondition < Struct.new(
  :comparison_operator,
  :operand)
  SENSITIVE = []
  include Aws::Structure
end

#operandTypes::CommandParameterValueComparisonOperand

The comparison operand for the command parameter.



2504
2505
2506
2507
2508
2509
# File 'lib/aws-sdk-iot/types.rb', line 2504

class CommandParameterValueCondition < Struct.new(
  :comparison_operator,
  :operand)
  SENSITIVE = []
  include Aws::Structure
end