Class: Aws::IoT::Types::ConfirmTopicRuleDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ConfirmTopicRuleDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass ConfirmTopicRuleDestinationRequest data as a hash:
{
confirmation_token: "ConfirmationToken", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#confirmation_token ⇒ String
The token used to confirm ownership or access to the topic rule confirmation URL.
Instance Attribute Details
#confirmation_token ⇒ String
The token used to confirm ownership or access to the topic rule confirmation URL.
2762 2763 2764 2765 2766 |
# File 'lib/aws-sdk-iot/types.rb', line 2762 class ConfirmTopicRuleDestinationRequest < Struct.new( :confirmation_token) SENSITIVE = [] include Aws::Structure end |