Class: Aws::IoT::Types::CreateAuditSuppressionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateAuditSuppressionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateAuditSuppressionRequest data as a hash:
{
check_name: "AuditCheckName", # required
resource_identifier: { # required
device_certificate_id: "CertificateId",
ca_certificate_id: "CertificateId",
cognito_identity_pool_id: "CognitoIdentityPoolId",
client_id: "ClientId",
policy_version_identifier: {
policy_name: "PolicyName",
policy_version_id: "PolicyVersionId",
},
account: "AwsAccountId",
iam_role_arn: "RoleArn",
role_alias_arn: "RoleAliasArn",
issuer_certificate_identifier: {
issuer_certificate_subject: "IssuerCertificateSubject",
issuer_id: "IssuerId",
issuer_certificate_serial_number: "IssuerCertificateSerialNumber",
},
device_certificate_arn: "CertificateArn",
},
expiration_date: Time.now,
suppress_indefinitely: false,
description: "AuditDescription",
client_request_token: "ClientRequestToken", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#check_name ⇒ String
An audit check name.
-
#client_request_token ⇒ String
Each audit supression must have a unique client request token.
-
#description ⇒ String
The description of the audit suppression.
-
#expiration_date ⇒ Time
The epoch timestamp in seconds at which this suppression expires.
-
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
-
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
Instance Attribute Details
#check_name ⇒ String
An audit check name. Checks must be enabled for your account. (Use `DescribeAccountAuditConfiguration` to see the list of all checks, including those that are enabled or use `UpdateAccountAuditConfiguration` to select which checks are enabled.)
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-iot/types.rb', line 2889 class CreateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
Each audit supression must have a unique client request token. If you try to create a new audit suppression with the same token as one that already exists, an exception occurs. If you omit this value, Amazon Web Services SDKs will automatically generate a unique client request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-iot/types.rb', line 2889 class CreateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the audit suppression.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-iot/types.rb', line 2889 class CreateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#expiration_date ⇒ Time
The epoch timestamp in seconds at which this suppression expires.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-iot/types.rb', line 2889 class CreateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-iot/types.rb', line 2889 class CreateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-iot/types.rb', line 2889 class CreateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description, :client_request_token) SENSITIVE = [] include Aws::Structure end |