Class: Aws::IoT::Types::CreateBillingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateBillingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass CreateBillingGroupRequest data as a hash:
{
billing_group_name: "BillingGroupName", # required
billing_group_properties: {
billing_group_description: "BillingGroupDescription",
},
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_group_name ⇒ String
The name you wish to give to the billing group.
-
#billing_group_properties ⇒ Types::BillingGroupProperties
The properties of the billing group.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the billing group.
Instance Attribute Details
#billing_group_name ⇒ String
The name you wish to give to the billing group.
3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/aws-sdk-iot/types.rb', line 3018 class CreateBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#billing_group_properties ⇒ Types::BillingGroupProperties
The properties of the billing group.
3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/aws-sdk-iot/types.rb', line 3018 class CreateBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the billing group.
3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/aws-sdk-iot/types.rb', line 3018 class CreateBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_properties, :tags) SENSITIVE = [] include Aws::Structure end |