Class: Aws::IoT::Types::CreateDimensionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateDimensionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateDimensionRequest data as a hash:
{
name: "DimensionName", # required
type: "TOPIC_FILTER", # required, accepts TOPIC_FILTER
string_values: ["DimensionStringValue"], # required
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
client_request_token: "ClientRequestToken", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
Each dimension must have a unique client request token.
-
#name ⇒ String
A unique identifier for the dimension.
-
#string_values ⇒ Array<String>
Specifies the value or list of values for the dimension.
-
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the dimension.
-
#type ⇒ String
Specifies the type of dimension.
Instance Attribute Details
#client_request_token ⇒ String
Each dimension must have a unique client request token. If you try to create a new dimension with the same token as a dimension that already exists, an exception occurs. If you omit this value, Amazon Web Services SDKs will automatically generate a unique client request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3214 3215 3216 3217 3218 3219 3220 3221 3222 |
# File 'lib/aws-sdk-iot/types.rb', line 3214 class CreateDimensionRequest < Struct.new( :name, :type, :string_values, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique identifier for the dimension. Choose something that describes the type and value to make it easy to remember what it does.
3214 3215 3216 3217 3218 3219 3220 3221 3222 |
# File 'lib/aws-sdk-iot/types.rb', line 3214 class CreateDimensionRequest < Struct.new( :name, :type, :string_values, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#string_values ⇒ Array<String>
Specifies the value or list of values for the dimension. For `TOPIC_FILTER` dimensions, this is a pattern used to match the MQTT topic (for example, “admin/#”).
3214 3215 3216 3217 3218 3219 3220 3221 3222 |
# File 'lib/aws-sdk-iot/types.rb', line 3214 class CreateDimensionRequest < Struct.new( :name, :type, :string_values, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the dimension.
3214 3215 3216 3217 3218 3219 3220 3221 3222 |
# File 'lib/aws-sdk-iot/types.rb', line 3214 class CreateDimensionRequest < Struct.new( :name, :type, :string_values, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies the type of dimension. Supported types: `TOPIC_FILTER.`
3214 3215 3216 3217 3218 3219 3220 3221 3222 |
# File 'lib/aws-sdk-iot/types.rb', line 3214 class CreateDimensionRequest < Struct.new( :name, :type, :string_values, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |