Class: Aws::IoT::Types::CreateDynamicThingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateDynamicThingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateDynamicThingGroupRequest data as a hash:
{
thing_group_name: "ThingGroupName", # required
thing_group_properties: {
thing_group_description: "ThingGroupDescription",
attribute_payload: {
attributes: {
"AttributeName" => "AttributeValue",
},
merge: false,
},
},
index_name: "IndexName",
query_string: "QueryString", # required
query_version: "QueryVersion",
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_name ⇒ String
The dynamic thing group index name.
-
#query_string ⇒ String
The dynamic thing group search query string.
-
#query_version ⇒ String
The dynamic thing group query version.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the dynamic thing group.
-
#thing_group_name ⇒ String
The dynamic thing group name to create.
-
#thing_group_properties ⇒ Types::ThingGroupProperties
The dynamic thing group properties.
Instance Attribute Details
#index_name ⇒ String
The dynamic thing group index name.
<note markdown=“1”> Currently one index is supported: `AWS_Things`.
</note>
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-iot/types.rb', line 3402 class CreateDynamicThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :index_name, :query_string, :query_version, :tags) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The dynamic thing group search query string.
See [Query Syntax] for information about query string syntax.
[1]: docs.aws.amazon.com/iot/latest/developerguide/query-syntax.html
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-iot/types.rb', line 3402 class CreateDynamicThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :index_name, :query_string, :query_version, :tags) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The dynamic thing group query version.
<note markdown=“1”> Currently one query version is supported: “2017-09-30”. If not specified, the query version defaults to this value.
</note>
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-iot/types.rb', line 3402 class CreateDynamicThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :index_name, :query_string, :query_version, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the dynamic thing group.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-iot/types.rb', line 3402 class CreateDynamicThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :index_name, :query_string, :query_version, :tags) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
The dynamic thing group name to create.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-iot/types.rb', line 3402 class CreateDynamicThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :index_name, :query_string, :query_version, :tags) SENSITIVE = [] include Aws::Structure end |
#thing_group_properties ⇒ Types::ThingGroupProperties
The dynamic thing group properties.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-iot/types.rb', line 3402 class CreateDynamicThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :index_name, :query_string, :query_version, :tags) SENSITIVE = [] include Aws::Structure end |