Class: Aws::IoT::Types::CreateFleetMetricRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_fieldString

The field to aggregate.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#aggregation_typeTypes::AggregationType

The type of the aggregation query.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The fleet metric description.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index to search.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the fleet metric to create.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#periodInteger

The time in seconds between fleet metric emissions. Range [60(1 min), 86400(1 day)] and must be multiple of 60.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The search query string.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_versionString

The query version.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata, which can be used to manage the fleet metric.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

Used to support unit transformation such as milliseconds to seconds. The unit must be supported by CW metric. Default to null.



3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
# File 'lib/aws-sdk-iot/types.rb', line 3486

class CreateFleetMetricRequest < Struct.new(
  :metric_name,
  :query_string,
  :aggregation_type,
  :period,
  :aggregation_field,
  :description,
  :query_version,
  :index_name,
  :unit,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end