Class: Aws::IoT::Types::CreateMitigationActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateMitigationActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass CreateMitigationActionRequest data as a hash:
{
action_name: "MitigationActionName", # required
role_arn: "RoleArn", # required
action_params: { # required
update_device_certificate_params: {
action: "DEACTIVATE", # required, accepts DEACTIVATE
},
update_ca_certificate_params: {
action: "DEACTIVATE", # required, accepts DEACTIVATE
},
add_things_to_thing_group_params: {
thing_group_names: ["ThingGroupName"], # required
override_dynamic_groups: false,
},
replace_default_policy_version_params: {
template_name: "BLANK_POLICY", # required, accepts BLANK_POLICY
},
enable_io_t_logging_params: {
role_arn_for_logging: "RoleArn", # required
log_level: "DEBUG", # required, accepts DEBUG, INFO, ERROR, WARN, DISABLED
},
publish_finding_to_sns_params: {
topic_arn: "SnsTopicArn", # required
},
},
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_name ⇒ String
A friendly name for the action.
-
#action_params ⇒ Types::MitigationActionParams
Defines the type of action and the parameters for that action.
-
#role_arn ⇒ String
The ARN of the IAM role that is used to apply the mitigation action.
-
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the mitigation action.
Instance Attribute Details
#action_name ⇒ String
A friendly name for the action. Choose a friendly name that accurately describes the action (for example, `EnableLoggingAction`).
3994 3995 3996 3997 3998 3999 4000 4001 |
# File 'lib/aws-sdk-iot/types.rb', line 3994 class CreateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params, :tags) SENSITIVE = [] include Aws::Structure end |
#action_params ⇒ Types::MitigationActionParams
Defines the type of action and the parameters for that action.
3994 3995 3996 3997 3998 3999 4000 4001 |
# File 'lib/aws-sdk-iot/types.rb', line 3994 class CreateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that is used to apply the mitigation action.
3994 3995 3996 3997 3998 3999 4000 4001 |
# File 'lib/aws-sdk-iot/types.rb', line 3994 class CreateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the mitigation action.
3994 3995 3996 3997 3998 3999 4000 4001 |
# File 'lib/aws-sdk-iot/types.rb', line 3994 class CreateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params, :tags) SENSITIVE = [] include Aws::Structure end |