Class: Aws::IoT::Types::CreateOTAUpdateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_parametersHash<String,String>

A list of additional OTA update parameters, which are name-value pairs. They won’t be sent to devices as a part of the Job document.

Returns:

  • (Hash<String,String>)


3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#aws_job_abort_configTypes::AwsJobAbortConfig

The criteria that determine when and how a job abort takes place.



3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#aws_job_executions_rollout_configTypes::AwsJobExecutionsRolloutConfig

Configuration for the rollout of OTA updates.



3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#aws_job_presigned_url_configTypes::AwsJobPresignedUrlConfig

Configuration information for pre-signed URLs.



3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#aws_job_timeout_configTypes::AwsJobTimeoutConfig

Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to ‘IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.



3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the OTA update.

Returns:

  • (String)


3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#filesArray<Types::OTAUpdateFile>

The files to be streamed by the OTA update.

Returns:



3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ota_update_idString

The ID of the OTA update to be created.

Returns:

  • (String)


3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#protocolsArray<String>

The protocol used to transfer the OTA update image. Valid values are [HTTP], [MQTT], [HTTP, MQTT]. When both HTTP and MQTT are specified, the target device can choose the protocol.

Returns:

  • (Array<String>)


3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The IAM role that grants Amazon Web Services IoT Core access to the Amazon S3, IoT jobs and Amazon Web Services Code Signing resources to create an OTA update job.

Returns:

  • (String)


3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata which can be used to manage updates.

Returns:



3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_selectionString

Specifies whether the update will continue to run (CONTINUOUS), or will be complete after all the things specified as targets have completed the update (SNAPSHOT). If continuous, the update may also be run on a thing when a change is detected in a target. For example, an update will run on a thing when the thing is added to a target group, even after the update was completed by all things originally in the group. Valid values: CONTINUOUS | SNAPSHOT.

Returns:

  • (String)


3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<String>

The devices targeted to receive OTA updates.

Returns:

  • (Array<String>)


3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-iot/types.rb', line 3231

class CreateOTAUpdateRequest < Struct.new(
  :ota_update_id,
  :description,
  :targets,
  :protocols,
  :target_selection,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :aws_job_abort_config,
  :aws_job_timeout_config,
  :files,
  :role_arn,
  :additional_parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end