Class: Aws::IoT::Types::CreatePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreatePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass CreatePolicyRequest data as a hash:
{
policy_name: "PolicyName", # required
policy_document: "PolicyDocument", # required
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
The input for the CreatePolicy operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_document ⇒ String
The JSON document that describes the policy.
-
#policy_name ⇒ String
The policy name.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the policy.
Instance Attribute Details
#policy_document ⇒ String
The JSON document that describes the policy. *policyDocument* must have a minimum length of 1, with a maximum length of 2048, excluding whitespace.
4212 4213 4214 4215 4216 4217 4218 |
# File 'lib/aws-sdk-iot/types.rb', line 4212 class CreatePolicyRequest < Struct.new( :policy_name, :policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The policy name.
4212 4213 4214 4215 4216 4217 4218 |
# File 'lib/aws-sdk-iot/types.rb', line 4212 class CreatePolicyRequest < Struct.new( :policy_name, :policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the policy.
<note markdown=“1”> For URI Request parameters use format: …key1=value1&key2=value2…
For the CLI command-line parameter use format: &&tags
“key1=value1&key2=value2…”
For the cli-input-json file use format: "tags":
“key1=value1&key2=value2…”
</note>
4212 4213 4214 4215 4216 4217 4218 |
# File 'lib/aws-sdk-iot/types.rb', line 4212 class CreatePolicyRequest < Struct.new( :policy_name, :policy_document, :tags) SENSITIVE = [] include Aws::Structure end |