Class: Aws::IoT::Types::CreateProvisioningTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateProvisioningTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateProvisioningTemplateRequest data as a hash:
{
template_name: "TemplateName", # required
description: "TemplateDescription",
template_body: "TemplateBody", # required
enabled: false,
provisioning_role_arn: "RoleArn", # required
pre_provisioning_hook: {
payload_version: "PayloadVersion",
target_arn: "TargetArn", # required
},
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
type: "FLEET_PROVISIONING", # accepts FLEET_PROVISIONING, JITP
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the provisioning template.
-
#enabled ⇒ Boolean
True to enable the provisioning template, otherwise false.
-
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Creates a pre-provisioning hook template.
-
#provisioning_role_arn ⇒ String
The role ARN for the role associated with the provisioning template.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the provisioning template.
-
#template_body ⇒ String
The JSON formatted contents of the provisioning template.
-
#template_name ⇒ String
The name of the provisioning template.
-
#type ⇒ String
The type you define in a provisioning template.
Instance Attribute Details
#description ⇒ String
The description of the provisioning template.
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
True to enable the provisioning template, otherwise false.
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Creates a pre-provisioning hook template. Only supports template of type `FLEET_PROVISIONING`. For more information about provisioning template types, see [type].
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#provisioning_role_arn ⇒ String
The role ARN for the role associated with the provisioning template. This IoT role grants permission to provision a device.
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the provisioning template.
<note markdown=“1”> For URI Request parameters use format: …key1=value1&key2=value2…
For the CLI command-line parameter use format: &&tags
“key1=value1&key2=value2…”
For the cli-input-json file use format: "tags":
“key1=value1&key2=value2…”
</note>
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#template_body ⇒ String
The JSON formatted contents of the provisioning template.
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the provisioning template.
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type you define in a provisioning template. You can create a template with only one type. You can't change the template type after its creation. The default value is `FLEET_PROVISIONING`. For more information about provisioning template, see: [Provisioning template].
[1]: docs.aws.amazon.com/iot/latest/developerguide/provision-template.html
4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 |
# File 'lib/aws-sdk-iot/types.rb', line 4538 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags, :type) SENSITIVE = [] include Aws::Structure end |