Class: Aws::IoT::Types::CreateProvisioningTemplateVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateProvisioningTemplateVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_default_version ⇒ Boolean
True if the provisioning template version is the default version, otherwise false.
-
#template_arn ⇒ String
The ARN that identifies the provisioning template.
-
#template_name ⇒ String
The name of the provisioning template.
-
#version_id ⇒ Integer
The version of the provisioning template.
Instance Attribute Details
#is_default_version ⇒ Boolean
True if the provisioning template version is the default version, otherwise false.
4441 4442 4443 4444 4445 4446 4447 4448 |
# File 'lib/aws-sdk-iot/types.rb', line 4441 class CreateProvisioningTemplateVersionResponse < Struct.new( :template_arn, :template_name, :version_id, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#template_arn ⇒ String
The ARN that identifies the provisioning template.
4441 4442 4443 4444 4445 4446 4447 4448 |
# File 'lib/aws-sdk-iot/types.rb', line 4441 class CreateProvisioningTemplateVersionResponse < Struct.new( :template_arn, :template_name, :version_id, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the provisioning template.
4441 4442 4443 4444 4445 4446 4447 4448 |
# File 'lib/aws-sdk-iot/types.rb', line 4441 class CreateProvisioningTemplateVersionResponse < Struct.new( :template_arn, :template_name, :version_id, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ Integer
The version of the provisioning template.
4441 4442 4443 4444 4445 4446 4447 4448 |
# File 'lib/aws-sdk-iot/types.rb', line 4441 class CreateProvisioningTemplateVersionResponse < Struct.new( :template_arn, :template_name, :version_id, :is_default_version) SENSITIVE = [] include Aws::Structure end |