Class: Aws::IoT::Types::CreateRoleAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateRoleAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credential_duration_seconds ⇒ Integer
How long (in seconds) the credentials will be valid.
-
#role_alias ⇒ String
The role alias that points to a role ARN.
-
#role_arn ⇒ String
The role ARN.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the role alias.
Instance Attribute Details
#credential_duration_seconds ⇒ Integer
How long (in seconds) the credentials will be valid. The default value is 3,600 seconds.
This value must be less than or equal to the maximum session duration of the IAM role that the role alias references.
3649 3650 3651 3652 3653 3654 3655 3656 |
# File 'lib/aws-sdk-iot/types.rb', line 3649 class CreateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds, :tags) SENSITIVE = [] include Aws::Structure end |
#role_alias ⇒ String
The role alias that points to a role ARN. This allows you to change the role without having to update the device.
3649 3650 3651 3652 3653 3654 3655 3656 |
# File 'lib/aws-sdk-iot/types.rb', line 3649 class CreateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role ARN.
3649 3650 3651 3652 3653 3654 3655 3656 |
# File 'lib/aws-sdk-iot/types.rb', line 3649 class CreateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the role alias.
<note markdown=“1”> For URI Request parameters use format: …key1=value1&key2=value2…
For the CLI command-line parameter use format: &&tags
“key1=value1&key2=value2…”
For the cli-input-json file use format: "tags":
“key1=value1&key2=value2…”
</note>
3649 3650 3651 3652 3653 3654 3655 3656 |
# File 'lib/aws-sdk-iot/types.rb', line 3649 class CreateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds, :tags) SENSITIVE = [] include Aws::Structure end |