Class: Aws::IoT::Types::CreateSecurityProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateSecurityProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_metrics_to_retain ⇒ Array<String>
Please use CreateSecurityProfileRequest$additionalMetricsToRetainV2 instead..
-
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored).
-
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Specifies the destinations to which alerts are sent.
-
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
-
#metrics_export_config ⇒ Types::MetricsExportConfig
Specifies the MQTT topic and role ARN required for metric export.
-
#security_profile_description ⇒ String
A description of the security profile.
-
#security_profile_name ⇒ String
The name you are giving to the security profile.
-
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the security profile.
Instance Attribute Details
#additional_metrics_to_retain ⇒ Array<String>
Please use CreateSecurityProfileRequest$additionalMetricsToRetainV2 instead.
A list of metrics whose data is retained (stored). By default, data
is retained for any metric used in the profile's behaviors, but
it is also retained for any metric specified here. Can be used with
custom metrics; cannot be used with dimensions.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored). By default, data
is retained for any metric used in the profile's behaviors, but
it is also retained for any metric specified here. Can be used with
custom metrics; cannot be used with dimensions.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Specifies the destinations to which alerts are sent. (Alerts are always sent to the console.) Alerts are generated when a device (thing) violates a behavior.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#metrics_export_config ⇒ Types::MetricsExportConfig
Specifies the MQTT topic and role ARN required for metric export.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_description ⇒ String
A description of the security profile.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_name ⇒ String
The name you are giving to the security profile.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the security profile.
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-iot/types.rb', line 4614 class CreateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :tags, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |