Class: Aws::IoT::Types::CreateThingTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass CreateThingTypeRequest data as a hash:

{
  thing_type_name: "ThingTypeName", # required
  thing_type_properties: {
    thing_type_description: "ThingTypeDescription",
    searchable_attributes: ["AttributeName"],
  },
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
}

The input for the CreateThingType operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tagsArray<Types::Tag>

Metadata which can be used to manage the thing type.

Returns:



5154
5155
5156
5157
5158
5159
5160
# File 'lib/aws-sdk-iot/types.rb', line 5154

class CreateThingTypeRequest < Struct.new(
  :thing_type_name,
  :thing_type_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#thing_type_nameString

The name of the thing type.

Returns:

  • (String)


5154
5155
5156
5157
5158
5159
5160
# File 'lib/aws-sdk-iot/types.rb', line 5154

class CreateThingTypeRequest < Struct.new(
  :thing_type_name,
  :thing_type_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#thing_type_propertiesTypes::ThingTypeProperties

The ThingTypeProperties for the thing type to create. It contains information about the new thing type including a description, and a list of searchable thing attribute names.



5154
5155
5156
5157
5158
5159
5160
# File 'lib/aws-sdk-iot/types.rb', line 5154

class CreateThingTypeRequest < Struct.new(
  :thing_type_name,
  :thing_type_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end