Class: Aws::IoT::Types::DeleteCertificateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass DeleteCertificateRequest data as a hash:

{
  certificate_id: "CertificateId", # required
  force_delete: false,
}

The input for the DeleteCertificate operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_idString

The ID of the certificate. (The last part of the certificate ARN contains the certificate ID.)

Returns:

  • (String)


5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-iot/types.rb', line 5697

class DeleteCertificateRequest < Struct.new(
  :certificate_id,
  :force_delete)
  SENSITIVE = []
  include Aws::Structure
end

#force_deleteBoolean

Forces the deletion of a certificate if it is inactive and is not attached to an IoT thing.

Returns:

  • (Boolean)


5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-iot/types.rb', line 5697

class DeleteCertificateRequest < Struct.new(
  :certificate_id,
  :force_delete)
  SENSITIVE = []
  include Aws::Structure
end