Class: Aws::IoT::Types::DeleteDimensionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteDimensionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteDimensionRequest data as a hash:
{
name: "DimensionName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The unique identifier for the dimension that you want to delete.
Instance Attribute Details
#name ⇒ String
The unique identifier for the dimension that you want to delete.
5737 5738 5739 5740 5741 |
# File 'lib/aws-sdk-iot/types.rb', line 5737 class DeleteDimensionRequest < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |