Class: Aws::IoT::Types::DeleteDynamicThingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_versionInteger

The expected version of the dynamic thing group to delete.

Returns:

  • (Integer)


4066
4067
4068
4069
4070
4071
# File 'lib/aws-sdk-iot/types.rb', line 4066

class DeleteDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#thing_group_nameString

The name of the dynamic thing group to delete.

Returns:

  • (String)


4066
4067
4068
4069
4070
4071
# File 'lib/aws-sdk-iot/types.rb', line 4066

class DeleteDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end