Class: Aws::IoT::Types::DeleteFleetMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteFleetMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_version ⇒ Integer
The expected version of the fleet metric to delete.
-
#metric_name ⇒ String
The name of the fleet metric to delete.
Instance Attribute Details
#expected_version ⇒ Integer
The expected version of the fleet metric to delete.
4090 4091 4092 4093 4094 4095 |
# File 'lib/aws-sdk-iot/types.rb', line 4090 class DeleteFleetMetricRequest < Struct.new( :metric_name, :expected_version) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the fleet metric to delete.
4090 4091 4092 4093 4094 4095 |
# File 'lib/aws-sdk-iot/types.rb', line 4090 class DeleteFleetMetricRequest < Struct.new( :metric_name, :expected_version) SENSITIVE = [] include Aws::Structure end |