Class: Aws::IoT::Types::DeleteJobExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteJobExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_number ⇒ Integer
The ID of the job execution to be deleted.
-
#force ⇒ Boolean
(Optional) When true, you can delete a job execution which is “IN_PROGRESS”.
-
#job_id ⇒ String
The ID of the job whose execution on a particular device will be deleted.
-
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
-
#thing_name ⇒ String
The name of the thing whose job execution will be deleted.
Instance Attribute Details
#execution_number ⇒ Integer
The ID of the job execution to be deleted. The executionNumber refers to the execution of a particular job on a particular device.
Note that once a job execution is deleted, the executionNumber may be reused by IoT, so be sure you get and use the correct value here.
5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-iot/types.rb', line 5193 class DeleteJobExecutionRequest < Struct.new( :job_id, :thing_name, :execution_number, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
(Optional) When true, you can delete a job execution which is “IN_PROGRESS”. Otherwise, you can only delete a job execution which is in a terminal state (“SUCCEEDED”, “FAILED”, “REJECTED”, “REMOVED” or “CANCELED”) or an exception will occur. The default is false.
<note markdown=“1”> Deleting a job execution which is “IN_PROGRESS”, will cause the device to be unable to access job information or update the job execution status. Use caution and ensure that the device is able to recover to a valid state.
</note>
5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-iot/types.rb', line 5193 class DeleteJobExecutionRequest < Struct.new( :job_id, :thing_name, :execution_number, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The ID of the job whose execution on a particular device will be deleted.
5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-iot/types.rb', line 5193 class DeleteJobExecutionRequest < Struct.new( :job_id, :thing_name, :execution_number, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.
‘$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`
<note markdown=“1”> The namespaceId feature is only supported by IoT Greengrass at this time. For more information, see [Setting up IoT Greengrass core devices.]
</note>
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/setting-up.html
5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-iot/types.rb', line 5193 class DeleteJobExecutionRequest < Struct.new( :job_id, :thing_name, :execution_number, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing whose job execution will be deleted.
5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-iot/types.rb', line 5193 class DeleteJobExecutionRequest < Struct.new( :job_id, :thing_name, :execution_number, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |