Class: Aws::IoT::Types::DeleteJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass DeleteJobRequest data as a hash:
{
job_id: "JobId", # required
force: false,
namespace_id: "NamespaceId",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(Optional) When true, you can delete a job which is “IN_PROGRESS”.
-
#job_id ⇒ String
The ID of the job to be deleted.
-
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
Instance Attribute Details
#force ⇒ Boolean
(Optional) When true, you can delete a job which is “IN_PROGRESS”. Otherwise, you can only delete a job which is in a terminal state (“COMPLETED” or “CANCELED”) or an exception will occur. The default is false.
<note markdown=“1”> Deleting a job which is “IN_PROGRESS”, will cause a device which is executing the job to be unable to access job information or update the job execution status. Use caution and ensure that each device executing a job which is deleted is able to recover to a valid state.
</note>
6008 6009 6010 6011 6012 6013 6014 |
# File 'lib/aws-sdk-iot/types.rb', line 6008 class DeleteJobRequest < Struct.new( :job_id, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The ID of the job to be deleted.
After a job deletion is completed, you may reuse this jobId when you create a new job. However, this is not recommended, and you must ensure that your devices are not using the jobId to refer to the deleted job.
6008 6009 6010 6011 6012 6013 6014 |
# File 'lib/aws-sdk-iot/types.rb', line 6008 class DeleteJobRequest < Struct.new( :job_id, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.
`$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`
<note markdown=“1”> The `namespaceId` feature is in public preview.
</note>
6008 6009 6010 6011 6012 6013 6014 |
# File 'lib/aws-sdk-iot/types.rb', line 6008 class DeleteJobRequest < Struct.new( :job_id, :force, :namespace_id) SENSITIVE = [] include Aws::Structure end |