Class: Aws::IoT::Types::DeleteJobTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteJobTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteJobTemplateRequest data as a hash:
{
job_template_id: "JobTemplateId", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_template_id ⇒ String
The unique identifier of the job template to delete.
Instance Attribute Details
#job_template_id ⇒ String
The unique identifier of the job template to delete.
6084 6085 6086 6087 6088 |
# File 'lib/aws-sdk-iot/types.rb', line 6084 class DeleteJobTemplateRequest < Struct.new( :job_template_id) SENSITIVE = [] include Aws::Structure end |