Class: Aws::IoT::Types::DeleteMitigationActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteMitigationActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteMitigationActionRequest data as a hash:
{
action_name: "MitigationActionName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_name ⇒ String
The name of the mitigation action that you want to delete.
Instance Attribute Details
#action_name ⇒ String
The name of the mitigation action that you want to delete.
5985 5986 5987 5988 5989 |
# File 'lib/aws-sdk-iot/types.rb', line 5985 class DeleteMitigationActionRequest < Struct.new( :action_name) SENSITIVE = [] include Aws::Structure end |