Class: Aws::IoT::Types::DeleteProvisioningTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteProvisioningTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteProvisioningTemplateRequest data as a hash:
{
template_name: "TemplateName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#template_name ⇒ String
The name of the fleet provision template to delete.
Instance Attribute Details
#template_name ⇒ String
The name of the fleet provision template to delete.
6061 6062 6063 6064 6065 |
# File 'lib/aws-sdk-iot/types.rb', line 6061 class DeleteProvisioningTemplateRequest < Struct.new( :template_name) SENSITIVE = [] include Aws::Structure end |