Class: Aws::IoT::Types::DeleteScheduledAuditRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteScheduledAuditRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteScheduledAuditRequest data as a hash:
{
scheduled_audit_name: "ScheduledAuditName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scheduled_audit_name ⇒ String
The name of the scheduled audit you want to delete.
Instance Attribute Details
#scheduled_audit_name ⇒ String
The name of the scheduled audit you want to delete.
6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-iot/types.rb', line 6144 class DeleteScheduledAuditRequest < Struct.new( :scheduled_audit_name) SENSITIVE = [] include Aws::Structure end |