Class: Aws::IoT::Types::DeleteThingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteThingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteThingGroupRequest data as a hash:
{
thing_group_name: "ThingGroupName", # required
expected_version: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_version ⇒ Integer
The expected version of the thing group to delete.
-
#thing_group_name ⇒ String
The name of the thing group to delete.
Instance Attribute Details
#expected_version ⇒ Integer
The expected version of the thing group to delete.
6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-iot/types.rb', line 6228 class DeleteThingGroupRequest < Struct.new( :thing_group_name, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
The name of the thing group to delete.
6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-iot/types.rb', line 6228 class DeleteThingGroupRequest < Struct.new( :thing_group_name, :expected_version) SENSITIVE = [] include Aws::Structure end |