Class: Aws::IoT::Types::DeleteThingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The input for the DeleteThing operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_versionInteger

The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the ‘DeleteThing` request is rejected with a `VersionConflictException`.

Returns:

  • (Integer)


4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-iot/types.rb', line 4743

class DeleteThingRequest < Struct.new(
  :thing_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

The name of the thing to delete.

Returns:

  • (String)


4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-iot/types.rb', line 4743

class DeleteThingRequest < Struct.new(
  :thing_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end