Class: Aws::IoT::Types::DeleteV2LoggingLevelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteV2LoggingLevelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_name ⇒ String
The name of the resource for which you are configuring logging.
-
#target_type ⇒ String
The type of resource for which you are configuring logging.
Instance Attribute Details
#target_name ⇒ String
The name of the resource for which you are configuring logging.
4803 4804 4805 4806 4807 4808 |
# File 'lib/aws-sdk-iot/types.rb', line 4803 class DeleteV2LoggingLevelRequest < Struct.new( :target_type, :target_name) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The type of resource for which you are configuring logging. Must be ‘THING_Group`.
4803 4804 4805 4806 4807 4808 |
# File 'lib/aws-sdk-iot/types.rb', line 4803 class DeleteV2LoggingLevelRequest < Struct.new( :target_type, :target_name) SENSITIVE = [] include Aws::Structure end |