Class: Aws::IoT::Types::DescribeDimensionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the dimension.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-iot/types.rb', line 6153

class DescribeDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date the dimension was created.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-iot/types.rb', line 6153

class DescribeDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date the dimension was last modified.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-iot/types.rb', line 6153

class DescribeDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The unique identifier for the dimension.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-iot/types.rb', line 6153

class DescribeDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#string_valuesArray<String>

The value or list of values used to scope the dimension. For example, for topic filters, this is the pattern used to match the MQTT topic name.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-iot/types.rb', line 6153

class DescribeDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the dimension.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-iot/types.rb', line 6153

class DescribeDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end