Class: Aws::IoT::Types::DescribeDomainConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeDomainConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
-
#domain_configuration_arn ⇒ String
The ARN of the domain configuration.
-
#domain_configuration_name ⇒ String
The name of the domain configuration.
-
#domain_configuration_status ⇒ String
A Boolean value that specifies the current state of the domain configuration.
-
#domain_name ⇒ String
The name of the domain.
-
#domain_type ⇒ String
The type of the domain.
-
#last_status_change_date ⇒ Time
The date and time the domain configuration's status was last changed.
-
#server_certificates ⇒ Array<Types::ServerCertificateSummary>
A list containing summary information about the server certificate included in the domain configuration.
-
#service_type ⇒ String
The type of service delivered by the endpoint.
Instance Attribute Details
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_arn ⇒ String
The ARN of the domain configuration.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_name ⇒ String
The name of the domain configuration.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_status ⇒ String
A Boolean value that specifies the current state of the domain configuration.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#domain_type ⇒ String
The type of the domain.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#last_status_change_date ⇒ Time
The date and time the domain configuration's status was last changed.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#server_certificates ⇒ Array<Types::ServerCertificateSummary>
A list containing summary information about the server certificate included in the domain configuration.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |
#service_type ⇒ String
The type of service delivered by the endpoint.
6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iot/types.rb', line 6985 class DescribeDomainConfigurationResponse < Struct.new( :domain_configuration_name, :domain_configuration_arn, :domain_name, :server_certificates, :authorizer_config, :domain_configuration_status, :service_type, :domain_type, :last_status_change_date) SENSITIVE = [] include Aws::Structure end |