Class: Aws::IoT::Types::DescribeEncryptionConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeEncryptionConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_details ⇒ Types::ConfigurationDetails
The encryption configuration details that include the status information of the KMS key and the KMS access role.
-
#encryption_type ⇒ String
The type of the KMS key.
-
#kms_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role assumed by Amazon Web Services IoT Core to call KMS on behalf of the customer.
-
#kms_key_arn ⇒ String
The ARN of the customer managed KMS key.
-
#last_modified_date ⇒ Time
The date when encryption configuration is last updated.
Instance Attribute Details
#configuration_details ⇒ Types::ConfigurationDetails
The encryption configuration details that include the status information of the KMS key and the KMS access role.
6343 6344 6345 6346 6347 6348 6349 6350 6351 |
# File 'lib/aws-sdk-iot/types.rb', line 6343 class DescribeEncryptionConfigurationResponse < Struct.new( :encryption_type, :kms_key_arn, :kms_access_role_arn, :configuration_details, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#encryption_type ⇒ String
The type of the KMS key.
6343 6344 6345 6346 6347 6348 6349 6350 6351 |
# File 'lib/aws-sdk-iot/types.rb', line 6343 class DescribeEncryptionConfigurationResponse < Struct.new( :encryption_type, :kms_key_arn, :kms_access_role_arn, :configuration_details, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#kms_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role assumed by Amazon Web Services IoT Core to call KMS on behalf of the customer.
6343 6344 6345 6346 6347 6348 6349 6350 6351 |
# File 'lib/aws-sdk-iot/types.rb', line 6343 class DescribeEncryptionConfigurationResponse < Struct.new( :encryption_type, :kms_key_arn, :kms_access_role_arn, :configuration_details, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the customer managed KMS key.
6343 6344 6345 6346 6347 6348 6349 6350 6351 |
# File 'lib/aws-sdk-iot/types.rb', line 6343 class DescribeEncryptionConfigurationResponse < Struct.new( :encryption_type, :kms_key_arn, :kms_access_role_arn, :configuration_details, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date when encryption configuration is last updated.
6343 6344 6345 6346 6347 6348 6349 6350 6351 |
# File 'lib/aws-sdk-iot/types.rb', line 6343 class DescribeEncryptionConfigurationResponse < Struct.new( :encryption_type, :kms_key_arn, :kms_access_role_arn, :configuration_details, :last_modified_date) SENSITIVE = [] include Aws::Structure end |