Class: Aws::IoT::Types::DescribeEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The input for the DescribeEndpoint operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint_type ⇒ String
The endpoint type.
Instance Attribute Details
#endpoint_type ⇒ String
The endpoint type. Valid endpoint types include:
iot:Data- Returns a VeriSign signed data endpoint.
^ ^
iot:Data-ATS- Returns an ATS signed data endpoint.
^ ^
iot:CredentialProvider- Returns an IoT credentials provider API endpoint.
^ ^
iot:Jobs- Returns an IoT device management Jobs API endpoint.
^
We strongly recommend that customers use the newer iot:Data-ATS
endpoint type to avoid issues related to the widespread distrust of
Symantec certificate authorities. ATS Signed Certificates are more
secure and are trusted by most popular browsers.
6384 6385 6386 6387 6388 |
# File 'lib/aws-sdk-iot/types.rb', line 6384 class DescribeEndpointRequest < Struct.new( :endpoint_type) SENSITIVE = [] include Aws::Structure end |