Class: Aws::IoT::Types::DescribeJobTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeJobTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
-
#created_at ⇒ Time
The time, in seconds since the epoch, when the job template was created.
-
#description ⇒ String
A description of the job template.
-
#destination_package_versions ⇒ Array<String>
The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.
-
#document ⇒ String
The job document.
-
#document_source ⇒ String
An S3 link to the job document.
-
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
The configuration that determines how many retries are allowed for each failure type for a job.
-
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
-
#job_template_arn ⇒ String
The ARN of the job template.
-
#job_template_id ⇒ String
The unique identifier of the job template.
-
#maintenance_windows ⇒ Array<Types::MaintenanceWindow>
Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.
-
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
-
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
Instance Attribute Details
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time, in seconds since the epoch, when the job template was created.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the job template.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#destination_package_versions ⇒ Array<String>
The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.
**Note:**The following Length Constraints relates to a single ARN. Up to 25 package version ARNs are allowed.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#document ⇒ String
The job document.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#document_source ⇒ String
An S3 link to the job document.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
The configuration that determines how many retries are allowed for each failure type for a job.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_template_arn ⇒ String
The ARN of the job template.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_template_id ⇒ String
The unique identifier of the job template.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#maintenance_windows ⇒ Array<Types::MaintenanceWindow>
Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to ‘IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.
5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 |
# File 'lib/aws-sdk-iot/types.rb', line 5748 class DescribeJobTemplateResponse < Struct.new( :job_template_arn, :job_template_id, :description, :document_source, :document, :created_at, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |