Class: Aws::IoT::Types::DescribeManagedJobTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The unique description of a managed template.

Returns:

  • (String)


7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
# File 'lib/aws-sdk-iot/types.rb', line 7438

class DescribeManagedJobTemplateResponse < Struct.new(
  :template_name,
  :template_arn,
  :description,
  :template_version,
  :environments,
  :document_parameters,
  :document)
  SENSITIVE = []
  include Aws::Structure
end

#documentString

The document schema for a managed job template.

Returns:

  • (String)


7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
# File 'lib/aws-sdk-iot/types.rb', line 7438

class DescribeManagedJobTemplateResponse < Struct.new(
  :template_name,
  :template_arn,
  :description,
  :template_version,
  :environments,
  :document_parameters,
  :document)
  SENSITIVE = []
  include Aws::Structure
end

#document_parametersArray<Types::DocumentParameter>

A map of key-value pairs that you can use as guidance to specify the inputs for creating a job from a managed template.

Returns:



7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
# File 'lib/aws-sdk-iot/types.rb', line 7438

class DescribeManagedJobTemplateResponse < Struct.new(
  :template_name,
  :template_arn,
  :description,
  :template_version,
  :environments,
  :document_parameters,
  :document)
  SENSITIVE = []
  include Aws::Structure
end

#environmentsArray<String>

A list of environments that are supported with the managed job template.

Returns:

  • (Array<String>)


7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
# File 'lib/aws-sdk-iot/types.rb', line 7438

class DescribeManagedJobTemplateResponse < Struct.new(
  :template_name,
  :template_arn,
  :description,
  :template_version,
  :environments,
  :document_parameters,
  :document)
  SENSITIVE = []
  include Aws::Structure
end

#template_arnString

The unique Amazon Resource Name (ARN) of the managed template.

Returns:

  • (String)


7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
# File 'lib/aws-sdk-iot/types.rb', line 7438

class DescribeManagedJobTemplateResponse < Struct.new(
  :template_name,
  :template_arn,
  :description,
  :template_version,
  :environments,
  :document_parameters,
  :document)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The unique name of a managed template, such as `AWS-Reboot`.

Returns:

  • (String)


7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
# File 'lib/aws-sdk-iot/types.rb', line 7438

class DescribeManagedJobTemplateResponse < Struct.new(
  :template_name,
  :template_arn,
  :description,
  :template_version,
  :environments,
  :document_parameters,
  :document)
  SENSITIVE = []
  include Aws::Structure
end

#template_versionString

The version for a managed template.

Returns:

  • (String)


7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
# File 'lib/aws-sdk-iot/types.rb', line 7438

class DescribeManagedJobTemplateResponse < Struct.new(
  :template_name,
  :template_arn,
  :description,
  :template_version,
  :environments,
  :document_parameters,
  :document)
  SENSITIVE = []
  include Aws::Structure
end