Class: Aws::IoT::Types::DescribeProvisioningTemplateVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeProvisioningTemplateVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date when the fleet provisioning template version was created.
-
#is_default_version ⇒ Boolean
True if the fleet provisioning template version is the default version.
-
#template_body ⇒ String
The JSON formatted contents of the fleet provisioning template version.
-
#version_id ⇒ Integer
The fleet provisioning template version ID.
Instance Attribute Details
#creation_date ⇒ Time
The date when the fleet provisioning template version was created.
7619 7620 7621 7622 7623 7624 7625 7626 |
# File 'lib/aws-sdk-iot/types.rb', line 7619 class DescribeProvisioningTemplateVersionResponse < Struct.new( :version_id, :creation_date, :template_body, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#is_default_version ⇒ Boolean
True if the fleet provisioning template version is the default version.
7619 7620 7621 7622 7623 7624 7625 7626 |
# File 'lib/aws-sdk-iot/types.rb', line 7619 class DescribeProvisioningTemplateVersionResponse < Struct.new( :version_id, :creation_date, :template_body, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#template_body ⇒ String
The JSON formatted contents of the fleet provisioning template version.
7619 7620 7621 7622 7623 7624 7625 7626 |
# File 'lib/aws-sdk-iot/types.rb', line 7619 class DescribeProvisioningTemplateVersionResponse < Struct.new( :version_id, :creation_date, :template_body, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ Integer
The fleet provisioning template version ID.
7619 7620 7621 7622 7623 7624 7625 7626 |
# File 'lib/aws-sdk-iot/types.rb', line 7619 class DescribeProvisioningTemplateVersionResponse < Struct.new( :version_id, :creation_date, :template_body, :is_default_version) SENSITIVE = [] include Aws::Structure end |