Class: Aws::IoT::Types::DescribeThingRegistrationTaskResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_dateTime

The task creation date.

Returns:

  • (Time)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#failure_countInteger

The number of things that failed to be provisioned.

Returns:

  • (Integer)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#input_file_bucketString

The S3 bucket that contains the input file.

Returns:

  • (String)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#input_file_keyString

The input file key.

Returns:

  • (String)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date when the task was last modified.

Returns:

  • (Time)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The message.

Returns:

  • (String)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#percentage_progressInteger

The progress of the bulk provisioning task expressed as a percentage.

Returns:

  • (Integer)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The role ARN that grants access to the input file bucket.

Returns:

  • (String)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the bulk thing provisioning task.

Returns:

  • (String)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#success_countInteger

The number of things successfully provisioned.

Returns:

  • (Integer)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The task ID.

Returns:

  • (String)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end

#template_bodyString

The task’s template.

Returns:

  • (String)


5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
# File 'lib/aws-sdk-iot/types.rb', line 5931

class DescribeThingRegistrationTaskResponse < Struct.new(
  :task_id,
  :creation_date,
  :last_modified_date,
  :template_body,
  :input_file_bucket,
  :input_file_key,
  :role_arn,
  :status,
  :message,
  :success_count,
  :failure_count,
  :percentage_progress)
  SENSITIVE = []
  include Aws::Structure
end