Class: Aws::IoT::Types::DetachPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DetachPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_name ⇒ String
The policy to detach.
-
#target ⇒ String
The target from which the policy will be detached.
Instance Attribute Details
#policy_name ⇒ String
The policy to detach.
6315 6316 6317 6318 6319 6320 |
# File 'lib/aws-sdk-iot/types.rb', line 6315 class DetachPolicyRequest < Struct.new( :policy_name, :target) SENSITIVE = [] include Aws::Structure end |
#target ⇒ String
The target from which the policy will be detached.
6315 6316 6317 6318 6319 6320 |
# File 'lib/aws-sdk-iot/types.rb', line 6315 class DetachPolicyRequest < Struct.new( :policy_name, :target) SENSITIVE = [] include Aws::Structure end |