Class: Aws::IoT::Types::DocumentParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DocumentParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
A map of key-value pairs containing the patterns that need to be replaced in a managed template job document schema. You can use the description of each key as a guidance to specify the inputs during runtime when creating a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the map field containing the patterns that need to be replaced in a managed template job document schema.
-
#example ⇒ String
An example illustrating a pattern that need to be replaced in a managed template job document schema.
-
#key ⇒ String
Key of the map field containing the patterns that need to be replaced in a managed template job document schema.
-
#optional ⇒ Boolean
Specifies whether a pattern that needs to be replaced in a managed template job document schema is optional or required.
-
#regex ⇒ String
A regular expression of the patterns that need to be replaced in a managed template job document schema.
Instance Attribute Details
#description ⇒ String
Description of the map field containing the patterns that need to be replaced in a managed template job document schema.
8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-iot/types.rb', line 8465 class DocumentParameter < Struct.new( :key, :description, :regex, :example, :optional) SENSITIVE = [] include Aws::Structure end |
#example ⇒ String
An example illustrating a pattern that need to be replaced in a managed template job document schema.
8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-iot/types.rb', line 8465 class DocumentParameter < Struct.new( :key, :description, :regex, :example, :optional) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
Key of the map field containing the patterns that need to be replaced in a managed template job document schema.
8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-iot/types.rb', line 8465 class DocumentParameter < Struct.new( :key, :description, :regex, :example, :optional) SENSITIVE = [] include Aws::Structure end |
#optional ⇒ Boolean
Specifies whether a pattern that needs to be replaced in a managed template job document schema is optional or required.
8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-iot/types.rb', line 8465 class DocumentParameter < Struct.new( :key, :description, :regex, :example, :optional) SENSITIVE = [] include Aws::Structure end |
#regex ⇒ String
A regular expression of the patterns that need to be replaced in a managed template job document schema.
8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-iot/types.rb', line 8465 class DocumentParameter < Struct.new( :key, :description, :regex, :example, :optional) SENSITIVE = [] include Aws::Structure end |