Class: Aws::IoT::Types::Field
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::Field
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass Field data as a hash:
{
name: "FieldName",
type: "Number", # accepts Number, String, Boolean
}
Describes the name and data type at a field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the field.
-
#type ⇒ String
The data type of the field.