Class: Aws::IoT::Types::GeoLocationTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::GeoLocationTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
A geolocation target that you select to index. Each geolocation target contains a name and order key-value pair that specifies the geolocation target fields.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The
nameof the geolocation target field. -
#order ⇒ String
The
orderof the geolocation target field.
Instance Attribute Details
#name ⇒ String
The name of the geolocation target field. If the target field is part of a named shadow, you must select the named shadow using the namedShadow filter.
8089 8090 8091 8092 8093 8094 |
# File 'lib/aws-sdk-iot/types.rb', line 8089 class GeoLocationTarget < Struct.new( :name, :order) SENSITIVE = [] include Aws::Structure end |
#order ⇒ String
The order of the geolocation target field. This field is optional. The default value is LatLon.
8089 8090 8091 8092 8093 8094 |
# File 'lib/aws-sdk-iot/types.rb', line 8089 class GeoLocationTarget < Struct.new( :name, :order) SENSITIVE = [] include Aws::Structure end |