Class: Aws::IoT::Types::GetBehaviorModelTrainingSummariesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::GetBehaviorModelTrainingSummariesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass GetBehaviorModelTrainingSummariesRequest data as a hash:
{
security_profile_name: "SecurityProfileName",
max_results: 1,
next_token: "NextToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The token for the next set of results.
-
#security_profile_name ⇒ String
The name of the security profile.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return at one time. The default is 25.
9064 9065 9066 9067 9068 9069 9070 |
# File 'lib/aws-sdk-iot/types.rb', line 9064 class GetBehaviorModelTrainingSummariesRequest < Struct.new( :security_profile_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results.
9064 9065 9066 9067 9068 9069 9070 |
# File 'lib/aws-sdk-iot/types.rb', line 9064 class GetBehaviorModelTrainingSummariesRequest < Struct.new( :security_profile_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#security_profile_name ⇒ String
The name of the security profile.
9064 9065 9066 9067 9068 9069 9070 |
# File 'lib/aws-sdk-iot/types.rb', line 9064 class GetBehaviorModelTrainingSummariesRequest < Struct.new( :security_profile_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |