Class: Aws::IoT::Types::GetBucketsAggregationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::GetBucketsAggregationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_field ⇒ String
The aggregation field.
-
#buckets_aggregation_type ⇒ Types::BucketsAggregationType
The basic control of the response shape and the bucket aggregation type to perform.
-
#index_name ⇒ String
The name of the index to search.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The version of the query.
Instance Attribute Details
#aggregation_field ⇒ String
The aggregation field.
6813 6814 6815 6816 6817 6818 6819 6820 6821 |
# File 'lib/aws-sdk-iot/types.rb', line 6813 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#buckets_aggregation_type ⇒ Types::BucketsAggregationType
The basic control of the response shape and the bucket aggregation type to perform.
6813 6814 6815 6816 6817 6818 6819 6820 6821 |
# File 'lib/aws-sdk-iot/types.rb', line 6813 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to search.
6813 6814 6815 6816 6817 6818 6819 6820 6821 |
# File 'lib/aws-sdk-iot/types.rb', line 6813 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string.
6813 6814 6815 6816 6817 6818 6819 6820 6821 |
# File 'lib/aws-sdk-iot/types.rb', line 6813 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The version of the query.
6813 6814 6815 6816 6817 6818 6819 6820 6821 |
# File 'lib/aws-sdk-iot/types.rb', line 6813 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |