Method: Aws::IoT::Types::GetCommandExecutionRequest#include_result

Defined in:
lib/aws-sdk-iot/types.rb

#include_resultBoolean

Can be used to specify whether to include the result of the command execution in the GetCommandExecution API response. Your device can use this field to provide additional information about the command execution. You only need to specify this field when using the AWS-IoT namespace.

Returns:

  • (Boolean)


8239
8240
8241
8242
8243
8244
8245
# File 'lib/aws-sdk-iot/types.rb', line 8239

class GetCommandExecutionRequest < Struct.new(
  :execution_id,
  :target_arn,
  :include_result)
  SENSITIVE = []
  include Aws::Structure
end