Class: Aws::IoT::Types::GetCommandExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#command_arnString

The Amazon Resource Number (ARN) of the command. For example, “arn:aws:iot:<region>:<accountid>:command/<commandId>

Returns:

  • (String)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#completed_atTime

The timestamp, when the command execution was completed.

Returns:

  • (Time)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp, when the command execution was created.

Returns:

  • (Time)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#execution_idString

The unique identifier of the command execution.

Returns:

  • (String)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#execution_timeout_secondsInteger

Specifies the amount of time in seconds that the device can take to finish a command execution. A timer starts when the command execution is created. If the command execution status is not set to another terminal state before the timer expires, it will automatically update to ‘TIMED_OUT`.

Returns:

  • (Integer)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The timestamp, when the command execution was last updated.

Returns:

  • (Time)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Types::CommandParameterValue>

The list of parameters that the ‘StartCommandExecution` API used when performing the command on the device.

Returns:



8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#resultHash<String,Types::CommandExecutionResult>

The result value for the current state of the command execution. The status provides information about the progress of the command execution. The device can use the result field to share additional details about the execution such as a return value of a remote function call.

<note markdown=“1”> If you use the ‘AWS-IoT-FleetWise` namespace, then this field is not applicable in the API response.

</note>

Returns:



8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp, when the command execution was started.

Returns:

  • (Time)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the command execution. After your devices receive the command and start performing the operations specified in the command, it can use the ‘UpdateCommandExecution` MQTT API to update the status information.

Returns:

  • (String)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonTypes::StatusReason

Your devices can use this parameter to provide additional context about the status of a command execution using a reason code and description.

Returns:



8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Number (ARN) of the device on which the command execution is being performed.

Returns:

  • (String)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end

#time_to_liveTime

The time to live (TTL) parameter that indicates the duration for which executions will be retained in your account. The default value is six months.

Returns:

  • (Time)


8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/aws-sdk-iot/types.rb', line 8358

class GetCommandExecutionResponse < Struct.new(
  :execution_id,
  :command_arn,
  :target_arn,
  :status,
  :status_reason,
  :result,
  :parameters,
  :execution_timeout_seconds,
  :created_at,
  :last_updated_at,
  :started_at,
  :completed_at,
  :time_to_live)
  SENSITIVE = []
  include Aws::Structure
end