Class: Aws::IoT::Types::GetCommandResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#command_arnString

The Amazon Resource Number (ARN) of the command. For example, arn:aws:iot:<region>:<accountid>:command/<commandId>

Returns:

  • (String)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#command_idString

The unique identifier of the command.

Returns:

  • (String)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp, when the command was created.

Returns:

  • (Time)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#deprecatedBoolean

Indicates whether the command has been deprecated.

Returns:

  • (Boolean)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A short text description of the command.

Returns:

  • (String)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The user-friendly name in the console for the command.

Returns:

  • (String)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The timestamp, when the command was last updated.

Returns:

  • (Time)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#mandatory_parametersArray<Types::CommandParameter>

A list of parameters for the command created.

Returns:



8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the command.

Returns:

  • (String)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#payloadTypes::CommandPayload

The payload object that you provided for the command.



8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#payload_templateString

The payload template for the dynamic command.

Returns:

  • (String)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#pending_deletionBoolean

Indicates whether the command is being deleted.

Returns:

  • (Boolean)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#preprocessorTypes::CommandPreprocessor

Configuration that determines how payloadTemplate is processed to generate command execution payload.



8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The IAM role that you provided when creating the command with AWS-IoT-FleetWise as the namespace.

Returns:

  • (String)


8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/aws-sdk-iot/types.rb', line 8451

class GetCommandResponse < Struct.new(
  :command_id,
  :command_arn,
  :namespace,
  :display_name,
  :description,
  :mandatory_parameters,
  :payload,
  :payload_template,
  :preprocessor,
  :role_arn,
  :created_at,
  :last_updated_at,
  :deprecated,
  :pending_deletion)
  SENSITIVE = []
  include Aws::Structure
end