Class: Aws::IoT::Types::GetPackageVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[:description, :attributes, :recipe]

Instance Attribute Summary collapse

Instance Attribute Details

#artifactTypes::PackageVersionArtifact

The various components that make up a software package version.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#attributesHash<String,String>

Metadata that were added to the package version that can be used to define a package version’s configuration.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#creation_dateTime

The date when the package version was created.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#descriptionString

The package version description.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#error_reasonString

Error reason for a package version failure during creation or update.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#last_modified_dateTime

The date when the package version was last updated.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#package_nameString

The name of the software package.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#package_version_arnString

The ARN for the package version.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#recipeString

The inline job document associated with a software package version used for a quick job deployment.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#sbomTypes::Sbom

The software bill of materials for a software package version.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#sbom_validation_statusString

The status of the validation for a new software bill of materials added to a software package version.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#statusString

The status associated to the package version. For more information, see Package version lifecycle.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end

#version_nameString

The name of the package version.



8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
# File 'lib/aws-sdk-iot/types.rb', line 8727

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :artifact,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date,
  :sbom,
  :sbom_validation_status,
  :recipe)
  SENSITIVE = [:description, :attributes, :recipe]
  include Aws::Structure
end