Class: Aws::IoT::Types::GetStatisticsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass GetStatisticsRequest data as a hash:

{
  index_name: "IndexName",
  query_string: "QueryString", # required
  aggregation_field: "AggregationField",
  query_version: "QueryVersion",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_fieldString

The aggregation field name.

Returns:

  • (String)


9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-iot/types.rb', line 9657

class GetStatisticsRequest < Struct.new(
  :index_name,
  :query_string,
  :aggregation_field,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index to search. The default value is `AWS_Things`.

Returns:

  • (String)


9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-iot/types.rb', line 9657

class GetStatisticsRequest < Struct.new(
  :index_name,
  :query_string,
  :aggregation_field,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The query used to search. You can specify “*” for the query string to get the count of all indexed things in your Amazon Web Services account.

Returns:

  • (String)


9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-iot/types.rb', line 9657

class GetStatisticsRequest < Struct.new(
  :index_name,
  :query_string,
  :aggregation_field,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#query_versionString

The version of the query used to search.

Returns:

  • (String)


9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-iot/types.rb', line 9657

class GetStatisticsRequest < Struct.new(
  :index_name,
  :query_string,
  :aggregation_field,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end