Class: Aws::IoT::Types::HttpAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Send data to an HTTPS endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authTypes::HttpAuthorization

The authentication method to use when sending data to an HTTPS endpoint.



9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
# File 'lib/aws-sdk-iot/types.rb', line 9104

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth,
  :enable_batching,
  :batch_config)
  SENSITIVE = []
  include Aws::Structure
end

#batch_configTypes::BatchConfig

The configuration settings for batching. For more information, see [ Batching HTTP action messages].

[1]: docs.aws.amazon.com/iot/latest/developerguide/http_batching.html

Returns:



9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
# File 'lib/aws-sdk-iot/types.rb', line 9104

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth,
  :enable_batching,
  :batch_config)
  SENSITIVE = []
  include Aws::Structure
end

#confirmation_urlString

The URL to which IoT sends a confirmation message. The value of the confirmation URL must be a prefix of the endpoint URL. If you do not specify a confirmation URL IoT uses the endpoint URL as the confirmation URL. If you use substitution templates in the confirmationUrl, you must create and enable topic rule destinations that match each possible value of the substitution template before traffic is allowed to your endpoint URL.

Returns:

  • (String)


9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
# File 'lib/aws-sdk-iot/types.rb', line 9104

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth,
  :enable_batching,
  :batch_config)
  SENSITIVE = []
  include Aws::Structure
end

#enable_batchingBoolean

Whether to process the HTTP action messages into a single request. Value can be true or false.

Returns:

  • (Boolean)


9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
# File 'lib/aws-sdk-iot/types.rb', line 9104

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth,
  :enable_batching,
  :batch_config)
  SENSITIVE = []
  include Aws::Structure
end

#headersArray<Types::HttpActionHeader>

The HTTP headers to send with the message data.

Returns:



9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
# File 'lib/aws-sdk-iot/types.rb', line 9104

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth,
  :enable_batching,
  :batch_config)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The endpoint URL. If substitution templates are used in the URL, you must also specify a ‘confirmationUrl`. If this is a new destination, a new `TopicRuleDestination` is created if possible.

Returns:

  • (String)


9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
# File 'lib/aws-sdk-iot/types.rb', line 9104

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth,
  :enable_batching,
  :batch_config)
  SENSITIVE = []
  include Aws::Structure
end