Class: Aws::IoT::Types::HttpContext

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass HttpContext data as a hash:

{
  headers: {
    "HttpHeaderName" => "HttpHeaderValue",
  },
  query_string: "HttpQueryString",
}

Specifies the HTTP context to use for the test authorizer request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#headersHash<String,String>

The header keys and values in an HTTP authorization request.

Returns:

  • (Hash<String,String>)


9911
9912
9913
9914
9915
9916
# File 'lib/aws-sdk-iot/types.rb', line 9911

class HttpContext < Struct.new(
  :headers,
  :query_string)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The query string keys and values in an HTTP authorization request.

Returns:

  • (String)


9911
9912
9913
9914
9915
9916
# File 'lib/aws-sdk-iot/types.rb', line 9911

class HttpContext < Struct.new(
  :headers,
  :query_string)
  SENSITIVE = []
  include Aws::Structure
end