Class: Aws::IoT::Types::HttpUrlDestinationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::HttpUrlDestinationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass HttpUrlDestinationConfiguration data as a hash:
{
confirmation_url: "Url", # required
}
HTTP URL destination configuration used by the topic rule's HTTP action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#confirmation_url ⇒ String
The URL IoT uses to confirm ownership of or access to the topic rule destination URL.
Instance Attribute Details
#confirmation_url ⇒ String
The URL IoT uses to confirm ownership of or access to the topic rule destination URL.
9984 9985 9986 9987 9988 |
# File 'lib/aws-sdk-iot/types.rb', line 9984 class HttpUrlDestinationConfiguration < Struct.new( :confirmation_url) SENSITIVE = [] include Aws::Structure end |