Class: Aws::IoT::Types::InfluxDBDestinationProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::InfluxDBDestinationProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The properties of an existing InfluxDB topic rule destination, as
returned by CreateTopicRuleDestination and
GetTopicRuleDestination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint ⇒ String
The URL of the InfluxDB instance that the destination writes to.
-
#influx_db_version ⇒ String
The major version of the InfluxDB instance.
-
#secret_id ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret that contains the InfluxDB API token.
-
#secret_key ⇒ String
The key that is read from the secret value when the secret contains a JSON object.
-
#secret_type ⇒ String
The type of the secret that contains the InfluxDB API token.
Instance Attribute Details
#endpoint ⇒ String
The URL of the InfluxDB instance that the destination writes to.
9573 9574 9575 9576 9577 9578 9579 9580 9581 |
# File 'lib/aws-sdk-iot/types.rb', line 9573 class InfluxDBDestinationProperties < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#influx_db_version ⇒ String
The major version of the InfluxDB instance. Valid values are V2
and V3.
9573 9574 9575 9576 9577 9578 9579 9580 9581 |
# File 'lib/aws-sdk-iot/types.rb', line 9573 class InfluxDBDestinationProperties < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#secret_id ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret that contains the InfluxDB API token.
9573 9574 9575 9576 9577 9578 9579 9580 9581 |
# File 'lib/aws-sdk-iot/types.rb', line 9573 class InfluxDBDestinationProperties < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#secret_key ⇒ String
The key that is read from the secret value when the secret contains a JSON object.
9573 9574 9575 9576 9577 9578 9579 9580 9581 |
# File 'lib/aws-sdk-iot/types.rb', line 9573 class InfluxDBDestinationProperties < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#secret_type ⇒ String
The type of the secret that contains the InfluxDB API token. Valid
values are SecretString and SecretBinary.
9573 9574 9575 9576 9577 9578 9579 9580 9581 |
# File 'lib/aws-sdk-iot/types.rb', line 9573 class InfluxDBDestinationProperties < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |