Class: Aws::IoT::Types::InfluxDBDestinationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

A summary of an InfluxDB topic rule destination, as returned by ListTopicRuleDestinations. For the full set of destination properties, see InfluxDBDestinationProperties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endpointString

The URL of the InfluxDB instance that the destination writes to.

Returns:

  • (String)


9611
9612
9613
9614
9615
9616
9617
9618
9619
# File 'lib/aws-sdk-iot/types.rb', line 9611

class InfluxDBDestinationSummary < Struct.new(
  :endpoint,
  :influx_db_version,
  :secret_id,
  :secret_type,
  :secret_key)
  SENSITIVE = []
  include Aws::Structure
end

#influx_db_versionString

The major version of the InfluxDB instance. Valid values are V2 and V3.

Returns:

  • (String)


9611
9612
9613
9614
9615
9616
9617
9618
9619
# File 'lib/aws-sdk-iot/types.rb', line 9611

class InfluxDBDestinationSummary < Struct.new(
  :endpoint,
  :influx_db_version,
  :secret_id,
  :secret_type,
  :secret_key)
  SENSITIVE = []
  include Aws::Structure
end

#secret_idString

The ARN or name of the Amazon Web Services Secrets Manager secret that contains the InfluxDB API token.

Returns:

  • (String)


9611
9612
9613
9614
9615
9616
9617
9618
9619
# File 'lib/aws-sdk-iot/types.rb', line 9611

class InfluxDBDestinationSummary < Struct.new(
  :endpoint,
  :influx_db_version,
  :secret_id,
  :secret_type,
  :secret_key)
  SENSITIVE = []
  include Aws::Structure
end

#secret_keyString

The key that is read from the secret value when the secret contains a JSON object.

Returns:

  • (String)


9611
9612
9613
9614
9615
9616
9617
9618
9619
# File 'lib/aws-sdk-iot/types.rb', line 9611

class InfluxDBDestinationSummary < Struct.new(
  :endpoint,
  :influx_db_version,
  :secret_id,
  :secret_type,
  :secret_key)
  SENSITIVE = []
  include Aws::Structure
end

#secret_typeString

The type of the secret that contains the InfluxDB API token. Valid values are SecretString and SecretBinary.

Returns:

  • (String)


9611
9612
9613
9614
9615
9616
9617
9618
9619
# File 'lib/aws-sdk-iot/types.rb', line 9611

class InfluxDBDestinationSummary < Struct.new(
  :endpoint,
  :influx_db_version,
  :secret_id,
  :secret_type,
  :secret_key)
  SENSITIVE = []
  include Aws::Structure
end