Class: Aws::IoT::Types::InvalidStateTransitionException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::InvalidStateTransitionException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
An attempt was made to change to an invalid state, for example by deleting a job or a job execution which is “IN_PROGRESS” without setting the `force` parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message for the exception.
Instance Attribute Details
#message ⇒ String
The message for the exception.
7537 7538 7539 7540 7541 |
# File 'lib/aws-sdk-iot/types.rb', line 7537 class InvalidStateTransitionException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |