Class: Aws::IoT::Types::IotEventsAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::IotEventsAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass IotEventsAction data as a hash:
{
input_name: "InputName", # required
message_id: "MessageId",
batch_mode: false,
role_arn: "AwsArn", # required
}
Sends an input to an IoT Events detector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_mode ⇒ Boolean
Whether to process the event actions as a batch.
-
#input_name ⇒ String
The name of the IoT Events input.
-
#message_id ⇒ String
The ID of the message.
-
#role_arn ⇒ String
The ARN of the role that grants IoT permission to send an input to an IoT Events detector.
Instance Attribute Details
#batch_mode ⇒ Boolean
Whether to process the event actions as a batch. The default value is `false`.
When `batchMode` is `true`, you can't specify a `messageId`.
When `batchMode` is `true` and the rule SQL statement evaluates to an Array, each Array element is treated as a separate message when it's sent to IoT Events by calling [ `BatchPutMessage` ][1]. The resulting array can't have more than 10 messages.
[1]: docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchPutMessage.html
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-iot/types.rb', line 10019 class IotEventsAction < Struct.new( :input_name, :message_id, :batch_mode, :role_arn) SENSITIVE = [] include Aws::Structure end |
#input_name ⇒ String
The name of the IoT Events input.
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-iot/types.rb', line 10019 class IotEventsAction < Struct.new( :input_name, :message_id, :batch_mode, :role_arn) SENSITIVE = [] include Aws::Structure end |
#message_id ⇒ String
The ID of the message. The default `messageId` is a new UUID value.
When `batchMode` is `true`, you can't specify a `messageId`–a new UUID value will be assigned.
Assign a value to this property to ensure that only one input (message) with a given `messageId` will be processed by an IoT Events detector.
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-iot/types.rb', line 10019 class IotEventsAction < Struct.new( :input_name, :message_id, :batch_mode, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the role that grants IoT permission to send an input to an IoT Events detector. (“Action”:“iotevents:BatchPutMessage”).
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-iot/types.rb', line 10019 class IotEventsAction < Struct.new( :input_name, :message_id, :batch_mode, :role_arn) SENSITIVE = [] include Aws::Structure end |