Class: Aws::IoT::Types::JobExecutionsRetryConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::JobExecutionsRetryConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass JobExecutionsRetryConfig data as a hash:
{
criteria_list: [ # required
{
failure_type: "FAILED", # required, accepts FAILED, TIMED_OUT, ALL
number_of_retries: 1, # required
},
],
}
The configuration that determines how many retries are allowed for each failure type for a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#criteria_list ⇒ Array<Types::RetryCriteria>
The list of criteria that determines how many retries are allowed for each failure type for a job.
Instance Attribute Details
#criteria_list ⇒ Array<Types::RetryCriteria>
The list of criteria that determines how many retries are allowed for each failure type for a job.
10714 10715 10716 10717 10718 |
# File 'lib/aws-sdk-iot/types.rb', line 10714 class JobExecutionsRetryConfig < Struct.new( :criteria_list) SENSITIVE = [] include Aws::Structure end |