Class: Aws::IoT::Types::JobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::JobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The job summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The time, in seconds since the epoch, when the job completed.
-
#created_at ⇒ Time
The time, in seconds since the epoch, when the job was created.
-
#is_concurrent ⇒ Boolean
Indicates whether a job is concurrent.
-
#job_arn ⇒ String
The job ARN.
-
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
-
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job was last updated.
-
#status ⇒ String
The job summary status.
-
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT).
-
#thing_group_id ⇒ String
The ID of the thing group.
Instance Attribute Details
#completed_at ⇒ Time
The time, in seconds since the epoch, when the job completed.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time, in seconds since the epoch, when the job was created.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#is_concurrent ⇒ Boolean
Indicates whether a job is concurrent. Will be true when a job is rolling out new job executions or canceling previously created executions, otherwise false.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The job ARN.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job was last updated.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The job summary status.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a thing when the thing is added to a target group, even after the job was completed by all things originally in the group.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#thing_group_id ⇒ String
The ID of the thing group.
10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 |
# File 'lib/aws-sdk-iot/types.rb', line 10355 class JobSummary < Struct.new( :job_arn, :job_id, :thing_group_id, :target_selection, :status, :created_at, :last_updated_at, :completed_at, :is_concurrent) SENSITIVE = [] include Aws::Structure end |