Class: Aws::IoT::Types::KafkaAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::KafkaAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_properties ⇒ Hash<String,String>
Properties of the Apache Kafka producer client.
-
#destination_arn ⇒ String
The ARN of Kafka action’s VPC ‘TopicRuleDestination`.
-
#key ⇒ String
The Kafka message key.
-
#partition ⇒ String
The Kafka message partition.
-
#topic ⇒ String
The Kafka topic for messages to be sent to the Kafka broker.
Instance Attribute Details
#client_properties ⇒ Hash<String,String>
Properties of the Apache Kafka producer client.
8242 8243 8244 8245 8246 8247 8248 8249 8250 |
# File 'lib/aws-sdk-iot/types.rb', line 8242 class KafkaAction < Struct.new( :destination_arn, :topic, :key, :partition, :client_properties) SENSITIVE = [] include Aws::Structure end |
#destination_arn ⇒ String
The ARN of Kafka action’s VPC ‘TopicRuleDestination`.
8242 8243 8244 8245 8246 8247 8248 8249 8250 |
# File 'lib/aws-sdk-iot/types.rb', line 8242 class KafkaAction < Struct.new( :destination_arn, :topic, :key, :partition, :client_properties) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The Kafka message key.
8242 8243 8244 8245 8246 8247 8248 8249 8250 |
# File 'lib/aws-sdk-iot/types.rb', line 8242 class KafkaAction < Struct.new( :destination_arn, :topic, :key, :partition, :client_properties) SENSITIVE = [] include Aws::Structure end |
#partition ⇒ String
The Kafka message partition.
8242 8243 8244 8245 8246 8247 8248 8249 8250 |
# File 'lib/aws-sdk-iot/types.rb', line 8242 class KafkaAction < Struct.new( :destination_arn, :topic, :key, :partition, :client_properties) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ String
The Kafka topic for messages to be sent to the Kafka broker.
8242 8243 8244 8245 8246 8247 8248 8249 8250 |
# File 'lib/aws-sdk-iot/types.rb', line 8242 class KafkaAction < Struct.new( :destination_arn, :topic, :key, :partition, :client_properties) SENSITIVE = [] include Aws::Structure end |