Class: Aws::IoT::Types::KafkaActionHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Specifies a Kafka header using key-value pairs when you create a Rule’s Kafka Action. You can use these headers to route data from IoT clients to downstream Kafka clusters without modifying your message payload.

For more information about Rule's Kafka action, see Apache Kafka.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

The key of the Kafka header.

Returns:

  • (String)


10455
10456
10457
10458
10459
10460
# File 'lib/aws-sdk-iot/types.rb', line 10455

class KafkaActionHeader < Struct.new(
  :key,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the Kafka header.

Returns:

  • (String)


10455
10456
10457
10458
10459
10460
# File 'lib/aws-sdk-iot/types.rb', line 10455

class KafkaActionHeader < Struct.new(
  :key,
  :value)
  SENSITIVE = []
  include Aws::Structure
end