Class: Aws::IoT::Types::ListBillingGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListBillingGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per request.
-
#name_prefix_filter ⇒ String
Limit the results to billing groups whose names have the given prefix.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per request.
10979 10980 10981 10982 10983 10984 10985 |
# File 'lib/aws-sdk-iot/types.rb', line 10979 class ListBillingGroupsRequest < Struct.new( :next_token, :max_results, :name_prefix_filter) SENSITIVE = [] include Aws::Structure end |
#name_prefix_filter ⇒ String
Limit the results to billing groups whose names have the given prefix.
10979 10980 10981 10982 10983 10984 10985 |
# File 'lib/aws-sdk-iot/types.rb', line 10979 class ListBillingGroupsRequest < Struct.new( :next_token, :max_results, :name_prefix_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
10979 10980 10981 10982 10983 10984 10985 |
# File 'lib/aws-sdk-iot/types.rb', line 10979 class ListBillingGroupsRequest < Struct.new( :next_token, :max_results, :name_prefix_filter) SENSITIVE = [] include Aws::Structure end |