Class: Aws::IoT::Types::ListCertificateProvidersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ascending_orderBoolean

Returns the list of certificate providers in ascending alphabetical order.

Returns:

  • (Boolean)


11057
11058
11059
11060
11061
11062
# File 'lib/aws-sdk-iot/types.rb', line 11057

class ListCertificateProvidersRequest < Struct.new(
  :next_token,
  :ascending_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


11057
11058
11059
11060
11061
11062
# File 'lib/aws-sdk-iot/types.rb', line 11057

class ListCertificateProvidersRequest < Struct.new(
  :next_token,
  :ascending_order)
  SENSITIVE = []
  include Aws::Structure
end