Class: Aws::IoT::Types::ListCertificateProvidersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListCertificateProvidersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_providers ⇒ Array<Types::CertificateProviderSummary>
The list of certificate providers in your Amazon Web Services account.
-
#next_token ⇒ String
The token for the next set of results, or
nullif there are no more results.
Instance Attribute Details
#certificate_providers ⇒ Array<Types::CertificateProviderSummary>
The list of certificate providers in your Amazon Web Services account.
11074 11075 11076 11077 11078 11079 |
# File 'lib/aws-sdk-iot/types.rb', line 11074 class ListCertificateProvidersResponse < Struct.new( :certificate_providers, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no
more results.
11074 11075 11076 11077 11078 11079 |
# File 'lib/aws-sdk-iot/types.rb', line 11074 class ListCertificateProvidersResponse < Struct.new( :certificate_providers, :next_token) SENSITIVE = [] include Aws::Structure end |