Class: Aws::IoT::Types::ListCommandsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListCommandsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#commands ⇒ Array<Types::CommandSummary>
The list of commands.
-
#next_token ⇒ String
The token to use to get the next set of results, or
nullif there are no additional results.
Instance Attribute Details
#commands ⇒ Array<Types::CommandSummary>
The list of commands.
11303 11304 11305 11306 11307 11308 |
# File 'lib/aws-sdk-iot/types.rb', line 11303 class ListCommandsResponse < Struct.new( :commands, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to get the next set of results, or null if there
are no additional results.
11303 11304 11305 11306 11307 11308 |
# File 'lib/aws-sdk-iot/types.rb', line 11303 class ListCommandsResponse < Struct.new( :commands, :next_token) SENSITIVE = [] include Aws::Structure end |