Class: Aws::IoT::Types::ListDetectMitigationActionsExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListDetectMitigationActionsExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The end of the time period for which ML Detect mitigation actions executions are returned.
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The token for the next set of results.
-
#start_time ⇒ Time
A filter to limit results to those found after the specified time.
-
#task_id ⇒ String
The unique identifier of the task.
-
#thing_name ⇒ String
The name of the thing whose mitigation actions are listed.
-
#violation_id ⇒ String
The unique identifier of the violation.
Instance Attribute Details
#end_time ⇒ Time
The end of the time period for which ML Detect mitigation actions executions are returned.
11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/aws-sdk-iot/types.rb', line 11374 class ListDetectMitigationActionsExecutionsRequest < Struct.new( :task_id, :violation_id, :thing_name, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return at one time. The default is 25.
11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/aws-sdk-iot/types.rb', line 11374 class ListDetectMitigationActionsExecutionsRequest < Struct.new( :task_id, :violation_id, :thing_name, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results.
11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/aws-sdk-iot/types.rb', line 11374 class ListDetectMitigationActionsExecutionsRequest < Struct.new( :task_id, :violation_id, :thing_name, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
A filter to limit results to those found after the specified time. You must specify either the startTime and endTime or the taskId, but not both.
11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/aws-sdk-iot/types.rb', line 11374 class ListDetectMitigationActionsExecutionsRequest < Struct.new( :task_id, :violation_id, :thing_name, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task.
11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/aws-sdk-iot/types.rb', line 11374 class ListDetectMitigationActionsExecutionsRequest < Struct.new( :task_id, :violation_id, :thing_name, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing whose mitigation actions are listed.
11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/aws-sdk-iot/types.rb', line 11374 class ListDetectMitigationActionsExecutionsRequest < Struct.new( :task_id, :violation_id, :thing_name, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#violation_id ⇒ String
The unique identifier of the violation.
11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/aws-sdk-iot/types.rb', line 11374 class ListDetectMitigationActionsExecutionsRequest < Struct.new( :task_id, :violation_id, :thing_name, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |