Class: Aws::IoT::Types::ListDetectMitigationActionsExecutionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actions_executionsArray<Types::DetectMitigationActionExecution>

List of actions executions.



11395
11396
11397
11398
11399
11400
# File 'lib/aws-sdk-iot/types.rb', line 11395

class ListDetectMitigationActionsExecutionsResponse < Struct.new(
  :actions_executions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that can be used to retrieve the next set of results, or null if there are no additional results.



11395
11396
11397
11398
11399
11400
# File 'lib/aws-sdk-iot/types.rb', line 11395

class ListDetectMitigationActionsExecutionsResponse < Struct.new(
  :actions_executions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end