Class: Aws::IoT::Types::ListFleetMetricsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListFleetMetricsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwisenullto receive the first set of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in this operation.
11526 11527 11528 11529 11530 11531 |
# File 'lib/aws-sdk-iot/types.rb', line 11526 class ListFleetMetricsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
11526 11527 11528 11529 11530 11531 |
# File 'lib/aws-sdk-iot/types.rb', line 11526 class ListFleetMetricsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |