Class: Aws::IoT::Types::ListIndicesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return at one time.

Returns:

  • (Integer)


11558
11559
11560
11561
11562
11563
# File 'lib/aws-sdk-iot/types.rb', line 11558

class ListIndicesRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token used to get the next set of results, or null if there are no additional results.

Returns:

  • (String)


11558
11559
11560
11561
11562
11563
# File 'lib/aws-sdk-iot/types.rb', line 11558

class ListIndicesRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end