Class: Aws::IoT::Types::ListIndicesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListIndicesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_names ⇒ Array<String>
The index names.
-
#next_token ⇒ String
The token used to get the next set of results, or
nullif there are no additional results.
Instance Attribute Details
#index_names ⇒ Array<String>
The index names.
11574 11575 11576 11577 11578 11579 |
# File 'lib/aws-sdk-iot/types.rb', line 11574 class ListIndicesResponse < Struct.new( :index_names, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token used to get the next set of results, or null if there
are no additional results.
11574 11575 11576 11577 11578 11579 |
# File 'lib/aws-sdk-iot/types.rb', line 11574 class ListIndicesResponse < Struct.new( :index_names, :next_token) SENSITIVE = [] include Aws::Structure end |