Class: Aws::IoT::Types::ListManagedJobTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListManagedJobTemplatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of entries that can be returned.
-
#next_token ⇒ String
The token to retrieve the next set of results.
-
#template_name ⇒ String
An optional parameter for template name.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of entries that can be returned.
11822 11823 11824 11825 11826 11827 11828 |
# File 'lib/aws-sdk-iot/types.rb', line 11822 class ListManagedJobTemplatesRequest < Struct.new( :template_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next set of results.
11822 11823 11824 11825 11826 11827 11828 |
# File 'lib/aws-sdk-iot/types.rb', line 11822 class ListManagedJobTemplatesRequest < Struct.new( :template_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
An optional parameter for template name. If specified, only the versions of the managed job templates that have the specified template name will be returned.
11822 11823 11824 11825 11826 11827 11828 |
# File 'lib/aws-sdk-iot/types.rb', line 11822 class ListManagedJobTemplatesRequest < Struct.new( :template_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |