Class: Aws::IoT::Types::ListOTAUpdatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListOTAUpdatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
A token used to retrieve the next set of results.
-
#ota_update_status ⇒ String
The OTA update job status.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return at one time.
11958 11959 11960 11961 11962 11963 11964 |
# File 'lib/aws-sdk-iot/types.rb', line 11958 class ListOTAUpdatesRequest < Struct.new( :max_results, :next_token, :ota_update_status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token used to retrieve the next set of results.
11958 11959 11960 11961 11962 11963 11964 |
# File 'lib/aws-sdk-iot/types.rb', line 11958 class ListOTAUpdatesRequest < Struct.new( :max_results, :next_token, :ota_update_status) SENSITIVE = [] include Aws::Structure end |
#ota_update_status ⇒ String
The OTA update job status.
11958 11959 11960 11961 11962 11963 11964 |
# File 'lib/aws-sdk-iot/types.rb', line 11958 class ListOTAUpdatesRequest < Struct.new( :max_results, :next_token, :ota_update_status) SENSITIVE = [] include Aws::Structure end |