Class: Aws::IoT::Types::ListPackagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListPackagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results returned at one time.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results returned at one time.
12074 12075 12076 12077 12078 12079 |
# File 'lib/aws-sdk-iot/types.rb', line 12074 class ListPackagesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results.
12074 12075 12076 12077 12078 12079 |
# File 'lib/aws-sdk-iot/types.rb', line 12074 class ListPackagesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |