Class: Aws::IoT::Types::ListPrincipalThingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListPrincipalThingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The input for the ListPrincipalThings operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#principal ⇒ String
The principal.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in this operation.
12273 12274 12275 12276 12277 12278 12279 |
# File 'lib/aws-sdk-iot/types.rb', line 12273 class ListPrincipalThingsRequest < Struct.new( :next_token, :max_results, :principal) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
12273 12274 12275 12276 12277 12278 12279 |
# File 'lib/aws-sdk-iot/types.rb', line 12273 class ListPrincipalThingsRequest < Struct.new( :next_token, :max_results, :principal) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
The principal.
12273 12274 12275 12276 12277 12278 12279 |
# File 'lib/aws-sdk-iot/types.rb', line 12273 class ListPrincipalThingsRequest < Struct.new( :next_token, :max_results, :principal) SENSITIVE = [] include Aws::Structure end |