Class: Aws::IoT::Types::ListPrincipalThingsV2Request

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in this operation.

Returns:



12333
12334
12335
12336
12337
12338
12339
12340
# File 'lib/aws-sdk-iot/types.rb', line 12333

class ListPrincipalThingsV2Request < Struct.new(
  :next_token,
  :max_results,
  :principal,
  :thing_principal_type)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:



12333
12334
12335
12336
12337
12338
12339
12340
# File 'lib/aws-sdk-iot/types.rb', line 12333

class ListPrincipalThingsV2Request < Struct.new(
  :next_token,
  :max_results,
  :principal,
  :thing_principal_type)
  SENSITIVE = []
  include Aws::Structure
end

#principalString

The principal. A principal can be an X.509 certificate or an Amazon Cognito ID.

Returns:



12333
12334
12335
12336
12337
12338
12339
12340
# File 'lib/aws-sdk-iot/types.rb', line 12333

class ListPrincipalThingsV2Request < Struct.new(
  :next_token,
  :max_results,
  :principal,
  :thing_principal_type)
  SENSITIVE = []
  include Aws::Structure
end

#thing_principal_typeString

The type of the relation you want to filter in the response. If no value is provided in this field, the response will list all things, including both the EXCLUSIVE_THING and NON_EXCLUSIVE_THING attachment types.

  • EXCLUSIVE_THING - Attaches the specified principal to the specified thing, exclusively. The thing will be the only thing that’s attached to the principal.

^ ^

  • NON_EXCLUSIVE_THING - Attaches the specified principal to the specified thing. Multiple things can be attached to the principal.

^

Returns:



12333
12334
12335
12336
12337
12338
12339
12340
# File 'lib/aws-sdk-iot/types.rb', line 12333

class ListPrincipalThingsV2Request < Struct.new(
  :next_token,
  :max_results,
  :principal,
  :thing_principal_type)
  SENSITIVE = []
  include Aws::Structure
end