Class: Aws::IoT::Types::ListPrincipalThingsV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListPrincipalThingsV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to get the next set of results, or null if there are no additional results.
-
#principal_thing_objects ⇒ Array<Types::PrincipalThingObject>
A list of
thingPrincipalObjectthat represents the principal and the type of relation it has with the thing.
Instance Attribute Details
#next_token ⇒ String
The token to use to get the next set of results, or null if there are no additional results.
12352 12353 12354 12355 12356 12357 |
# File 'lib/aws-sdk-iot/types.rb', line 12352 class ListPrincipalThingsV2Response < Struct.new( :principal_thing_objects, :next_token) SENSITIVE = [] include Aws::Structure end |
#principal_thing_objects ⇒ Array<Types::PrincipalThingObject>
A list of thingPrincipalObject that represents the principal and
the type of relation it has with the thing.
12352 12353 12354 12355 12356 12357 |
# File 'lib/aws-sdk-iot/types.rb', line 12352 class ListPrincipalThingsV2Response < Struct.new( :principal_thing_objects, :next_token) SENSITIVE = [] include Aws::Structure end |