Class: Aws::IoT::Types::ListScheduledAuditsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token that can be used to retrieve the next set of results, or null if there are no additional results.

Returns:



12569
12570
12571
12572
12573
12574
# File 'lib/aws-sdk-iot/types.rb', line 12569

class ListScheduledAuditsResponse < Struct.new(
  :scheduled_audits,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_auditsArray<Types::ScheduledAuditMetadata>

The list of scheduled audits.

Returns:



12569
12570
12571
12572
12573
12574
# File 'lib/aws-sdk-iot/types.rb', line 12569

class ListScheduledAuditsResponse < Struct.new(
  :scheduled_audits,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end