Class: Aws::IoT::Types::ListThingPrincipalsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListThingPrincipalsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The input for the ListThingPrincipal operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#thing_name ⇒ String
The name of the thing.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in this operation.
12903 12904 12905 12906 12907 12908 12909 |
# File 'lib/aws-sdk-iot/types.rb', line 12903 class ListThingPrincipalsRequest < Struct.new( :next_token, :max_results, :thing_name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
12903 12904 12905 12906 12907 12908 12909 |
# File 'lib/aws-sdk-iot/types.rb', line 12903 class ListThingPrincipalsRequest < Struct.new( :next_token, :max_results, :thing_name) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing.
12903 12904 12905 12906 12907 12908 12909 |
# File 'lib/aws-sdk-iot/types.rb', line 12903 class ListThingPrincipalsRequest < Struct.new( :next_token, :max_results, :thing_name) SENSITIVE = [] include Aws::Structure end |