Class: Aws::IoT::Types::ListThingPrincipalsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The output from the ListThingPrincipals operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use to get the next set of results, or null if there are no additional results.



12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-iot/types.rb', line 12922

class ListThingPrincipalsResponse < Struct.new(
  :principals,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#principalsArray<String>

The principals associated with the thing.



12922
12923
12924
12925
12926
12927
# File 'lib/aws-sdk-iot/types.rb', line 12922

class ListThingPrincipalsResponse < Struct.new(
  :principals,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end