Class: Aws::IoT::Types::ListThingsInBillingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListThingsInBillingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_group_name ⇒ String
The name of the billing group.
-
#max_results ⇒ Integer
The maximum number of results to return per request.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results.
Instance Attribute Details
#billing_group_name ⇒ String
The name of the billing group.
13130 13131 13132 13133 13134 13135 13136 |
# File 'lib/aws-sdk-iot/types.rb', line 13130 class ListThingsInBillingGroupRequest < Struct.new( :billing_group_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per request.
13130 13131 13132 13133 13134 13135 13136 |
# File 'lib/aws-sdk-iot/types.rb', line 13130 class ListThingsInBillingGroupRequest < Struct.new( :billing_group_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
13130 13131 13132 13133 13134 13135 13136 |
# File 'lib/aws-sdk-iot/types.rb', line 13130 class ListThingsInBillingGroupRequest < Struct.new( :billing_group_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |