Class: Aws::IoT::Types::ListThingsInThingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListThingsInThingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#recursive ⇒ Boolean
When true, list things in this thing group and in all child groups as well.
-
#thing_group_name ⇒ String
The thing group name.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return at one time.
13173 13174 13175 13176 13177 13178 13179 13180 |
# File 'lib/aws-sdk-iot/types.rb', line 13173 class ListThingsInThingGroupRequest < Struct.new( :thing_group_name, :recursive, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
13173 13174 13175 13176 13177 13178 13179 13180 |
# File 'lib/aws-sdk-iot/types.rb', line 13173 class ListThingsInThingGroupRequest < Struct.new( :thing_group_name, :recursive, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#recursive ⇒ Boolean
When true, list things in this thing group and in all child groups as well.
13173 13174 13175 13176 13177 13178 13179 13180 |
# File 'lib/aws-sdk-iot/types.rb', line 13173 class ListThingsInThingGroupRequest < Struct.new( :thing_group_name, :recursive, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
The thing group name.
13173 13174 13175 13176 13177 13178 13179 13180 |
# File 'lib/aws-sdk-iot/types.rb', line 13173 class ListThingsInThingGroupRequest < Struct.new( :thing_group_name, :recursive, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |