Class: Aws::IoT::Types::ListThingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListThingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The input for the ListThings operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The attribute name used to search for things.
-
#attribute_value ⇒ String
The attribute value used to search for things.
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#thing_type_name ⇒ String
The name of the thing type used to search for things.
-
#use_prefix_attribute_value ⇒ Boolean
When
true, the action returns the thing resources with attribute values that start with theattributeValueprovided.
Instance Attribute Details
#attribute_name ⇒ String
The attribute name used to search for things.
13231 13232 13233 13234 13235 13236 13237 13238 13239 13240 |
# File 'lib/aws-sdk-iot/types.rb', line 13231 class ListThingsRequest < Struct.new( :next_token, :max_results, :attribute_name, :attribute_value, :thing_type_name, :use_prefix_attribute_value) SENSITIVE = [] include Aws::Structure end |
#attribute_value ⇒ String
The attribute value used to search for things.
13231 13232 13233 13234 13235 13236 13237 13238 13239 13240 |
# File 'lib/aws-sdk-iot/types.rb', line 13231 class ListThingsRequest < Struct.new( :next_token, :max_results, :attribute_name, :attribute_value, :thing_type_name, :use_prefix_attribute_value) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in this operation.
13231 13232 13233 13234 13235 13236 13237 13238 13239 13240 |
# File 'lib/aws-sdk-iot/types.rb', line 13231 class ListThingsRequest < Struct.new( :next_token, :max_results, :attribute_name, :attribute_value, :thing_type_name, :use_prefix_attribute_value) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
13231 13232 13233 13234 13235 13236 13237 13238 13239 13240 |
# File 'lib/aws-sdk-iot/types.rb', line 13231 class ListThingsRequest < Struct.new( :next_token, :max_results, :attribute_name, :attribute_value, :thing_type_name, :use_prefix_attribute_value) SENSITIVE = [] include Aws::Structure end |
#thing_type_name ⇒ String
The name of the thing type used to search for things.
13231 13232 13233 13234 13235 13236 13237 13238 13239 13240 |
# File 'lib/aws-sdk-iot/types.rb', line 13231 class ListThingsRequest < Struct.new( :next_token, :max_results, :attribute_name, :attribute_value, :thing_type_name, :use_prefix_attribute_value) SENSITIVE = [] include Aws::Structure end |
#use_prefix_attribute_value ⇒ Boolean
When true, the action returns the thing resources with attribute
values that start with the attributeValue provided.
When false, or not present, the action returns only the thing
resources with attribute values that match the entire
attributeValue provided.
13231 13232 13233 13234 13235 13236 13237 13238 13239 13240 |
# File 'lib/aws-sdk-iot/types.rb', line 13231 class ListThingsRequest < Struct.new( :next_token, :max_results, :attribute_name, :attribute_value, :thing_type_name, :use_prefix_attribute_value) SENSITIVE = [] include Aws::Structure end |