Class: Aws::IoT::Types::ListV2LoggingLevelsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return at one time.

Returns:

  • (Integer)


13011
13012
13013
13014
13015
13016
13017
# File 'lib/aws-sdk-iot/types.rb', line 13011

class ListV2LoggingLevelsRequest < Struct.new(
  :target_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


13011
13012
13013
13014
13015
13016
13017
# File 'lib/aws-sdk-iot/types.rb', line 13011

class ListV2LoggingLevelsRequest < Struct.new(
  :target_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#target_typeString

The type of resource for which you are configuring logging. Must be THING_Group.

Returns:

  • (String)


13011
13012
13013
13014
13015
13016
13017
# File 'lib/aws-sdk-iot/types.rb', line 13011

class ListV2LoggingLevelsRequest < Struct.new(
  :target_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end