Class: Aws::IoT::Types::ListViolationEventsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#behavior_criteria_typeString

The criteria for a behavior.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time for the alerts to be listed.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#list_suppressed_alertsBoolean

A list of all suppressed alerts.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return at one time.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_nameString

A filter to limit results to those alerts generated by the specified security profile.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time for the alerts to be listed.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

A filter to limit results to those alerts caused by the specified thing.



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#verification_stateString

The verification state of the violation (detect alarm).



13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
# File 'lib/aws-sdk-iot/types.rb', line 13417

class ListViolationEventsRequest < Struct.new(
  :start_time,
  :end_time,
  :thing_name,
  :security_profile_name,
  :behavior_criteria_type,
  :list_suppressed_alerts,
  :verification_state,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end