Class: Aws::IoT::Types::ListViolationEventsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListViolationEventsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that can be used to retrieve the next set of results, or
nullif there are no additional results. -
#violation_events ⇒ Array<Types::ViolationEvent>
The security profile violation alerts issued for this account during the given time period, potentially filtered by security profile, behavior violated, or thing (device) violating.
Instance Attribute Details
#next_token ⇒ String
A token that can be used to retrieve the next set of results, or
null if there are no additional results.
13442 13443 13444 13445 13446 13447 |
# File 'lib/aws-sdk-iot/types.rb', line 13442 class ListViolationEventsResponse < Struct.new( :violation_events, :next_token) SENSITIVE = [] include Aws::Structure end |
#violation_events ⇒ Array<Types::ViolationEvent>
The security profile violation alerts issued for this account during the given time period, potentially filtered by security profile, behavior violated, or thing (device) violating.
13442 13443 13444 13445 13446 13447 |
# File 'lib/aws-sdk-iot/types.rb', line 13442 class ListViolationEventsResponse < Struct.new( :violation_events, :next_token) SENSITIVE = [] include Aws::Structure end |