Class: Aws::IoT::Types::LocationAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::LocationAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass LocationAction data as a hash:
{
role_arn: "AwsArn", # required
tracker_name: "String", # required
device_id: "String", # required
timestamp: {
value: "String", # required
unit: "String",
},
latitude: "String", # required
longitude: "String", # required
}
The Amazon Location rule action sends device location updates from an MQTT message to an Amazon Location tracker resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_id ⇒ String
The unique ID of the device providing the location data.
-
#latitude ⇒ String
A string that evaluates to a double value that represents the latitude of the device's location.
-
#longitude ⇒ String
A string that evaluates to a double value that represents the longitude of the device's location.
-
#role_arn ⇒ String
The IAM role that grants permission to write to the Amazon Location resource.
-
#timestamp ⇒ Types::LocationTimestamp
The time that the location data was sampled.
-
#tracker_name ⇒ String
The name of the tracker resource in Amazon Location in which the location is updated.
Instance Attribute Details
#device_id ⇒ String
The unique ID of the device providing the location data.
14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 |
# File 'lib/aws-sdk-iot/types.rb', line 14112 class LocationAction < Struct.new( :role_arn, :tracker_name, :device_id, :timestamp, :latitude, :longitude) SENSITIVE = [] include Aws::Structure end |
#latitude ⇒ String
A string that evaluates to a double value that represents the latitude of the device's location.
14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 |
# File 'lib/aws-sdk-iot/types.rb', line 14112 class LocationAction < Struct.new( :role_arn, :tracker_name, :device_id, :timestamp, :latitude, :longitude) SENSITIVE = [] include Aws::Structure end |
#longitude ⇒ String
A string that evaluates to a double value that represents the longitude of the device's location.
14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 |
# File 'lib/aws-sdk-iot/types.rb', line 14112 class LocationAction < Struct.new( :role_arn, :tracker_name, :device_id, :timestamp, :latitude, :longitude) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role that grants permission to write to the Amazon Location resource.
14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 |
# File 'lib/aws-sdk-iot/types.rb', line 14112 class LocationAction < Struct.new( :role_arn, :tracker_name, :device_id, :timestamp, :latitude, :longitude) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Types::LocationTimestamp
The time that the location data was sampled. The default value is the time the MQTT message was processed.
14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 |
# File 'lib/aws-sdk-iot/types.rb', line 14112 class LocationAction < Struct.new( :role_arn, :tracker_name, :device_id, :timestamp, :latitude, :longitude) SENSITIVE = [] include Aws::Structure end |
#tracker_name ⇒ String
The name of the tracker resource in Amazon Location in which the location is updated.
14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 |
# File 'lib/aws-sdk-iot/types.rb', line 14112 class LocationAction < Struct.new( :role_arn, :tracker_name, :device_id, :timestamp, :latitude, :longitude) SENSITIVE = [] include Aws::Structure end |