Class: Aws::IoT::Types::LocationTimestamp
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::LocationTimestamp
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes how to interpret an application-defined timestamp value from an MQTT message payload and the precision of that value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unit ⇒ String
The precision of the timestamp value that results from the expression described in
value. -
#value ⇒ String
An expression that returns a long epoch time value.
Instance Attribute Details
#unit ⇒ String
The precision of the timestamp value that results from the
expression described in value.
Valid values: SECONDS | MILLISECONDS | MICROSECONDS |
NANOSECONDS. The default is MILLISECONDS.
13507 13508 13509 13510 13511 13512 |
# File 'lib/aws-sdk-iot/types.rb', line 13507 class LocationTimestamp < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
An expression that returns a long epoch time value.
13507 13508 13509 13510 13511 13512 |
# File 'lib/aws-sdk-iot/types.rb', line 13507 class LocationTimestamp < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |