Class: Aws::IoT::Types::MetricDimension

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass MetricDimension data as a hash:

{
  dimension_name: "DimensionName", # required
  operator: "IN", # accepts IN, NOT_IN
}

The dimension of a metric.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dimension_nameString

A unique identifier for the dimension.

Returns:

  • (String)


13800
13801
13802
13803
13804
13805
# File 'lib/aws-sdk-iot/types.rb', line 13800

class MetricDimension < Struct.new(
  :dimension_name,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end

#operatorString

Defines how the `dimensionValues` of a dimension are interpreted. For example, for dimension type TOPIC_FILTER, the `IN` operator, a message will be counted only if its topic matches one of the topic filters. With `NOT_IN` operator, a message will be counted only if it doesn't match any of the topic filters. The operator is optional: if it's not provided (is `null`), it will be interpreted as `IN`.

Returns:

  • (String)


13800
13801
13802
13803
13804
13805
# File 'lib/aws-sdk-iot/types.rb', line 13800

class MetricDimension < Struct.new(
  :dimension_name,
  :operator)
  SENSITIVE = []
  include Aws::Structure
end