Class: Aws::IoT::Types::MetricValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::MetricValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass MetricValue data as a hash:
{
count: 1,
cidrs: ["Cidr"],
ports: [1],
number: 1.0,
numbers: [1.0],
strings: ["stringValue"],
}
The value to be compared with the `metric`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidrs ⇒ Array<String>
If the `comparisonOperator` calls for a set of CIDRs, use this to specify that set to be compared with the `metric`.
-
#count ⇒ Integer
If the `comparisonOperator` calls for a numeric value, use this to specify that numeric value to be compared with the `metric`.
-
#number ⇒ Float
The numeral value of a metric.
-
#numbers ⇒ Array<Float>
The numeral values of a metric.
-
#ports ⇒ Array<Integer>
If the `comparisonOperator` calls for a set of ports, use this to specify that set to be compared with the `metric`.
-
#strings ⇒ Array<String>
The string values of a metric.
Instance Attribute Details
#cidrs ⇒ Array<String>
If the `comparisonOperator` calls for a set of CIDRs, use this to specify that set to be compared with the `metric`.
14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 |
# File 'lib/aws-sdk-iot/types.rb', line 14460 class MetricValue < Struct.new( :count, :cidrs, :ports, :number, :numbers, :strings) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Integer
If the `comparisonOperator` calls for a numeric value, use this to specify that numeric value to be compared with the `metric`.
14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 |
# File 'lib/aws-sdk-iot/types.rb', line 14460 class MetricValue < Struct.new( :count, :cidrs, :ports, :number, :numbers, :strings) SENSITIVE = [] include Aws::Structure end |
#number ⇒ Float
The numeral value of a metric.
14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 |
# File 'lib/aws-sdk-iot/types.rb', line 14460 class MetricValue < Struct.new( :count, :cidrs, :ports, :number, :numbers, :strings) SENSITIVE = [] include Aws::Structure end |
#numbers ⇒ Array<Float>
The numeral values of a metric.
14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 |
# File 'lib/aws-sdk-iot/types.rb', line 14460 class MetricValue < Struct.new( :count, :cidrs, :ports, :number, :numbers, :strings) SENSITIVE = [] include Aws::Structure end |
#ports ⇒ Array<Integer>
If the `comparisonOperator` calls for a set of ports, use this to specify that set to be compared with the `metric`.
14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 |
# File 'lib/aws-sdk-iot/types.rb', line 14460 class MetricValue < Struct.new( :count, :cidrs, :ports, :number, :numbers, :strings) SENSITIVE = [] include Aws::Structure end |
#strings ⇒ Array<String>
The string values of a metric.
14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 |
# File 'lib/aws-sdk-iot/types.rb', line 14460 class MetricValue < Struct.new( :count, :cidrs, :ports, :number, :numbers, :strings) SENSITIVE = [] include Aws::Structure end |