Class: Aws::IoT::Types::MetricsExportConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Set configurations for metrics export.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#mqtt_topicString

The MQTT topic that Device Defender Detect should publish messages to for metrics export.



13788
13789
13790
13791
13792
13793
# File 'lib/aws-sdk-iot/types.rb', line 13788

class MetricsExportConfig < Struct.new(
  :mqtt_topic,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

This role ARN has permission to publish MQTT messages, after which Device Defender Detect can assume the role and publish messages on your behalf.



13788
13789
13790
13791
13792
13793
# File 'lib/aws-sdk-iot/types.rb', line 13788

class MetricsExportConfig < Struct.new(
  :mqtt_topic,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end