Class: Aws::IoT::Types::MitigationActionParams
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::MitigationActionParams
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The set of parameters for this mitigation action. You can specify only one type of parameter (in other words, you can apply only one action for each defined mitigation action).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_things_to_thing_group_params ⇒ Types::AddThingsToThingGroupParams
Parameters to define a mitigation action that moves devices associated with a certificate to one or more specified thing groups, typically for quarantine.
-
#enable_io_t_logging_params ⇒ Types::EnableIoTLoggingParams
Parameters to define a mitigation action that enables Amazon Web Services IoT Core logging at a specified level of detail.
-
#publish_finding_to_sns_params ⇒ Types::PublishFindingToSnsParams
Parameters to define a mitigation action that publishes findings to Amazon Simple Notification Service (Amazon SNS. You can implement your own custom actions in response to the Amazon SNS messages..
-
#replace_default_policy_version_params ⇒ Types::ReplaceDefaultPolicyVersionParams
Parameters to define a mitigation action that adds a blank policy to restrict permissions.
-
#update_ca_certificate_params ⇒ Types::UpdateCACertificateParams
Parameters to define a mitigation action that changes the state of the CA certificate to inactive.
-
#update_device_certificate_params ⇒ Types::UpdateDeviceCertificateParams
Parameters to define a mitigation action that changes the state of the device certificate to inactive.
Instance Attribute Details
#add_things_to_thing_group_params ⇒ Types::AddThingsToThingGroupParams
Parameters to define a mitigation action that moves devices associated with a certificate to one or more specified thing groups, typically for quarantine.
13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 |
# File 'lib/aws-sdk-iot/types.rb', line 13546 class MitigationActionParams < Struct.new( :update_device_certificate_params, :update_ca_certificate_params, :add_things_to_thing_group_params, :replace_default_policy_version_params, :enable_io_t_logging_params, :publish_finding_to_sns_params) SENSITIVE = [] include Aws::Structure end |
#enable_io_t_logging_params ⇒ Types::EnableIoTLoggingParams
Parameters to define a mitigation action that enables Amazon Web Services IoT Core logging at a specified level of detail.
13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 |
# File 'lib/aws-sdk-iot/types.rb', line 13546 class MitigationActionParams < Struct.new( :update_device_certificate_params, :update_ca_certificate_params, :add_things_to_thing_group_params, :replace_default_policy_version_params, :enable_io_t_logging_params, :publish_finding_to_sns_params) SENSITIVE = [] include Aws::Structure end |
#publish_finding_to_sns_params ⇒ Types::PublishFindingToSnsParams
Parameters to define a mitigation action that publishes findings to Amazon Simple Notification Service (Amazon SNS. You can implement your own custom actions in response to the Amazon SNS messages.
13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 |
# File 'lib/aws-sdk-iot/types.rb', line 13546 class MitigationActionParams < Struct.new( :update_device_certificate_params, :update_ca_certificate_params, :add_things_to_thing_group_params, :replace_default_policy_version_params, :enable_io_t_logging_params, :publish_finding_to_sns_params) SENSITIVE = [] include Aws::Structure end |
#replace_default_policy_version_params ⇒ Types::ReplaceDefaultPolicyVersionParams
Parameters to define a mitigation action that adds a blank policy to restrict permissions.
13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 |
# File 'lib/aws-sdk-iot/types.rb', line 13546 class MitigationActionParams < Struct.new( :update_device_certificate_params, :update_ca_certificate_params, :add_things_to_thing_group_params, :replace_default_policy_version_params, :enable_io_t_logging_params, :publish_finding_to_sns_params) SENSITIVE = [] include Aws::Structure end |
#update_ca_certificate_params ⇒ Types::UpdateCACertificateParams
Parameters to define a mitigation action that changes the state of the CA certificate to inactive.
13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 |
# File 'lib/aws-sdk-iot/types.rb', line 13546 class MitigationActionParams < Struct.new( :update_device_certificate_params, :update_ca_certificate_params, :add_things_to_thing_group_params, :replace_default_policy_version_params, :enable_io_t_logging_params, :publish_finding_to_sns_params) SENSITIVE = [] include Aws::Structure end |
#update_device_certificate_params ⇒ Types::UpdateDeviceCertificateParams
Parameters to define a mitigation action that changes the state of the device certificate to inactive.
13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 |
# File 'lib/aws-sdk-iot/types.rb', line 13546 class MitigationActionParams < Struct.new( :update_device_certificate_params, :update_ca_certificate_params, :add_things_to_thing_group_params, :replace_default_policy_version_params, :enable_io_t_logging_params, :publish_finding_to_sns_params) SENSITIVE = [] include Aws::Structure end |