Class: Aws::IoT::Types::OTAUpdateFile
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::OTAUpdateFile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes a file to be associated with an OTA update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A list of name-attribute pairs.
-
#code_signing ⇒ Types::CodeSigning
The code signing method of the file.
-
#file_location ⇒ Types::FileLocation
The location of the updated firmware.
-
#file_name ⇒ String
The name of the file.
-
#file_type ⇒ Integer
An integer value you can include in the job document to allow your devices to identify the type of file received from the cloud.
-
#file_version ⇒ String
The file version.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A list of name-attribute pairs. They won’t be sent to devices as a part of the Job document.
13861 13862 13863 13864 13865 13866 13867 13868 13869 13870 |
# File 'lib/aws-sdk-iot/types.rb', line 13861 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#code_signing ⇒ Types::CodeSigning
The code signing method of the file.
13861 13862 13863 13864 13865 13866 13867 13868 13869 13870 |
# File 'lib/aws-sdk-iot/types.rb', line 13861 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_location ⇒ Types::FileLocation
The location of the updated firmware.
13861 13862 13863 13864 13865 13866 13867 13868 13869 13870 |
# File 'lib/aws-sdk-iot/types.rb', line 13861 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The name of the file.
13861 13862 13863 13864 13865 13866 13867 13868 13869 13870 |
# File 'lib/aws-sdk-iot/types.rb', line 13861 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_type ⇒ Integer
An integer value you can include in the job document to allow your devices to identify the type of file received from the cloud.
13861 13862 13863 13864 13865 13866 13867 13868 13869 13870 |
# File 'lib/aws-sdk-iot/types.rb', line 13861 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_version ⇒ String
The file version.
13861 13862 13863 13864 13865 13866 13867 13868 13869 13870 |
# File 'lib/aws-sdk-iot/types.rb', line 13861 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |