Class: Aws::IoT::Types::OTAUpdateInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Information about an OTA update.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_parametersHash<String,String>

A collection of name/value pairs

Returns:

  • (Hash<String,String>)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#aws_iot_job_arnString

The IoT job ARN associated with the OTA update.

Returns:

  • (String)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#aws_iot_job_idString

The IoT job ID associated with the OTA update.

Returns:

  • (String)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#aws_job_executions_rollout_configTypes::AwsJobExecutionsRolloutConfig

Configuration for the rollout of OTA updates.



13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#aws_job_presigned_url_configTypes::AwsJobPresignedUrlConfig

Configuration information for pre-signed URLs. Valid when ‘protocols` contains HTTP.



13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date when the OTA update was created.

Returns:

  • (Time)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the OTA update.

Returns:

  • (String)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#error_infoTypes::ErrorInfo

Error information associated with the OTA update.

Returns:



13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date when the OTA update was last updated.

Returns:

  • (Time)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#ota_update_arnString

The OTA update ARN.

Returns:

  • (String)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#ota_update_filesArray<Types::OTAUpdateFile>

A list of files associated with the OTA update.

Returns:



13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#ota_update_idString

The OTA update ID.

Returns:

  • (String)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#ota_update_statusString

The status of the OTA update.

Returns:

  • (String)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#protocolsArray<String>

The protocol used to transfer the OTA update image. Valid values are [HTTP], [MQTT], [HTTP, MQTT]. When both HTTP and MQTT are specified, the target device can choose the protocol.

Returns:

  • (Array<String>)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#target_selectionString

Specifies whether the OTA update will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the OTA update (SNAPSHOT). If continuous, the OTA update may also be run on a thing when a change is detected in a target. For example, an OTA update will run on a thing when the thing is added to a target group, even after the OTA update was completed by all things originally in the group.

Returns:

  • (String)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<String>

The targets of the OTA update.

Returns:

  • (Array<String>)


13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
# File 'lib/aws-sdk-iot/types.rb', line 13953

class OTAUpdateInfo < Struct.new(
  :ota_update_id,
  :ota_update_arn,
  :creation_date,
  :last_modified_date,
  :description,
  :targets,
  :protocols,
  :aws_job_executions_rollout_config,
  :aws_job_presigned_url_config,
  :target_selection,
  :ota_update_files,
  :ota_update_status,
  :aws_iot_job_id,
  :aws_iot_job_arn,
  :error_info,
  :additional_parameters)
  SENSITIVE = []
  include Aws::Structure
end