Class: Aws::IoT::Types::OpenSearchAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::OpenSearchAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass OpenSearchAction data as a hash:
{
role_arn: "AwsArn", # required
endpoint: "ElasticsearchEndpoint", # required
index: "ElasticsearchIndex", # required
type: "ElasticsearchType", # required
id: "ElasticsearchId", # required
}
Describes an action that writes data to an Amazon OpenSearch Service domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint ⇒ String
The endpoint of your OpenSearch domain.
-
#id ⇒ String
The unique identifier for the document you are storing.
-
#index ⇒ String
The OpenSearch index where you want to store your data.
-
#role_arn ⇒ String
The IAM role ARN that has access to OpenSearch.
-
#type ⇒ String
The type of document you are storing.
Instance Attribute Details
#endpoint ⇒ String
The endpoint of your OpenSearch domain.
14738 14739 14740 14741 14742 14743 14744 14745 14746 |
# File 'lib/aws-sdk-iot/types.rb', line 14738 class OpenSearchAction < Struct.new( :role_arn, :endpoint, :index, :type, :id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the document you are storing.
14738 14739 14740 14741 14742 14743 14744 14745 14746 |
# File 'lib/aws-sdk-iot/types.rb', line 14738 class OpenSearchAction < Struct.new( :role_arn, :endpoint, :index, :type, :id) SENSITIVE = [] include Aws::Structure end |
#index ⇒ String
The OpenSearch index where you want to store your data.
14738 14739 14740 14741 14742 14743 14744 14745 14746 |
# File 'lib/aws-sdk-iot/types.rb', line 14738 class OpenSearchAction < Struct.new( :role_arn, :endpoint, :index, :type, :id) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role ARN that has access to OpenSearch.
14738 14739 14740 14741 14742 14743 14744 14745 14746 |
# File 'lib/aws-sdk-iot/types.rb', line 14738 class OpenSearchAction < Struct.new( :role_arn, :endpoint, :index, :type, :id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of document you are storing.
14738 14739 14740 14741 14742 14743 14744 14745 14746 |
# File 'lib/aws-sdk-iot/types.rb', line 14738 class OpenSearchAction < Struct.new( :role_arn, :endpoint, :index, :type, :id) SENSITIVE = [] include Aws::Structure end |