Class: Aws::IoT::Types::PolicyVersionIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::PolicyVersionIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass PolicyVersionIdentifier data as a hash:
{
policy_name: "PolicyName",
policy_version_id: "PolicyVersionId",
}
Information about the version of the policy associated with the resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_name ⇒ String
The name of the policy.
-
#policy_version_id ⇒ String
The ID of the version of the policy associated with the resource.
Instance Attribute Details
#policy_name ⇒ String
The name of the policy.
14667 14668 14669 14670 14671 14672 |
# File 'lib/aws-sdk-iot/types.rb', line 14667 class PolicyVersionIdentifier < Struct.new( :policy_name, :policy_version_id) SENSITIVE = [] include Aws::Structure end |
#policy_version_id ⇒ String
The ID of the version of the policy associated with the resource.
14667 14668 14669 14670 14671 14672 |
# File 'lib/aws-sdk-iot/types.rb', line 14667 class PolicyVersionIdentifier < Struct.new( :policy_name, :policy_version_id) SENSITIVE = [] include Aws::Structure end |