Class: Aws::IoT::Types::ProvisioningHook
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ProvisioningHook
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Structure that contains `payloadVersion` and `targetArn`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#payload_version ⇒ String
The payload that was sent to the target function.
-
#target_arn ⇒ String
The ARN of the target function.
Instance Attribute Details
#payload_version ⇒ String
The payload that was sent to the target function.
Note: Only Lambda functions are currently supported.
11663 11664 11665 11666 11667 11668 |
# File 'lib/aws-sdk-iot/types.rb', line 11663 class ProvisioningHook < Struct.new( :payload_version, :target_arn) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The ARN of the target function.
Note: Only Lambda functions are currently supported.
11663 11664 11665 11666 11667 11668 |
# File 'lib/aws-sdk-iot/types.rb', line 11663 class ProvisioningHook < Struct.new( :payload_version, :target_arn) SENSITIVE = [] include Aws::Structure end |