Class: Aws::IoT::Types::ProvisioningTemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ProvisioningTemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
A summary of information about a fleet provisioning template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date when the fleet provisioning template summary was created.
-
#description ⇒ String
The description of the fleet provisioning template.
-
#enabled ⇒ Boolean
True if the fleet provision template is enabled, otherwise false.
-
#last_modified_date ⇒ Time
The date when the fleet provisioning template summary was last modified.
-
#template_arn ⇒ String
The ARN of the fleet provisioning template.
-
#template_name ⇒ String
The name of the fleet provisioning template.
Instance Attribute Details
#creation_date ⇒ Time
The date when the fleet provisioning template summary was created.
14767 14768 14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-iot/types.rb', line 14767 class ProvisioningTemplateSummary < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :enabled) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the fleet provisioning template.
14767 14768 14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-iot/types.rb', line 14767 class ProvisioningTemplateSummary < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :enabled) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
True if the fleet provision template is enabled, otherwise false.
14767 14768 14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-iot/types.rb', line 14767 class ProvisioningTemplateSummary < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :enabled) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date when the fleet provisioning template summary was last modified.
14767 14768 14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-iot/types.rb', line 14767 class ProvisioningTemplateSummary < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :enabled) SENSITIVE = [] include Aws::Structure end |
#template_arn ⇒ String
The ARN of the fleet provisioning template.
14767 14768 14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-iot/types.rb', line 14767 class ProvisioningTemplateSummary < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :enabled) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the fleet provisioning template.
14767 14768 14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-iot/types.rb', line 14767 class ProvisioningTemplateSummary < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :enabled) SENSITIVE = [] include Aws::Structure end |