Class: Aws::IoT::Types::ProvisioningTemplateVersionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

A summary of information about a fleet provision template version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_dateTime

The date when the fleet provisioning template version was created

Returns:

  • (Time)


14733
14734
14735
14736
14737
14738
14739
# File 'lib/aws-sdk-iot/types.rb', line 14733

class ProvisioningTemplateVersionSummary < Struct.new(
  :version_id,
  :creation_date,
  :is_default_version)
  SENSITIVE = []
  include Aws::Structure
end

#is_default_versionBoolean

True if the fleet provisioning template version is the default version, otherwise false.

Returns:

  • (Boolean)


14733
14734
14735
14736
14737
14738
14739
# File 'lib/aws-sdk-iot/types.rb', line 14733

class ProvisioningTemplateVersionSummary < Struct.new(
  :version_id,
  :creation_date,
  :is_default_version)
  SENSITIVE = []
  include Aws::Structure
end

#version_idInteger

The ID of the fleet privisioning template version.

Returns:

  • (Integer)


14733
14734
14735
14736
14737
14738
14739
# File 'lib/aws-sdk-iot/types.rb', line 14733

class ProvisioningTemplateVersionSummary < Struct.new(
  :version_id,
  :creation_date,
  :is_default_version)
  SENSITIVE = []
  include Aws::Structure
end