Class: Aws::IoT::Types::PublishFindingToSnsParams

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass PublishFindingToSnsParams data as a hash:

{
  topic_arn: "SnsTopicArn", # required
}

Parameters to define a mitigation action that publishes findings to Amazon SNS. You can implement your own custom actions in response to the Amazon SNS messages.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#topic_arnString

The ARN of the topic to which you want to publish the findings.

Returns:

  • (String)


15128
15129
15130
15131
15132
# File 'lib/aws-sdk-iot/types.rb', line 15128

class PublishFindingToSnsParams < Struct.new(
  :topic_arn)
  SENSITIVE = []
  include Aws::Structure
end