Class: Aws::IoT::Types::PutAssetPropertyValueEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::PutAssetPropertyValueEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass PutAssetPropertyValueEntry data as a hash:
{
entry_id: "AssetPropertyEntryId",
asset_id: "AssetId",
property_id: "AssetPropertyId",
property_alias: "AssetPropertyAlias",
property_values: [ # required
{
value: { # required
string_value: "AssetPropertyStringValue",
integer_value: "AssetPropertyIntegerValue",
double_value: "AssetPropertyDoubleValue",
boolean_value: "AssetPropertyBooleanValue",
},
timestamp: { # required
time_in_seconds: "AssetPropertyTimeInSeconds", # required
offset_in_nanos: "AssetPropertyOffsetInNanos",
},
quality: "AssetPropertyQuality",
},
],
}
An asset property value entry containing the following information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The ID of the IoT SiteWise asset.
-
#entry_id ⇒ String
Optional.
-
#property_alias ⇒ String
The name of the property alias associated with your asset property.
-
#property_id ⇒ String
The ID of the asset's property.
-
#property_values ⇒ Array<Types::AssetPropertyValue>
A list of property values to insert that each contain timestamp, quality, and value (TQV) information.
Instance Attribute Details
#asset_id ⇒ String
The ID of the IoT SiteWise asset. You must specify either a `propertyAlias` or both an `aliasId` and a `propertyId`. Accepts substitution templates.
14644 14645 14646 14647 14648 14649 14650 14651 14652 |
# File 'lib/aws-sdk-iot/types.rb', line 14644 class PutAssetPropertyValueEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :property_values) SENSITIVE = [] include Aws::Structure end |
#entry_id ⇒ String
Optional. A unique identifier for this entry that you can define to better track which message caused an error in case of failure. Accepts substitution templates. Defaults to a new UUID.
14644 14645 14646 14647 14648 14649 14650 14651 14652 |
# File 'lib/aws-sdk-iot/types.rb', line 14644 class PutAssetPropertyValueEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :property_values) SENSITIVE = [] include Aws::Structure end |
#property_alias ⇒ String
The name of the property alias associated with your asset property. You must specify either a `propertyAlias` or both an `aliasId` and a `propertyId`. Accepts substitution templates.
14644 14645 14646 14647 14648 14649 14650 14651 14652 |
# File 'lib/aws-sdk-iot/types.rb', line 14644 class PutAssetPropertyValueEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :property_values) SENSITIVE = [] include Aws::Structure end |
#property_id ⇒ String
The ID of the asset's property. You must specify either a `propertyAlias` or both an `aliasId` and a `propertyId`. Accepts substitution templates.
14644 14645 14646 14647 14648 14649 14650 14651 14652 |
# File 'lib/aws-sdk-iot/types.rb', line 14644 class PutAssetPropertyValueEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :property_values) SENSITIVE = [] include Aws::Structure end |
#property_values ⇒ Array<Types::AssetPropertyValue>
A list of property values to insert that each contain timestamp, quality, and value (TQV) information.
14644 14645 14646 14647 14648 14649 14650 14651 14652 |
# File 'lib/aws-sdk-iot/types.rb', line 14644 class PutAssetPropertyValueEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :property_values) SENSITIVE = [] include Aws::Structure end |