Class: Aws::IoT::Types::PutVerificationStateOnViolationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::PutVerificationStateOnViolationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass PutVerificationStateOnViolationRequest data as a hash:
{
violation_id: "ViolationId", # required
verification_state: "FALSE_POSITIVE", # required, accepts FALSE_POSITIVE, BENIGN_POSITIVE, TRUE_POSITIVE, UNKNOWN
verification_state_description: "VerificationStateDescription",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#verification_state ⇒ String
The verification state of the violation.
-
#verification_state_description ⇒ String
The description of the verification state of the violation (detect alarm).
-
#violation_id ⇒ String
The violation ID.
Instance Attribute Details
#verification_state ⇒ String
The verification state of the violation.
14800 14801 14802 14803 14804 14805 14806 |
# File 'lib/aws-sdk-iot/types.rb', line 14800 class PutVerificationStateOnViolationRequest < Struct.new( :violation_id, :verification_state, :verification_state_description) SENSITIVE = [] include Aws::Structure end |
#verification_state_description ⇒ String
The description of the verification state of the violation (detect alarm).
14800 14801 14802 14803 14804 14805 14806 |
# File 'lib/aws-sdk-iot/types.rb', line 14800 class PutVerificationStateOnViolationRequest < Struct.new( :violation_id, :verification_state, :verification_state_description) SENSITIVE = [] include Aws::Structure end |
#violation_id ⇒ String
The violation ID.
14800 14801 14802 14803 14804 14805 14806 |
# File 'lib/aws-sdk-iot/types.rb', line 14800 class PutVerificationStateOnViolationRequest < Struct.new( :violation_id, :verification_state, :verification_state_description) SENSITIVE = [] include Aws::Structure end |