Class: Aws::IoT::Types::RemoveThingFromBillingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::RemoveThingFromBillingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_group_arn ⇒ String
The ARN of the billing group.
-
#billing_group_name ⇒ String
The name of the billing group.
-
#thing_arn ⇒ String
The ARN of the thing to be removed from the billing group.
-
#thing_name ⇒ String
The name of the thing to be removed from the billing group.
Instance Attribute Details
#billing_group_arn ⇒ String
The ARN of the billing group.
14805 14806 14807 14808 14809 14810 14811 14812 |
# File 'lib/aws-sdk-iot/types.rb', line 14805 class RemoveThingFromBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_arn, :thing_name, :thing_arn) SENSITIVE = [] include Aws::Structure end |
#billing_group_name ⇒ String
The name of the billing group.
14805 14806 14807 14808 14809 14810 14811 14812 |
# File 'lib/aws-sdk-iot/types.rb', line 14805 class RemoveThingFromBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_arn, :thing_name, :thing_arn) SENSITIVE = [] include Aws::Structure end |
#thing_arn ⇒ String
The ARN of the thing to be removed from the billing group.
14805 14806 14807 14808 14809 14810 14811 14812 |
# File 'lib/aws-sdk-iot/types.rb', line 14805 class RemoveThingFromBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_arn, :thing_name, :thing_arn) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing to be removed from the billing group.
14805 14806 14807 14808 14809 14810 14811 14812 |
# File 'lib/aws-sdk-iot/types.rb', line 14805 class RemoveThingFromBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_arn, :thing_name, :thing_arn) SENSITIVE = [] include Aws::Structure end |