Class: Aws::IoT::Types::ResourceIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ResourceIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass ResourceIdentifier data as a hash:
{
device_certificate_id: "CertificateId",
ca_certificate_id: "CertificateId",
cognito_identity_pool_id: "CognitoIdentityPoolId",
client_id: "ClientId",
policy_version_identifier: {
policy_name: "PolicyName",
policy_version_id: "PolicyVersionId",
},
account: "AwsAccountId",
iam_role_arn: "RoleArn",
role_alias_arn: "RoleAliasArn",
issuer_certificate_identifier: {
issuer_certificate_subject: "IssuerCertificateSubject",
issuer_id: "IssuerId",
issuer_certificate_serial_number: "IssuerCertificateSerialNumber",
},
device_certificate_arn: "CertificateArn",
}
Information that identifies the noncompliant resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account ⇒ String
The account with which the resource is associated.
-
#ca_certificate_id ⇒ String
The ID of the CA certificate used to authorize the certificate.
-
#client_id ⇒ String
The client ID.
-
#cognito_identity_pool_id ⇒ String
The ID of the Amazon Cognito identity pool.
-
#device_certificate_arn ⇒ String
The ARN of the identified device certificate.
-
#device_certificate_id ⇒ String
The ID of the certificate attached to the resource.
-
#iam_role_arn ⇒ String
The ARN of the IAM role that has overly permissive actions.
-
#issuer_certificate_identifier ⇒ Types::IssuerCertificateIdentifier
The issuer certificate identifier.
-
#policy_version_identifier ⇒ Types::PolicyVersionIdentifier
The version of the policy associated with the resource.
-
#role_alias_arn ⇒ String
The ARN of the role alias that has overly permissive actions.
Instance Attribute Details
#account ⇒ String
The account with which the resource is associated.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#ca_certificate_id ⇒ String
The ID of the CA certificate used to authorize the certificate.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#client_id ⇒ String
The client ID.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#cognito_identity_pool_id ⇒ String
The ID of the Amazon Cognito identity pool.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#device_certificate_arn ⇒ String
The ARN of the identified device certificate.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#device_certificate_id ⇒ String
The ID of the certificate attached to the resource.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The ARN of the IAM role that has overly permissive actions.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#issuer_certificate_identifier ⇒ Types::IssuerCertificateIdentifier
The issuer certificate identifier.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#policy_version_identifier ⇒ Types::PolicyVersionIdentifier
The version of the policy associated with the resource.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |
#role_alias_arn ⇒ String
The ARN of the role alias that has overly permissive actions.
16247 16248 16249 16250 16251 16252 16253 16254 16255 16256 16257 16258 16259 16260 |
# File 'lib/aws-sdk-iot/types.rb', line 16247 class ResourceIdentifier < Struct.new( :device_certificate_id, :ca_certificate_id, :cognito_identity_pool_id, :client_id, :policy_version_identifier, :account, :iam_role_arn, :role_alias_arn, :issuer_certificate_identifier, :device_certificate_arn) SENSITIVE = [] include Aws::Structure end |