Class: Aws::IoT::Types::RoleAliasDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::RoleAliasDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Role alias description.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The UNIX timestamp of when the role alias was created.
-
#credential_duration_seconds ⇒ Integer
The number of seconds for which the credential is valid.
-
#last_modified_date ⇒ Time
The UNIX timestamp of when the role alias was last modified.
-
#owner ⇒ String
The role alias owner.
-
#role_alias ⇒ String
The role alias.
-
#role_alias_arn ⇒ String
The ARN of the role alias.
-
#role_arn ⇒ String
The role ARN.
Instance Attribute Details
#creation_date ⇒ Time
The UNIX timestamp of when the role alias was created.
12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/aws-sdk-iot/types.rb', line 12460 class RoleAliasDescription < Struct.new( :role_alias, :role_alias_arn, :role_arn, :owner, :credential_duration_seconds, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#credential_duration_seconds ⇒ Integer
The number of seconds for which the credential is valid.
12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/aws-sdk-iot/types.rb', line 12460 class RoleAliasDescription < Struct.new( :role_alias, :role_alias_arn, :role_arn, :owner, :credential_duration_seconds, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The UNIX timestamp of when the role alias was last modified.
12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/aws-sdk-iot/types.rb', line 12460 class RoleAliasDescription < Struct.new( :role_alias, :role_alias_arn, :role_arn, :owner, :credential_duration_seconds, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The role alias owner.
12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/aws-sdk-iot/types.rb', line 12460 class RoleAliasDescription < Struct.new( :role_alias, :role_alias_arn, :role_arn, :owner, :credential_duration_seconds, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#role_alias ⇒ String
The role alias.
12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/aws-sdk-iot/types.rb', line 12460 class RoleAliasDescription < Struct.new( :role_alias, :role_alias_arn, :role_arn, :owner, :credential_duration_seconds, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#role_alias_arn ⇒ String
The ARN of the role alias.
12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/aws-sdk-iot/types.rb', line 12460 class RoleAliasDescription < Struct.new( :role_alias, :role_alias_arn, :role_arn, :owner, :credential_duration_seconds, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role ARN.
12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/aws-sdk-iot/types.rb', line 12460 class RoleAliasDescription < Struct.new( :role_alias, :role_alias_arn, :role_arn, :owner, :credential_duration_seconds, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |