Class: Aws::IoT::Types::S3Action

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Describes an action to write data to an Amazon S3 bucket.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_nameString

The Amazon S3 bucket.



15334
15335
15336
15337
15338
15339
15340
15341
# File 'lib/aws-sdk-iot/types.rb', line 15334

class S3Action < Struct.new(
  :role_arn,
  :bucket_name,
  :key,
  :canned_acl)
  SENSITIVE = []
  include Aws::Structure
end

#canned_aclString

The Amazon S3 canned ACL that controls access to the object identified by the object key. For more information, see S3 canned ACLs.



15334
15335
15336
15337
15338
15339
15340
15341
# File 'lib/aws-sdk-iot/types.rb', line 15334

class S3Action < Struct.new(
  :role_arn,
  :bucket_name,
  :key,
  :canned_acl)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The object key. For more information, see Actions, resources, and condition keys for Amazon S3.



15334
15335
15336
15337
15338
15339
15340
15341
# File 'lib/aws-sdk-iot/types.rb', line 15334

class S3Action < Struct.new(
  :role_arn,
  :bucket_name,
  :key,
  :canned_acl)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that grants access.



15334
15335
15336
15337
15338
15339
15340
15341
# File 'lib/aws-sdk-iot/types.rb', line 15334

class S3Action < Struct.new(
  :role_arn,
  :bucket_name,
  :key,
  :canned_acl)
  SENSITIVE = []
  include Aws::Structure
end