Class: Aws::IoT::Types::ScheduledAuditMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Information about the scheduled audit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#day_of_monthString

The day of the month on which the scheduled audit is run (if the frequency is "MONTHLY"). If days 29-31 are specified, and the month does not have that many days, the audit takes place on the "LAST" day of the month.

Returns:

  • (String)


15473
15474
15475
15476
15477
15478
15479
15480
15481
# File 'lib/aws-sdk-iot/types.rb', line 15473

class ScheduledAuditMetadata < Struct.new(
  :scheduled_audit_name,
  :scheduled_audit_arn,
  :frequency,
  :day_of_month,
  :day_of_week)
  SENSITIVE = []
  include Aws::Structure
end

#day_of_weekString

The day of the week on which the scheduled audit is run (if the frequency is "WEEKLY" or "BIWEEKLY").

Returns:

  • (String)


15473
15474
15475
15476
15477
15478
15479
15480
15481
# File 'lib/aws-sdk-iot/types.rb', line 15473

class ScheduledAuditMetadata < Struct.new(
  :scheduled_audit_name,
  :scheduled_audit_arn,
  :frequency,
  :day_of_month,
  :day_of_week)
  SENSITIVE = []
  include Aws::Structure
end

#frequencyString

How often the scheduled audit occurs.

Returns:

  • (String)


15473
15474
15475
15476
15477
15478
15479
15480
15481
# File 'lib/aws-sdk-iot/types.rb', line 15473

class ScheduledAuditMetadata < Struct.new(
  :scheduled_audit_name,
  :scheduled_audit_arn,
  :frequency,
  :day_of_month,
  :day_of_week)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_audit_arnString

The ARN of the scheduled audit.

Returns:

  • (String)


15473
15474
15475
15476
15477
15478
15479
15480
15481
# File 'lib/aws-sdk-iot/types.rb', line 15473

class ScheduledAuditMetadata < Struct.new(
  :scheduled_audit_name,
  :scheduled_audit_arn,
  :frequency,
  :day_of_month,
  :day_of_week)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_audit_nameString

The name of the scheduled audit.

Returns:

  • (String)


15473
15474
15475
15476
15477
15478
15479
15480
15481
# File 'lib/aws-sdk-iot/types.rb', line 15473

class ScheduledAuditMetadata < Struct.new(
  :scheduled_audit_name,
  :scheduled_audit_arn,
  :frequency,
  :day_of_month,
  :day_of_week)
  SENSITIVE = []
  include Aws::Structure
end