Class: Aws::IoT::Types::SearchIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SearchIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_name ⇒ String
The search index name.
-
#max_results ⇒ Integer
The maximum number of results to return per page at one time.
-
#next_token ⇒ String
The token used to get the next set of results, or ‘null` if there are no additional results.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The query version.
Instance Attribute Details
#index_name ⇒ String
The search index name.
15350 15351 15352 15353 15354 15355 15356 15357 15358 |
# File 'lib/aws-sdk-iot/types.rb', line 15350 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page at one time. This maximum number cannot exceed 100. The response might contain fewer results but will never contain more. You can use [ ‘nextToken` ][1] to retrieve the next set of results until `nextToken` returns `NULL`.
[1]: docs.aws.amazon.com/iot/latest/apireference/API_SearchIndex.html#iot-SearchIndex-request-nextToken
15350 15351 15352 15353 15354 15355 15356 15357 15358 |
# File 'lib/aws-sdk-iot/types.rb', line 15350 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token used to get the next set of results, or ‘null` if there are no additional results.
15350 15351 15352 15353 15354 15355 15356 15357 15358 |
# File 'lib/aws-sdk-iot/types.rb', line 15350 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string. For more information about the search query syntax, see [Query syntax].
[1]: docs.aws.amazon.com/iot/latest/developerguide/query-syntax.html
15350 15351 15352 15353 15354 15355 15356 15357 15358 |
# File 'lib/aws-sdk-iot/types.rb', line 15350 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The query version.
15350 15351 15352 15353 15354 15355 15356 15357 15358 |
# File 'lib/aws-sdk-iot/types.rb', line 15350 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |