Class: Aws::IoT::Types::SearchIndexResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SearchIndexResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token used to get the next set of results, or `null` if there are no additional results.
-
#thing_groups ⇒ Array<Types::ThingGroupDocument>
The thing groups that match the search query.
-
#things ⇒ Array<Types::ThingDocument>
The things that match the search query.
Instance Attribute Details
#next_token ⇒ String
The token used to get the next set of results, or `null` if there are no additional results.
15986 15987 15988 15989 15990 15991 15992 |
# File 'lib/aws-sdk-iot/types.rb', line 15986 class SearchIndexResponse < Struct.new( :next_token, :things, :thing_groups) SENSITIVE = [] include Aws::Structure end |
#thing_groups ⇒ Array<Types::ThingGroupDocument>
The thing groups that match the search query.
15986 15987 15988 15989 15990 15991 15992 |
# File 'lib/aws-sdk-iot/types.rb', line 15986 class SearchIndexResponse < Struct.new( :next_token, :things, :thing_groups) SENSITIVE = [] include Aws::Structure end |
#things ⇒ Array<Types::ThingDocument>
The things that match the search query.
15986 15987 15988 15989 15990 15991 15992 |
# File 'lib/aws-sdk-iot/types.rb', line 15986 class SearchIndexResponse < Struct.new( :next_token, :things, :thing_groups) SENSITIVE = [] include Aws::Structure end |