Class: Aws::IoT::Types::SigV4Authorization
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SigV4Authorization
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass SigV4Authorization data as a hash:
{
signing_region: "SigningRegion", # required
service_name: "ServiceName", # required
role_arn: "AwsArn", # required
}
For more information, see [Signature Version 4 signing process].
[1]: docs.aws.amazon.com/general/latest/gr/signature-version-4.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role_arn ⇒ String
The ARN of the signing role.
-
#service_name ⇒ String
The service name to use while signing with Sig V4.
-
#signing_region ⇒ String
The signing region.
Instance Attribute Details
#role_arn ⇒ String
The ARN of the signing role.
16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16393 class SigV4Authorization < Struct.new( :signing_region, :service_name, :role_arn) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The service name to use while signing with Sig V4.
16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16393 class SigV4Authorization < Struct.new( :signing_region, :service_name, :role_arn) SENSITIVE = [] include Aws::Structure end |
#signing_region ⇒ String
The signing region.
16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16393 class SigV4Authorization < Struct.new( :signing_region, :service_name, :role_arn) SENSITIVE = [] include Aws::Structure end |