Class: Aws::IoT::Types::SnsAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Describes an action to publish to an Amazon SNS topic.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message_formatString

(Optional) The message format of the message to publish. Accepted values are "JSON" and "RAW". The default value of the attribute is "RAW". SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. To read more about SNS message formats, see https://docs.aws.amazon.com/sns/latest/dg/json-formats.html refer to their official documentation.

Returns:

  • (String)


15934
15935
15936
15937
15938
15939
15940
# File 'lib/aws-sdk-iot/types.rb', line 15934

class SnsAction < Struct.new(
  :target_arn,
  :role_arn,
  :message_format)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that grants access.

Returns:

  • (String)


15934
15935
15936
15937
15938
15939
15940
# File 'lib/aws-sdk-iot/types.rb', line 15934

class SnsAction < Struct.new(
  :target_arn,
  :role_arn,
  :message_format)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The ARN of the SNS topic.

Returns:

  • (String)


15934
15935
15936
15937
15938
15939
15940
# File 'lib/aws-sdk-iot/types.rb', line 15934

class SnsAction < Struct.new(
  :target_arn,
  :role_arn,
  :message_format)
  SENSITIVE = []
  include Aws::Structure
end