Class: Aws::IoT::Types::StartDetectMitigationActionsTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::StartDetectMitigationActionsTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass StartDetectMitigationActionsTaskRequest data as a hash:
{
task_id: "MitigationActionsTaskId", # required
target: { # required
violation_ids: ["ViolationId"],
security_profile_name: "SecurityProfileName",
behavior_name: "BehaviorName",
},
actions: ["MitigationActionName"], # required
violation_event_occurrence_range: {
start_time: Time.now, # required
end_time: Time.now, # required
},
include_only_active_violations: false,
include_suppressed_alerts: false,
client_request_token: "ClientRequestToken", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<String>
The actions to be performed when a device has unexpected behavior.
-
#client_request_token ⇒ String
Each mitigation action task must have a unique client request token.
-
#include_only_active_violations ⇒ Boolean
Specifies to list only active violations.
-
#include_suppressed_alerts ⇒ Boolean
Specifies to include suppressed alerts.
-
#target ⇒ Types::DetectMitigationActionsTaskTarget
Specifies the ML Detect findings to which the mitigation actions are applied.
-
#task_id ⇒ String
The unique identifier of the task.
-
#violation_event_occurrence_range ⇒ Types::ViolationEventOccurrenceRange
Specifies the time period of which violation events occurred between.
Instance Attribute Details
#actions ⇒ Array<String>
The actions to be performed when a device has unexpected behavior.
16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 |
# File 'lib/aws-sdk-iot/types.rb', line 16482 class StartDetectMitigationActionsTaskRequest < Struct.new( :task_id, :target, :actions, :violation_event_occurrence_range, :include_only_active_violations, :include_suppressed_alerts, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
Each mitigation action task must have a unique client request token. If you try to create a new task with the same token as a task that already exists, an exception occurs. If you omit this value, Amazon Web Services SDKs will automatically generate a unique client request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 |
# File 'lib/aws-sdk-iot/types.rb', line 16482 class StartDetectMitigationActionsTaskRequest < Struct.new( :task_id, :target, :actions, :violation_event_occurrence_range, :include_only_active_violations, :include_suppressed_alerts, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#include_only_active_violations ⇒ Boolean
Specifies to list only active violations.
16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 |
# File 'lib/aws-sdk-iot/types.rb', line 16482 class StartDetectMitigationActionsTaskRequest < Struct.new( :task_id, :target, :actions, :violation_event_occurrence_range, :include_only_active_violations, :include_suppressed_alerts, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#include_suppressed_alerts ⇒ Boolean
Specifies to include suppressed alerts.
16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 |
# File 'lib/aws-sdk-iot/types.rb', line 16482 class StartDetectMitigationActionsTaskRequest < Struct.new( :task_id, :target, :actions, :violation_event_occurrence_range, :include_only_active_violations, :include_suppressed_alerts, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#target ⇒ Types::DetectMitigationActionsTaskTarget
Specifies the ML Detect findings to which the mitigation actions are applied.
16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 |
# File 'lib/aws-sdk-iot/types.rb', line 16482 class StartDetectMitigationActionsTaskRequest < Struct.new( :task_id, :target, :actions, :violation_event_occurrence_range, :include_only_active_violations, :include_suppressed_alerts, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task.
16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 |
# File 'lib/aws-sdk-iot/types.rb', line 16482 class StartDetectMitigationActionsTaskRequest < Struct.new( :task_id, :target, :actions, :violation_event_occurrence_range, :include_only_active_violations, :include_suppressed_alerts, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#violation_event_occurrence_range ⇒ Types::ViolationEventOccurrenceRange
Specifies the time period of which violation events occurred between.
16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 |
# File 'lib/aws-sdk-iot/types.rb', line 16482 class StartDetectMitigationActionsTaskRequest < Struct.new( :task_id, :target, :actions, :violation_event_occurrence_range, :include_only_active_violations, :include_suppressed_alerts, :client_request_token) SENSITIVE = [] include Aws::Structure end |