Class: Aws::IoT::Types::StartOnDemandAuditTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::StartOnDemandAuditTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_check_names ⇒ Array<String>
Which checks are performed during the audit.
Instance Attribute Details
#target_check_names ⇒ Array<String>
Which checks are performed during the audit. The checks you specify must be enabled for your account or an exception occurs. Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or UpdateAccountAuditConfiguration to select which checks are enabled.
15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-iot/types.rb', line 15746 class StartOnDemandAuditTaskRequest < Struct.new( :target_check_names) SENSITIVE = [] include Aws::Structure end |