Class: Aws::IoT::Types::StatisticalThreshold
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::StatisticalThreshold
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
A statistical ranking (percentile) that indicates a threshold value by which a behavior is determined to be in compliance or in violation of the behavior.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#statistic ⇒ String
The percentile that resolves to a threshold value by which compliance with a behavior is determined.
Instance Attribute Details
#statistic ⇒ String
The percentile that resolves to a threshold value by which compliance with a behavior is determined. Metrics are collected over the specified period (durationSeconds) from all reporting devices in your account and statistical ranks are calculated. Then, the measurements from a device are collected over the same period. If the accumulated measurements from the device fall above or below (comparisonOperator) the value associated with the percentile specified, then the device is considered to be in compliance with the behavior, otherwise a violation occurs.
15837 15838 15839 15840 15841 |
# File 'lib/aws-sdk-iot/types.rb', line 15837 class StatisticalThreshold < Struct.new( :statistic) SENSITIVE = [] include Aws::Structure end |