Class: Aws::IoT::Types::Stream
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::Stream
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass Stream data as a hash:
{
stream_id: "StreamId",
file_id: 1,
}
Describes a group of files that can be streamed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_id ⇒ Integer
The ID of a file associated with a stream.
-
#stream_id ⇒ String
The stream ID.