Class: Aws::IoT::Types::ThingGroupIndexingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ThingGroupIndexingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Thing group indexing configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_fields ⇒ Array<Types::Field>
A list of thing group fields to index.
-
#managed_fields ⇒ Array<Types::Field>
Contains fields that are indexed and whose types are already known by the Fleet Indexing service.
-
#thing_group_indexing_mode ⇒ String
Thing group indexing mode.
Instance Attribute Details
#custom_fields ⇒ Array<Types::Field>
A list of thing group fields to index. This list cannot contain any managed fields. Use the GetIndexingConfiguration API to get a list of managed fields.
Contains custom field names and their data type.
16873 16874 16875 16876 16877 16878 16879 |
# File 'lib/aws-sdk-iot/types.rb', line 16873 class ThingGroupIndexingConfiguration < Struct.new( :thing_group_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#managed_fields ⇒ Array<Types::Field>
Contains fields that are indexed and whose types are already known by the Fleet Indexing service. This is an optional field. For more information, see Managed fields in the Amazon Web Services IoT Core Developer Guide.
16873 16874 16875 16876 16877 16878 16879 |
# File 'lib/aws-sdk-iot/types.rb', line 16873 class ThingGroupIndexingConfiguration < Struct.new( :thing_group_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#thing_group_indexing_mode ⇒ String
Thing group indexing mode.
16873 16874 16875 16876 16877 16878 16879 |
# File 'lib/aws-sdk-iot/types.rb', line 16873 class ThingGroupIndexingConfiguration < Struct.new( :thing_group_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |