Class: Aws::IoT::Types::ThingIndexingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The thing indexing configuration. For more information, see [Managing Thing Indexing].

[1]: docs.aws.amazon.com/iot/latest/developerguide/managing-index.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_fieldsArray<Types::Field>

Contains custom field names and their data type.

Returns:



13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
# File 'lib/aws-sdk-iot/types.rb', line 13915

class ThingIndexingConfiguration < Struct.new(
  :thing_indexing_mode,
  :thing_connectivity_indexing_mode,
  :device_defender_indexing_mode,
  :named_shadow_indexing_mode,
  :managed_fields,
  :custom_fields,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#device_defender_indexing_modeString

Device Defender indexing mode. Valid values are:

  • VIOLATIONS – Your thing index contains Device Defender violations. To enable Device Defender indexing, deviceDefenderIndexingMode must not be set to OFF.

  • OFF - Device Defender indexing is disabled.

For more information about Device Defender violations, see [Device Defender Detect.]

[1]: docs.aws.amazon.com/iot/latest/developerguide/device-defender-detect.html

Returns:

  • (String)


13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
# File 'lib/aws-sdk-iot/types.rb', line 13915

class ThingIndexingConfiguration < Struct.new(
  :thing_indexing_mode,
  :thing_connectivity_indexing_mode,
  :device_defender_indexing_mode,
  :named_shadow_indexing_mode,
  :managed_fields,
  :custom_fields,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#filterTypes::IndexingFilter

Provides additional filters for specific data sources. Named shadow is the only data source that currently supports and requires a filter. To add named shadows to your fleet indexing configuration, set ‘namedShadowIndexingMode` to be `ON` and specify your shadow names in `filter`.



13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
# File 'lib/aws-sdk-iot/types.rb', line 13915

class ThingIndexingConfiguration < Struct.new(
  :thing_indexing_mode,
  :thing_connectivity_indexing_mode,
  :device_defender_indexing_mode,
  :named_shadow_indexing_mode,
  :managed_fields,
  :custom_fields,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#managed_fieldsArray<Types::Field>

Contains fields that are indexed and whose types are already known by the Fleet Indexing service.

Returns:



13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
# File 'lib/aws-sdk-iot/types.rb', line 13915

class ThingIndexingConfiguration < Struct.new(
  :thing_indexing_mode,
  :thing_connectivity_indexing_mode,
  :device_defender_indexing_mode,
  :named_shadow_indexing_mode,
  :managed_fields,
  :custom_fields,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#named_shadow_indexing_modeString

Named shadow indexing mode. Valid values are:

  • ON – Your thing index contains named shadow. To enable thing named shadow indexing, namedShadowIndexingMode must not be set to OFF.

  • OFF - Named shadow indexing is disabled.

For more information about Shadows, see [IoT Device Shadow service.]

[1]: docs.aws.amazon.com/iot/latest/developerguide/iot-device-shadows.html

Returns:

  • (String)


13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
# File 'lib/aws-sdk-iot/types.rb', line 13915

class ThingIndexingConfiguration < Struct.new(
  :thing_indexing_mode,
  :thing_connectivity_indexing_mode,
  :device_defender_indexing_mode,
  :named_shadow_indexing_mode,
  :managed_fields,
  :custom_fields,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#thing_connectivity_indexing_modeString

Thing connectivity indexing mode. Valid values are:

  • STATUS – Your thing index contains connectivity status. To enable thing connectivity indexing, thingIndexMode must not be set to OFF.

  • OFF - Thing connectivity status indexing is disabled.

Returns:

  • (String)


13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
# File 'lib/aws-sdk-iot/types.rb', line 13915

class ThingIndexingConfiguration < Struct.new(
  :thing_indexing_mode,
  :thing_connectivity_indexing_mode,
  :device_defender_indexing_mode,
  :named_shadow_indexing_mode,
  :managed_fields,
  :custom_fields,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#thing_indexing_modeString

Thing indexing mode. Valid values are:

  • REGISTRY – Your thing index contains registry data only.

  • REGISTRY_AND_SHADOW - Your thing index contains registry and shadow data.

  • OFF - Thing indexing is disabled.

Returns:

  • (String)


13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
# File 'lib/aws-sdk-iot/types.rb', line 13915

class ThingIndexingConfiguration < Struct.new(
  :thing_indexing_mode,
  :thing_connectivity_indexing_mode,
  :device_defender_indexing_mode,
  :named_shadow_indexing_mode,
  :managed_fields,
  :custom_fields,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end