Class: Aws::IoT::Types::TimestreamAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::TimestreamAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass TimestreamAction data as a hash:
{
role_arn: "AwsArn", # required
database_name: "TimestreamDatabaseName", # required
table_name: "TimestreamTableName", # required
dimensions: [ # required
{
name: "TimestreamDimensionName", # required
value: "TimestreamDimensionValue", # required
},
],
timestamp: {
value: "TimestreamTimestampValue", # required
unit: "TimestreamTimestampUnit", # required
},
}
The Timestream rule action writes attributes (measures) from an MQTT message into an Amazon Timestream table. For more information, see the
- Timestream][1
-
topic rule action documentation.
[1]: docs.aws.amazon.com/iot/latest/developerguide/timestream-rule-action.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database_name ⇒ String
The name of an Amazon Timestream database.
-
#dimensions ⇒ Array<Types::TimestreamDimension>
Metadata attributes of the time series that are written in each measure record.
-
#role_arn ⇒ String
The ARN of the role that grants permission to write to the Amazon Timestream database table.
-
#table_name ⇒ String
The name of the database table into which to write the measure records.
-
#timestamp ⇒ Types::TimestreamTimestamp
Specifies an application-defined value to replace the default value assigned to the Timestream record's timestamp in the `time` column.
Instance Attribute Details
#database_name ⇒ String
The name of an Amazon Timestream database.
17912 17913 17914 17915 17916 17917 17918 17919 17920 |
# File 'lib/aws-sdk-iot/types.rb', line 17912 class TimestreamAction < Struct.new( :role_arn, :database_name, :table_name, :dimensions, :timestamp) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Array<Types::TimestreamDimension>
Metadata attributes of the time series that are written in each measure record.
17912 17913 17914 17915 17916 17917 17918 17919 17920 |
# File 'lib/aws-sdk-iot/types.rb', line 17912 class TimestreamAction < Struct.new( :role_arn, :database_name, :table_name, :dimensions, :timestamp) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the role that grants permission to write to the Amazon Timestream database table.
17912 17913 17914 17915 17916 17917 17918 17919 17920 |
# File 'lib/aws-sdk-iot/types.rb', line 17912 class TimestreamAction < Struct.new( :role_arn, :database_name, :table_name, :dimensions, :timestamp) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the database table into which to write the measure records.
17912 17913 17914 17915 17916 17917 17918 17919 17920 |
# File 'lib/aws-sdk-iot/types.rb', line 17912 class TimestreamAction < Struct.new( :role_arn, :database_name, :table_name, :dimensions, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Types::TimestreamTimestamp
Specifies an application-defined value to replace the default value assigned to the Timestream record's timestamp in the `time` column.
You can use this property to specify the value and the precision of the Timestream record's timestamp. You can specify a value from the message payload or a value computed by a substitution template.
If omitted, the topic rule action assigns the timestamp, in milliseconds, at the time it processed the rule.
17912 17913 17914 17915 17916 17917 17918 17919 17920 |
# File 'lib/aws-sdk-iot/types.rb', line 17912 class TimestreamAction < Struct.new( :role_arn, :database_name, :table_name, :dimensions, :timestamp) SENSITIVE = [] include Aws::Structure end |