Class: Aws::IoT::Types::TimestreamDimension

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass TimestreamDimension data as a hash:

{
  name: "TimestreamDimensionName", # required
  value: "TimestreamDimensionValue", # required
}

Metadata attributes of the time series that are written in each measure record.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The metadata dimension name. This is the name of the column in the Amazon Timestream database table record.

Dimensions cannot be named: `measure_name`, `measure_value`, or `time`. These names are reserved. Dimension names cannot start with `ts_` or `measure_value` and they cannot contain the colon (`:`) character.

Returns:

  • (String)


18033
18034
18035
18036
18037
18038
# File 'lib/aws-sdk-iot/types.rb', line 18033

class TimestreamDimension < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value to write in this column of the database record.

Returns:

  • (String)


18033
18034
18035
18036
18037
18038
# File 'lib/aws-sdk-iot/types.rb', line 18033

class TimestreamDimension < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end