Class: Aws::IoT::Types::TimestreamTimestamp

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass TimestreamTimestamp data as a hash:

{
  value: "TimestreamTimestampValue", # required
  unit: "TimestreamTimestampUnit", # required
}

Describes how to interpret an application-defined timestamp value from an MQTT message payload and the precision of that value.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unitString

The precision of the timestamp value that results from the expression described in `value`.

Valid values: `SECONDS` | `MILLISECONDS` | `MICROSECONDS` | `NANOSECONDS`. The default is `MILLISECONDS`.

Returns:

  • (String)


18105
18106
18107
18108
18109
18110
# File 'lib/aws-sdk-iot/types.rb', line 18105

class TimestreamTimestamp < Struct.new(
  :value,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

An expression that returns a long epoch time value.

Returns:

  • (String)


18105
18106
18107
18108
18109
18110
# File 'lib/aws-sdk-iot/types.rb', line 18105

class TimestreamTimestamp < Struct.new(
  :value,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end