Class: Aws::IoT::Types::TopicRuleDestinationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Information about the topic rule destination.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The topic rule destination ARN.

Returns:

  • (String)


17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the topic rule destination was created.

Returns:

  • (Time)


17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end

#http_url_summaryTypes::HttpUrlDestinationSummary

Information about the HTTP URL.



17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end

#influx_db_summaryTypes::InfluxDBDestinationSummary

A summary of an InfluxDB topic rule destination, as returned by ListTopicRuleDestinations.



17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time when the topic rule destination was last updated.

Returns:

  • (Time)


17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the topic rule destination. Valid values are:

IN_PROGRESS

: A topic rule destination was created but has not been confirmed. You can set status to IN_PROGRESS by calling UpdateTopicRuleDestination. Calling UpdateTopicRuleDestination causes a new confirmation challenge to be sent to your confirmation endpoint.

ENABLED

: Confirmation was completed, and traffic to this destination is allowed. You can set status to DISABLED by calling UpdateTopicRuleDestination.

DISABLED

: Confirmation was completed, and traffic to this destination is not allowed. You can set status to ENABLED by calling UpdateTopicRuleDestination.

ERROR

: Confirmation could not be completed, for example if the confirmation timed out. You can call GetTopicRuleDestination for details about the error. You can set status to IN_PROGRESS by calling UpdateTopicRuleDestination. Calling UpdateTopicRuleDestination causes a new confirmation challenge to be sent to your confirmation endpoint.

Returns:

  • (String)


17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The reason the topic rule destination is in the current status.

Returns:

  • (String)


17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_destination_summaryTypes::VpcDestinationSummary

Information about the virtual private cloud (VPC) connection.



17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/aws-sdk-iot/types.rb', line 17543

class TopicRuleDestinationSummary < Struct.new(
  :arn,
  :status,
  :created_at,
  :last_updated_at,
  :status_reason,
  :http_url_summary,
  :vpc_destination_summary,
  :influx_db_summary)
  SENSITIVE = []
  include Aws::Structure
end