Class: Aws::IoT::Types::TopicRulePayload
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::TopicRulePayload
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes a rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::Action>
The actions associated with the rule.
-
#aws_iot_sql_version ⇒ String
The version of the SQL rules engine to use when evaluating the rule.
-
#description ⇒ String
The description of the rule.
-
#error_action ⇒ Types::Action
The action to take when an error occurs.
-
#rule_disabled ⇒ Boolean
Specifies whether the rule is disabled.
-
#sql ⇒ String
The SQL statement used to query the topic.
Instance Attribute Details
#actions ⇒ Array<Types::Action>
The actions associated with the rule.
17619 17620 17621 17622 17623 17624 17625 17626 17627 17628 |
# File 'lib/aws-sdk-iot/types.rb', line 17619 class TopicRulePayload < Struct.new( :sql, :description, :actions, :rule_disabled, :aws_iot_sql_version, :error_action) SENSITIVE = [] include Aws::Structure end |
#aws_iot_sql_version ⇒ String
The version of the SQL rules engine to use when evaluating the rule.
17619 17620 17621 17622 17623 17624 17625 17626 17627 17628 |
# File 'lib/aws-sdk-iot/types.rb', line 17619 class TopicRulePayload < Struct.new( :sql, :description, :actions, :rule_disabled, :aws_iot_sql_version, :error_action) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the rule.
17619 17620 17621 17622 17623 17624 17625 17626 17627 17628 |
# File 'lib/aws-sdk-iot/types.rb', line 17619 class TopicRulePayload < Struct.new( :sql, :description, :actions, :rule_disabled, :aws_iot_sql_version, :error_action) SENSITIVE = [] include Aws::Structure end |
#error_action ⇒ Types::Action
The action to take when an error occurs.
17619 17620 17621 17622 17623 17624 17625 17626 17627 17628 |
# File 'lib/aws-sdk-iot/types.rb', line 17619 class TopicRulePayload < Struct.new( :sql, :description, :actions, :rule_disabled, :aws_iot_sql_version, :error_action) SENSITIVE = [] include Aws::Structure end |
#rule_disabled ⇒ Boolean
Specifies whether the rule is disabled.
17619 17620 17621 17622 17623 17624 17625 17626 17627 17628 |
# File 'lib/aws-sdk-iot/types.rb', line 17619 class TopicRulePayload < Struct.new( :sql, :description, :actions, :rule_disabled, :aws_iot_sql_version, :error_action) SENSITIVE = [] include Aws::Structure end |
#sql ⇒ String
The SQL statement used to query the topic. For more information, see IoT SQL Reference in the IoT Developer Guide.
17619 17620 17621 17622 17623 17624 17625 17626 17627 17628 |
# File 'lib/aws-sdk-iot/types.rb', line 17619 class TopicRulePayload < Struct.new( :sql, :description, :actions, :rule_disabled, :aws_iot_sql_version, :error_action) SENSITIVE = [] include Aws::Structure end |