Class: Aws::IoT::Types::UpdateAccountAuditConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateAccountAuditConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass UpdateAccountAuditConfigurationRequest data as a hash:
{
role_arn: "RoleArn",
audit_notification_target_configurations: {
"SNS" => {
target_arn: "TargetArn",
role_arn: "RoleArn",
enabled: false,
},
},
audit_check_configurations: {
"AuditCheckName" => {
enabled: false,
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_check_configurations ⇒ Hash<String,Types::AuditCheckConfiguration>
Specifies which audit checks are enabled and disabled for this account.
-
#audit_notification_target_configurations ⇒ Hash<String,Types::AuditNotificationTarget>
Information about the targets to which audit notifications are sent.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that grants permission to IoT to access information about your devices, policies, certificates, and other items as required when performing an audit.
Instance Attribute Details
#audit_check_configurations ⇒ Hash<String,Types::AuditCheckConfiguration>
Specifies which audit checks are enabled and disabled for this account. Use `DescribeAccountAuditConfiguration` to see the list of all checks, including those that are currently enabled.
Some data collection might start immediately when certain checks are enabled. When a check is disabled, any data collected so far in relation to the check is deleted.
You cannot disable a check if it's used by any scheduled audit. You must first delete the check from the scheduled audit or delete the scheduled audit itself.
On the first call to `UpdateAccountAuditConfiguration`, this parameter is required and must specify at least one enabled check.
18785 18786 18787 18788 18789 18790 18791 |
# File 'lib/aws-sdk-iot/types.rb', line 18785 class UpdateAccountAuditConfigurationRequest < Struct.new( :role_arn, :audit_notification_target_configurations, :audit_check_configurations) SENSITIVE = [] include Aws::Structure end |
#audit_notification_target_configurations ⇒ Hash<String,Types::AuditNotificationTarget>
Information about the targets to which audit notifications are sent.
18785 18786 18787 18788 18789 18790 18791 |
# File 'lib/aws-sdk-iot/types.rb', line 18785 class UpdateAccountAuditConfigurationRequest < Struct.new( :role_arn, :audit_notification_target_configurations, :audit_check_configurations) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that grants permission to IoT to access information about your devices, policies, certificates, and other items as required when performing an audit.
18785 18786 18787 18788 18789 18790 18791 |
# File 'lib/aws-sdk-iot/types.rb', line 18785 class UpdateAccountAuditConfigurationRequest < Struct.new( :role_arn, :audit_notification_target_configurations, :audit_check_configurations) SENSITIVE = [] include Aws::Structure end |