Class: Aws::IoT::Types::UpdateAuditSuppressionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#check_nameString

An audit check name. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.)

Returns:

  • (String)


17814
17815
17816
17817
17818
17819
17820
17821
17822
# File 'lib/aws-sdk-iot/types.rb', line 17814

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the audit suppression.

Returns:

  • (String)


17814
17815
17816
17817
17818
17819
17820
17821
17822
# File 'lib/aws-sdk-iot/types.rb', line 17814

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_dateTime

The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.

Returns:

  • (Time)


17814
17815
17816
17817
17818
17819
17820
17821
17822
# File 'lib/aws-sdk-iot/types.rb', line 17814

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifierTypes::ResourceIdentifier

Information that identifies the noncompliant resource.



17814
17815
17816
17817
17818
17819
17820
17821
17822
# File 'lib/aws-sdk-iot/types.rb', line 17814

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#suppress_indefinitelyBoolean

Indicates whether a suppression should exist indefinitely or not.

Returns:

  • (Boolean)


17814
17815
17816
17817
17818
17819
17820
17821
17822
# File 'lib/aws-sdk-iot/types.rb', line 17814

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end