Class: Aws::IoT::Types::UpdateBillingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_group_nameString

The name of the billing group.

Returns:

  • (String)


17893
17894
17895
17896
17897
17898
17899
# File 'lib/aws-sdk-iot/types.rb', line 17893

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#billing_group_propertiesTypes::BillingGroupProperties

The properties of the billing group.



17893
17894
17895
17896
17897
17898
17899
# File 'lib/aws-sdk-iot/types.rb', line 17893

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#expected_versionInteger

The expected version of the billing group. If the version of the billing group does not match the expected version specified in the request, the UpdateBillingGroup request is rejected with a VersionConflictException.

Returns:

  • (Integer)


17893
17894
17895
17896
17897
17898
17899
# File 'lib/aws-sdk-iot/types.rb', line 17893

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end