Method: Aws::IoT::Types::UpdateBillingGroupRequest#expected_version

Defined in:
lib/aws-sdk-iot/types.rb

#expected_versionInteger

The expected version of the billing group. If the version of the billing group does not match the expected version specified in the request, the UpdateBillingGroup request is rejected with a VersionConflictException.

Returns:

  • (Integer)


17510
17511
17512
17513
17514
17515
17516
# File 'lib/aws-sdk-iot/types.rb', line 17510

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end