Class: Aws::IoT::Types::UpdateCACertificateParams

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Parameters to define a mitigation action that changes the state of the CA certificate to inactive.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action that you want to apply to the CA certificate. The only supported value is ‘DEACTIVATE`.

Returns:

  • (String)


14715
14716
14717
14718
14719
# File 'lib/aws-sdk-iot/types.rb', line 14715

class UpdateCACertificateParams < Struct.new(
  :action)
  SENSITIVE = []
  include Aws::Structure
end