Class: Aws::IoT::Types::UpdateDeviceCertificateParams

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Parameters to define a mitigation action that changes the state of the device certificate to inactive.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action that you want to apply to the device certificate. The only supported value is DEACTIVATE.

Returns:

  • (String)


18147
18148
18149
18150
18151
# File 'lib/aws-sdk-iot/types.rb', line 18147

class UpdateDeviceCertificateParams < Struct.new(
  :action)
  SENSITIVE = []
  include Aws::Structure
end