Class: Aws::IoT::Types::UpdateDimensionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateDimensionRequest data as a hash:

{
  name: "DimensionName", # required
  string_values: ["DimensionStringValue"], # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

A unique identifier for the dimension. Choose something that describes the type and value to make it easy to remember what it does.

Returns:

  • (String)


19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-iot/types.rb', line 19366

class UpdateDimensionRequest < Struct.new(
  :name,
  :string_values)
  SENSITIVE = []
  include Aws::Structure
end

#string_valuesArray<String>

Specifies the value or list of values for the dimension. For `TOPIC_FILTER` dimensions, this is a pattern used to match the MQTT topic (for example, “admin/#”).

Returns:

  • (Array<String>)


19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-iot/types.rb', line 19366

class UpdateDimensionRequest < Struct.new(
  :name,
  :string_values)
  SENSITIVE = []
  include Aws::Structure
end