Class: Aws::IoT::Types::UpdateDimensionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN)of the created dimension.



18200
18201
18202
18203
18204
18205
18206
18207
18208
18209
# File 'lib/aws-sdk-iot/types.rb', line 18200

class UpdateDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time, in milliseconds since epoch, when the dimension was initially created.



18200
18201
18202
18203
18204
18205
18206
18207
18208
18209
# File 'lib/aws-sdk-iot/types.rb', line 18200

class UpdateDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date and time, in milliseconds since epoch, when the dimension was most recently updated.



18200
18201
18202
18203
18204
18205
18206
18207
18208
18209
# File 'lib/aws-sdk-iot/types.rb', line 18200

class UpdateDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A unique identifier for the dimension.



18200
18201
18202
18203
18204
18205
18206
18207
18208
18209
# File 'lib/aws-sdk-iot/types.rb', line 18200

class UpdateDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#string_valuesArray<String>

The value or list of values used to scope the dimension. For example, for topic filters, this is the pattern used to match the MQTT topic name.



18200
18201
18202
18203
18204
18205
18206
18207
18208
18209
# File 'lib/aws-sdk-iot/types.rb', line 18200

class UpdateDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the dimension.



18200
18201
18202
18203
18204
18205
18206
18207
18208
18209
# File 'lib/aws-sdk-iot/types.rb', line 18200

class UpdateDimensionResponse < Struct.new(
  :name,
  :arn,
  :type,
  :string_values,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end