Class: Aws::IoT::Types::UpdateDomainConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizer_configTypes::AuthorizerConfig

An object that specifies the authorization service for a domain.



15918
15919
15920
15921
15922
15923
15924
15925
15926
# File 'lib/aws-sdk-iot/types.rb', line 15918

class UpdateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :authorizer_config,
  :domain_configuration_status,
  :remove_authorizer_config,
  :tls_config)
  SENSITIVE = []
  include Aws::Structure
end

#domain_configuration_nameString

The name of the domain configuration to be updated.

Returns:

  • (String)


15918
15919
15920
15921
15922
15923
15924
15925
15926
# File 'lib/aws-sdk-iot/types.rb', line 15918

class UpdateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :authorizer_config,
  :domain_configuration_status,
  :remove_authorizer_config,
  :tls_config)
  SENSITIVE = []
  include Aws::Structure
end

#domain_configuration_statusString

The status to which the domain configuration should be updated.

Returns:

  • (String)


15918
15919
15920
15921
15922
15923
15924
15925
15926
# File 'lib/aws-sdk-iot/types.rb', line 15918

class UpdateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :authorizer_config,
  :domain_configuration_status,
  :remove_authorizer_config,
  :tls_config)
  SENSITIVE = []
  include Aws::Structure
end

#remove_authorizer_configBoolean

Removes the authorization configuration from a domain.

Returns:

  • (Boolean)


15918
15919
15920
15921
15922
15923
15924
15925
15926
# File 'lib/aws-sdk-iot/types.rb', line 15918

class UpdateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :authorizer_config,
  :domain_configuration_status,
  :remove_authorizer_config,
  :tls_config)
  SENSITIVE = []
  include Aws::Structure
end

#tls_configTypes::TlsConfig

An object that specifies the TLS configuration for a domain.

Returns:



15918
15919
15920
15921
15922
15923
15924
15925
15926
# File 'lib/aws-sdk-iot/types.rb', line 15918

class UpdateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :authorizer_config,
  :domain_configuration_status,
  :remove_authorizer_config,
  :tls_config)
  SENSITIVE = []
  include Aws::Structure
end