Class: Aws::IoT::Types::UpdateFleetMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateFleetMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_field ⇒ String
The field to aggregate.
-
#aggregation_type ⇒ Types::AggregationType
The type of the aggregation query.
-
#description ⇒ String
The description of the fleet metric.
-
#expected_version ⇒ Integer
The expected version of the fleet metric record in the registry.
-
#index_name ⇒ String
The name of the index to search.
-
#metric_name ⇒ String
The name of the fleet metric to update.
-
#period ⇒ Integer
The time in seconds between fleet metric emissions.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The version of the query.
-
#unit ⇒ String
Used to support unit transformation such as milliseconds to seconds.
Instance Attribute Details
#aggregation_field ⇒ String
The field to aggregate.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#aggregation_type ⇒ Types::AggregationType
The type of the aggregation query.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the fleet metric.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#expected_version ⇒ Integer
The expected version of the fleet metric record in the registry.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to search.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the fleet metric to update.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The time in seconds between fleet metric emissions. Range [60(1 min), 86400(1 day)] and must be multiple of 60.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The version of the query.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
Used to support unit transformation such as milliseconds to seconds. The unit must be supported by CW metric.
18476 18477 18478 18479 18480 18481 18482 18483 18484 18485 18486 18487 18488 18489 |
# File 'lib/aws-sdk-iot/types.rb', line 18476 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |