Class: Aws::IoT::Types::UpdateJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateJobRequest data as a hash:

{
  job_id: "JobId", # required
  description: "JobDescription",
  presigned_url_config: {
    role_arn: "RoleArn",
    expires_in_sec: 1,
  },
  job_executions_rollout_config: {
    maximum_per_minute: 1,
    exponential_rate: {
      base_rate_per_minute: 1, # required
      increment_factor: 1.0, # required
      rate_increase_criteria: { # required
        number_of_notified_things: 1,
        number_of_succeeded_things: 1,
      },
    },
  },
  abort_config: {
    criteria_list: [ # required
      {
        failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
        action: "CANCEL", # required, accepts CANCEL
        threshold_percentage: 1.0, # required
        min_number_of_executed_things: 1, # required
      },
    ],
  },
  timeout_config: {
    in_progress_timeout_in_minutes: 1,
  },
  namespace_id: "NamespaceId",
  job_executions_retry_config: {
    criteria_list: [ # required
      {
        failure_type: "FAILED", # required, accepts FAILED, TIMED_OUT, ALL
        number_of_retries: 1, # required
      },
    ],
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#abort_configTypes::AbortConfig

Allows you to create criteria to abort a job.

Returns:



19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A short text description of the job.

Returns:

  • (String)


19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_retry_configTypes::JobExecutionsRetryConfig

Allows you to create the criteria to retry a job.



19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_rollout_configTypes::JobExecutionsRolloutConfig

Allows you to create a staged rollout of the job.



19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The ID of the job to be updated.

Returns:

  • (String)


19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#namespace_idString

The namespace used to indicate that a job is a customer-managed job.

When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.

`$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`

<note markdown=“1”> The `namespaceId` feature is in public preview.

</note>

Returns:

  • (String)


19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#presigned_url_configTypes::PresignedUrlConfig

Configuration information for pre-signed S3 URLs.



19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_configTypes::TimeoutConfig

Specifies the amount of time each device has to finish its execution of the job. The timer is started when the job execution status is set to `IN_PROGRESS`. If the job execution status is not set to another terminal state before the time expires, it will be automatically set to `TIMED_OUT`.



19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
# File 'lib/aws-sdk-iot/types.rb', line 19842

class UpdateJobRequest < Struct.new(
  :job_id,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :namespace_id,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end