Class: Aws::IoT::Types::UpdateMitigationActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateMitigationActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_name ⇒ String
The friendly name for the mitigation action.
-
#action_params ⇒ Types::MitigationActionParams
Defines the type of action and the parameters for that action.
-
#role_arn ⇒ String
The ARN of the IAM role that is used to apply the mitigation action.
Instance Attribute Details
#action_name ⇒ String
The friendly name for the mitigation action. You cannot change the
name by using UpdateMitigationAction. Instead, you must delete and
recreate the mitigation action with the new name.
18587 18588 18589 18590 18591 18592 18593 |
# File 'lib/aws-sdk-iot/types.rb', line 18587 class UpdateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params) SENSITIVE = [] include Aws::Structure end |
#action_params ⇒ Types::MitigationActionParams
Defines the type of action and the parameters for that action.
18587 18588 18589 18590 18591 18592 18593 |
# File 'lib/aws-sdk-iot/types.rb', line 18587 class UpdateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that is used to apply the mitigation action.
18587 18588 18589 18590 18591 18592 18593 |
# File 'lib/aws-sdk-iot/types.rb', line 18587 class UpdateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params) SENSITIVE = [] include Aws::Structure end |