Class: Aws::IoT::Types::UpdateProvisioningTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateProvisioningTemplateRequest data as a hash:

{
  template_name: "TemplateName", # required
  description: "TemplateDescription",
  enabled: false,
  default_version_id: 1,
  provisioning_role_arn: "RoleArn",
  pre_provisioning_hook: {
    payload_version: "PayloadVersion",
    target_arn: "TargetArn", # required
  },
  remove_pre_provisioning_hook: false,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_version_idInteger

The ID of the default provisioning template version.

Returns:

  • (Integer)


20588
20589
20590
20591
20592
20593
20594
20595
20596
20597
20598
# File 'lib/aws-sdk-iot/types.rb', line 20588

class UpdateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :enabled,
  :default_version_id,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :remove_pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the provisioning template.

Returns:

  • (String)


20588
20589
20590
20591
20592
20593
20594
20595
20596
20597
20598
# File 'lib/aws-sdk-iot/types.rb', line 20588

class UpdateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :enabled,
  :default_version_id,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :remove_pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

True to enable the provisioning template, otherwise false.

Returns:

  • (Boolean)


20588
20589
20590
20591
20592
20593
20594
20595
20596
20597
20598
# File 'lib/aws-sdk-iot/types.rb', line 20588

class UpdateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :enabled,
  :default_version_id,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :remove_pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#pre_provisioning_hookTypes::ProvisioningHook

Updates the pre-provisioning hook template. Only supports template of type `FLEET_PROVISIONING`. For more information about provisioning template types, see [type].

[1]: docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningTemplate.html#iot-CreateProvisioningTemplate-request-type



20588
20589
20590
20591
20592
20593
20594
20595
20596
20597
20598
# File 'lib/aws-sdk-iot/types.rb', line 20588

class UpdateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :enabled,
  :default_version_id,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :remove_pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#provisioning_role_arnString

The ARN of the role associated with the provisioning template. This IoT role grants permission to provision a device.

Returns:

  • (String)


20588
20589
20590
20591
20592
20593
20594
20595
20596
20597
20598
# File 'lib/aws-sdk-iot/types.rb', line 20588

class UpdateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :enabled,
  :default_version_id,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :remove_pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#remove_pre_provisioning_hookBoolean

Removes pre-provisioning hook template.

Returns:

  • (Boolean)


20588
20589
20590
20591
20592
20593
20594
20595
20596
20597
20598
# File 'lib/aws-sdk-iot/types.rb', line 20588

class UpdateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :enabled,
  :default_version_id,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :remove_pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the provisioning template.

Returns:

  • (String)


20588
20589
20590
20591
20592
20593
20594
20595
20596
20597
20598
# File 'lib/aws-sdk-iot/types.rb', line 20588

class UpdateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :enabled,
  :default_version_id,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :remove_pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end