Class: Aws::IoT::Types::UpdateScheduledAuditRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateScheduledAuditRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#day_of_month ⇒ String
The day of the month on which the scheduled audit takes place.
-
#day_of_week ⇒ String
The day of the week on which the scheduled audit takes place.
-
#frequency ⇒ String
How often the scheduled audit takes place, either
DAILY,WEEKLY,BIWEEKLY, orMONTHLY. -
#scheduled_audit_name ⇒ String
The name of the scheduled audit.
-
#target_check_names ⇒ Array<String>
Which checks are performed during the scheduled audit.
Instance Attribute Details
#day_of_month ⇒ String
The day of the month on which the scheduled audit takes place. This can be 1 through 31 or LAST. This field is required if the frequency parameter is set to MONTHLY. If days 29-31 are specified, and the month does not have that many days, the audit takes place on the “LAST” day of the month.
18482 18483 18484 18485 18486 18487 18488 18489 18490 |
# File 'lib/aws-sdk-iot/types.rb', line 18482 class UpdateScheduledAuditRequest < Struct.new( :frequency, :day_of_month, :day_of_week, :target_check_names, :scheduled_audit_name) SENSITIVE = [] include Aws::Structure end |
#day_of_week ⇒ String
The day of the week on which the scheduled audit takes place. This can be one of SUN, MON, TUE, WED, THU, FRI, or SAT. This field is required if the “frequency” parameter is set to WEEKLY or BIWEEKLY.
18482 18483 18484 18485 18486 18487 18488 18489 18490 |
# File 'lib/aws-sdk-iot/types.rb', line 18482 class UpdateScheduledAuditRequest < Struct.new( :frequency, :day_of_month, :day_of_week, :target_check_names, :scheduled_audit_name) SENSITIVE = [] include Aws::Structure end |
#frequency ⇒ String
How often the scheduled audit takes place, either DAILY, WEEKLY, BIWEEKLY, or MONTHLY. The start time of each audit is determined by the system.
18482 18483 18484 18485 18486 18487 18488 18489 18490 |
# File 'lib/aws-sdk-iot/types.rb', line 18482 class UpdateScheduledAuditRequest < Struct.new( :frequency, :day_of_month, :day_of_week, :target_check_names, :scheduled_audit_name) SENSITIVE = [] include Aws::Structure end |
#scheduled_audit_name ⇒ String
The name of the scheduled audit. (Max. 128 chars)
18482 18483 18484 18485 18486 18487 18488 18489 18490 |
# File 'lib/aws-sdk-iot/types.rb', line 18482 class UpdateScheduledAuditRequest < Struct.new( :frequency, :day_of_month, :day_of_week, :target_check_names, :scheduled_audit_name) SENSITIVE = [] include Aws::Structure end |
#target_check_names ⇒ Array<String>
Which checks are performed during the scheduled audit. Checks must be enabled for your account. (Use DescribeAccountAuditConfiguration to see the list of all checks, including those that are enabled or use UpdateAccountAuditConfiguration to select which checks are enabled.)
18482 18483 18484 18485 18486 18487 18488 18489 18490 |
# File 'lib/aws-sdk-iot/types.rb', line 18482 class UpdateScheduledAuditRequest < Struct.new( :frequency, :day_of_month, :day_of_week, :target_check_names, :scheduled_audit_name) SENSITIVE = [] include Aws::Structure end |