Class: Aws::IoT::Types::UpdateSecurityProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateSecurityProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_metrics_to_retain ⇒ Array<String>
*Please use UpdateSecurityProfileRequest$additionalMetricsToRetainV2 instead.*.
-
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored).
-
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Where the alerts are sent.
-
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
-
#delete_additional_metrics_to_retain ⇒ Boolean
If true, delete all ‘additionalMetricsToRetain` defined for this security profile.
-
#delete_alert_targets ⇒ Boolean
If true, delete all ‘alertTargets` defined for this security profile.
-
#delete_behaviors ⇒ Boolean
If true, delete all ‘behaviors` defined for this security profile.
-
#expected_version ⇒ Integer
The expected version of the security profile.
-
#security_profile_description ⇒ String
A description of the security profile.
-
#security_profile_name ⇒ String
The name of the security profile you want to update.
Instance Attribute Details
#additional_metrics_to_retain ⇒ Array<String>
*Please use UpdateSecurityProfileRequest$additionalMetricsToRetainV2 instead.*
A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s ‘behaviors`, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Where the alerts are sent. (Alerts are always sent to the console.)
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#delete_additional_metrics_to_retain ⇒ Boolean
If true, delete all ‘additionalMetricsToRetain` defined for this security profile. If any `additionalMetricsToRetain` are defined in the current invocation, an exception occurs.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#delete_alert_targets ⇒ Boolean
If true, delete all ‘alertTargets` defined for this security profile. If any `alertTargets` are defined in the current invocation, an exception occurs.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#delete_behaviors ⇒ Boolean
If true, delete all ‘behaviors` defined for this security profile. If any `behaviors` are defined in the current invocation, an exception occurs.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#expected_version ⇒ Integer
The expected version of the security profile. A new version is generated whenever the security profile is updated. If you specify a value that is different from the actual version, a ‘VersionConflictException` is thrown.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#security_profile_description ⇒ String
A description of the security profile.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |
#security_profile_name ⇒ String
The name of the security profile you want to update.
16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 |
# File 'lib/aws-sdk-iot/types.rb', line 16178 class UpdateSecurityProfileRequest < Struct.new( :security_profile_name, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :delete_behaviors, :delete_alert_targets, :delete_additional_metrics_to_retain, :expected_version) SENSITIVE = [] include Aws::Structure end |