Method: Aws::IoT::Types::UpdateSecurityProfileRequest#expected_version

Defined in:
lib/aws-sdk-iot/types.rb

#expected_versionInteger

The expected version of the security profile. A new version is generated whenever the security profile is updated. If you specify a value that is different from the actual version, a VersionConflictException is thrown.



18570
18571
18572
18573
18574
18575
18576
18577
18578
18579
18580
18581
18582
18583
18584
18585
# File 'lib/aws-sdk-iot/types.rb', line 18570

class UpdateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :delete_behaviors,
  :delete_alert_targets,
  :delete_additional_metrics_to_retain,
  :expected_version,
  :metrics_export_config,
  :delete_metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end