Class: Aws::IoT::Types::UpdateThingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_versionInteger

The expected version of the thing group. If this does not match the version of the thing group being updated, the update will fail.



19103
19104
19105
19106
19107
19108
19109
# File 'lib/aws-sdk-iot/types.rb', line 19103

class UpdateThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#thing_group_nameString

The thing group to update.



19103
19104
19105
19106
19107
19108
19109
# File 'lib/aws-sdk-iot/types.rb', line 19103

class UpdateThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#thing_group_propertiesTypes::ThingGroupProperties

The thing group properties.



19103
19104
19105
19106
19107
19108
19109
# File 'lib/aws-sdk-iot/types.rb', line 19103

class UpdateThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end