Class: Aws::IoT::Types::UpdateTopicRuleDestinationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the topic rule destination.

Returns:

  • (String)


18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-iot/types.rb', line 18998

class UpdateTopicRuleDestinationRequest < Struct.new(
  :arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the topic rule destination. Valid values are:

IN_PROGRESS

: A topic rule destination was created but has not been confirmed. You can set status to IN_PROGRESS by calling UpdateTopicRuleDestination. Calling UpdateTopicRuleDestination causes a new confirmation challenge to be sent to your confirmation endpoint.

ENABLED

: Confirmation was completed, and traffic to this destination is allowed. You can set status to DISABLED by calling UpdateTopicRuleDestination.

DISABLED

: Confirmation was completed, and traffic to this destination is not allowed. You can set status to ENABLED by calling UpdateTopicRuleDestination.

ERROR

: Confirmation could not be completed, for example if the confirmation timed out. You can call GetTopicRuleDestination for details about the error. You can set status to IN_PROGRESS by calling UpdateTopicRuleDestination. Calling UpdateTopicRuleDestination causes a new confirmation challenge to be sent to your confirmation endpoint.

Returns:

  • (String)


18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-iot/types.rb', line 18998

class UpdateTopicRuleDestinationRequest < Struct.new(
  :arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end