Class: Aws::IoT::Types::ValidateSecurityProfileBehaviorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ValidateSecurityProfileBehaviorsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass ValidateSecurityProfileBehaviorsRequest data as a hash:
{
behaviors: [ # required
{
name: "BehaviorName", # required
metric: "BehaviorMetric",
metric_dimension: {
dimension_name: "DimensionName", # required
operator: "IN", # accepts IN, NOT_IN
},
criteria: {
comparison_operator: "less-than", # accepts less-than, less-than-equals, greater-than, greater-than-equals, in-cidr-set, not-in-cidr-set, in-port-set, not-in-port-set, in-set, not-in-set
value: {
count: 1,
cidrs: ["Cidr"],
ports: [1],
number: 1.0,
numbers: [1.0],
strings: ["stringValue"],
},
duration_seconds: 1,
consecutive_datapoints_to_alarm: 1,
consecutive_datapoints_to_clear: 1,
statistical_threshold: {
statistic: "EvaluationStatistic",
},
ml_detection_config: {
confidence_level: "LOW", # required, accepts LOW, MEDIUM, HIGH
},
},
suppress_alerts: false,
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
Instance Attribute Details
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
20515 20516 20517 20518 20519 |
# File 'lib/aws-sdk-iot/types.rb', line 20515 class ValidateSecurityProfileBehaviorsRequest < Struct.new( :behaviors) SENSITIVE = [] include Aws::Structure end |