Class: Aws::IoT::Types::Action

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Describes the actions associated with a rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloudwatch_alarmTypes::CloudwatchAlarmAction

Change the state of a CloudWatch alarm.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#cloudwatch_logsTypes::CloudwatchLogsAction

Send data to CloudWatch Logs.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#cloudwatch_metricTypes::CloudwatchMetricAction

Capture a CloudWatch metric.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#dynamo_d_bv_2Types::DynamoDBv2Action

Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#dynamo_dbTypes::DynamoDBAction

Write to a DynamoDB table.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#elasticsearchTypes::ElasticsearchAction

Write data to an Amazon OpenSearch Service domain.

The Elasticsearch action can only be used by existing rule actions. To create a new rule action or to update an existing rule action, use the OpenSearch rule action instead. For more information, see OpenSearchAction.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#firehoseTypes::FirehoseAction

Write to an Amazon Kinesis Firehose stream.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#httpTypes::HttpAction

Send data to an HTTPS endpoint.

Returns:



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#influx_dbTypes::InfluxDBAction

Write data to an InfluxDB database.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#iot_analyticsTypes::IotAnalyticsAction

Sends message data to an IoT Analytics channel.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#iot_eventsTypes::IotEventsAction

Sends an input to an IoT Events detector.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#iot_site_wiseTypes::IotSiteWiseAction

Sends data from the MQTT message that triggered the rule to IoT SiteWise asset properties.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#kafkaTypes::KafkaAction

Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.

Returns:



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#kinesisTypes::KinesisAction

Write data to an Amazon Kinesis stream.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#lambdaTypes::LambdaAction

Invoke a Lambda function.

Returns:



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::LocationAction

The Amazon Location Service rule action sends device location updates from an MQTT message to an Amazon Location tracker resource.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#open_searchTypes::OpenSearchAction

Write data to an Amazon OpenSearch Service domain.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#republishTypes::RepublishAction

Publish to another MQTT topic.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#s3Types::S3Action

Write to an Amazon S3 bucket.

Returns:



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#salesforceTypes::SalesforceAction

Send a message to a Salesforce IoT Cloud Input Stream.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#snsTypes::SnsAction

Publish to an Amazon SNS topic.

Returns:



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#sqsTypes::SqsAction

Publish to an Amazon SQS queue.

Returns:



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#step_functionsTypes::StepFunctionsAction

Starts execution of a Step Functions state machine.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end

#timestreamTypes::TimestreamAction

The Timestream rule action writes attributes (measures) from an MQTT message into an Amazon Timestream table. For more information, see the Timestream topic rule action documentation.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/aws-sdk-iot/types.rb', line 195

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location,
  :influx_db)
  SENSITIVE = []
  include Aws::Structure
end