Class: Aws::IoT::Types::Action

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass Action data as a hash:

{
  dynamo_db: {
    table_name: "TableName", # required
    role_arn: "AwsArn", # required
    operation: "DynamoOperation",
    hash_key_field: "HashKeyField", # required
    hash_key_value: "HashKeyValue", # required
    hash_key_type: "STRING", # accepts STRING, NUMBER
    range_key_field: "RangeKeyField",
    range_key_value: "RangeKeyValue",
    range_key_type: "STRING", # accepts STRING, NUMBER
    payload_field: "PayloadField",
  },
  dynamo_d_bv_2: {
    role_arn: "AwsArn", # required
    put_item: { # required
      table_name: "TableName", # required
    },
  },
  lambda: {
    function_arn: "FunctionArn", # required
  },
  sns: {
    target_arn: "AwsArn", # required
    role_arn: "AwsArn", # required
    message_format: "RAW", # accepts RAW, JSON
  },
  sqs: {
    role_arn: "AwsArn", # required
    queue_url: "QueueUrl", # required
    use_base_64: false,
  },
  kinesis: {
    role_arn: "AwsArn", # required
    stream_name: "StreamName", # required
    partition_key: "PartitionKey",
  },
  republish: {
    role_arn: "AwsArn", # required
    topic: "TopicPattern", # required
    qos: 1,
    headers: {
      payload_format_indicator: "PayloadFormatIndicator",
      content_type: "ContentType",
      response_topic: "ResponseTopic",
      correlation_data: "CorrelationData",
      message_expiry: "MessageExpiry",
      user_properties: [
        {
          key: "UserPropertyKey", # required
          value: "UserPropertyValue", # required
        },
      ],
    },
  },
  s3: {
    role_arn: "AwsArn", # required
    bucket_name: "BucketName", # required
    key: "Key", # required
    canned_acl: "private", # accepts private, public-read, public-read-write, aws-exec-read, authenticated-read, bucket-owner-read, bucket-owner-full-control, log-delivery-write
  },
  firehose: {
    role_arn: "AwsArn", # required
    delivery_stream_name: "DeliveryStreamName", # required
    separator: "FirehoseSeparator",
    batch_mode: false,
  },
  cloudwatch_metric: {
    role_arn: "AwsArn", # required
    metric_namespace: "String", # required
    metric_name: "String", # required
    metric_value: "String", # required
    metric_unit: "String", # required
    metric_timestamp: "String",
  },
  cloudwatch_alarm: {
    role_arn: "AwsArn", # required
    alarm_name: "AlarmName", # required
    state_reason: "StateReason", # required
    state_value: "StateValue", # required
  },
  cloudwatch_logs: {
    role_arn: "AwsArn", # required
    log_group_name: "LogGroupName", # required
  },
  elasticsearch: {
    role_arn: "AwsArn", # required
    endpoint: "ElasticsearchEndpoint", # required
    index: "ElasticsearchIndex", # required
    type: "ElasticsearchType", # required
    id: "ElasticsearchId", # required
  },
  salesforce: {
    token: "SalesforceToken", # required
    url: "SalesforceEndpoint", # required
  },
  iot_analytics: {
    channel_arn: "AwsArn",
    channel_name: "ChannelName",
    batch_mode: false,
    role_arn: "AwsArn",
  },
  iot_events: {
    input_name: "InputName", # required
    message_id: "MessageId",
    batch_mode: false,
    role_arn: "AwsArn", # required
  },
  iot_site_wise: {
    put_asset_property_value_entries: [ # required
      {
        entry_id: "AssetPropertyEntryId",
        asset_id: "AssetId",
        property_id: "AssetPropertyId",
        property_alias: "AssetPropertyAlias",
        property_values: [ # required
          {
            value: { # required
              string_value: "AssetPropertyStringValue",
              integer_value: "AssetPropertyIntegerValue",
              double_value: "AssetPropertyDoubleValue",
              boolean_value: "AssetPropertyBooleanValue",
            },
            timestamp: { # required
              time_in_seconds: "AssetPropertyTimeInSeconds", # required
              offset_in_nanos: "AssetPropertyOffsetInNanos",
            },
            quality: "AssetPropertyQuality",
          },
        ],
      },
    ],
    role_arn: "AwsArn", # required
  },
  step_functions: {
    execution_name_prefix: "ExecutionNamePrefix",
    state_machine_name: "StateMachineName", # required
    role_arn: "AwsArn", # required
  },
  timestream: {
    role_arn: "AwsArn", # required
    database_name: "TimestreamDatabaseName", # required
    table_name: "TimestreamTableName", # required
    dimensions: [ # required
      {
        name: "TimestreamDimensionName", # required
        value: "TimestreamDimensionValue", # required
      },
    ],
    timestamp: {
      value: "TimestreamTimestampValue", # required
      unit: "TimestreamTimestampUnit", # required
    },
  },
  http: {
    url: "Url", # required
    confirmation_url: "Url",
    headers: [
      {
        key: "HeaderKey", # required
        value: "HeaderValue", # required
      },
    ],
    auth: {
      sigv4: {
        signing_region: "SigningRegion", # required
        service_name: "ServiceName", # required
        role_arn: "AwsArn", # required
      },
    },
  },
  kafka: {
    destination_arn: "AwsArn", # required
    topic: "String", # required
    key: "String",
    partition: "String",
    client_properties: { # required
      "String" => "String",
    },
  },
  open_search: {
    role_arn: "AwsArn", # required
    endpoint: "ElasticsearchEndpoint", # required
    index: "ElasticsearchIndex", # required
    type: "ElasticsearchType", # required
    id: "ElasticsearchId", # required
  },
  location: {
    role_arn: "AwsArn", # required
    tracker_name: "String", # required
    device_id: "String", # required
    timestamp: {
      value: "String", # required
      unit: "String",
    },
    latitude: "String", # required
    longitude: "String", # required
  },
}

Describes the actions associated with a rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloudwatch_alarmTypes::CloudwatchAlarmAction

Change the state of a CloudWatch alarm.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#cloudwatch_logsTypes::CloudwatchLogsAction

Send data to CloudWatch Logs.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#cloudwatch_metricTypes::CloudwatchMetricAction

Capture a CloudWatch metric.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#dynamo_d_bv_2Types::DynamoDBv2Action

Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#dynamo_dbTypes::DynamoDBAction

Write to a DynamoDB table.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#elasticsearchTypes::ElasticsearchAction

Write data to an Amazon OpenSearch Service domain.

<note markdown=“1”> The `Elasticsearch` action can only be used by existing rule actions. To create a new rule action or to update an existing rule action, use the `OpenSearch` rule action instead. For more information, see [OpenSearchAction].

</note>

[1]: docs.aws.amazon.com/iot/latest/apireference/API_OpenSearchAction.html



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#firehoseTypes::FirehoseAction

Write to an Amazon Kinesis Firehose stream.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#httpTypes::HttpAction

Send data to an HTTPS endpoint.

Returns:



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#iot_analyticsTypes::IotAnalyticsAction

Sends message data to an IoT Analytics channel.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#iot_eventsTypes::IotEventsAction

Sends an input to an IoT Events detector.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#iot_site_wiseTypes::IotSiteWiseAction

Sends data from the MQTT message that triggered the rule to IoT SiteWise asset properties.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#kafkaTypes::KafkaAction

Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.

Returns:



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#kinesisTypes::KinesisAction

Write data to an Amazon Kinesis stream.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#lambdaTypes::LambdaAction

Invoke a Lambda function.

Returns:



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::LocationAction

The Amazon Location Service rule action sends device location updates from an MQTT message to an Amazon Location tracker resource.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#open_searchTypes::OpenSearchAction

Write data to an Amazon OpenSearch Service domain.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#republishTypes::RepublishAction

Publish to another MQTT topic.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#s3Types::S3Action

Write to an Amazon S3 bucket.

Returns:



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#salesforceTypes::SalesforceAction

Send a message to a Salesforce IoT Cloud Input Stream.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#snsTypes::SnsAction

Publish to an Amazon SNS topic.

Returns:



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#sqsTypes::SqsAction

Publish to an Amazon SQS queue.

Returns:



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#step_functionsTypes::StepFunctionsAction

Starts execution of a Step Functions state machine.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#timestreamTypes::TimestreamAction

The Timestream rule action writes attributes (measures) from an MQTT message into an Amazon Timestream table. For more information, see the [Timestream] topic rule action documentation.

[1]: docs.aws.amazon.com/iot/latest/developerguide/timestream-rule-action.html



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-iot/types.rb', line 426

class Action < Struct.new(
  :dynamo_db,
  :dynamo_d_bv_2,
  :lambda,
  :sns,
  :sqs,
  :kinesis,
  :republish,
  :s3,
  :firehose,
  :cloudwatch_metric,
  :cloudwatch_alarm,
  :cloudwatch_logs,
  :elasticsearch,
  :salesforce,
  :iot_analytics,
  :iot_events,
  :iot_site_wise,
  :step_functions,
  :timestream,
  :http,
  :kafka,
  :open_search,
  :location)
  SENSITIVE = []
  include Aws::Structure
end