Class: Aws::IoT::Types::Action
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::Action
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass Action data as a hash:
{
dynamo_db: {
table_name: "TableName", # required
role_arn: "AwsArn", # required
operation: "DynamoOperation",
hash_key_field: "HashKeyField", # required
hash_key_value: "HashKeyValue", # required
hash_key_type: "STRING", # accepts STRING, NUMBER
range_key_field: "RangeKeyField",
range_key_value: "RangeKeyValue",
range_key_type: "STRING", # accepts STRING, NUMBER
payload_field: "PayloadField",
},
dynamo_d_bv_2: {
role_arn: "AwsArn", # required
put_item: { # required
table_name: "TableName", # required
},
},
lambda: {
function_arn: "FunctionArn", # required
},
sns: {
target_arn: "AwsArn", # required
role_arn: "AwsArn", # required
message_format: "RAW", # accepts RAW, JSON
},
sqs: {
role_arn: "AwsArn", # required
queue_url: "QueueUrl", # required
use_base_64: false,
},
kinesis: {
role_arn: "AwsArn", # required
stream_name: "StreamName", # required
partition_key: "PartitionKey",
},
republish: {
role_arn: "AwsArn", # required
topic: "TopicPattern", # required
qos: 1,
headers: {
payload_format_indicator: "PayloadFormatIndicator",
content_type: "ContentType",
response_topic: "ResponseTopic",
correlation_data: "CorrelationData",
message_expiry: "MessageExpiry",
user_properties: [
{
key: "UserPropertyKey", # required
value: "UserPropertyValue", # required
},
],
},
},
s3: {
role_arn: "AwsArn", # required
bucket_name: "BucketName", # required
key: "Key", # required
canned_acl: "private", # accepts private, public-read, public-read-write, aws-exec-read, authenticated-read, bucket-owner-read, bucket-owner-full-control, log-delivery-write
},
firehose: {
role_arn: "AwsArn", # required
delivery_stream_name: "DeliveryStreamName", # required
separator: "FirehoseSeparator",
batch_mode: false,
},
cloudwatch_metric: {
role_arn: "AwsArn", # required
metric_namespace: "String", # required
metric_name: "String", # required
metric_value: "String", # required
metric_unit: "String", # required
metric_timestamp: "String",
},
cloudwatch_alarm: {
role_arn: "AwsArn", # required
alarm_name: "AlarmName", # required
state_reason: "StateReason", # required
state_value: "StateValue", # required
},
cloudwatch_logs: {
role_arn: "AwsArn", # required
log_group_name: "LogGroupName", # required
},
elasticsearch: {
role_arn: "AwsArn", # required
endpoint: "ElasticsearchEndpoint", # required
index: "ElasticsearchIndex", # required
type: "ElasticsearchType", # required
id: "ElasticsearchId", # required
},
salesforce: {
token: "SalesforceToken", # required
url: "SalesforceEndpoint", # required
},
iot_analytics: {
channel_arn: "AwsArn",
channel_name: "ChannelName",
batch_mode: false,
role_arn: "AwsArn",
},
iot_events: {
input_name: "InputName", # required
message_id: "MessageId",
batch_mode: false,
role_arn: "AwsArn", # required
},
iot_site_wise: {
put_asset_property_value_entries: [ # required
{
entry_id: "AssetPropertyEntryId",
asset_id: "AssetId",
property_id: "AssetPropertyId",
property_alias: "AssetPropertyAlias",
property_values: [ # required
{
value: { # required
string_value: "AssetPropertyStringValue",
integer_value: "AssetPropertyIntegerValue",
double_value: "AssetPropertyDoubleValue",
boolean_value: "AssetPropertyBooleanValue",
},
timestamp: { # required
time_in_seconds: "AssetPropertyTimeInSeconds", # required
offset_in_nanos: "AssetPropertyOffsetInNanos",
},
quality: "AssetPropertyQuality",
},
],
},
],
role_arn: "AwsArn", # required
},
step_functions: {
execution_name_prefix: "ExecutionNamePrefix",
state_machine_name: "StateMachineName", # required
role_arn: "AwsArn", # required
},
timestream: {
role_arn: "AwsArn", # required
database_name: "TimestreamDatabaseName", # required
table_name: "TimestreamTableName", # required
dimensions: [ # required
{
name: "TimestreamDimensionName", # required
value: "TimestreamDimensionValue", # required
},
],
timestamp: {
value: "TimestreamTimestampValue", # required
unit: "TimestreamTimestampUnit", # required
},
},
http: {
url: "Url", # required
confirmation_url: "Url",
headers: [
{
key: "HeaderKey", # required
value: "HeaderValue", # required
},
],
auth: {
sigv4: {
signing_region: "SigningRegion", # required
service_name: "ServiceName", # required
role_arn: "AwsArn", # required
},
},
},
kafka: {
destination_arn: "AwsArn", # required
topic: "String", # required
key: "String",
partition: "String",
client_properties: { # required
"String" => "String",
},
},
open_search: {
role_arn: "AwsArn", # required
endpoint: "ElasticsearchEndpoint", # required
index: "ElasticsearchIndex", # required
type: "ElasticsearchType", # required
id: "ElasticsearchId", # required
},
location: {
role_arn: "AwsArn", # required
tracker_name: "String", # required
device_id: "String", # required
timestamp: {
value: "String", # required
unit: "String",
},
latitude: "String", # required
longitude: "String", # required
},
}
Describes the actions associated with a rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloudwatch_alarm ⇒ Types::CloudwatchAlarmAction
Change the state of a CloudWatch alarm.
-
#cloudwatch_logs ⇒ Types::CloudwatchLogsAction
Send data to CloudWatch Logs.
-
#cloudwatch_metric ⇒ Types::CloudwatchMetricAction
Capture a CloudWatch metric.
-
#dynamo_d_bv_2 ⇒ Types::DynamoDBv2Action
Write to a DynamoDB table.
-
#dynamo_db ⇒ Types::DynamoDBAction
Write to a DynamoDB table.
-
#elasticsearch ⇒ Types::ElasticsearchAction
Write data to an Amazon OpenSearch Service domain.
-
#firehose ⇒ Types::FirehoseAction
Write to an Amazon Kinesis Firehose stream.
-
#http ⇒ Types::HttpAction
Send data to an HTTPS endpoint.
-
#iot_analytics ⇒ Types::IotAnalyticsAction
Sends message data to an IoT Analytics channel.
-
#iot_events ⇒ Types::IotEventsAction
Sends an input to an IoT Events detector.
-
#iot_site_wise ⇒ Types::IotSiteWiseAction
Sends data from the MQTT message that triggered the rule to IoT SiteWise asset properties.
-
#kafka ⇒ Types::KafkaAction
Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.
-
#kinesis ⇒ Types::KinesisAction
Write data to an Amazon Kinesis stream.
-
#lambda ⇒ Types::LambdaAction
Invoke a Lambda function.
-
#location ⇒ Types::LocationAction
The Amazon Location Service rule action sends device location updates from an MQTT message to an Amazon Location tracker resource.
-
#open_search ⇒ Types::OpenSearchAction
Write data to an Amazon OpenSearch Service domain.
-
#republish ⇒ Types::RepublishAction
Publish to another MQTT topic.
-
#s3 ⇒ Types::S3Action
Write to an Amazon S3 bucket.
-
#salesforce ⇒ Types::SalesforceAction
Send a message to a Salesforce IoT Cloud Input Stream.
-
#sns ⇒ Types::SnsAction
Publish to an Amazon SNS topic.
-
#sqs ⇒ Types::SqsAction
Publish to an Amazon SQS queue.
-
#step_functions ⇒ Types::StepFunctionsAction
Starts execution of a Step Functions state machine.
-
#timestream ⇒ Types::TimestreamAction
The Timestream rule action writes attributes (measures) from an MQTT message into an Amazon Timestream table.
Instance Attribute Details
#cloudwatch_alarm ⇒ Types::CloudwatchAlarmAction
Change the state of a CloudWatch alarm.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#cloudwatch_logs ⇒ Types::CloudwatchLogsAction
Send data to CloudWatch Logs.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#cloudwatch_metric ⇒ Types::CloudwatchMetricAction
Capture a CloudWatch metric.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#dynamo_d_bv_2 ⇒ Types::DynamoDBv2Action
Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#dynamo_db ⇒ Types::DynamoDBAction
Write to a DynamoDB table.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#elasticsearch ⇒ Types::ElasticsearchAction
Write data to an Amazon OpenSearch Service domain.
<note markdown=“1”> The `Elasticsearch` action can only be used by existing rule actions. To create a new rule action or to update an existing rule action, use the `OpenSearch` rule action instead. For more information, see [OpenSearchAction].
</note>
[1]: docs.aws.amazon.com/iot/latest/apireference/API_OpenSearchAction.html
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#firehose ⇒ Types::FirehoseAction
Write to an Amazon Kinesis Firehose stream.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#http ⇒ Types::HttpAction
Send data to an HTTPS endpoint.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#iot_analytics ⇒ Types::IotAnalyticsAction
Sends message data to an IoT Analytics channel.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#iot_events ⇒ Types::IotEventsAction
Sends an input to an IoT Events detector.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#iot_site_wise ⇒ Types::IotSiteWiseAction
Sends data from the MQTT message that triggered the rule to IoT SiteWise asset properties.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#kafka ⇒ Types::KafkaAction
Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#kinesis ⇒ Types::KinesisAction
Write data to an Amazon Kinesis stream.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#lambda ⇒ Types::LambdaAction
Invoke a Lambda function.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::LocationAction
The Amazon Location Service rule action sends device location updates from an MQTT message to an Amazon Location tracker resource.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#open_search ⇒ Types::OpenSearchAction
Write data to an Amazon OpenSearch Service domain.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#republish ⇒ Types::RepublishAction
Publish to another MQTT topic.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#s3 ⇒ Types::S3Action
Write to an Amazon S3 bucket.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#salesforce ⇒ Types::SalesforceAction
Send a message to a Salesforce IoT Cloud Input Stream.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#sns ⇒ Types::SnsAction
Publish to an Amazon SNS topic.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#sqs ⇒ Types::SqsAction
Publish to an Amazon SQS queue.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#step_functions ⇒ Types::StepFunctionsAction
Starts execution of a Step Functions state machine.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |
#timestream ⇒ Types::TimestreamAction
The Timestream rule action writes attributes (measures) from an MQTT message into an Amazon Timestream table. For more information, see the [Timestream] topic rule action documentation.
[1]: docs.aws.amazon.com/iot/latest/developerguide/timestream-rule-action.html
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-iot/types.rb', line 426 class Action < Struct.new( :dynamo_db, :dynamo_d_bv_2, :lambda, :sns, :sqs, :kinesis, :republish, :s3, :firehose, :cloudwatch_metric, :cloudwatch_alarm, :cloudwatch_logs, :elasticsearch, :salesforce, :iot_analytics, :iot_events, :iot_site_wise, :step_functions, :timestream, :http, :kafka, :open_search, :location) SENSITIVE = [] include Aws::Structure end |