Class: Aws::IoT::Types::AssetPropertyValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AssetPropertyValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass AssetPropertyValue data as a hash:
{
value: { # required
string_value: "AssetPropertyStringValue",
integer_value: "AssetPropertyIntegerValue",
double_value: "AssetPropertyDoubleValue",
boolean_value: "AssetPropertyBooleanValue",
},
timestamp: { # required
time_in_seconds: "AssetPropertyTimeInSeconds", # required
offset_in_nanos: "AssetPropertyOffsetInNanos",
},
quality: "AssetPropertyQuality",
}
An asset property value entry containing the following information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#quality ⇒ String
Optional.
-
#timestamp ⇒ Types::AssetPropertyTimestamp
The asset property value timestamp.
-
#value ⇒ Types::AssetPropertyVariant
The value of the asset property.
Instance Attribute Details
#quality ⇒ String
Optional. A string that describes the quality of the value. Accepts substitution templates. Must be `GOOD`, `BAD`, or `UNCERTAIN`.
743 744 745 746 747 748 749 |
# File 'lib/aws-sdk-iot/types.rb', line 743 class AssetPropertyValue < Struct.new( :value, :timestamp, :quality) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Types::AssetPropertyTimestamp
The asset property value timestamp.
743 744 745 746 747 748 749 |
# File 'lib/aws-sdk-iot/types.rb', line 743 class AssetPropertyValue < Struct.new( :value, :timestamp, :quality) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Types::AssetPropertyVariant
The value of the asset property.
743 744 745 746 747 748 749 |
# File 'lib/aws-sdk-iot/types.rb', line 743 class AssetPropertyValue < Struct.new( :value, :timestamp, :quality) SENSITIVE = [] include Aws::Structure end |