Class: Aws::IoT::Types::AssociateTargetsWithJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AssociateTargetsWithJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass AssociateTargetsWithJobRequest data as a hash:
{
targets: ["TargetArn"], # required
job_id: "JobId", # required
comment: "Comment",
namespace_id: "NamespaceId",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comment ⇒ String
An optional comment string describing why the job was associated with the targets.
-
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
-
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
-
#targets ⇒ Array<String>
A list of thing group ARNs that define the targets of the job.
Instance Attribute Details
#comment ⇒ String
An optional comment string describing why the job was associated with the targets.
842 843 844 845 846 847 848 849 |
# File 'lib/aws-sdk-iot/types.rb', line 842 class AssociateTargetsWithJobRequest < Struct.new( :targets, :job_id, :comment, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
842 843 844 845 846 847 848 849 |
# File 'lib/aws-sdk-iot/types.rb', line 842 class AssociateTargetsWithJobRequest < Struct.new( :targets, :job_id, :comment, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.
`$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`
<note markdown=“1”> The `namespaceId` feature is in public preview.
</note>
842 843 844 845 846 847 848 849 |
# File 'lib/aws-sdk-iot/types.rb', line 842 class AssociateTargetsWithJobRequest < Struct.new( :targets, :job_id, :comment, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<String>
A list of thing group ARNs that define the targets of the job.
842 843 844 845 846 847 848 849 |
# File 'lib/aws-sdk-iot/types.rb', line 842 class AssociateTargetsWithJobRequest < Struct.new( :targets, :job_id, :comment, :namespace_id) SENSITIVE = [] include Aws::Structure end |