Class: Aws::IoT::Types::AuditCheckConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass AuditCheckConfiguration data as a hash:

{
  enabled: false,
}

Which audit checks are enabled and disabled for this account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

True if this audit check is enabled for this account.

Returns:

  • (Boolean)


1034
1035
1036
1037
1038
# File 'lib/aws-sdk-iot/types.rb', line 1034

class AuditCheckConfiguration < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end