Class: Aws::IoT::Types::AuditMitigationActionsTaskTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuditMitigationActionsTaskTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass AuditMitigationActionsTaskTarget data as a hash:
{
audit_task_id: "AuditTaskId",
finding_ids: ["FindingId"],
audit_check_to_reason_code_filter: {
"AuditCheckName" => ["ReasonForNonComplianceCode"],
},
}
Used in MitigationActionParams, this information identifies the target findings to which the mitigation actions are applied. Only one entry appears.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_check_to_reason_code_filter ⇒ Hash<String,Array<String>>
Specifies a filter in the form of an audit check and set of reason codes that identify the findings from the audit to which the audit mitigation actions task apply.
-
#audit_task_id ⇒ String
If the task will apply a mitigation action to findings from a specific audit, this value uniquely identifies the audit.
-
#finding_ids ⇒ Array<String>
If the task will apply a mitigation action to one or more listed findings, this value uniquely identifies those findings.
Instance Attribute Details
#audit_check_to_reason_code_filter ⇒ Hash<String,Array<String>>
Specifies a filter in the form of an audit check and set of reason codes that identify the findings from the audit to which the audit mitigation actions task apply.
1267 1268 1269 1270 1271 1272 1273 |
# File 'lib/aws-sdk-iot/types.rb', line 1267 class AuditMitigationActionsTaskTarget < Struct.new( :audit_task_id, :finding_ids, :audit_check_to_reason_code_filter) SENSITIVE = [] include Aws::Structure end |
#audit_task_id ⇒ String
If the task will apply a mitigation action to findings from a specific audit, this value uniquely identifies the audit.
1267 1268 1269 1270 1271 1272 1273 |
# File 'lib/aws-sdk-iot/types.rb', line 1267 class AuditMitigationActionsTaskTarget < Struct.new( :audit_task_id, :finding_ids, :audit_check_to_reason_code_filter) SENSITIVE = [] include Aws::Structure end |
#finding_ids ⇒ Array<String>
If the task will apply a mitigation action to one or more listed findings, this value uniquely identifies those findings.
1267 1268 1269 1270 1271 1272 1273 |
# File 'lib/aws-sdk-iot/types.rb', line 1267 class AuditMitigationActionsTaskTarget < Struct.new( :audit_task_id, :finding_ids, :audit_check_to_reason_code_filter) SENSITIVE = [] include Aws::Structure end |