Class: Aws::IoT::Types::AuditSuppression
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuditSuppression
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Filters out specific findings of a Device Defender audit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#check_name ⇒ String
An audit check name.
-
#description ⇒ String
The description of the audit suppression.
-
#expiration_date ⇒ Time
The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.
-
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
-
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
Instance Attribute Details
#check_name ⇒ String
An audit check name. Checks must be enabled for your account. (Use
DescribeAccountAuditConfiguration to see the list of all checks,
including those that are enabled or use
UpdateAccountAuditConfiguration to select which checks are
enabled.)
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-iot/types.rb', line 1035 class AuditSuppression < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the audit suppression.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-iot/types.rb', line 1035 class AuditSuppression < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#expiration_date ⇒ Time
The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-iot/types.rb', line 1035 class AuditSuppression < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-iot/types.rb', line 1035 class AuditSuppression < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-iot/types.rb', line 1035 class AuditSuppression < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |