Class: Aws::IoT::Types::AuthResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AuthResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The authorizer result.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed ⇒ Types::Allowed
The policies and statements that allowed the specified action.
-
#auth_decision ⇒ String
The final authorization decision of this scenario.
-
#auth_info ⇒ Types::AuthInfo
Authorization information.
-
#denied ⇒ Types::Denied
The policies and statements that denied the specified action.
-
#missing_context_values ⇒ Array<String>
Contains any missing context values found while evaluating policy.
Instance Attribute Details
#allowed ⇒ Types::Allowed
The policies and statements that allowed the specified action.
1390 1391 1392 1393 1394 1395 1396 1397 1398 |
# File 'lib/aws-sdk-iot/types.rb', line 1390 class AuthResult < Struct.new( :auth_info, :allowed, :denied, :auth_decision, :missing_context_values) SENSITIVE = [] include Aws::Structure end |
#auth_decision ⇒ String
The final authorization decision of this scenario. Multiple statements are taken into account when determining the authorization decision. An explicit deny statement can override multiple allow statements.
1390 1391 1392 1393 1394 1395 1396 1397 1398 |
# File 'lib/aws-sdk-iot/types.rb', line 1390 class AuthResult < Struct.new( :auth_info, :allowed, :denied, :auth_decision, :missing_context_values) SENSITIVE = [] include Aws::Structure end |
#auth_info ⇒ Types::AuthInfo
Authorization information.
1390 1391 1392 1393 1394 1395 1396 1397 1398 |
# File 'lib/aws-sdk-iot/types.rb', line 1390 class AuthResult < Struct.new( :auth_info, :allowed, :denied, :auth_decision, :missing_context_values) SENSITIVE = [] include Aws::Structure end |
#denied ⇒ Types::Denied
The policies and statements that denied the specified action.
1390 1391 1392 1393 1394 1395 1396 1397 1398 |
# File 'lib/aws-sdk-iot/types.rb', line 1390 class AuthResult < Struct.new( :auth_info, :allowed, :denied, :auth_decision, :missing_context_values) SENSITIVE = [] include Aws::Structure end |
#missing_context_values ⇒ Array<String>
Contains any missing context values found while evaluating policy.
1390 1391 1392 1393 1394 1395 1396 1397 1398 |
# File 'lib/aws-sdk-iot/types.rb', line 1390 class AuthResult < Struct.new( :auth_info, :allowed, :denied, :auth_decision, :missing_context_values) SENSITIVE = [] include Aws::Structure end |