Class: Aws::IoT::Types::AwsJobAbortCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::AwsJobAbortCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass AwsJobAbortCriteria data as a hash:
{
failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
action: "CANCEL", # required, accepts CANCEL
threshold_percentage: 1.0, # required
min_number_of_executed_things: 1, # required
}
The criteria that determine when and how a job abort takes place.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The type of job action to take to initiate the job abort.
-
#failure_type ⇒ String
The type of job execution failures that can initiate a job abort.
-
#min_number_of_executed_things ⇒ Integer
The minimum number of things which must receive job execution notifications before the job can be aborted.
-
#threshold_percentage ⇒ Float
The minimum percentage of job execution failures that must occur to initiate the job abort.
Instance Attribute Details
#action ⇒ String
The type of job action to take to initiate the job abort.
1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-iot/types.rb', line 1580 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#failure_type ⇒ String
The type of job execution failures that can initiate a job abort.
1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-iot/types.rb', line 1580 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#min_number_of_executed_things ⇒ Integer
The minimum number of things which must receive job execution notifications before the job can be aborted.
1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-iot/types.rb', line 1580 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#threshold_percentage ⇒ Float
The minimum percentage of job execution failures that must occur to initiate the job abort.
Amazon Web Services IoT Core supports up to two digits after the decimal (for example, 10.9 and 10.99, but not 10.999).
1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-iot/types.rb', line 1580 class AwsJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |