Class: Aws::IoT::Types::Behavior
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::Behavior
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
A Device Defender security profile behavior.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#criteria ⇒ Types::BehaviorCriteria
The criteria that determine if a device is behaving normally in regard to the ‘metric`.
-
#export_metric ⇒ Boolean
Value indicates exporting metrics related to the behavior when it is true.
-
#metric ⇒ String
What is measured by the behavior.
-
#metric_dimension ⇒ Types::MetricDimension
The dimension for a metric in your behavior.
-
#name ⇒ String
The name you’ve given to the behavior.
-
#suppress_alerts ⇒ Boolean
Suppresses alerts.
Instance Attribute Details
#criteria ⇒ Types::BehaviorCriteria
The criteria that determine if a device is behaving normally in regard to the ‘metric`.
<note markdown=“1”> In the IoT console, you can choose to be sent an alert through Amazon SNS when IoT Device Defender detects that a device is behaving anomalously.
</note>
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-iot/types.rb', line 1446 class Behavior < Struct.new( :name, :metric, :metric_dimension, :criteria, :suppress_alerts, :export_metric) SENSITIVE = [] include Aws::Structure end |
#export_metric ⇒ Boolean
Value indicates exporting metrics related to the behavior when it is true.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-iot/types.rb', line 1446 class Behavior < Struct.new( :name, :metric, :metric_dimension, :criteria, :suppress_alerts, :export_metric) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ String
What is measured by the behavior.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-iot/types.rb', line 1446 class Behavior < Struct.new( :name, :metric, :metric_dimension, :criteria, :suppress_alerts, :export_metric) SENSITIVE = [] include Aws::Structure end |
#metric_dimension ⇒ Types::MetricDimension
The dimension for a metric in your behavior. For example, using a ‘TOPIC_FILTER` dimension, you can narrow down the scope of the metric to only MQTT topics where the name matches the pattern specified in the dimension. This can’t be used with custom metrics.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-iot/types.rb', line 1446 class Behavior < Struct.new( :name, :metric, :metric_dimension, :criteria, :suppress_alerts, :export_metric) SENSITIVE = [] include Aws::Structure end |