Class: Aws::IoT::Types::Behavior

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

A Device Defender security profile behavior.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#criteriaTypes::BehaviorCriteria

The criteria that determine if a device is behaving normally in regard to the ‘metric`.

<note markdown=“1”> In the IoT console, you can choose to be sent an alert through Amazon SNS when IoT Device Defender detects that a device is behaving anomalously.

</note>


1303
1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-iot/types.rb', line 1303

class Behavior < Struct.new(
  :name,
  :metric,
  :metric_dimension,
  :criteria,
  :suppress_alerts)
  SENSITIVE = []
  include Aws::Structure
end

#metricString

What is measured by the behavior.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-iot/types.rb', line 1303

class Behavior < Struct.new(
  :name,
  :metric,
  :metric_dimension,
  :criteria,
  :suppress_alerts)
  SENSITIVE = []
  include Aws::Structure
end

#metric_dimensionTypes::MetricDimension

The dimension for a metric in your behavior. For example, using a ‘TOPIC_FILTER` dimension, you can narrow down the scope of the metric to only MQTT topics where the name matches the pattern specified in the dimension. This can’t be used with custom metrics.



1303
1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-iot/types.rb', line 1303

class Behavior < Struct.new(
  :name,
  :metric,
  :metric_dimension,
  :criteria,
  :suppress_alerts)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name you’ve given to the behavior.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-iot/types.rb', line 1303

class Behavior < Struct.new(
  :name,
  :metric,
  :metric_dimension,
  :criteria,
  :suppress_alerts)
  SENSITIVE = []
  include Aws::Structure
end

#suppress_alertsBoolean

Suppresses alerts.

Returns:

  • (Boolean)


1303
1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-iot/types.rb', line 1303

class Behavior < Struct.new(
  :name,
  :metric,
  :metric_dimension,
  :criteria,
  :suppress_alerts)
  SENSITIVE = []
  include Aws::Structure
end