Class: Aws::IoT::Types::Behavior
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::Behavior
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass Behavior data as a hash:
{
name: "BehaviorName", # required
metric: "BehaviorMetric",
metric_dimension: {
dimension_name: "DimensionName", # required
operator: "IN", # accepts IN, NOT_IN
},
criteria: {
comparison_operator: "less-than", # accepts less-than, less-than-equals, greater-than, greater-than-equals, in-cidr-set, not-in-cidr-set, in-port-set, not-in-port-set, in-set, not-in-set
value: {
count: 1,
cidrs: ["Cidr"],
ports: [1],
number: 1.0,
numbers: [1.0],
strings: ["stringValue"],
},
duration_seconds: 1,
consecutive_datapoints_to_alarm: 1,
consecutive_datapoints_to_clear: 1,
statistical_threshold: {
statistic: "EvaluationStatistic",
},
ml_detection_config: {
confidence_level: "LOW", # required, accepts LOW, MEDIUM, HIGH
},
},
suppress_alerts: false,
}
A Device Defender security profile behavior.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#criteria ⇒ Types::BehaviorCriteria
The criteria that determine if a device is behaving normally in regard to the `metric`.
-
#metric ⇒ String
What is measured by the behavior.
-
#metric_dimension ⇒ Types::MetricDimension
The dimension for a metric in your behavior.
-
#name ⇒ String
The name you've given to the behavior.
-
#suppress_alerts ⇒ Boolean
Suppresses alerts.
Instance Attribute Details
#criteria ⇒ Types::BehaviorCriteria
The criteria that determine if a device is behaving normally in regard to the `metric`.
1813 1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-iot/types.rb', line 1813 class Behavior < Struct.new( :name, :metric, :metric_dimension, :criteria, :suppress_alerts) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ String
What is measured by the behavior.
1813 1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-iot/types.rb', line 1813 class Behavior < Struct.new( :name, :metric, :metric_dimension, :criteria, :suppress_alerts) SENSITIVE = [] include Aws::Structure end |
#metric_dimension ⇒ Types::MetricDimension
The dimension for a metric in your behavior. For example, using a `TOPIC_FILTER` dimension, you can narrow down the scope of the metric to only MQTT topics where the name matches the pattern specified in the dimension. This can't be used with custom metrics.
1813 1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-iot/types.rb', line 1813 class Behavior < Struct.new( :name, :metric, :metric_dimension, :criteria, :suppress_alerts) SENSITIVE = [] include Aws::Structure end |