Class: Aws::IoT::Types::CACertificateDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CACertificateDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes a CA certificate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_registration_status ⇒ String
Whether the CA certificate configured for auto registration of device certificates.
-
#certificate_arn ⇒ String
The CA certificate ARN.
-
#certificate_id ⇒ String
The CA certificate ID.
-
#certificate_mode ⇒ String
The mode of the CA.
-
#certificate_pem ⇒ String
The CA certificate data, in PEM format.
-
#creation_date ⇒ Time
The date the CA certificate was created.
-
#customer_version ⇒ Integer
The customer version of the CA certificate.
-
#generation_id ⇒ String
The generation ID of the CA certificate.
-
#last_modified_date ⇒ Time
The date the CA certificate was last modified.
-
#owned_by ⇒ String
The owner of the CA certificate.
-
#status ⇒ String
The status of a CA certificate.
-
#validity ⇒ Types::CertificateValidity
When the CA certificate is valid.
Instance Attribute Details
#auto_registration_status ⇒ String
Whether the CA certificate configured for auto registration of device certificates. Valid values are “ENABLE” and “DISABLE”
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The CA certificate ARN.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_id ⇒ String
The CA certificate ID.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_mode ⇒ String
The mode of the CA.
All the device certificates that are registered using this CA will be registered in the same mode as the CA. For more information about certificate mode for device certificates, see [certificate mode].
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_pem ⇒ String
The CA certificate data, in PEM format.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date the CA certificate was created.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#customer_version ⇒ Integer
The customer version of the CA certificate.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#generation_id ⇒ String
The generation ID of the CA certificate.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the CA certificate was last modified.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#owned_by ⇒ String
The owner of the CA certificate.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of a CA certificate.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#validity ⇒ Types::CertificateValidity
When the CA certificate is valid.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-iot/types.rb', line 2099 class CACertificateDescription < Struct.new( :certificate_arn, :certificate_id, :status, :certificate_pem, :owned_by, :creation_date, :auto_registration_status, :last_modified_date, :customer_version, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |