Class: Aws::IoT::Types::Certificate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Information about a certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

The ARN of the certificate.

Returns:

  • (String)


2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-iot/types.rb', line 2370

class Certificate < Struct.new(
  :certificate_arn,
  :certificate_id,
  :status,
  :certificate_mode,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_idString

The ID of the certificate. (The last part of the certificate ARN contains the certificate ID.)

Returns:

  • (String)


2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-iot/types.rb', line 2370

class Certificate < Struct.new(
  :certificate_arn,
  :certificate_id,
  :status,
  :certificate_mode,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_modeString

The mode of the certificate.

`DEFAULT`: A certificate in `DEFAULT` mode is either generated by Amazon Web Services IoT Core or registered with an issuer certificate authority (CA) in `DEFAULT` mode. Devices with certificates in `DEFAULT` mode aren't required to send the Server Name Indication (SNI) extension when connecting to Amazon Web Services IoT Core. However, to use features such as custom domains and VPC endpoints, we recommend that you use the SNI extension when connecting to Amazon Web Services IoT Core.

`SNI_ONLY`: A certificate in `SNI_ONLY` mode is registered without an issuer CA. Devices with certificates in `SNI_ONLY` mode must send the SNI extension when connecting to Amazon Web Services IoT Core.

Returns:

  • (String)


2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-iot/types.rb', line 2370

class Certificate < Struct.new(
  :certificate_arn,
  :certificate_id,
  :status,
  :certificate_mode,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time the certificate was created.

Returns:

  • (Time)


2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-iot/types.rb', line 2370

class Certificate < Struct.new(
  :certificate_arn,
  :certificate_id,
  :status,
  :certificate_mode,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the certificate.

The status value REGISTER_INACTIVE is deprecated and should not be used.

Returns:

  • (String)


2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-iot/types.rb', line 2370

class Certificate < Struct.new(
  :certificate_arn,
  :certificate_id,
  :status,
  :certificate_mode,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end