Class: Aws::IoT::Types::CertificateConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CertificateConflictException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Unable to verify the CA certificate used to sign the device certificate you are attempting to register. This is happens when you have registered more than one CA certificate that has the same subject field and public key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message for the exception.
Instance Attribute Details
#message ⇒ String
The message for the exception.
1794 1795 1796 1797 1798 |
# File 'lib/aws-sdk-iot/types.rb', line 1794 class CertificateConflictException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |