Class: Aws::IoT::Types::CertificateDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Describes a certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ca_certificate_idString

The certificate ID of the CA certificate used to sign this certificate.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_arnString

The ARN of the certificate.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_idString

The ID of the certificate.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_modeString

The mode of the certificate.

`DEFAULT`: A certificate in `DEFAULT` mode is either generated by Amazon Web Services IoT Core or registered with an issuer certificate authority (CA) in `DEFAULT` mode. Devices with certificates in `DEFAULT` mode aren't required to send the Server Name Indication (SNI) extension when connecting to Amazon Web Services IoT Core. However, to use features such as custom domains and VPC endpoints, we recommend that you use the SNI extension when connecting to Amazon Web Services IoT Core.

`SNI_ONLY`: A certificate in `SNI_ONLY` mode is registered without an issuer CA. Devices with certificates in `SNI_ONLY` mode must send the SNI extension when connecting to Amazon Web Services IoT Core.

For more information about the value for SNI extension, see [Transport security in IoT].

[1]: docs.aws.amazon.com/iot/latest/developerguide/transport-security.html

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_pemString

The certificate data, in PEM format.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time the certificate was created.

Returns:

  • (Time)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#customer_versionInteger

The customer version of the certificate.

Returns:

  • (Integer)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#generation_idString

The generation ID of the certificate.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date and time the certificate was last modified.

Returns:

  • (Time)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#owned_byString

The ID of the Amazon Web Services account that owns the certificate.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#previous_owned_byString

The ID of the Amazon Web Services account of the previous owner of the certificate.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the certificate.

Returns:

  • (String)


2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#transfer_dataTypes::TransferData

The transfer data.

Returns:



2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end

#validityTypes::CertificateValidity

When the certificate is valid.



2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-iot/types.rb', line 2462

class CertificateDescription < Struct.new(
  :certificate_arn,
  :certificate_id,
  :ca_certificate_id,
  :status,
  :certificate_pem,
  :owned_by,
  :previous_owned_by,
  :creation_date,
  :last_modified_date,
  :customer_version,
  :transfer_data,
  :generation_id,
  :validity,
  :certificate_mode)
  SENSITIVE = []
  include Aws::Structure
end