Class: Aws::IoT::Types::CertificateDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CertificateDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes a certificate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ca_certificate_id ⇒ String
The certificate ID of the CA certificate used to sign this certificate.
-
#certificate_arn ⇒ String
The ARN of the certificate.
-
#certificate_id ⇒ String
The ID of the certificate.
-
#certificate_mode ⇒ String
The mode of the certificate.
-
#certificate_pem ⇒ String
The certificate data, in PEM format.
-
#creation_date ⇒ Time
The date and time the certificate was created.
-
#customer_version ⇒ Integer
The customer version of the certificate.
-
#generation_id ⇒ String
The generation ID of the certificate.
-
#last_modified_date ⇒ Time
The date and time the certificate was last modified.
-
#owned_by ⇒ String
The ID of the Amazon Web Services account that owns the certificate.
-
#previous_owned_by ⇒ String
The ID of the Amazon Web Services account of the previous owner of the certificate.
-
#status ⇒ String
The status of the certificate.
-
#transfer_data ⇒ Types::TransferData
The transfer data.
-
#validity ⇒ Types::CertificateValidity
When the certificate is valid.
Instance Attribute Details
#ca_certificate_id ⇒ String
The certificate ID of the CA certificate used to sign this certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The ARN of the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_id ⇒ String
The ID of the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_mode ⇒ String
The mode of the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#certificate_pem ⇒ String
The certificate data, in PEM format.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time the certificate was created.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#customer_version ⇒ Integer
The customer version of the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#generation_id ⇒ String
The generation ID of the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time the certificate was last modified.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#owned_by ⇒ String
The ID of the Amazon Web Services account that owns the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#previous_owned_by ⇒ String
The ID of the Amazon Web Services account of the previous owner of the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the certificate.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#transfer_data ⇒ Types::TransferData
The transfer data.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |
#validity ⇒ Types::CertificateValidity
When the certificate is valid.
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/aws-sdk-iot/types.rb', line 2399 class CertificateDescription < Struct.new( :certificate_arn, :certificate_id, :ca_certificate_id, :status, :certificate_pem, :owned_by, :previous_owned_by, :creation_date, :last_modified_date, :customer_version, :transfer_data, :generation_id, :validity, :certificate_mode) SENSITIVE = [] include Aws::Structure end |