Class: Aws::IoT::Types::CommandParameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

A map of key-value pairs that describe the command.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_valueTypes::CommandParameterValue

The default value used to describe the command. This is the value assumed by the parameter if no other value is assigned to it.



2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-iot/types.rb', line 2373

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the command parameter.

Returns:

  • (String)


2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-iot/types.rb', line 2373

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of a specific parameter used in a command and command execution.

Returns:

  • (String)


2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-iot/types.rb', line 2373

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the command parameter.

Returns:

  • (String)


2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-iot/types.rb', line 2373

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#valueTypes::CommandParameterValue

Parameter value that overrides the default value, if set.



2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-iot/types.rb', line 2373

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#value_conditionsArray<Types::CommandParameterValueCondition>

The list of conditions that a command parameter value must satisfy to create a command execution.



2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-iot/types.rb', line 2373

class CommandParameter < Struct.new(
  :name,
  :type,
  :value,
  :default_value,
  :value_conditions,
  :description)
  SENSITIVE = []
  include Aws::Structure
end