Class: Aws::IoT::Types::CommandParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CommandParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
A map of key-value pairs that describe the command.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_value ⇒ Types::CommandParameterValue
The default value used to describe the command.
-
#description ⇒ String
The description of the command parameter.
-
#name ⇒ String
The name of a specific parameter used in a command and command execution.
-
#type ⇒ String
The type of the command parameter.
-
#value ⇒ Types::CommandParameterValue
Parameter value that overrides the default value, if set.
-
#value_conditions ⇒ Array<Types::CommandParameterValueCondition>
The list of conditions that a command parameter value must satisfy to create a command execution.
Instance Attribute Details
#default_value ⇒ Types::CommandParameterValue
The default value used to describe the command. This is the value assumed by the parameter if no other value is assigned to it.
2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-iot/types.rb', line 2373 class CommandParameter < Struct.new( :name, :type, :value, :default_value, :value_conditions, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the command parameter.
2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-iot/types.rb', line 2373 class CommandParameter < Struct.new( :name, :type, :value, :default_value, :value_conditions, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of a specific parameter used in a command and command execution.
2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-iot/types.rb', line 2373 class CommandParameter < Struct.new( :name, :type, :value, :default_value, :value_conditions, :description) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the command parameter.
2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-iot/types.rb', line 2373 class CommandParameter < Struct.new( :name, :type, :value, :default_value, :value_conditions, :description) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Types::CommandParameterValue
Parameter value that overrides the default value, if set.
2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-iot/types.rb', line 2373 class CommandParameter < Struct.new( :name, :type, :value, :default_value, :value_conditions, :description) SENSITIVE = [] include Aws::Structure end |
#value_conditions ⇒ Array<Types::CommandParameterValueCondition>
The list of conditions that a command parameter value must satisfy to create a command execution.
2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-iot/types.rb', line 2373 class CommandParameter < Struct.new( :name, :type, :value, :default_value, :value_conditions, :description) SENSITIVE = [] include Aws::Structure end |