Class: Aws::IoT::Types::CreateAuthorizerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateAuthorizerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_function_arn ⇒ String
The ARN of the authorizer's Lambda function.
-
#authorizer_name ⇒ String
The authorizer name.
-
#enable_caching_for_http ⇒ Boolean
When
true, the result from the authorizer’s Lambda function is cached for clients that use persistent HTTP connections. -
#signing_disabled ⇒ Boolean
Specifies whether IoT validates the token signature in an authorization request.
-
#status ⇒ String
The status of the create authorizer request.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the custom authorizer.
-
#token_key_name ⇒ String
The name of the token key used to extract the token from the HTTP headers.
-
#token_signing_public_keys ⇒ Hash<String,String>
The public keys used to verify the digital signature returned by your custom authentication service.
Instance Attribute Details
#authorizer_function_arn ⇒ String
The ARN of the authorizer's Lambda function.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#authorizer_name ⇒ String
The authorizer name.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#enable_caching_for_http ⇒ Boolean
When true, the result from the authorizer’s Lambda function is
cached for clients that use persistent HTTP connections. The results
are cached for the time specified by the Lambda function in
refreshAfterInSeconds. This value does not affect authorization of
clients that use MQTT connections.
The default value is false.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#signing_disabled ⇒ Boolean
Specifies whether IoT validates the token signature in an authorization request.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the create authorizer request.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the custom authorizer.
For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..."
For the cli-input-json file use format: "tags": "key1=value1&key2=value2..."
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#token_key_name ⇒ String
The name of the token key used to extract the token from the HTTP headers.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#token_signing_public_keys ⇒ Hash<String,String>
The public keys used to verify the digital signature returned by your custom authentication service.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/aws-sdk-iot/types.rb', line 2803 class CreateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :tags, :signing_disabled, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |