Class: Aws::IoT::Types::CreateCommandRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateCommandRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command_id ⇒ String
A unique identifier for the command.
-
#description ⇒ String
A short text decription of the command.
-
#display_name ⇒ String
The user-friendly name in the console for the command.
-
#mandatory_parameters ⇒ Array<Types::CommandParameter>
A list of parameters that are used by ‘StartCommandExecution` API for execution payload generation.
-
#namespace ⇒ String
The namespace of the command.
-
#payload ⇒ Types::CommandPayload
The payload object for the static command.
-
#payload_template ⇒ String
The payload template for the dynamic command.
-
#preprocessor ⇒ Types::CommandPreprocessor
Configuration that determines how ‘payloadTemplate` is processed to generate command execution payload.
-
#role_arn ⇒ String
The IAM role that you must provide when using the ‘AWS-IoT-FleetWise` namespace.
-
#tags ⇒ Array<Types::Tag>
Name-value pairs that are used as metadata to manage a command.
Instance Attribute Details
#command_id ⇒ String
A unique identifier for the command. We recommend using UUID. Alpha-numeric characters, hyphens, and underscores are valid for use here.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A short text decription of the command.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name in the console for the command. This name doesn’t have to be unique. You can update the user-friendly name after you define it.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#mandatory_parameters ⇒ Array<Types::CommandParameter>
A list of parameters that are used by ‘StartCommandExecution` API for execution payload generation.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the command. The MQTT reserved topics and validations will be used for command executions according to the namespace setting.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ Types::CommandPayload
The payload object for the static command.
You can upload a static payload file from your local storage that contains the instructions for the device to process. The payload file can use any format. To make sure that the device correctly interprets the payload, we recommend you to specify the payload content type.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#payload_template ⇒ String
The payload template for the dynamic command.
<note markdown=“1”> This parameter is required for dynamic commands where the command execution placeholders are supplied either from ‘mandatoryParameters` or when `StartCommandExecution` is invoked.
</note>
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#preprocessor ⇒ Types::CommandPreprocessor
Configuration that determines how ‘payloadTemplate` is processed to generate command execution payload.
<note markdown=“1”> This parameter is required for dynamic commands, along with ‘payloadTemplate`, and `mandatoryParameters`.
</note>
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role that you must provide when using the ‘AWS-IoT-FleetWise` namespace. The role grants IoT Device Management the permission to access IoT FleetWise resources for generating the payload for the command. This field is not supported when you use the `AWS-IoT` namespace.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Name-value pairs that are used as metadata to manage a command.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-iot/types.rb', line 3033 class CreateCommandRequest < Struct.new( :command_id, :namespace, :display_name, :description, :payload, :payload_template, :preprocessor, :mandatory_parameters, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |