Class: Aws::IoT::Types::CreateCustomMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateCustomMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateCustomMetricRequest data as a hash:
{
metric_name: "MetricName", # required
display_name: "CustomMetricDisplayName",
metric_type: "string-list", # required, accepts string-list, ip-address-list, number-list, number
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
client_request_token: "ClientRequestToken", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
Each custom metric must have a unique client request token.
-
#display_name ⇒ String
Field represents a friendly name in the console for the custom metric; it doesn't have to be unique.
-
#metric_name ⇒ String
The name of the custom metric.
-
#metric_type ⇒ String
The type of the custom metric.
-
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the custom metric.
Instance Attribute Details
#client_request_token ⇒ String
Each custom metric must have a unique client request token. If you try to create a new custom metric that already exists with a different token, an exception occurs. If you omit this value, Amazon Web Services SDKs will automatically generate a unique client request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-iot/types.rb', line 3075 class CreateCustomMetricRequest < Struct.new( :metric_name, :display_name, :metric_type, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
Field represents a friendly name in the console for the custom metric; it doesn't have to be unique. Don't use this name as the metric identifier in the device metric report. Can be updated once defined.
3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-iot/types.rb', line 3075 class CreateCustomMetricRequest < Struct.new( :metric_name, :display_name, :metric_type, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the custom metric. This will be used in the metric report submitted from the device/thing. Shouldn't begin with `aws:`. Cannot be updated once defined.
3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-iot/types.rb', line 3075 class CreateCustomMetricRequest < Struct.new( :metric_name, :display_name, :metric_type, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
The type of the custom metric. Types include `string-list`, `ip-address-list`, `number-list`, and `number`.
3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-iot/types.rb', line 3075 class CreateCustomMetricRequest < Struct.new( :metric_name, :display_name, :metric_type, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the custom metric.
3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/aws-sdk-iot/types.rb', line 3075 class CreateCustomMetricRequest < Struct.new( :metric_name, :display_name, :metric_type, :tags, :client_request_token) SENSITIVE = [] include Aws::Structure end |