Class: Aws::IoT::Types::CreateDomainConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizer_configTypes::AuthorizerConfig

An object that specifies the authorization service for a domain.



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-iot/types.rb', line 2511

class CreateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :domain_name,
  :server_certificate_arns,
  :validation_certificate_arn,
  :authorizer_config,
  :service_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_configuration_nameString

The name of the domain configuration. This value must be unique to a region.

Returns:

  • (String)


2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-iot/types.rb', line 2511

class CreateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :domain_name,
  :server_certificate_arns,
  :validation_certificate_arn,
  :authorizer_config,
  :service_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The name of the domain.

Returns:

  • (String)


2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-iot/types.rb', line 2511

class CreateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :domain_name,
  :server_certificate_arns,
  :validation_certificate_arn,
  :authorizer_config,
  :service_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#server_certificate_arnsArray<String>

The ARNs of the certificates that IoT passes to the device during the TLS handshake. Currently you can specify only one certificate ARN. This value is not required for Amazon Web Services-managed domains.

Returns:

  • (Array<String>)


2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-iot/types.rb', line 2511

class CreateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :domain_name,
  :server_certificate_arns,
  :validation_certificate_arn,
  :authorizer_config,
  :service_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#service_typeString

The type of service delivered by the endpoint.

<note markdown=“1”> Amazon Web Services IoT Core currently supports only the DATA service type.

</note>

Returns:

  • (String)


2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-iot/types.rb', line 2511

class CreateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :domain_name,
  :server_certificate_arns,
  :validation_certificate_arn,
  :authorizer_config,
  :service_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata which can be used to manage the domain configuration.

<note markdown=“1”> For URI Request parameters use format: …key1=value1&amp;key2=value2…

For the CLI command-line parameter use format: &amp;&amp;tags

“key1=value1&amp;key2=value2…”

For the cli-input-json file use format: "tags":

“key1=value1&amp;key2=value2…”

</note>

Returns:



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-iot/types.rb', line 2511

class CreateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :domain_name,
  :server_certificate_arns,
  :validation_certificate_arn,
  :authorizer_config,
  :service_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#validation_certificate_arnString

The certificate used to validate the server certificate and prove domain name ownership. This certificate must be signed by a public certificate authority. This value is not required for Amazon Web Services-managed domains.

Returns:

  • (String)


2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/aws-sdk-iot/types.rb', line 2511

class CreateDomainConfigurationRequest < Struct.new(
  :domain_configuration_name,
  :domain_name,
  :server_certificate_arns,
  :validation_certificate_arn,
  :authorizer_config,
  :service_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end