Class: Aws::IoT::Types::CreateDomainConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateDomainConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
-
#domain_configuration_name ⇒ String
The name of the domain configuration.
-
#domain_name ⇒ String
The name of the domain.
-
#server_certificate_arns ⇒ Array<String>
The ARNs of the certificates that IoT passes to the device during the TLS handshake.
-
#service_type ⇒ String
The type of service delivered by the endpoint.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the domain configuration.
-
#validation_certificate_arn ⇒ String
The certificate used to validate the server certificate and prove domain name ownership.
Instance Attribute Details
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 |
# File 'lib/aws-sdk-iot/types.rb', line 2511 class CreateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :domain_name, :server_certificate_arns, :validation_certificate_arn, :authorizer_config, :service_type, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_name ⇒ String
The name of the domain configuration. This value must be unique to a region.
2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 |
# File 'lib/aws-sdk-iot/types.rb', line 2511 class CreateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :domain_name, :server_certificate_arns, :validation_certificate_arn, :authorizer_config, :service_type, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain.
2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 |
# File 'lib/aws-sdk-iot/types.rb', line 2511 class CreateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :domain_name, :server_certificate_arns, :validation_certificate_arn, :authorizer_config, :service_type, :tags) SENSITIVE = [] include Aws::Structure end |
#server_certificate_arns ⇒ Array<String>
The ARNs of the certificates that IoT passes to the device during the TLS handshake. Currently you can specify only one certificate ARN. This value is not required for Amazon Web Services-managed domains.
2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 |
# File 'lib/aws-sdk-iot/types.rb', line 2511 class CreateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :domain_name, :server_certificate_arns, :validation_certificate_arn, :authorizer_config, :service_type, :tags) SENSITIVE = [] include Aws::Structure end |
#service_type ⇒ String
The type of service delivered by the endpoint.
<note markdown=“1”> Amazon Web Services IoT Core currently supports only the DATA service type.
</note>
2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 |
# File 'lib/aws-sdk-iot/types.rb', line 2511 class CreateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :domain_name, :server_certificate_arns, :validation_certificate_arn, :authorizer_config, :service_type, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the domain configuration.
<note markdown=“1”> For URI Request parameters use format: …key1=value1&key2=value2…
For the CLI command-line parameter use format: &&
“key1=value1&key2=value2…”
For the cli-input-json file use format: "tags":
“key1=value1&key2=value2…”
</note>
2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 |
# File 'lib/aws-sdk-iot/types.rb', line 2511 class CreateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :domain_name, :server_certificate_arns, :validation_certificate_arn, :authorizer_config, :service_type, :tags) SENSITIVE = [] include Aws::Structure end |
#validation_certificate_arn ⇒ String
The certificate used to validate the server certificate and prove domain name ownership. This certificate must be signed by a public certificate authority. This value is not required for Amazon Web Services-managed domains.
2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 |
# File 'lib/aws-sdk-iot/types.rb', line 2511 class CreateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :domain_name, :server_certificate_arns, :validation_certificate_arn, :authorizer_config, :service_type, :tags) SENSITIVE = [] include Aws::Structure end |