Class: Aws::IoT::Types::CreateDynamicThingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass CreateDynamicThingGroupRequest data as a hash:

{
  thing_group_name: "ThingGroupName", # required
  thing_group_properties: {
    thing_group_description: "ThingGroupDescription",
    attribute_payload: {
      attributes: {
        "AttributeName" => "AttributeValue",
      },
      merge: false,
    },
  },
  index_name: "IndexName",
  query_string: "QueryString", # required
  query_version: "QueryVersion",
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#index_nameString

The dynamic thing group index name.

<note markdown=“1”> Currently one index is supported: `AWS_Things`.

</note>

Returns:

  • (String)


3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/aws-sdk-iot/types.rb', line 3339

class CreateDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :index_name,
  :query_string,
  :query_version,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The dynamic thing group search query string.

See [Query Syntax] for information about query string syntax.

[1]: docs.aws.amazon.com/iot/latest/developerguide/query-syntax.html

Returns:

  • (String)


3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/aws-sdk-iot/types.rb', line 3339

class CreateDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :index_name,
  :query_string,
  :query_version,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_versionString

The dynamic thing group query version.

<note markdown=“1”> Currently one query version is supported: “2017-09-30”. If not specified, the query version defaults to this value.

</note>

Returns:

  • (String)


3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/aws-sdk-iot/types.rb', line 3339

class CreateDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :index_name,
  :query_string,
  :query_version,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata which can be used to manage the dynamic thing group.

Returns:



3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/aws-sdk-iot/types.rb', line 3339

class CreateDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :index_name,
  :query_string,
  :query_version,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#thing_group_nameString

The dynamic thing group name to create.

Returns:

  • (String)


3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/aws-sdk-iot/types.rb', line 3339

class CreateDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :index_name,
  :query_string,
  :query_version,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#thing_group_propertiesTypes::ThingGroupProperties

The dynamic thing group properties.



3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/aws-sdk-iot/types.rb', line 3339

class CreateDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :thing_group_properties,
  :index_name,
  :query_string,
  :query_version,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end