Class: Aws::IoT::Types::CreateFleetMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateFleetMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateFleetMetricRequest data as a hash:
{
metric_name: "FleetMetricName", # required
query_string: "QueryString", # required
aggregation_type: { # required
name: "Statistics", # required, accepts Statistics, Percentiles, Cardinality
values: ["AggregationTypeValue"],
},
period: 1, # required
aggregation_field: "AggregationField", # required
description: "FleetMetricDescription",
query_version: "QueryVersion",
index_name: "IndexName",
unit: "Seconds", # accepts Seconds, Microseconds, Milliseconds, Bytes, Kilobytes, Megabytes, Gigabytes, Terabytes, Bits, Kilobits, Megabits, Gigabits, Terabits, Percent, Count, Bytes/Second, Kilobytes/Second, Megabytes/Second, Gigabytes/Second, Terabytes/Second, Bits/Second, Kilobits/Second, Megabits/Second, Gigabits/Second, Terabits/Second, Count/Second, None
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_field ⇒ String
The field to aggregate.
-
#aggregation_type ⇒ Types::AggregationType
The type of the aggregation query.
-
#description ⇒ String
The fleet metric description.
-
#index_name ⇒ String
The name of the index to search.
-
#metric_name ⇒ String
The name of the fleet metric to create.
-
#period ⇒ Integer
The time in seconds between fleet metric emissions.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The query version.
-
#tags ⇒ Array<Types::Tag>
Metadata, which can be used to manage the fleet metric.
-
#unit ⇒ String
Used to support unit transformation such as milliseconds to seconds.
Instance Attribute Details
#aggregation_field ⇒ String
The field to aggregate.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#aggregation_type ⇒ Types::AggregationType
The type of the aggregation query.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The fleet metric description.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to search.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the fleet metric to create.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The time in seconds between fleet metric emissions. Range [60(1 min), 86400(1 day)] and must be multiple of 60.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The query version.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata, which can be used to manage the fleet metric.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
Used to support unit transformation such as milliseconds to seconds. The unit must be supported by [CW metric]. Default to null.
3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/aws-sdk-iot/types.rb', line 3524 class CreateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :tags) SENSITIVE = [] include Aws::Structure end |