Class: Aws::IoT::Types::CreateJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateJobRequest data as a hash:
{
job_id: "JobId", # required
targets: ["TargetArn"], # required
document_source: "JobDocumentSource",
document: "JobDocument",
description: "JobDescription",
presigned_url_config: {
role_arn: "RoleArn",
expires_in_sec: 1,
},
target_selection: "CONTINUOUS", # accepts CONTINUOUS, SNAPSHOT
job_executions_rollout_config: {
maximum_per_minute: 1,
exponential_rate: {
base_rate_per_minute: 1, # required
increment_factor: 1.0, # required
rate_increase_criteria: { # required
number_of_notified_things: 1,
number_of_succeeded_things: 1,
},
},
},
abort_config: {
criteria_list: [ # required
{
failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
action: "CANCEL", # required, accepts CANCEL
threshold_percentage: 1.0, # required
min_number_of_executed_things: 1, # required
},
],
},
timeout_config: {
in_progress_timeout_in_minutes: 1,
},
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
namespace_id: "NamespaceId",
job_template_arn: "JobTemplateArn",
job_executions_retry_config: {
criteria_list: [ # required
{
failure_type: "FAILED", # required, accepts FAILED, TIMED_OUT, ALL
number_of_retries: 1, # required
},
],
},
document_parameters: {
"ParameterKey" => "ParameterValue",
},
scheduling_config: {
start_time: "StringDateTime",
end_time: "StringDateTime",
end_behavior: "STOP_ROLLOUT", # accepts STOP_ROLLOUT, CANCEL, FORCE_CANCEL
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_config ⇒ Types::AbortConfig
Allows you to create the criteria to abort a job.
-
#description ⇒ String
A short text description of the job.
-
#document ⇒ String
The job document.
-
#document_parameters ⇒ Hash<String,String>
Parameters of an Amazon Web Services managed template that you can specify to create the job document.
-
#document_source ⇒ String
An S3 link to the job document.
-
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
-
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of the job.
-
#job_id ⇒ String
A job identifier which must be unique for your Amazon Web Services account.
-
#job_template_arn ⇒ String
The ARN of the job template used to create the job.
-
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
-
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration information for pre-signed S3 URLs.
-
#scheduling_config ⇒ Types::SchedulingConfig
The configuration that allows you to schedule a job for a future date and time in addition to specifying the end behavior for each job execution.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the job.
-
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT).
-
#targets ⇒ Array<String>
A list of things and thing groups to which the job should be sent.
-
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
Instance Attribute Details
#abort_config ⇒ Types::AbortConfig
Allows you to create the criteria to abort a job.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A short text description of the job.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#document ⇒ String
The job document. Required if you don't specify a value for `documentSource`.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#document_parameters ⇒ Hash<String,String>
Parameters of an Amazon Web Services managed template that you can specify to create the job document.
<note markdown=“1”> `documentParameters` can only be used when creating jobs from Amazon Web Services managed templates. This parameter can't be used with custom job templates or to create jobs from them.
</note>
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#document_source ⇒ String
An S3 link to the job document. Required if you don't specify a value for `document`.
<note markdown=“1”> If the job document resides in an S3 bucket, you must use a placeholder link when specifying the document.
The placeholder link is of the following form:
`$\{aws:iot:s3-presigned-url:https://s3.amazonaws.com/bucket/key\}`
where *bucket* is your bucket name and *key* is the object in the
bucket to which you are linking.
</note>
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of the job.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
A job identifier which must be unique for your Amazon Web Services account. We recommend using a UUID. Alpha-numeric characters, “-” and “_” are valid for use here.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_template_arn ⇒ String
The ARN of the job template used to create the job.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.
`$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`
<note markdown=“1”> The `namespaceId` feature is in public preview.
</note>
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration information for pre-signed S3 URLs.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#scheduling_config ⇒ Types::SchedulingConfig
The configuration that allows you to schedule a job for a future date and time in addition to specifying the end behavior for each job execution.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the job.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a thing when the thing is added to a target group, even after the job was completed by all things originally in the group.
<note markdown=“1”> We recommend that you use continuous jobs instead of snapshot jobs for dynamic thing group targets. By using continuous jobs, devices that join the group receive the job execution even after the job has been created.
</note>
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<String>
A list of things and thing groups to which the job should be sent.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. The timer is started when the job execution status is set to `IN_PROGRESS`. If the job execution status is not set to another terminal state before the time expires, it will be automatically set to `TIMED_OUT`.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iot/types.rb', line 3746 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |