Class: Aws::IoT::Types::CreateJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_config ⇒ Types::AbortConfig
Allows you to create the criteria to abort a job.
-
#description ⇒ String
A short text description of the job.
-
#document ⇒ String
The job document.
-
#document_parameters ⇒ Hash<String,String>
Parameters of an Amazon Web Services managed template that you can specify to create the job document.
-
#document_source ⇒ String
An S3 link to the job document.
-
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
-
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of the job.
-
#job_id ⇒ String
A job identifier which must be unique for your Amazon Web Services account.
-
#job_template_arn ⇒ String
The ARN of the job template used to create the job.
-
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
-
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration information for pre-signed S3 URLs.
-
#scheduling_config ⇒ Types::SchedulingConfig
The configuration that allows you to schedule a job for a future date and time in addition to specifying the end behavior for each job execution.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the job.
-
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT).
-
#targets ⇒ Array<String>
A list of things and thing groups to which the job should be sent.
-
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
Instance Attribute Details
#abort_config ⇒ Types::AbortConfig
Allows you to create the criteria to abort a job.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A short text description of the job.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#document ⇒ String
The job document. Required if you don’t specify a value for documentSource.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#document_parameters ⇒ Hash<String,String>
Parameters of an Amazon Web Services managed template that you can specify to create the job document.
<note markdown=“1”> documentParameters can only be used when creating jobs from Amazon Web Services managed templates. This parameter can’t be used with custom job templates or to create jobs from them.
</note>
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#document_source ⇒ String
An S3 link to the job document. Required if you don’t specify a value for document.
<note markdown=“1”> If the job document resides in an S3 bucket, you must use a placeholder link when specifying the document.
The placeholder link is of the following form:
`$\{aws:iot:s3-presigned-url:https://s3.amazonaws.com/bucket/key\}`
where *bucket* is your bucket name and *key* is the object in the
bucket to which you are linking.
</note>
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of the job.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
A job identifier which must be unique for your Amazon Web Services account. We recommend using a UUID. Alpha-numeric characters, “-” and “_” are valid for use here.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#job_template_arn ⇒ String
The ARN of the job template used to create the job.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.
‘$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`
<note markdown=“1”> The namespaceId feature is in public preview.
</note>
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration information for pre-signed S3 URLs.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#scheduling_config ⇒ Types::SchedulingConfig
The configuration that allows you to schedule a job for a future date and time in addition to specifying the end behavior for each job execution.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the job.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a thing when the thing is added to a target group, even after the job was completed by all things originally in the group.
<note markdown=“1”> We recommend that you use continuous jobs instead of snapshot jobs for dynamic thing group targets. By using continuous jobs, devices that join the group receive the job execution even after the job has been created.
</note>
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<String>
A list of things and thing groups to which the job should be sent.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. The timer is started when the job execution status is set to IN_PROGRESS. If the job execution status is not set to another terminal state before the time expires, it will be automatically set to TIMED_OUT.
2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-iot/types.rb', line 2814 class CreateJobRequest < Struct.new( :job_id, :targets, :document_source, :document, :description, :presigned_url_config, :target_selection, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :scheduling_config) SENSITIVE = [] include Aws::Structure end |