Class: Aws::IoT::Types::CreateJobTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateJobTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
-
#description ⇒ String
A description of the job document.
-
#destination_package_versions ⇒ Array<String>
The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.
-
#document ⇒ String
The job document.
-
#document_source ⇒ String
An S3 link, or S3 object URL, to the job document.
-
#job_arn ⇒ String
The ARN of the job to use as the basis for the job template.
-
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
-
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
-
#job_template_id ⇒ String
A unique identifier for the job template.
-
#maintenance_windows ⇒ Array<Types::MaintenanceWindow>
Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.
-
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
-
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the job template.
-
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
Instance Attribute Details
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the job document.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#destination_package_versions ⇒ Array<String>
The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.
**Note:**The following Length Constraints relates to a single ARN. Up to 25 package version ARNs are allowed.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#document ⇒ String
The job document. Required if you don’t specify a value for ‘documentSource`.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#document_source ⇒ String
An S3 link, or S3 object URL, to the job document. The link is an Amazon S3 object URL and is required if you don’t specify a value for ‘document`.
For example, ‘–document-source s3.region-code.amazonaws.com/example-firmware/device-firmware.1.0`
For more information, see [Methods for accessing a bucket].
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/access-bucket-intro.html
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The ARN of the job to use as the basis for the job template.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_template_id ⇒ String
A unique identifier for the job template. We recommend using a UUID. Alpha-numeric characters, “-”, and “_” are valid for use here.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#maintenance_windows ⇒ Array<Types::MaintenanceWindow>
Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the job template.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to ‘IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.
2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-iot/types.rb', line 2959 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |