Class: Aws::IoT::Types::CreateJobTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#abort_configTypes::AbortConfig

The criteria that determine when and how a job abort takes place.

Returns:



2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the job document.

Returns:

  • (String)


2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#destination_package_versionsArray<String>

The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.

**Note:**The following Length Constraints relates to a single string. Up to five strings are allowed.

Returns:

  • (Array<String>)


2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#documentString

The job document. Required if you don’t specify a value for ‘documentSource`.

Returns:

  • (String)


2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#document_sourceString

An S3 link, or S3 object URL, to the job document. The link is an Amazon S3 object URL and is required if you don’t specify a value for ‘document`.

For example, ‘–document-source s3.region-code.amazonaws.com/example-firmware/device-firmware.1.0`

For more information, see [Methods for accessing a bucket].

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/access-bucket-intro.html

Returns:

  • (String)


2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The ARN of the job to use as the basis for the job template.

Returns:

  • (String)


2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_retry_configTypes::JobExecutionsRetryConfig

Allows you to create the criteria to retry a job.



2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_rollout_configTypes::JobExecutionsRolloutConfig

Allows you to create a staged rollout of a job.



2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_template_idString

A unique identifier for the job template. We recommend using a UUID. Alpha-numeric characters, “-”, and “_” are valid for use here.

Returns:

  • (String)


2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_windowsArray<Types::MaintenanceWindow>

Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.

Returns:



2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#presigned_url_configTypes::PresignedUrlConfig

Configuration for pre-signed S3 URLs.



2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata that can be used to manage the job template.

Returns:



2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_configTypes::TimeoutConfig

Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to ‘IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.



2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-iot/types.rb', line 2953

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end