Class: Aws::IoT::Types::CreateJobTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateJobTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
-
#description ⇒ String
A description of the job document.
-
#destination_package_versions ⇒ Array<String>
The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.
-
#document ⇒ String
The job document.
-
#document_source ⇒ String
An S3 link to the job document to use in the template.
-
#job_arn ⇒ String
The ARN of the job to use as the basis for the job template.
-
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
-
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
-
#job_template_id ⇒ String
A unique identifier for the job template.
-
#maintenance_windows ⇒ Array<Types::MaintenanceWindow>
Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.
-
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
-
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the job template.
-
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
Instance Attribute Details
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the job document.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#destination_package_versions ⇒ Array<String>
The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.
**Note:**The following Length Constraints relates to a single string. Up to five strings are allowed.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#document ⇒ String
The job document. Required if you don’t specify a value for ‘documentSource`.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#document_source ⇒ String
An S3 link to the job document to use in the template. Required if you don’t specify a value for ‘document`.
<note markdown=“1”> If the job document resides in an S3 bucket, you must use a placeholder link when specifying the document.
The placeholder link is of the following form:
`$\{aws:iot:s3-presigned-url:https://s3.amazonaws.com/bucket/key\}`
where *bucket* is your bucket name and *key* is the object in the
bucket to which you are linking.
</note>
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The ARN of the job to use as the basis for the job template.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#job_template_id ⇒ String
A unique identifier for the job template. We recommend using a UUID. Alpha-numeric characters, “-”, and “_” are valid for use here.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#maintenance_windows ⇒ Array<Types::MaintenanceWindow>
Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the job template.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to ‘IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 |
# File 'lib/aws-sdk-iot/types.rb', line 2949 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config, :maintenance_windows, :destination_package_versions) SENSITIVE = [] include Aws::Structure end |