Class: Aws::IoT::Types::CreateJobTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#abort_configTypes::AbortConfig

The criteria that determine when and how a job abort takes place.

Returns:



2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the job document.

Returns:

  • (String)


2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#documentString

The job document. Required if you don’t specify a value for ‘documentSource`.

Returns:

  • (String)


2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#document_sourceString

An S3 link to the job document to use in the template. Required if you don’t specify a value for ‘document`.

<note markdown=“1”> If the job document resides in an S3 bucket, you must use a placeholder link when specifying the document.

The placeholder link is of the following form:

`$\{aws:iot:s3-presigned-url:https://s3.amazonaws.com/bucket/key\}`

where *bucket* is your bucket name and *key* is the object in the

bucket to which you are linking.

</note>

Returns:

  • (String)


2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The ARN of the job to use as the basis for the job template.

Returns:

  • (String)


2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_retry_configTypes::JobExecutionsRetryConfig

Allows you to create the criteria to retry a job.



2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_rollout_configTypes::JobExecutionsRolloutConfig

Allows you to create a staged rollout of a job.



2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_template_idString

A unique identifier for the job template. We recommend using a UUID. Alpha-numeric characters, “-”, and “_” are valid for use here.

Returns:

  • (String)


2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#presigned_url_configTypes::PresignedUrlConfig

Configuration for pre-signed S3 URLs.



2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata that can be used to manage the job template.

Returns:



2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_configTypes::TimeoutConfig

Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to ‘IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.



2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-iot/types.rb', line 2918

class CreateJobTemplateRequest < Struct.new(
  :job_template_id,
  :job_arn,
  :document_source,
  :document,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :tags,
  :job_executions_retry_config)
  SENSITIVE = []
  include Aws::Structure
end