Class: Aws::IoT::Types::CreateJobTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateJobTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateJobTemplateRequest data as a hash:
{
job_template_id: "JobTemplateId", # required
job_arn: "JobArn",
document_source: "JobDocumentSource",
document: "JobDocument",
description: "JobDescription", # required
presigned_url_config: {
role_arn: "RoleArn",
expires_in_sec: 1,
},
job_executions_rollout_config: {
maximum_per_minute: 1,
exponential_rate: {
base_rate_per_minute: 1, # required
increment_factor: 1.0, # required
rate_increase_criteria: { # required
number_of_notified_things: 1,
number_of_succeeded_things: 1,
},
},
},
abort_config: {
criteria_list: [ # required
{
failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
action: "CANCEL", # required, accepts CANCEL
threshold_percentage: 1.0, # required
min_number_of_executed_things: 1, # required
},
],
},
timeout_config: {
in_progress_timeout_in_minutes: 1,
},
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
job_executions_retry_config: {
criteria_list: [ # required
{
failure_type: "FAILED", # required, accepts FAILED, TIMED_OUT, ALL
number_of_retries: 1, # required
},
],
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
-
#description ⇒ String
A description of the job document.
-
#document ⇒ String
The job document.
-
#document_source ⇒ String
An S3 link to the job document to use in the template.
-
#job_arn ⇒ String
The ARN of the job to use as the basis for the job template.
-
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
-
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
-
#job_template_id ⇒ String
A unique identifier for the job template.
-
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
-
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the job template.
-
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
Instance Attribute Details
#abort_config ⇒ Types::AbortConfig
The criteria that determine when and how a job abort takes place.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the job document.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#document ⇒ String
The job document. Required if you don't specify a value for `documentSource`.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#document_source ⇒ String
An S3 link to the job document to use in the template. Required if you don't specify a value for `document`.
<note markdown=“1”> If the job document resides in an S3 bucket, you must use a placeholder link when specifying the document.
The placeholder link is of the following form:
`$\{aws:iot:s3-presigned-url:https://s3.amazonaws.com/bucket/key\}`
where *bucket* is your bucket name and *key* is the object in the
bucket to which you are linking.
</note>
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The ARN of the job to use as the basis for the job template.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
Allows you to create the criteria to retry a job.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#job_template_id ⇒ String
A unique identifier for the job template. We recommend using a UUID. Alpha-numeric characters, “-”, and “_” are valid for use here.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata that can be used to manage the job template.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to `IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.
3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/aws-sdk-iot/types.rb', line 3793 class CreateJobTemplateRequest < Struct.new( :job_template_id, :job_arn, :document_source, :document, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :timeout_config, :tags, :job_executions_retry_config) SENSITIVE = [] include Aws::Structure end |