Class: Aws::IoT::Types::CreateOTAUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateOTAUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateOTAUpdateRequest data as a hash:
{
ota_update_id: "OTAUpdateId", # required
description: "OTAUpdateDescription",
targets: ["Target"], # required
protocols: ["MQTT"], # accepts MQTT, HTTP
target_selection: "CONTINUOUS", # accepts CONTINUOUS, SNAPSHOT
aws_job_executions_rollout_config: {
maximum_per_minute: 1,
exponential_rate: {
base_rate_per_minute: 1, # required
increment_factor: 1.0, # required
rate_increase_criteria: { # required
number_of_notified_things: 1,
number_of_succeeded_things: 1,
},
},
},
aws_job_presigned_url_config: {
expires_in_sec: 1,
},
aws_job_abort_config: {
abort_criteria_list: [ # required
{
failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
action: "CANCEL", # required, accepts CANCEL
threshold_percentage: 1.0, # required
min_number_of_executed_things: 1, # required
},
],
},
aws_job_timeout_config: {
in_progress_timeout_in_minutes: 1,
},
files: [ # required
{
file_name: "FileName",
file_type: 1,
file_version: "OTAUpdateFileVersion",
file_location: {
stream: {
stream_id: "StreamId",
file_id: 1,
},
s3_location: {
bucket: "S3Bucket",
key: "S3Key",
version: "S3Version",
},
},
code_signing: {
aws_signer_job_id: "SigningJobId",
start_signing_job_parameter: {
signing_profile_parameter: {
certificate_arn: "CertificateArn",
platform: "Platform",
certificate_path_on_device: "CertificatePathOnDevice",
},
signing_profile_name: "SigningProfileName",
destination: {
s3_destination: {
bucket: "S3Bucket",
prefix: "Prefix",
},
},
},
custom_code_signing: {
signature: {
inline_document: "data",
},
certificate_chain: {
certificate_name: "CertificateName",
inline_document: "InlineDocument",
},
hash_algorithm: "HashAlgorithm",
signature_algorithm: "SignatureAlgorithm",
},
},
attributes: {
"AttributeKey" => "Value",
},
},
],
role_arn: "RoleArn", # required
additional_parameters: {
"AttributeKey" => "Value",
},
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_parameters ⇒ Hash<String,String>
A list of additional OTA update parameters which are name-value pairs.
-
#aws_job_abort_config ⇒ Types::AwsJobAbortConfig
The criteria that determine when and how a job abort takes place.
-
#aws_job_executions_rollout_config ⇒ Types::AwsJobExecutionsRolloutConfig
Configuration for the rollout of OTA updates.
-
#aws_job_presigned_url_config ⇒ Types::AwsJobPresignedUrlConfig
Configuration information for pre-signed URLs.
-
#aws_job_timeout_config ⇒ Types::AwsJobTimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
-
#description ⇒ String
The description of the OTA update.
-
#files ⇒ Array<Types::OTAUpdateFile>
The files to be streamed by the OTA update.
-
#ota_update_id ⇒ String
The ID of the OTA update to be created.
-
#protocols ⇒ Array<String>
The protocol used to transfer the OTA update image.
-
#role_arn ⇒ String
The IAM role that grants Amazon Web Services IoT Core access to the Amazon S3, IoT jobs and Amazon Web Services Code Signing resources to create an OTA update job.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage updates.
-
#target_selection ⇒ String
Specifies whether the update will continue to run (CONTINUOUS), or will be complete after all the things specified as targets have completed the update (SNAPSHOT).
-
#targets ⇒ Array<String>
The devices targeted to receive OTA updates.
Instance Attribute Details
#additional_parameters ⇒ Hash<String,String>
A list of additional OTA update parameters which are name-value pairs.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#aws_job_abort_config ⇒ Types::AwsJobAbortConfig
The criteria that determine when and how a job abort takes place.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#aws_job_executions_rollout_config ⇒ Types::AwsJobExecutionsRolloutConfig
Configuration for the rollout of OTA updates.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#aws_job_presigned_url_config ⇒ Types::AwsJobPresignedUrlConfig
Configuration information for pre-signed URLs.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#aws_job_timeout_config ⇒ Types::AwsJobTimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to `IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the OTA update.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#files ⇒ Array<Types::OTAUpdateFile>
The files to be streamed by the OTA update.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#ota_update_id ⇒ String
The ID of the OTA update to be created.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#protocols ⇒ Array<String>
The protocol used to transfer the OTA update image. Valid values are [HTTP], [MQTT], [HTTP, MQTT]. When both HTTP and MQTT are specified, the target device can choose the protocol.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role that grants Amazon Web Services IoT Core access to the Amazon S3, IoT jobs and Amazon Web Services Code Signing resources to create an OTA update job.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage updates.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#target_selection ⇒ String
Specifies whether the update will continue to run (CONTINUOUS), or will be complete after all the things specified as targets have completed the update (SNAPSHOT). If continuous, the update may also be run on a thing when a change is detected in a target. For example, an update will run on a thing when the thing is added to a target group, even after the update was completed by all things originally in the group. Valid values: CONTINUOUS | SNAPSHOT.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<String>
The devices targeted to receive OTA updates.
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 |
# File 'lib/aws-sdk-iot/types.rb', line 4182 class CreateOTAUpdateRequest < Struct.new( :ota_update_id, :description, :targets, :protocols, :target_selection, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :aws_job_abort_config, :aws_job_timeout_config, :files, :role_arn, :additional_parameters, :tags) SENSITIVE = [] include Aws::Structure end |