Class: Aws::IoT::Types::CreatePolicyVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreatePolicyVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The input for the CreatePolicyVersion operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_document ⇒ String
The JSON document that describes the policy.
-
#policy_name ⇒ String
The policy name.
-
#set_as_default ⇒ Boolean
Specifies whether the policy version is set as the default.
Instance Attribute Details
#policy_document ⇒ String
The JSON document that describes the policy. Minimum length of 1. Maximum length of 2048, excluding whitespace.
3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iot/types.rb', line 3410 class CreatePolicyVersionRequest < Struct.new( :policy_name, :policy_document, :set_as_default) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The policy name.
3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iot/types.rb', line 3410 class CreatePolicyVersionRequest < Struct.new( :policy_name, :policy_document, :set_as_default) SENSITIVE = [] include Aws::Structure end |
#set_as_default ⇒ Boolean
Specifies whether the policy version is set as the default. When this parameter is true, the new policy version becomes the operative version (that is, the version that is in effect for the certificates to which the policy is attached).
3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/aws-sdk-iot/types.rb', line 3410 class CreatePolicyVersionRequest < Struct.new( :policy_name, :policy_document, :set_as_default) SENSITIVE = [] include Aws::Structure end |