Class: Aws::IoT::Types::CreatePolicyVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The input for the CreatePolicyVersion operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_documentString

The JSON document that describes the policy. Minimum length of 1. Maximum length of 2048, excluding whitespace.

Returns:

  • (String)


3240
3241
3242
3243
3244
3245
3246
# File 'lib/aws-sdk-iot/types.rb', line 3240

class CreatePolicyVersionRequest < Struct.new(
  :policy_name,
  :policy_document,
  :set_as_default)
  SENSITIVE = []
  include Aws::Structure
end

#policy_nameString

The policy name.

Returns:

  • (String)


3240
3241
3242
3243
3244
3245
3246
# File 'lib/aws-sdk-iot/types.rb', line 3240

class CreatePolicyVersionRequest < Struct.new(
  :policy_name,
  :policy_document,
  :set_as_default)
  SENSITIVE = []
  include Aws::Structure
end

#set_as_defaultBoolean

Specifies whether the policy version is set as the default. When this parameter is true, the new policy version becomes the operative version (that is, the version that is in effect for the certificates to which the policy is attached).

Returns:

  • (Boolean)


3240
3241
3242
3243
3244
3245
3246
# File 'lib/aws-sdk-iot/types.rb', line 3240

class CreatePolicyVersionRequest < Struct.new(
  :policy_name,
  :policy_document,
  :set_as_default)
  SENSITIVE = []
  include Aws::Structure
end