Class: Aws::IoT::Types::CreateProvisioningTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass CreateProvisioningTemplateRequest data as a hash:

{
  template_name: "TemplateName", # required
  description: "TemplateDescription",
  template_body: "TemplateBody", # required
  enabled: false,
  provisioning_role_arn: "RoleArn", # required
  pre_provisioning_hook: {
    payload_version: "PayloadVersion",
    target_arn: "TargetArn", # required
  },
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
  type: "FLEET_PROVISIONING", # accepts FLEET_PROVISIONING, JITP
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the provisioning template.

Returns:

  • (String)


4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

True to enable the provisioning template, otherwise false.

Returns:

  • (Boolean)


4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#pre_provisioning_hookTypes::ProvisioningHook

Creates a pre-provisioning hook template. Only supports template of type `FLEET_PROVISIONING`. For more information about provisioning template types, see [type].

[1]: docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningTemplate.html#iot-CreateProvisioningTemplate-request-type



4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#provisioning_role_arnString

The role ARN for the role associated with the provisioning template. This IoT role grants permission to provision a device.

Returns:

  • (String)


4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata which can be used to manage the provisioning template.

<note markdown=“1”> For URI Request parameters use format: …key1=value1&amp;key2=value2…

For the CLI command-line parameter use format: &amp;&amp;tags

“key1=value1&amp;key2=value2…”

For the cli-input-json file use format: "tags":

“key1=value1&amp;key2=value2…”

</note>

Returns:



4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#template_bodyString

The JSON formatted contents of the provisioning template.

Returns:

  • (String)


4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the provisioning template.

Returns:

  • (String)


4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type you define in a provisioning template. You can create a template with only one type. You can't change the template type after its creation. The default value is `FLEET_PROVISIONING`. For more information about provisioning template, see: [Provisioning template].

[1]: docs.aws.amazon.com/iot/latest/developerguide/provision-template.html

Returns:

  • (String)


4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/aws-sdk-iot/types.rb', line 4507

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end