Class: Aws::IoT::Types::CreateProvisioningTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::CreateProvisioningTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass CreateProvisioningTemplateRequest data as a hash:
{
template_name: "TemplateName", # required
description: "TemplateDescription",
template_body: "TemplateBody", # required
enabled: false,
provisioning_role_arn: "RoleArn", # required
pre_provisioning_hook: {
payload_version: "PayloadVersion",
target_arn: "TargetArn", # required
},
tags: [
{
key: "TagKey", # required
value: "TagValue",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the fleet provisioning template.
-
#enabled ⇒ Boolean
True to enable the fleet provisioning template, otherwise false.
-
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Creates a pre-provisioning hook template.
-
#provisioning_role_arn ⇒ String
The role ARN for the role associated with the fleet provisioning template.
-
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the fleet provisioning template.
-
#template_body ⇒ String
The JSON formatted contents of the fleet provisioning template.
-
#template_name ⇒ String
The name of the fleet provisioning template.
Instance Attribute Details
#description ⇒ String
The description of the fleet provisioning template.
4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-iot/types.rb', line 4472 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
True to enable the fleet provisioning template, otherwise false.
4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-iot/types.rb', line 4472 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags) SENSITIVE = [] include Aws::Structure end |
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Creates a pre-provisioning hook template.
4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-iot/types.rb', line 4472 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags) SENSITIVE = [] include Aws::Structure end |
#provisioning_role_arn ⇒ String
The role ARN for the role associated with the fleet provisioning template. This IoT role grants permission to provision a device.
4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-iot/types.rb', line 4472 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata which can be used to manage the fleet provisioning template.
<note markdown=“1”> For URI Request parameters use format: …key1=value1&key2=value2…
For the CLI command-line parameter use format: &&tags
“key1=value1&key2=value2…”
For the cli-input-json file use format: "tags":
“key1=value1&key2=value2…”
</note>
4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-iot/types.rb', line 4472 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags) SENSITIVE = [] include Aws::Structure end |
#template_body ⇒ String
The JSON formatted contents of the fleet provisioning template.
4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-iot/types.rb', line 4472 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the fleet provisioning template.
4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-iot/types.rb', line 4472 class CreateProvisioningTemplateRequest < Struct.new( :template_name, :description, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook, :tags) SENSITIVE = [] include Aws::Structure end |