Class: Aws::IoT::Types::CreateProvisioningTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass CreateProvisioningTemplateRequest data as a hash:

{
  template_name: "TemplateName", # required
  description: "TemplateDescription",
  template_body: "TemplateBody", # required
  enabled: false,
  provisioning_role_arn: "RoleArn", # required
  pre_provisioning_hook: {
    payload_version: "PayloadVersion",
    target_arn: "TargetArn", # required
  },
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the fleet provisioning template.

Returns:

  • (String)


4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
# File 'lib/aws-sdk-iot/types.rb', line 4413

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

True to enable the fleet provisioning template, otherwise false.

Returns:

  • (Boolean)


4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
# File 'lib/aws-sdk-iot/types.rb', line 4413

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#pre_provisioning_hookTypes::ProvisioningHook

Creates a pre-provisioning hook template.



4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
# File 'lib/aws-sdk-iot/types.rb', line 4413

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#provisioning_role_arnString

The role ARN for the role associated with the fleet provisioning template. This IoT role grants permission to provision a device.

Returns:

  • (String)


4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
# File 'lib/aws-sdk-iot/types.rb', line 4413

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata which can be used to manage the fleet provisioning template.

<note markdown=“1”> For URI Request parameters use format: …key1=value1&amp;key2=value2…

For the CLI command-line parameter use format: &amp;&amp;tags

“key1=value1&amp;key2=value2…”

For the cli-input-json file use format: "tags":

“key1=value1&amp;key2=value2…”

</note>

Returns:



4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
# File 'lib/aws-sdk-iot/types.rb', line 4413

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#template_bodyString

The JSON formatted contents of the fleet provisioning template.

Returns:

  • (String)


4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
# File 'lib/aws-sdk-iot/types.rb', line 4413

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the fleet provisioning template.

Returns:

  • (String)


4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
# File 'lib/aws-sdk-iot/types.rb', line 4413

class CreateProvisioningTemplateRequest < Struct.new(
  :template_name,
  :description,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end