Class: Aws::IoT::Types::CreateRoleAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass CreateRoleAliasRequest data as a hash:

{
  role_alias: "RoleAlias", # required
  role_arn: "RoleArn", # required
  credential_duration_seconds: 1,
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#credential_duration_secondsInteger

How long (in seconds) the credentials will be valid. The default value is 3,600 seconds.

This value must be less than or equal to the maximum session duration of the IAM role that the role alias references.

Returns:

  • (Integer)


4619
4620
4621
4622
4623
4624
4625
4626
# File 'lib/aws-sdk-iot/types.rb', line 4619

class CreateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_aliasString

The role alias that points to a role ARN. This allows you to change the role without having to update the device.

Returns:

  • (String)


4619
4620
4621
4622
4623
4624
4625
4626
# File 'lib/aws-sdk-iot/types.rb', line 4619

class CreateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The role ARN.

Returns:

  • (String)


4619
4620
4621
4622
4623
4624
4625
4626
# File 'lib/aws-sdk-iot/types.rb', line 4619

class CreateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata which can be used to manage the role alias.

<note markdown=“1”> For URI Request parameters use format: …key1=value1&amp;key2=value2…

For the CLI command-line parameter use format: &amp;&amp;tags

“key1=value1&amp;key2=value2…”

For the cli-input-json file use format: "tags":

“key1=value1&amp;key2=value2…”

</note>

Returns:



4619
4620
4621
4622
4623
4624
4625
4626
# File 'lib/aws-sdk-iot/types.rb', line 4619

class CreateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end