Class: Aws::IoT::Types::CreateScheduledAuditRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass CreateScheduledAuditRequest data as a hash:

{
  frequency: "DAILY", # required, accepts DAILY, WEEKLY, BIWEEKLY, MONTHLY
  day_of_month: "DayOfMonth",
  day_of_week: "SUN", # accepts SUN, MON, TUE, WED, THU, FRI, SAT
  target_check_names: ["AuditCheckName"], # required
  scheduled_audit_name: "ScheduledAuditName", # required
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#day_of_monthString

The day of the month on which the scheduled audit takes place. This can be “1” through “31” or “LAST”. This field is required if the “frequency” parameter is set to `MONTHLY`. If days 29 to 31 are specified, and the month doesn't have that many days, the audit takes place on the `LAST` day of the month.

Returns:

  • (String)


4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
# File 'lib/aws-sdk-iot/types.rb', line 4639

class CreateScheduledAuditRequest < Struct.new(
  :frequency,
  :day_of_month,
  :day_of_week,
  :target_check_names,
  :scheduled_audit_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#day_of_weekString

The day of the week on which the scheduled audit takes place, either `SUN`, `MON`, `TUE`, `WED`, `THU`, `FRI`, or `SAT`. This field is required if the `frequency` parameter is set to `WEEKLY` or `BIWEEKLY`.

Returns:

  • (String)


4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
# File 'lib/aws-sdk-iot/types.rb', line 4639

class CreateScheduledAuditRequest < Struct.new(
  :frequency,
  :day_of_month,
  :day_of_week,
  :target_check_names,
  :scheduled_audit_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#frequencyString

How often the scheduled audit takes place, either `DAILY`, `WEEKLY`, `BIWEEKLY` or `MONTHLY`. The start time of each audit is determined by the system.

Returns:

  • (String)


4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
# File 'lib/aws-sdk-iot/types.rb', line 4639

class CreateScheduledAuditRequest < Struct.new(
  :frequency,
  :day_of_month,
  :day_of_week,
  :target_check_names,
  :scheduled_audit_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_audit_nameString

The name you want to give to the scheduled audit. (Max. 128 chars)

Returns:

  • (String)


4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
# File 'lib/aws-sdk-iot/types.rb', line 4639

class CreateScheduledAuditRequest < Struct.new(
  :frequency,
  :day_of_month,
  :day_of_week,
  :target_check_names,
  :scheduled_audit_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata that can be used to manage the scheduled audit.

Returns:



4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
# File 'lib/aws-sdk-iot/types.rb', line 4639

class CreateScheduledAuditRequest < Struct.new(
  :frequency,
  :day_of_month,
  :day_of_week,
  :target_check_names,
  :scheduled_audit_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_check_namesArray<String>

Which checks are performed during the scheduled audit. Checks must be enabled for your account. (Use `DescribeAccountAuditConfiguration` to see the list of all checks, including those that are enabled or use `UpdateAccountAuditConfiguration` to select which checks are enabled.)

Returns:

  • (Array<String>)


4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
# File 'lib/aws-sdk-iot/types.rb', line 4639

class CreateScheduledAuditRequest < Struct.new(
  :frequency,
  :day_of_month,
  :day_of_week,
  :target_check_names,
  :scheduled_audit_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end