Class: Aws::IoT::Types::CreateSecurityProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass CreateSecurityProfileRequest data as a hash:

{
  security_profile_name: "SecurityProfileName", # required
  security_profile_description: "SecurityProfileDescription",
  behaviors: [
    {
      name: "BehaviorName", # required
      metric: "BehaviorMetric",
      metric_dimension: {
        dimension_name: "DimensionName", # required
        operator: "IN", # accepts IN, NOT_IN
      },
      criteria: {
        comparison_operator: "less-than", # accepts less-than, less-than-equals, greater-than, greater-than-equals, in-cidr-set, not-in-cidr-set, in-port-set, not-in-port-set, in-set, not-in-set
        value: {
          count: 1,
          cidrs: ["Cidr"],
          ports: [1],
          number: 1.0,
          numbers: [1.0],
          strings: ["stringValue"],
        },
        duration_seconds: 1,
        consecutive_datapoints_to_alarm: 1,
        consecutive_datapoints_to_clear: 1,
        statistical_threshold: {
          statistic: "EvaluationStatistic",
        },
        ml_detection_config: {
          confidence_level: "LOW", # required, accepts LOW, MEDIUM, HIGH
        },
      },
      suppress_alerts: false,
    },
  ],
  alert_targets: {
    "SNS" => {
      alert_target_arn: "AlertTargetArn", # required
      role_arn: "RoleArn", # required
    },
  },
  additional_metrics_to_retain: ["BehaviorMetric"],
  additional_metrics_to_retain_v2: [
    {
      metric: "BehaviorMetric", # required
      metric_dimension: {
        dimension_name: "DimensionName", # required
        operator: "IN", # accepts IN, NOT_IN
      },
    },
  ],
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue",
    },
  ],
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_metrics_to_retainArray<String>

*Please use CreateSecurityProfileRequest$additionalMetricsToRetainV2 instead.*

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's `behaviors`, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.

Returns:

  • (Array<String>)


4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-iot/types.rb', line 4807

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#additional_metrics_to_retain_v2Array<Types::MetricToRetain>

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's `behaviors`, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.

Returns:



4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-iot/types.rb', line 4807

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#alert_targetsHash<String,Types::AlertTarget>

Specifies the destinations to which alerts are sent. (Alerts are always sent to the console.) Alerts are generated when a device (thing) violates a behavior.

Returns:



4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-iot/types.rb', line 4807

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#behaviorsArray<Types::Behavior>

Specifies the behaviors that, when violated by a device (thing), cause an alert.

Returns:



4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-iot/types.rb', line 4807

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_descriptionString

A description of the security profile.

Returns:

  • (String)


4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-iot/types.rb', line 4807

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_nameString

The name you are giving to the security profile.

Returns:

  • (String)


4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-iot/types.rb', line 4807

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata that can be used to manage the security profile.

Returns:



4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-iot/types.rb', line 4807

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end