Class: Aws::IoT::Types::CreateSecurityProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_metrics_to_retainArray<String>

*Please use CreateSecurityProfileRequest$additionalMetricsToRetainV2 instead.*

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.

Returns:

  • (Array<String>)


3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-iot/types.rb', line 3602

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#additional_metrics_to_retain_v2Array<Types::MetricToRetain>

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-iot/types.rb', line 3602

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#alert_targetsHash<String,Types::AlertTarget>

Specifies the destinations to which alerts are sent. (Alerts are always sent to the console.) Alerts are generated when a device (thing) violates a behavior.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-iot/types.rb', line 3602

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#behaviorsArray<Types::Behavior>

Specifies the behaviors that, when violated by a device (thing), cause an alert.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-iot/types.rb', line 3602

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_descriptionString

A description of the security profile.

Returns:

  • (String)


3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-iot/types.rb', line 3602

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_nameString

The name you are giving to the security profile.

Returns:

  • (String)


3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-iot/types.rb', line 3602

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Metadata that can be used to manage the security profile.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-iot/types.rb', line 3602

class CreateSecurityProfileRequest < Struct.new(
  :security_profile_name,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end