Class: Aws::IoT::Types::DeleteDynamicThingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass DeleteDynamicThingGroupRequest data as a hash:

{
  thing_group_name: "ThingGroupName", # required
  expected_version: 1,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_versionInteger

The expected version of the dynamic thing group to delete.

Returns:

  • (Integer)


5862
5863
5864
5865
5866
5867
# File 'lib/aws-sdk-iot/types.rb', line 5862

class DeleteDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#thing_group_nameString

The name of the dynamic thing group to delete.

Returns:

  • (String)


5862
5863
5864
5865
5866
5867
# File 'lib/aws-sdk-iot/types.rb', line 5862

class DeleteDynamicThingGroupRequest < Struct.new(
  :thing_group_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end