Class: Aws::IoT::Types::DeleteDynamicThingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteDynamicThingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteDynamicThingGroupRequest data as a hash:
{
thing_group_name: "ThingGroupName", # required
expected_version: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_version ⇒ Integer
The expected version of the dynamic thing group to delete.
-
#thing_group_name ⇒ String
The name of the dynamic thing group to delete.
Instance Attribute Details
#expected_version ⇒ Integer
The expected version of the dynamic thing group to delete.
5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-iot/types.rb', line 5780 class DeleteDynamicThingGroupRequest < Struct.new( :thing_group_name, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
The name of the dynamic thing group to delete.
5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-iot/types.rb', line 5780 class DeleteDynamicThingGroupRequest < Struct.new( :thing_group_name, :expected_version) SENSITIVE = [] include Aws::Structure end |