Class: Aws::IoT::Types::DeleteThingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteThingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The input for the DeleteThing operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_version ⇒ Integer
The expected version of the thing record in the registry.
-
#thing_name ⇒ String
The name of the thing to delete.
Instance Attribute Details
#expected_version ⇒ Integer
The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the ‘DeleteThing` request is rejected with a `VersionConflictException`.
4409 4410 4411 4412 4413 4414 |
# File 'lib/aws-sdk-iot/types.rb', line 4409 class DeleteThingRequest < Struct.new( :thing_name, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing to delete.
4409 4410 4411 4412 4413 4414 |
# File 'lib/aws-sdk-iot/types.rb', line 4409 class DeleteThingRequest < Struct.new( :thing_name, :expected_version) SENSITIVE = [] include Aws::Structure end |