Class: Aws::IoT::Types::DeleteThingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass DeleteThingRequest data as a hash:

{
  thing_name: "ThingName", # required
  expected_version: 1,
}

The input for the DeleteThing operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_versionInteger

The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the `DeleteThing` request is rejected with a `VersionConflictException`.

Returns:

  • (Integer)


6425
6426
6427
6428
6429
6430
# File 'lib/aws-sdk-iot/types.rb', line 6425

class DeleteThingRequest < Struct.new(
  :thing_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

The name of the thing to delete.

Returns:

  • (String)


6425
6426
6427
6428
6429
6430
# File 'lib/aws-sdk-iot/types.rb', line 6425

class DeleteThingRequest < Struct.new(
  :thing_name,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end