Class: Aws::IoT::Types::DeleteV2LoggingLevelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass DeleteV2LoggingLevelRequest data as a hash:

{
  target_type: "DEFAULT", # required, accepts DEFAULT, THING_GROUP, CLIENT_ID, SOURCE_IP, PRINCIPAL_ID
  target_name: "LogTargetName", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#target_nameString

The name of the resource for which you are configuring logging.

Returns:

  • (String)


6514
6515
6516
6517
6518
6519
# File 'lib/aws-sdk-iot/types.rb', line 6514

class DeleteV2LoggingLevelRequest < Struct.new(
  :target_type,
  :target_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_typeString

The type of resource for which you are configuring logging. Must be `THING_Group`.

Returns:

  • (String)


6514
6515
6516
6517
6518
6519
# File 'lib/aws-sdk-iot/types.rb', line 6514

class DeleteV2LoggingLevelRequest < Struct.new(
  :target_type,
  :target_name)
  SENSITIVE = []
  include Aws::Structure
end