Class: Aws::IoT::Types::DeleteV2LoggingLevelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DeleteV2LoggingLevelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DeleteV2LoggingLevelRequest data as a hash:
{
target_type: "DEFAULT", # required, accepts DEFAULT, THING_GROUP, CLIENT_ID, SOURCE_IP, PRINCIPAL_ID
target_name: "LogTargetName", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_name ⇒ String
The name of the resource for which you are configuring logging.
-
#target_type ⇒ String
The type of resource for which you are configuring logging.
Instance Attribute Details
#target_name ⇒ String
The name of the resource for which you are configuring logging.
6334 6335 6336 6337 6338 6339 |
# File 'lib/aws-sdk-iot/types.rb', line 6334 class DeleteV2LoggingLevelRequest < Struct.new( :target_type, :target_name) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The type of resource for which you are configuring logging. Must be `THING_Group`.
6334 6335 6336 6337 6338 6339 |
# File 'lib/aws-sdk-iot/types.rb', line 6334 class DeleteV2LoggingLevelRequest < Struct.new( :target_type, :target_name) SENSITIVE = [] include Aws::Structure end |