Class: Aws::IoT::Types::DescribeAccountAuditConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audit_check_configurationsHash<String,Types::AuditCheckConfiguration>

Which audit checks are enabled and disabled for this account.

Returns:



5645
5646
5647
5648
5649
5650
5651
# File 'lib/aws-sdk-iot/types.rb', line 5645

class DescribeAccountAuditConfigurationResponse < Struct.new(
  :role_arn,
  :audit_notification_target_configurations,
  :audit_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#audit_notification_target_configurationsHash<String,Types::AuditNotificationTarget>

Information about the targets to which audit notifications are sent for this account.

Returns:



5645
5646
5647
5648
5649
5650
5651
# File 'lib/aws-sdk-iot/types.rb', line 5645

class DescribeAccountAuditConfigurationResponse < Struct.new(
  :role_arn,
  :audit_notification_target_configurations,
  :audit_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the role that grants permission to IoT to access information about your devices, policies, certificates, and other items as required when performing an audit.

On the first call to ‘UpdateAccountAuditConfiguration`, this parameter is required.

Returns:

  • (String)


5645
5646
5647
5648
5649
5650
5651
# File 'lib/aws-sdk-iot/types.rb', line 5645

class DescribeAccountAuditConfigurationResponse < Struct.new(
  :role_arn,
  :audit_notification_target_configurations,
  :audit_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end