Class: Aws::IoT::Types::DescribeAccountAuditConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeAccountAuditConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_check_configurations ⇒ Hash<String,Types::AuditCheckConfiguration>
Which audit checks are enabled and disabled for this account.
-
#audit_notification_target_configurations ⇒ Hash<String,Types::AuditNotificationTarget>
Information about the targets to which audit notifications are sent for this account.
-
#role_arn ⇒ String
The ARN of the role that grants permission to IoT to access information about your devices, policies, certificates, and other items as required when performing an audit.
Instance Attribute Details
#audit_check_configurations ⇒ Hash<String,Types::AuditCheckConfiguration>
Which audit checks are enabled and disabled for this account.
6542 6543 6544 6545 6546 6547 6548 |
# File 'lib/aws-sdk-iot/types.rb', line 6542 class DescribeAccountAuditConfigurationResponse < Struct.new( :role_arn, :audit_notification_target_configurations, :audit_check_configurations) SENSITIVE = [] include Aws::Structure end |
#audit_notification_target_configurations ⇒ Hash<String,Types::AuditNotificationTarget>
Information about the targets to which audit notifications are sent for this account.
6542 6543 6544 6545 6546 6547 6548 |
# File 'lib/aws-sdk-iot/types.rb', line 6542 class DescribeAccountAuditConfigurationResponse < Struct.new( :role_arn, :audit_notification_target_configurations, :audit_check_configurations) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the role that grants permission to IoT to access information about your devices, policies, certificates, and other items as required when performing an audit.
On the first call to `UpdateAccountAuditConfiguration`, this parameter is required.
6542 6543 6544 6545 6546 6547 6548 |
# File 'lib/aws-sdk-iot/types.rb', line 6542 class DescribeAccountAuditConfigurationResponse < Struct.new( :role_arn, :audit_notification_target_configurations, :audit_check_configurations) SENSITIVE = [] include Aws::Structure end |