Class: Aws::IoT::Types::DescribeAccountAuditConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audit_check_configurationsHash<String,Types::AuditCheckConfiguration>

Which audit checks are enabled and disabled for this account.

Returns:



6413
6414
6415
6416
6417
6418
6419
# File 'lib/aws-sdk-iot/types.rb', line 6413

class DescribeAccountAuditConfigurationResponse < Struct.new(
  :role_arn,
  :audit_notification_target_configurations,
  :audit_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#audit_notification_target_configurationsHash<String,Types::AuditNotificationTarget>

Information about the targets to which audit notifications are sent for this account.

Returns:



6413
6414
6415
6416
6417
6418
6419
# File 'lib/aws-sdk-iot/types.rb', line 6413

class DescribeAccountAuditConfigurationResponse < Struct.new(
  :role_arn,
  :audit_notification_target_configurations,
  :audit_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the role that grants permission to IoT to access information about your devices, policies, certificates, and other items as required when performing an audit.

On the first call to `UpdateAccountAuditConfiguration`, this parameter is required.

Returns:

  • (String)


6413
6414
6415
6416
6417
6418
6419
# File 'lib/aws-sdk-iot/types.rb', line 6413

class DescribeAccountAuditConfigurationResponse < Struct.new(
  :role_arn,
  :audit_notification_target_configurations,
  :audit_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end