Class: Aws::IoT::Types::DescribeAuditMitigationActionsTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeAuditMitigationActionsTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions_definition ⇒ Array<Types::MitigationAction>
Specifies the mitigation actions and their parameters that are applied as part of this task.
-
#audit_check_to_actions_mapping ⇒ Hash<String,Array<String>>
Specifies the mitigation actions that should be applied to specific audit checks.
-
#end_time ⇒ Time
The date and time when the task was completed or canceled.
-
#start_time ⇒ Time
The date and time when the task was started.
-
#target ⇒ Types::AuditMitigationActionsTaskTarget
Identifies the findings to which the mitigation actions are applied.
-
#task_statistics ⇒ Hash<String,Types::TaskStatisticsForAuditCheck>
Aggregate counts of the results when the mitigation tasks were applied to the findings for this audit mitigation actions task.
-
#task_status ⇒ String
The current status of the task.
Instance Attribute Details
#actions_definition ⇒ Array<Types::MitigationAction>
Specifies the mitigation actions and their parameters that are applied as part of this task.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 |
# File 'lib/aws-sdk-iot/types.rb', line 6570 class DescribeAuditMitigationActionsTaskResponse < Struct.new( :task_status, :start_time, :end_time, :task_statistics, :target, :audit_check_to_actions_mapping, :actions_definition) SENSITIVE = [] include Aws::Structure end |
#audit_check_to_actions_mapping ⇒ Hash<String,Array<String>>
Specifies the mitigation actions that should be applied to specific audit checks.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 |
# File 'lib/aws-sdk-iot/types.rb', line 6570 class DescribeAuditMitigationActionsTaskResponse < Struct.new( :task_status, :start_time, :end_time, :task_statistics, :target, :audit_check_to_actions_mapping, :actions_definition) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time when the task was completed or canceled.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 |
# File 'lib/aws-sdk-iot/types.rb', line 6570 class DescribeAuditMitigationActionsTaskResponse < Struct.new( :task_status, :start_time, :end_time, :task_statistics, :target, :audit_check_to_actions_mapping, :actions_definition) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time when the task was started.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 |
# File 'lib/aws-sdk-iot/types.rb', line 6570 class DescribeAuditMitigationActionsTaskResponse < Struct.new( :task_status, :start_time, :end_time, :task_statistics, :target, :audit_check_to_actions_mapping, :actions_definition) SENSITIVE = [] include Aws::Structure end |
#target ⇒ Types::AuditMitigationActionsTaskTarget
Identifies the findings to which the mitigation actions are applied. This can be by audit checks, by audit task, or a set of findings.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 |
# File 'lib/aws-sdk-iot/types.rb', line 6570 class DescribeAuditMitigationActionsTaskResponse < Struct.new( :task_status, :start_time, :end_time, :task_statistics, :target, :audit_check_to_actions_mapping, :actions_definition) SENSITIVE = [] include Aws::Structure end |
#task_statistics ⇒ Hash<String,Types::TaskStatisticsForAuditCheck>
Aggregate counts of the results when the mitigation tasks were applied to the findings for this audit mitigation actions task.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 |
# File 'lib/aws-sdk-iot/types.rb', line 6570 class DescribeAuditMitigationActionsTaskResponse < Struct.new( :task_status, :start_time, :end_time, :task_statistics, :target, :audit_check_to_actions_mapping, :actions_definition) SENSITIVE = [] include Aws::Structure end |
#task_status ⇒ String
The current status of the task.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 |
# File 'lib/aws-sdk-iot/types.rb', line 6570 class DescribeAuditMitigationActionsTaskResponse < Struct.new( :task_status, :start_time, :end_time, :task_statistics, :target, :audit_check_to_actions_mapping, :actions_definition) SENSITIVE = [] include Aws::Structure end |