Class: Aws::IoT::Types::DescribeDimensionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeDimensionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the dimension.
-
#creation_date ⇒ Time
The date the dimension was created.
-
#last_modified_date ⇒ Time
The date the dimension was last modified.
-
#name ⇒ String
The unique identifier for the dimension.
-
#string_values ⇒ Array<String>
The value or list of values used to scope the dimension.
-
#type ⇒ String
The type of the dimension.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the dimension.
4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/aws-sdk-iot/types.rb', line 4968 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date the dimension was created.
4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/aws-sdk-iot/types.rb', line 4968 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the dimension was last modified.
4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/aws-sdk-iot/types.rb', line 4968 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique identifier for the dimension.
4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/aws-sdk-iot/types.rb', line 4968 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#string_values ⇒ Array<String>
The value or list of values used to scope the dimension. For example, for topic filters, this is the pattern used to match the MQTT topic name.
4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/aws-sdk-iot/types.rb', line 4968 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the dimension.
4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 |
# File 'lib/aws-sdk-iot/types.rb', line 4968 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |