Class: Aws::IoT::Types::DescribeDimensionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeDimensionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the dimension.
-
#creation_date ⇒ Time
The date the dimension was created.
-
#last_modified_date ⇒ Time
The date the dimension was last modified.
-
#name ⇒ String
The unique identifier for the dimension.
-
#string_values ⇒ Array<String>
The value or list of values used to scope the dimension.
-
#type ⇒ String
The type of the dimension.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the dimension.
4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-iot/types.rb', line 4951 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date the dimension was created.
4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-iot/types.rb', line 4951 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the dimension was last modified.
4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-iot/types.rb', line 4951 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique identifier for the dimension.
4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-iot/types.rb', line 4951 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#string_values ⇒ Array<String>
The value or list of values used to scope the dimension. For example, for topic filters, this is the pattern used to match the MQTT topic name.
4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-iot/types.rb', line 4951 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the dimension.
4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-iot/types.rb', line 4951 class DescribeDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |