Class: Aws::IoT::Types::DescribeEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DescribeEndpointRequest data as a hash:
{
endpoint_type: "EndpointType",
}
The input for the DescribeEndpoint operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint_type ⇒ String
The endpoint type.
Instance Attribute Details
#endpoint_type ⇒ String
The endpoint type. Valid endpoint types include:
-
`iot:Data` - Returns a VeriSign signed data endpoint.
^ ^
-
`iot:Data-ATS` - Returns an ATS signed data endpoint.
^ ^
-
`iot:CredentialProvider` - Returns an IoT credentials provider API endpoint.
^ ^
-
`iot:Jobs` - Returns an IoT device management Jobs API endpoint.
^
We strongly recommend that customers use the newer `iot:Data-ATS` endpoint type to avoid issues related to the widespread distrust of Symantec certificate authorities.
7105 7106 7107 7108 7109 |
# File 'lib/aws-sdk-iot/types.rb', line 7105 class DescribeEndpointRequest < Struct.new( :endpoint_type) SENSITIVE = [] include Aws::Structure end |