Class: Aws::IoT::Types::DescribeJobTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#abort_configTypes::AbortConfig

The criteria that determine when and how a job abort takes place.

Returns:



5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time, in seconds since the epoch, when the job template was created.

Returns:

  • (Time)


5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the job template.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#destination_package_versionsArray<String>

The package version Amazon Resource Names (ARNs) that are installed on the device when the job successfully completes.

**Note:**The following Length Constraints relates to a single string. Up to five strings are allowed.

Returns:

  • (Array<String>)


5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#documentString

The job document.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#document_sourceString

An S3 link to the job document.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_retry_configTypes::JobExecutionsRetryConfig

The configuration that determines how many retries are allowed for each failure type for a job.



5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_rollout_configTypes::JobExecutionsRolloutConfig

Allows you to create a staged rollout of a job.



5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_template_arnString

The ARN of the job template.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#job_template_idString

The unique identifier of the job template.

Returns:

  • (String)


5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_windowsArray<Types::MaintenanceWindow>

Allows you to configure an optional maintenance window for the rollout of a job document to all devices in the target group for a job.

Returns:



5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#presigned_url_configTypes::PresignedUrlConfig

Configuration for pre-signed S3 URLs.



5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_configTypes::TimeoutConfig

Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to ‘IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.



5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
# File 'lib/aws-sdk-iot/types.rb', line 5607

class DescribeJobTemplateResponse < Struct.new(
  :job_template_arn,
  :job_template_id,
  :description,
  :document_source,
  :document,
  :created_at,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :timeout_config,
  :job_executions_retry_config,
  :maintenance_windows,
  :destination_package_versions)
  SENSITIVE = []
  include Aws::Structure
end