Class: Aws::IoT::Types::DescribeProvisioningTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_dateTime

The date when the fleet provisioning template was created.

Returns:

  • (Time)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#default_version_idInteger

The default fleet template version ID.

Returns:

  • (Integer)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the fleet provisioning template.

Returns:

  • (String)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

True if the fleet provisioning template is enabled, otherwise false.

Returns:

  • (Boolean)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date when the fleet provisioning template was last modified.

Returns:

  • (Time)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#pre_provisioning_hookTypes::ProvisioningHook

Gets information about a pre-provisioned hook.



7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#provisioning_role_arnString

The ARN of the role associated with the provisioning template. This IoT role grants permission to provision a device.

Returns:

  • (String)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#template_arnString

The ARN of the fleet provisioning template.

Returns:

  • (String)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#template_bodyString

The JSON formatted contents of the fleet provisioning template.

Returns:

  • (String)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the fleet provisioning template.

Returns:

  • (String)


7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/aws-sdk-iot/types.rb', line 7582

class DescribeProvisioningTemplateResponse < Struct.new(
  :template_arn,
  :template_name,
  :description,
  :creation_date,
  :last_modified_date,
  :default_version_id,
  :template_body,
  :enabled,
  :provisioning_role_arn,
  :pre_provisioning_hook)
  SENSITIVE = []
  include Aws::Structure
end