Class: Aws::IoT::Types::DescribeProvisioningTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeProvisioningTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date when the fleet provisioning template was created.
-
#default_version_id ⇒ Integer
The default fleet template version ID.
-
#description ⇒ String
The description of the fleet provisioning template.
-
#enabled ⇒ Boolean
True if the fleet provisioning template is enabled, otherwise false.
-
#last_modified_date ⇒ Time
The date when the fleet provisioning template was last modified.
-
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Gets information about a pre-provisioned hook.
-
#provisioning_role_arn ⇒ String
The ARN of the role associated with the provisioning template.
-
#template_arn ⇒ String
The ARN of the fleet provisioning template.
-
#template_body ⇒ String
The JSON formatted contents of the fleet provisioning template.
-
#template_name ⇒ String
The name of the fleet provisioning template.
Instance Attribute Details
#creation_date ⇒ Time
The date when the fleet provisioning template was created.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#default_version_id ⇒ Integer
The default fleet template version ID.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the fleet provisioning template.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
True if the fleet provisioning template is enabled, otherwise false.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date when the fleet provisioning template was last modified.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Gets information about a pre-provisioned hook.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#provisioning_role_arn ⇒ String
The ARN of the role associated with the provisioning template. This IoT role grants permission to provision a device.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#template_arn ⇒ String
The ARN of the fleet provisioning template.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#template_body ⇒ String
The JSON formatted contents of the fleet provisioning template.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the fleet provisioning template.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 |
# File 'lib/aws-sdk-iot/types.rb', line 7582 class DescribeProvisioningTemplateResponse < Struct.new( :template_arn, :template_name, :description, :creation_date, :last_modified_date, :default_version_id, :template_body, :enabled, :provisioning_role_arn, :pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |