Class: Aws::IoT::Types::DescribeSecurityProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DescribeSecurityProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_metrics_to_retain ⇒ Array<String>
*Please use DescribeSecurityProfileResponse$additionalMetricsToRetainV2 instead.*.
-
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored).
-
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Where the alerts are sent.
-
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
-
#creation_date ⇒ Time
The time the security profile was created.
-
#last_modified_date ⇒ Time
The time the security profile was last modified.
-
#metrics_export_config ⇒ Types::MetricsExportConfig
Specifies the MQTT topic and role ARN required for metric export.
-
#security_profile_arn ⇒ String
The ARN of the security profile.
-
#security_profile_description ⇒ String
A description of the security profile (associated with the security profile when it was created or updated).
-
#security_profile_name ⇒ String
The name of the security profile.
-
#version ⇒ Integer
The version of the security profile.
Instance Attribute Details
#additional_metrics_to_retain ⇒ Array<String>
*Please use DescribeSecurityProfileResponse$additionalMetricsToRetainV2 instead.*
A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s ‘behaviors`, but it is also retained for any metric specified here.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s behaviors, but it is also retained for any metric specified here.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Where the alerts are sent. (Alerts are always sent to the console.)
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The time the security profile was created.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The time the security profile was last modified.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#metrics_export_config ⇒ Types::MetricsExportConfig
Specifies the MQTT topic and role ARN required for metric export.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_arn ⇒ String
The ARN of the security profile.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_description ⇒ String
A description of the security profile (associated with the security profile when it was created or updated).
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_name ⇒ String
The name of the security profile.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of the security profile. A new version is generated whenever the security profile is updated.
7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/aws-sdk-iot/types.rb', line 7100 class DescribeSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |