Class: Aws::IoT::Types::DescribeSecurityProfileResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_metrics_to_retainArray<String>

*Please use DescribeSecurityProfileResponse$additionalMetricsToRetainV2 instead.*

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s ‘behaviors`, but it is also retained for any metric specified here.

Returns:

  • (Array<String>)


7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#additional_metrics_to_retain_v2Array<Types::MetricToRetain>

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s behaviors, but it is also retained for any metric specified here.

Returns:



7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#alert_targetsHash<String,Types::AlertTarget>

Where the alerts are sent. (Alerts are always sent to the console.)

Returns:



7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#behaviorsArray<Types::Behavior>

Specifies the behaviors that, when violated by a device (thing), cause an alert.

Returns:



7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The time the security profile was created.

Returns:

  • (Time)


7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The time the security profile was last modified.

Returns:

  • (Time)


7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#metrics_export_configTypes::MetricsExportConfig

Specifies the MQTT topic and role ARN required for metric export.



7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_arnString

The ARN of the security profile.

Returns:

  • (String)


7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_descriptionString

A description of the security profile (associated with the security profile when it was created or updated).

Returns:

  • (String)


7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_nameString

The name of the security profile.

Returns:

  • (String)


7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version of the security profile. A new version is generated whenever the security profile is updated.

Returns:

  • (Integer)


7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-iot/types.rb', line 7071

class DescribeSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date,
  :metrics_export_config)
  SENSITIVE = []
  include Aws::Structure
end