Class: Aws::IoT::Types::DescribeThingResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The output from the DescribeThing operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

The thing attributes.

Returns:

  • (Hash<String,String>)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#billing_group_nameString

The name of the billing group the thing belongs to.

Returns:

  • (String)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#default_client_idString

The default MQTT client ID. For a typical device, the thing name is also used as the default MQTT client ID. Although we don’t require a mapping between a thing's registry name and its use of MQTT client IDs, certificates, or shadow state, we recommend that you choose a thing name and use it as the MQTT client ID for the registry and the Device Shadow service.

This lets you better organize your IoT fleet without removing the flexibility of the underlying device certificate model or shadows.

Returns:

  • (String)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#thing_arnString

The ARN of the thing to describe.

Returns:

  • (String)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#thing_idString

The ID of the thing to describe.

Returns:

  • (String)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

The name of the thing.

Returns:

  • (String)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#thing_type_nameString

The thing type name.

Returns:

  • (String)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The current version of the thing record in the registry.

<note markdown=“1”> To avoid unintentional changes to the information in the registry, you can pass the version information in the `expectedVersion` parameter of the `UpdateThing` and `DeleteThing` calls.

</note>

Returns:

  • (Integer)


5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-iot/types.rb', line 5979

class DescribeThingResponse < Struct.new(
  :default_client_id,
  :thing_name,
  :thing_id,
  :thing_arn,
  :thing_type_name,
  :attributes,
  :version,
  :billing_group_name)
  SENSITIVE = []
  include Aws::Structure
end