Class: Aws::IoT::Types::DetachPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DetachPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DetachPolicyRequest data as a hash:
{
policy_name: "PolicyName", # required
target: "PolicyTarget", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_name ⇒ String
The policy to detach.
-
#target ⇒ String
The target from which the policy will be detached.
Instance Attribute Details
#policy_name ⇒ String
The policy to detach.
8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-iot/types.rb', line 8265 class DetachPolicyRequest < Struct.new( :policy_name, :target) SENSITIVE = [] include Aws::Structure end |
#target ⇒ String
The target from which the policy will be detached.
8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-iot/types.rb', line 8265 class DetachPolicyRequest < Struct.new( :policy_name, :target) SENSITIVE = [] include Aws::Structure end |