Class: Aws::IoT::Types::DetachThingPrincipalRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::DetachThingPrincipalRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass DetachThingPrincipalRequest data as a hash:
{
thing_name: "ThingName", # required
principal: "Principal", # required
}
The input for the DetachThingPrincipal operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#principal ⇒ String
If the principal is a certificate, this value must be ARN of the certificate.
-
#thing_name ⇒ String
The name of the thing.
Instance Attribute Details
#principal ⇒ String
If the principal is a certificate, this value must be ARN of the certificate. If the principal is an Amazon Cognito identity, this value must be the ID of the Amazon Cognito identity.
8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-iot/types.rb', line 8241 class DetachThingPrincipalRequest < Struct.new( :thing_name, :principal) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing.
8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-iot/types.rb', line 8241 class DetachThingPrincipalRequest < Struct.new( :thing_name, :principal) SENSITIVE = [] include Aws::Structure end |