Class: Aws::IoT::Types::FirehoseAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::FirehoseAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes an action that writes data to an Amazon Kinesis Firehose stream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_mode ⇒ Boolean
Whether to deliver the Kinesis Data Firehose stream as a batch by using [
PutRecordBatch][1]. -
#delivery_stream_name ⇒ String
The delivery stream name.
-
#role_arn ⇒ String
The IAM role that grants access to the Amazon Kinesis Firehose stream.
-
#separator ⇒ String
A character separator that will be used to separate records written to the Firehose stream.
Instance Attribute Details
#batch_mode ⇒ Boolean
Whether to deliver the Kinesis Data Firehose stream as a batch by
using PutRecordBatch . The default value is false.
When batchMode is true and the rule's SQL statement evaluates
to an Array, each Array element forms one record in the
PutRecordBatch request. The resulting array can't have more
than 500 records.
8089 8090 8091 8092 8093 8094 8095 8096 |
# File 'lib/aws-sdk-iot/types.rb', line 8089 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |
#delivery_stream_name ⇒ String
The delivery stream name.
8089 8090 8091 8092 8093 8094 8095 8096 |
# File 'lib/aws-sdk-iot/types.rb', line 8089 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role that grants access to the Amazon Kinesis Firehose stream.
8089 8090 8091 8092 8093 8094 8095 8096 |
# File 'lib/aws-sdk-iot/types.rb', line 8089 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |
#separator ⇒ String
A character separator that will be used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
8089 8090 8091 8092 8093 8094 8095 8096 |
# File 'lib/aws-sdk-iot/types.rb', line 8089 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |