Class: Aws::IoT::Types::FirehoseAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::FirehoseAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass FirehoseAction data as a hash:
{
role_arn: "AwsArn", # required
delivery_stream_name: "DeliveryStreamName", # required
separator: "FirehoseSeparator",
batch_mode: false,
}
Describes an action that writes data to an Amazon Kinesis Firehose stream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_mode ⇒ Boolean
Whether to deliver the Kinesis Data Firehose stream as a batch by using [ `PutRecordBatch` ][1].
-
#delivery_stream_name ⇒ String
The delivery stream name.
-
#role_arn ⇒ String
The IAM role that grants access to the Amazon Kinesis Firehose stream.
-
#separator ⇒ String
A character separator that will be used to separate records written to the Firehose stream.
Instance Attribute Details
#batch_mode ⇒ Boolean
Whether to deliver the Kinesis Data Firehose stream as a batch by using [ `PutRecordBatch` ][1]. The default value is `false`.
When `batchMode` is `true` and the rule's SQL statement evaluates to an Array, each Array element forms one record in the [ `PutRecordBatch` ][1] request. The resulting array can't have more than 500 records.
[1]: docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecordBatch.html
9040 9041 9042 9043 9044 9045 9046 9047 |
# File 'lib/aws-sdk-iot/types.rb', line 9040 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |
#delivery_stream_name ⇒ String
The delivery stream name.
9040 9041 9042 9043 9044 9045 9046 9047 |
# File 'lib/aws-sdk-iot/types.rb', line 9040 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The IAM role that grants access to the Amazon Kinesis Firehose stream.
9040 9041 9042 9043 9044 9045 9046 9047 |
# File 'lib/aws-sdk-iot/types.rb', line 9040 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |
#separator ⇒ String
A character separator that will be used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
9040 9041 9042 9043 9044 9045 9046 9047 |
# File 'lib/aws-sdk-iot/types.rb', line 9040 class FirehoseAction < Struct.new( :role_arn, :delivery_stream_name, :separator, :batch_mode) SENSITIVE = [] include Aws::Structure end |