Class: Aws::IoT::Types::FirehoseAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass FirehoseAction data as a hash:

{
  role_arn: "AwsArn", # required
  delivery_stream_name: "DeliveryStreamName", # required
  separator: "FirehoseSeparator",
  batch_mode: false,
}

Describes an action that writes data to an Amazon Kinesis Firehose stream.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_modeBoolean

Whether to deliver the Kinesis Data Firehose stream as a batch by using [ `PutRecordBatch` ][1]. The default value is `false`.

When `batchMode` is `true` and the rule's SQL statement evaluates to an Array, each Array element forms one record in the [ `PutRecordBatch` ][1] request. The resulting array can't have more than 500 records.

[1]: docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecordBatch.html

Returns:

  • (Boolean)


8945
8946
8947
8948
8949
8950
8951
8952
# File 'lib/aws-sdk-iot/types.rb', line 8945

class FirehoseAction < Struct.new(
  :role_arn,
  :delivery_stream_name,
  :separator,
  :batch_mode)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_stream_nameString

The delivery stream name.

Returns:

  • (String)


8945
8946
8947
8948
8949
8950
8951
8952
# File 'lib/aws-sdk-iot/types.rb', line 8945

class FirehoseAction < Struct.new(
  :role_arn,
  :delivery_stream_name,
  :separator,
  :batch_mode)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The IAM role that grants access to the Amazon Kinesis Firehose stream.

Returns:

  • (String)


8945
8946
8947
8948
8949
8950
8951
8952
# File 'lib/aws-sdk-iot/types.rb', line 8945

class FirehoseAction < Struct.new(
  :role_arn,
  :delivery_stream_name,
  :separator,
  :batch_mode)
  SENSITIVE = []
  include Aws::Structure
end

#separatorString

A character separator that will be used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).

Returns:

  • (String)


8945
8946
8947
8948
8949
8950
8951
8952
# File 'lib/aws-sdk-iot/types.rb', line 8945

class FirehoseAction < Struct.new(
  :role_arn,
  :delivery_stream_name,
  :separator,
  :batch_mode)
  SENSITIVE = []
  include Aws::Structure
end