Class: Aws::IoT::Types::GetBucketsAggregationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::GetBucketsAggregationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass GetBucketsAggregationRequest data as a hash:
{
index_name: "IndexName",
query_string: "QueryString", # required
aggregation_field: "AggregationField", # required
query_version: "QueryVersion",
buckets_aggregation_type: { # required
terms_aggregation: {
max_buckets: 1,
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_field ⇒ String
The aggregation field.
-
#buckets_aggregation_type ⇒ Types::BucketsAggregationType
The basic control of the response shape and the bucket aggregation type to perform.
-
#index_name ⇒ String
The name of the index to search.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The version of the query.
Instance Attribute Details
#aggregation_field ⇒ String
The aggregation field.
9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iot/types.rb', line 9125 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#buckets_aggregation_type ⇒ Types::BucketsAggregationType
The basic control of the response shape and the bucket aggregation type to perform.
9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iot/types.rb', line 9125 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to search.
9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iot/types.rb', line 9125 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string.
9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iot/types.rb', line 9125 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The version of the query.
9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iot/types.rb', line 9125 class GetBucketsAggregationRequest < Struct.new( :index_name, :query_string, :aggregation_field, :query_version, :buckets_aggregation_type) SENSITIVE = [] include Aws::Structure end |