Class: Aws::IoT::Types::GetPackageVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[:description, :attributes]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

Metadata that were added to the package version that can be used to define a package version’s configuration.

Returns:

  • (Hash<String,String>)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#creation_dateTime

The date when the package version was created.

Returns:

  • (Time)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#descriptionString

The package version description.

Returns:

  • (String)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#error_reasonString

Error reason for a package version failure during creation or update.

Returns:

  • (String)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#last_modified_dateTime

The date when the package version was last updated.

Returns:

  • (Time)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#package_nameString

The name of the software package.

Returns:

  • (String)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#package_version_arnString

The ARN for the package version.

Returns:

  • (String)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#statusString

The status associated to the package version. For more information, see [Package version lifecycle].

[1]: docs.aws.amazon.com/iot/latest/developerguide/preparing-to-use-software-package-catalog.html#package-version-lifecycle

Returns:

  • (String)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end

#version_nameString

The name of the package version.

Returns:

  • (String)


7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/aws-sdk-iot/types.rb', line 7342

class GetPackageVersionResponse < Struct.new(
  :package_version_arn,
  :package_name,
  :version_name,
  :description,
  :attributes,
  :status,
  :error_reason,
  :creation_date,
  :last_modified_date)
  SENSITIVE = [:description, :attributes]
  include Aws::Structure
end