Class: Aws::IoT::Types::GetThingConnectivityDataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]

Instance Attribute Summary collapse

Instance Attribute Details

#clean_sessionBoolean

Indicates whether the client is using a clean session. Returns ‘true` for clean sessions.

Returns:

  • (Boolean)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#client_idString

The unique identifier of the MQTT client.

Returns:

  • (String)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#connectedBoolean

A Boolean that indicates the connectivity status.

Returns:

  • (Boolean)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#disconnect_reasonString

The reason why the client is disconnecting. When you enable or update the indexing configuration, this value might be ‘UNKNOWN` for devices that have never connected or have been disconnected for more than an hour.

Returns:

  • (String)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#keep_alive_durationInteger

The keep-alive interval in seconds that the client specified when establishing the connection.

Returns:

  • (Integer)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#session_expiryInteger

The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.

Returns:

  • (Integer)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#source_ipString

The IP address of the client that initiated the connection.

Returns:

  • (String)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#source_portInteger

The client’s source port.

Returns:

  • (Integer)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#target_ipString

The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.

Returns:

  • (String)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#target_portInteger

The port number of the Amazon Web Services IoT Core endpoint that the client connected to.

Returns:

  • (Integer)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#thing_nameString

The name of your IoT thing.

Returns:

  • (String)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#timestampTime

The timestamp of when the event occurred. When you enable or update the indexing configuration, this value might be the Unix epoch time (0) for devices that have never connected or have been disconnected for more than an hour.

Returns:

  • (Time)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the VPC endpoint. Present for clients connected to Amazon Web Services IoT Core via a VPC endpoint.

Returns:

  • (String)


9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-iot/types.rb', line 9038

class GetThingConnectivityDataResponse < Struct.new(
  :thing_name,
  :connected,
  :timestamp,
  :disconnect_reason,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :vpc_endpoint_id,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
  include Aws::Structure
end