Class: Aws::IoT::Types::GetThingConnectivityDataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::GetThingConnectivityDataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id]
Instance Attribute Summary collapse
-
#clean_session ⇒ Boolean
Indicates whether the client is using a clean session.
-
#client_id ⇒ String
The unique identifier of the MQTT client.
-
#connected ⇒ Boolean
A Boolean that indicates the connectivity status.
-
#disconnect_reason ⇒ String
The reason why the client is disconnecting.
-
#keep_alive_duration ⇒ Integer
The keep-alive interval in seconds that the client specified when establishing the connection.
-
#session_expiry ⇒ Integer
The session expiry interval in seconds for the MQTT client connection.
-
#source_ip ⇒ String
The IP address of the client that initiated the connection.
-
#source_port ⇒ Integer
The client’s source port.
-
#target_ip ⇒ String
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.
-
#target_port ⇒ Integer
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
-
#thing_name ⇒ String
The name of your IoT thing.
-
#timestamp ⇒ Time
The timestamp of when the event occurred.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
Instance Attribute Details
#clean_session ⇒ Boolean
Indicates whether the client is using a clean session. Returns ‘true` for clean sessions.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#client_id ⇒ String
The unique identifier of the MQTT client.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#connected ⇒ Boolean
A Boolean that indicates the connectivity status.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#disconnect_reason ⇒ String
The reason why the client is disconnecting. When you enable or update the indexing configuration, this value might be ‘UNKNOWN` for devices that have never connected or have been disconnected for more than an hour.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#keep_alive_duration ⇒ Integer
The keep-alive interval in seconds that the client specified when establishing the connection.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#session_expiry ⇒ Integer
The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#source_ip ⇒ String
The IP address of the client that initiated the connection.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#source_port ⇒ Integer
The client’s source port.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#target_ip ⇒ String
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#target_port ⇒ Integer
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#thing_name ⇒ String
The name of your IoT thing.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#timestamp ⇒ Time
The timestamp of when the event occurred. When you enable or update the indexing configuration, this value might be the Unix epoch time (0) for devices that have never connected or have been disconnected for more than an hour.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint. Present for clients connected to Amazon Web Services IoT Core via a VPC endpoint.
9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-iot/types.rb', line 9038 class GetThingConnectivityDataResponse < Struct.new( :thing_name, :connected, :timestamp, :disconnect_reason, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [:thing_name, :source_ip, :source_port, :target_ip, :target_port, :vpc_endpoint_id] include Aws::Structure end |