Class: Aws::IoT::Types::HttpAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Send data to an HTTPS endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authTypes::HttpAuthorization

The authentication method to use when sending data to an HTTPS endpoint.



7855
7856
7857
7858
7859
7860
7861
7862
# File 'lib/aws-sdk-iot/types.rb', line 7855

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth)
  SENSITIVE = []
  include Aws::Structure
end

#confirmation_urlString

The URL to which IoT sends a confirmation message. The value of the confirmation URL must be a prefix of the endpoint URL. If you do not specify a confirmation URL IoT uses the endpoint URL as the confirmation URL. If you use substitution templates in the confirmationUrl, you must create and enable topic rule destinations that match each possible value of the substitution template before traffic is allowed to your endpoint URL.

Returns:

  • (String)


7855
7856
7857
7858
7859
7860
7861
7862
# File 'lib/aws-sdk-iot/types.rb', line 7855

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth)
  SENSITIVE = []
  include Aws::Structure
end

#headersArray<Types::HttpActionHeader>

The HTTP headers to send with the message data.

Returns:



7855
7856
7857
7858
7859
7860
7861
7862
# File 'lib/aws-sdk-iot/types.rb', line 7855

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The endpoint URL. If substitution templates are used in the URL, you must also specify a ‘confirmationUrl`. If this is a new destination, a new `TopicRuleDestination` is created if possible.

Returns:

  • (String)


7855
7856
7857
7858
7859
7860
7861
7862
# File 'lib/aws-sdk-iot/types.rb', line 7855

class HttpAction < Struct.new(
  :url,
  :confirmation_url,
  :headers,
  :auth)
  SENSITIVE = []
  include Aws::Structure
end