Class: Aws::IoT::Types::HttpAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::HttpAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass HttpAction data as a hash:
{
url: "Url", # required
confirmation_url: "Url",
headers: [
{
key: "HeaderKey", # required
value: "HeaderValue", # required
},
],
auth: {
sigv4: {
signing_region: "SigningRegion", # required
service_name: "ServiceName", # required
role_arn: "AwsArn", # required
},
},
}
Send data to an HTTPS endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth ⇒ Types::HttpAuthorization
The authentication method to use when sending data to an HTTPS endpoint.
-
#confirmation_url ⇒ String
The URL to which IoT sends a confirmation message.
-
#headers ⇒ Array<Types::HttpActionHeader>
The HTTP headers to send with the message data.
-
#url ⇒ String
The endpoint URL.
Instance Attribute Details
#auth ⇒ Types::HttpAuthorization
The authentication method to use when sending data to an HTTPS endpoint.
9742 9743 9744 9745 9746 9747 9748 9749 |
# File 'lib/aws-sdk-iot/types.rb', line 9742 class HttpAction < Struct.new( :url, :confirmation_url, :headers, :auth) SENSITIVE = [] include Aws::Structure end |
#confirmation_url ⇒ String
The URL to which IoT sends a confirmation message. The value of the confirmation URL must be a prefix of the endpoint URL. If you do not specify a confirmation URL IoT uses the endpoint URL as the confirmation URL. If you use substitution templates in the confirmationUrl, you must create and enable topic rule destinations that match each possible value of the substitution template before traffic is allowed to your endpoint URL.
9742 9743 9744 9745 9746 9747 9748 9749 |
# File 'lib/aws-sdk-iot/types.rb', line 9742 class HttpAction < Struct.new( :url, :confirmation_url, :headers, :auth) SENSITIVE = [] include Aws::Structure end |
#headers ⇒ Array<Types::HttpActionHeader>
The HTTP headers to send with the message data.
9742 9743 9744 9745 9746 9747 9748 9749 |
# File 'lib/aws-sdk-iot/types.rb', line 9742 class HttpAction < Struct.new( :url, :confirmation_url, :headers, :auth) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The endpoint URL. If substitution templates are used in the URL, you must also specify a `confirmationUrl`. If this is a new destination, a new `TopicRuleDestination` is created if possible.
9742 9743 9744 9745 9746 9747 9748 9749 |
# File 'lib/aws-sdk-iot/types.rb', line 9742 class HttpAction < Struct.new( :url, :confirmation_url, :headers, :auth) SENSITIVE = [] include Aws::Structure end |