Class: Aws::IoT::Types::HttpContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::HttpContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass HttpContext data as a hash:
{
headers: {
"HttpHeaderName" => "HttpHeaderValue",
},
query_string: "HttpQueryString",
}
Specifies the HTTP context to use for the test authorizer request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#headers ⇒ Hash<String,String>
The header keys and values in an HTTP authorization request.
-
#query_string ⇒ String
The query string keys and values in an HTTP authorization request.
Instance Attribute Details
#headers ⇒ Hash<String,String>
The header keys and values in an HTTP authorization request.
9824 9825 9826 9827 9828 9829 |
# File 'lib/aws-sdk-iot/types.rb', line 9824 class HttpContext < Struct.new( :headers, :query_string) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string keys and values in an HTTP authorization request.
9824 9825 9826 9827 9828 9829 |
# File 'lib/aws-sdk-iot/types.rb', line 9824 class HttpContext < Struct.new( :headers, :query_string) SENSITIVE = [] include Aws::Structure end |