Class: Aws::IoT::Types::InfluxDBAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::InfluxDBAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The InfluxDB rule action converts the message payload into InfluxDB line protocol. It writes the result to a table in an InfluxDB database. The database can be an Amazon Timestream for InfluxDB instance or a self-managed InfluxDB cluster.
The action connects to InfluxDB through an InfluxDB topic rule
destination, which must be in the ENABLED state before the action
can write data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_config ⇒ Types::InfluxDBBatchConfig
The batching configuration for the action.
-
#database_name ⇒ String
The name of the InfluxDB database to write to.
-
#destination_arn ⇒ String
The ARN of the InfluxDB topic rule destination that identifies the InfluxDB instance to write to.
-
#organization ⇒ String
The name of the InfluxDB organization that owns the database.
-
#role_arn ⇒ String
The ARN of the role that grants permission to retrieve the InfluxDB API token from Amazon Web Services Secrets Manager.
-
#table_name ⇒ String
The name of the table to write the data point to.
-
#tags ⇒ Hash<String,String>
The set of tags to write with each data point.
-
#timestamp_unit ⇒ String
The precision of the timestamp written with each data point.
Instance Attribute Details
#batch_config ⇒ Types::InfluxDBBatchConfig
The batching configuration for the action. When present, IoT collects data points from multiple messages and writes them to InfluxDB in a single request.
If omitted, each message is written to InfluxDB in its own request.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the InfluxDB database to write to. In InfluxDB 2, this is the name of the bucket.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |
#destination_arn ⇒ String
The ARN of the InfluxDB topic rule destination that identifies the InfluxDB instance to write to.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |
#organization ⇒ String
The name of the InfluxDB organization that owns the database.
A write to an InfluxDB 2 instance fails if this value isn't set. This value isn't used when the destination is an InfluxDB 3 instance.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the role that grants permission to retrieve the InfluxDB API token from Amazon Web Services Secrets Manager.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table to write the data point to. This is the measurement name of the InfluxDB line protocol record.
Accepts substitution templates.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The set of tags to write with each data point. Tags are the indexed metadata of an InfluxDB data point.
Tag names and tag values accept substitution templates. A tag name
can't use the @{...} per-element form. A tag name must resolve to
the same value for every element of an array payload.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |
#timestamp_unit ⇒ String
The precision of the timestamp written with each data point. Valid
values are s (seconds), ms (milliseconds), us (microseconds),
and ns (nanoseconds).
If omitted, the topic rule action uses ms.
9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-iot/types.rb', line 9449 class InfluxDBAction < Struct.new( :destination_arn, :role_arn, :database_name, :table_name, :organization, :tags, :timestamp_unit, :batch_config) SENSITIVE = [] include Aws::Structure end |