Class: Aws::IoT::Types::InfluxDBBatchConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::InfluxDBBatchConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The batching configuration of an InfluxDB rule action. IoT closes a batch and writes it to InfluxDB when the first of the configured limits is reached.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_across_topics ⇒ Boolean
Specifies whether to collect data points from different topics into the same batch.
-
#max_batch_open_ms ⇒ Integer
The maximum length of time, in milliseconds, to keep a batch open before writing it to InfluxDB.
-
#max_batch_size ⇒ Integer
The maximum number of data points to collect in a batch.
-
#max_batch_size_bytes ⇒ Integer
The maximum size of a batch, in bytes, before IoT writes it to InfluxDB.
Instance Attribute Details
#batch_across_topics ⇒ Boolean
Specifies whether to collect data points from different topics into the same batch.
If omitted or false, IoT batches data points for each topic
separately.
9497 9498 9499 9500 9501 9502 9503 9504 |
# File 'lib/aws-sdk-iot/types.rb', line 9497 class InfluxDBBatchConfig < Struct.new( :max_batch_size, :max_batch_open_ms, :max_batch_size_bytes, :batch_across_topics) SENSITIVE = [] include Aws::Structure end |
#max_batch_open_ms ⇒ Integer
The maximum length of time, in milliseconds, to keep a batch open before writing it to InfluxDB.
If you don't specify a value, this limit doesn't apply. IoT then closes each batch when another configured limit is reached.
9497 9498 9499 9500 9501 9502 9503 9504 |
# File 'lib/aws-sdk-iot/types.rb', line 9497 class InfluxDBBatchConfig < Struct.new( :max_batch_size, :max_batch_open_ms, :max_batch_size_bytes, :batch_across_topics) SENSITIVE = [] include Aws::Structure end |
#max_batch_size ⇒ Integer
The maximum number of data points to collect in a batch.
If you don't specify a value, this limit doesn't apply. IoT then closes each batch when another configured limit is reached.
9497 9498 9499 9500 9501 9502 9503 9504 |
# File 'lib/aws-sdk-iot/types.rb', line 9497 class InfluxDBBatchConfig < Struct.new( :max_batch_size, :max_batch_open_ms, :max_batch_size_bytes, :batch_across_topics) SENSITIVE = [] include Aws::Structure end |
#max_batch_size_bytes ⇒ Integer
The maximum size of a batch, in bytes, before IoT writes it to InfluxDB.
If you don't specify a value, this limit doesn't apply. IoT then closes each batch when another configured limit is reached.
9497 9498 9499 9500 9501 9502 9503 9504 |
# File 'lib/aws-sdk-iot/types.rb', line 9497 class InfluxDBBatchConfig < Struct.new( :max_batch_size, :max_batch_open_ms, :max_batch_size_bytes, :batch_across_topics) SENSITIVE = [] include Aws::Structure end |