Class: Aws::IoT::Types::InfluxDBDestinationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::InfluxDBDestinationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The configuration of an InfluxDB topic rule destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint ⇒ String
The URL of the InfluxDB instance to write to.
-
#influx_db_version ⇒ String
The major version of the InfluxDB instance.
-
#secret_id ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret that contains the InfluxDB API token.
-
#secret_key ⇒ String
The key to read from the secret value when the secret contains a JSON object.
-
#secret_type ⇒ String
The type of the secret that contains the InfluxDB API token.
Instance Attribute Details
#endpoint ⇒ String
The URL of the InfluxDB instance to write to.
9535 9536 9537 9538 9539 9540 9541 9542 9543 |
# File 'lib/aws-sdk-iot/types.rb', line 9535 class InfluxDBDestinationConfiguration < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#influx_db_version ⇒ String
The major version of the InfluxDB instance. Valid values are V2
and V3.
9535 9536 9537 9538 9539 9540 9541 9542 9543 |
# File 'lib/aws-sdk-iot/types.rb', line 9535 class InfluxDBDestinationConfiguration < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#secret_id ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret that contains the InfluxDB API token.
9535 9536 9537 9538 9539 9540 9541 9542 9543 |
# File 'lib/aws-sdk-iot/types.rb', line 9535 class InfluxDBDestinationConfiguration < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#secret_key ⇒ String
The key to read from the secret value when the secret contains a JSON object. If omitted, IoT uses the entire secret value as the InfluxDB API token.
9535 9536 9537 9538 9539 9540 9541 9542 9543 |
# File 'lib/aws-sdk-iot/types.rb', line 9535 class InfluxDBDestinationConfiguration < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |
#secret_type ⇒ String
The type of the secret that contains the InfluxDB API token. Valid
values are SecretString and SecretBinary.
If omitted, IoT reads the secret as a string.
9535 9536 9537 9538 9539 9540 9541 9542 9543 |
# File 'lib/aws-sdk-iot/types.rb', line 9535 class InfluxDBDestinationConfiguration < Struct.new( :endpoint, :influx_db_version, :secret_id, :secret_type, :secret_key) SENSITIVE = [] include Aws::Structure end |