Class: Aws::IoT::Types::Job

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The `Job` object contains details about a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#abort_configTypes::AbortConfig

Configuration for criteria to abort the job.

Returns:



10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#commentString

If the job was updated, describes the reason for the update.

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#completed_atTime

The time, in seconds since the epoch, when the job was completed.

Returns:

  • (Time)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time, in seconds since the epoch, when the job was created.

Returns:

  • (Time)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A short text description of the job.

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#document_parametersHash<String,String>

A key-value map that pairs the patterns that need to be replaced in a managed template job document schema. You can use the description of each key as a guidance to specify the inputs during runtime when creating a job.

<note markdown=“1”> `documentParameters` can only be used when creating jobs from Amazon Web Services managed templates. This parameter can't be used with custom job templates or to create jobs from them.

</note>

Returns:

  • (Hash<String,String>)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#force_canceledBoolean

Will be `true` if the job was canceled with the optional `force` parameter set to `true`.

Returns:

  • (Boolean)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#is_concurrentBoolean

Indicates whether a job is concurrent. Will be true when a job is rolling out new job executions or canceling previously created executions, otherwise false.

Returns:

  • (Boolean)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

An ARN identifying the job with format “arn:aws:iot:region:account:job/jobId”.

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_retry_configTypes::JobExecutionsRetryConfig

The configuration for the criteria to retry the job.



10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_executions_rollout_configTypes::JobExecutionsRolloutConfig

Allows you to create a staged rollout of a job.



10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier you assigned to this job when it was created.

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_process_detailsTypes::JobProcessDetails

Details about the job process.



10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_template_arnString

The ARN of the job template used to create the job.

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The time, in seconds since the epoch, when the job was last updated.

Returns:

  • (Time)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#namespace_idString

The namespace used to indicate that a job is a customer-managed job.

When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.

`$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`

<note markdown=“1”> The `namespaceId` feature is in public preview.

</note>

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#presigned_url_configTypes::PresignedUrlConfig

Configuration for pre-signed S3 URLs.



10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#reason_codeString

If the job was updated, provides the reason code for the update.

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the job, one of `IN_PROGRESS`, `CANCELED`, `DELETION_IN_PROGRESS` or `COMPLETED`.

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#target_selectionString

Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a device when the thing representing the device is added to a target group, even after the job was completed by all things originally in the group.

<note markdown=“1”> We recommend that you use continuous jobs instead of snapshot jobs for dynamic thing group targets. By using continuous jobs, devices that join the group receive the job execution even after the job has been created.

</note>

Returns:

  • (String)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<String>

A list of IoT things and thing groups to which the job should be sent.

Returns:

  • (Array<String>)


10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_configTypes::TimeoutConfig

Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to `IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.



10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/aws-sdk-iot/types.rb', line 10292

class Job < Struct.new(
  :job_arn,
  :job_id,
  :target_selection,
  :status,
  :force_canceled,
  :reason_code,
  :comment,
  :targets,
  :description,
  :presigned_url_config,
  :job_executions_rollout_config,
  :abort_config,
  :created_at,
  :last_updated_at,
  :completed_at,
  :job_process_details,
  :timeout_config,
  :namespace_id,
  :job_template_arn,
  :job_executions_retry_config,
  :document_parameters,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end