Class: Aws::IoT::Types::Job
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::Job
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The `Job` object contains details about a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abort_config ⇒ Types::AbortConfig
Configuration for criteria to abort the job.
-
#comment ⇒ String
If the job was updated, describes the reason for the update.
-
#completed_at ⇒ Time
The time, in seconds since the epoch, when the job was completed.
-
#created_at ⇒ Time
The time, in seconds since the epoch, when the job was created.
-
#description ⇒ String
A short text description of the job.
-
#document_parameters ⇒ Hash<String,String>
A key-value map that pairs the patterns that need to be replaced in a managed template job document schema.
-
#force_canceled ⇒ Boolean
Will be `true` if the job was canceled with the optional `force` parameter set to `true`.
- #is_concurrent ⇒ Boolean
-
#job_arn ⇒ String
An ARN identifying the job with format “arn:aws:iot:region:account:job/jobId”.
-
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
The configuration for the criteria to retry the job.
-
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
-
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
-
#job_process_details ⇒ Types::JobProcessDetails
Details about the job process.
-
#job_template_arn ⇒ String
The ARN of the job template used to create the job.
-
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job was last updated.
-
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
-
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
-
#reason_code ⇒ String
If the job was updated, provides the reason code for the update.
-
#status ⇒ String
The status of the job, one of `IN_PROGRESS`, `CANCELED`, `DELETION_IN_PROGRESS` or `COMPLETED`.
-
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT).
-
#targets ⇒ Array<String>
A list of IoT things and thing groups to which the job should be sent.
-
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job.
Instance Attribute Details
#abort_config ⇒ Types::AbortConfig
Configuration for criteria to abort the job.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#comment ⇒ String
If the job was updated, describes the reason for the update.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#completed_at ⇒ Time
The time, in seconds since the epoch, when the job was completed.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time, in seconds since the epoch, when the job was created.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A short text description of the job.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#document_parameters ⇒ Hash<String,String>
A key-value map that pairs the patterns that need to be replaced in a managed template job document schema. You can use the description of each key as a guidance to specify the inputs during runtime when creating a job.
<note markdown=“1”> `documentParameters` can only be used when creating jobs from Amazon Web Services managed templates. This parameter can't be used with custom job templates or to create jobs from them.
</note>
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#force_canceled ⇒ Boolean
Will be `true` if the job was canceled with the optional `force` parameter set to `true`.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#is_concurrent ⇒ Boolean
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
An ARN identifying the job with format “arn:aws:iot:region:account:job/jobId”.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_executions_retry_config ⇒ Types::JobExecutionsRetryConfig
The configuration for the criteria to retry the job.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_executions_rollout_config ⇒ Types::JobExecutionsRolloutConfig
Allows you to create a staged rollout of a job.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier you assigned to this job when it was created.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_process_details ⇒ Types::JobProcessDetails
Details about the job process.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#job_template_arn ⇒ String
The ARN of the job template used to create the job.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job was last updated.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.
`$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/`
<note markdown=“1”> The `namespaceId` feature is in public preview.
</note>
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#presigned_url_config ⇒ Types::PresignedUrlConfig
Configuration for pre-signed S3 URLs.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#reason_code ⇒ String
If the job was updated, provides the reason code for the update.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the job, one of `IN_PROGRESS`, `CANCELED`, `DELETION_IN_PROGRESS` or `COMPLETED`.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a device when the thing representing the device is added to a target group, even after the job was completed by all things originally in the group.
<note markdown=“1”> We recommend that you use continuous jobs instead of snapshot jobs for dynamic thing group targets. By using continuous jobs, devices that join the group receive the job execution even after the job has been created.
</note>
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<String>
A list of IoT things and thing groups to which the job should be sent.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::TimeoutConfig
Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to `IN_PROGRESS`. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to `TIMED_OUT`.
10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/aws-sdk-iot/types.rb', line 10243 class Job < Struct.new( :job_arn, :job_id, :target_selection, :status, :force_canceled, :reason_code, :comment, :targets, :description, :presigned_url_config, :job_executions_rollout_config, :abort_config, :created_at, :last_updated_at, :completed_at, :job_process_details, :timeout_config, :namespace_id, :job_template_arn, :job_executions_retry_config, :document_parameters, :is_concurrent) SENSITIVE = [] include Aws::Structure end |