Class: Aws::IoT::Types::JobExecution
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::JobExecution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The job execution object represents the execution of a job on a particular device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_seconds_before_timed_out ⇒ Integer
The estimated number of seconds that remain before the job execution status will be changed to `TIMED_OUT`.
-
#execution_number ⇒ Integer
A string (consisting of the digits “0” through “9”) which identifies this particular job execution on this particular device.
-
#force_canceled ⇒ Boolean
Will be `true` if the job execution was canceled with the optional `force` parameter set to `true`.
-
#job_id ⇒ String
The unique identifier you assigned to the job when it was created.
-
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job execution was last updated.
-
#queued_at ⇒ Time
The time, in seconds since the epoch, when the job execution was queued.
-
#started_at ⇒ Time
The time, in seconds since the epoch, when the job execution started.
-
#status ⇒ String
The status of the job execution (IN_PROGRESS, QUEUED, FAILED, SUCCEEDED, TIMED_OUT, CANCELED, or REJECTED).
-
#status_details ⇒ Types::JobExecutionStatusDetails
A collection of name/value pairs that describe the status of the job execution.
-
#thing_arn ⇒ String
The ARN of the thing on which the job execution is running.
-
#version_number ⇒ Integer
The version of the job execution.
Instance Attribute Details
#approximate_seconds_before_timed_out ⇒ Integer
The estimated number of seconds that remain before the job execution status will be changed to `TIMED_OUT`. The timeout interval can be anywhere between 1 minute and 7 days (1 to 10080 minutes). The actual job execution timeout can occur up to 60 seconds later than the estimated duration. This value will not be included if the job execution has reached a terminal status.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#execution_number ⇒ Integer
A string (consisting of the digits “0” through “9”) which identifies this particular job execution on this particular device. It can be used in commands which return or update job execution information.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#force_canceled ⇒ Boolean
Will be `true` if the job execution was canceled with the optional `force` parameter set to `true`.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier you assigned to the job when it was created.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job execution was last updated.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#queued_at ⇒ Time
The time, in seconds since the epoch, when the job execution was queued.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The time, in seconds since the epoch, when the job execution started.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the job execution (IN_PROGRESS, QUEUED, FAILED, SUCCEEDED, TIMED_OUT, CANCELED, or REJECTED).
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ Types::JobExecutionStatusDetails
A collection of name/value pairs that describe the status of the job execution.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#thing_arn ⇒ String
The ARN of the thing on which the job execution is running.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The version of the job execution. Job execution versions are incremented each time they are updated by a device.
10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-iot/types.rb', line 10435 class JobExecution < Struct.new( :job_id, :status, :force_canceled, :status_details, :thing_arn, :queued_at, :started_at, :last_updated_at, :execution_number, :version_number, :approximate_seconds_before_timed_out) SENSITIVE = [] include Aws::Structure end |