Class: Aws::IoT::Types::JobExecution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The job execution object represents the execution of a job on a particular device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_seconds_before_timed_outInteger

The estimated number of seconds that remain before the job execution status will be changed to `TIMED_OUT`. The timeout interval can be anywhere between 1 minute and 7 days (1 to 10080 minutes). The actual job execution timeout can occur up to 60 seconds later than the estimated duration. This value will not be included if the job execution has reached a terminal status.

Returns:

  • (Integer)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#execution_numberInteger

A string (consisting of the digits “0” through “9”) which identifies this particular job execution on this particular device. It can be used in commands which return or update job execution information.

Returns:

  • (Integer)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#force_canceledBoolean

Will be `true` if the job execution was canceled with the optional `force` parameter set to `true`.

Returns:

  • (Boolean)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier you assigned to the job when it was created.

Returns:

  • (String)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The time, in seconds since the epoch, when the job execution was last updated.

Returns:

  • (Time)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#queued_atTime

The time, in seconds since the epoch, when the job execution was queued.

Returns:

  • (Time)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The time, in seconds since the epoch, when the job execution started.

Returns:

  • (Time)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the job execution (IN_PROGRESS, QUEUED, FAILED, SUCCEEDED, TIMED_OUT, CANCELED, or REJECTED).

Returns:

  • (String)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#status_detailsTypes::JobExecutionStatusDetails

A collection of name/value pairs that describe the status of the job execution.



10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#thing_arnString

The ARN of the thing on which the job execution is running.

Returns:

  • (String)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end

#version_numberInteger

The version of the job execution. Job execution versions are incremented each time they are updated by a device.

Returns:

  • (Integer)


10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
# File 'lib/aws-sdk-iot/types.rb', line 10411

class JobExecution < Struct.new(
  :job_id,
  :status,
  :force_canceled,
  :status_details,
  :thing_arn,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :version_number,
  :approximate_seconds_before_timed_out)
  SENSITIVE = []
  include Aws::Structure
end