Class: Aws::IoT::Types::JobExecutionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The job execution summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_numberInteger

A string (consisting of the digits “0” through “9”) which identifies this particular job execution on this particular device. It can be used later in commands which return or update job execution information.

Returns:

  • (Integer)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-iot/types.rb', line 8384

class JobExecutionSummary < Struct.new(
  :status,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :retry_attempt)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The time, in seconds since the epoch, when the job execution was last updated.

Returns:

  • (Time)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-iot/types.rb', line 8384

class JobExecutionSummary < Struct.new(
  :status,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :retry_attempt)
  SENSITIVE = []
  include Aws::Structure
end

#queued_atTime

The time, in seconds since the epoch, when the job execution was queued.

Returns:

  • (Time)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-iot/types.rb', line 8384

class JobExecutionSummary < Struct.new(
  :status,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :retry_attempt)
  SENSITIVE = []
  include Aws::Structure
end

#retry_attemptInteger

The number that indicates how many retry attempts have been completed for this job on this device.

Returns:

  • (Integer)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-iot/types.rb', line 8384

class JobExecutionSummary < Struct.new(
  :status,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :retry_attempt)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The time, in seconds since the epoch, when the job execution started.

Returns:

  • (Time)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-iot/types.rb', line 8384

class JobExecutionSummary < Struct.new(
  :status,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :retry_attempt)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the job execution.

Returns:

  • (String)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-iot/types.rb', line 8384

class JobExecutionSummary < Struct.new(
  :status,
  :queued_at,
  :started_at,
  :last_updated_at,
  :execution_number,
  :retry_attempt)
  SENSITIVE = []
  include Aws::Structure
end