Class: Aws::IoT::Types::JobExecutionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::JobExecutionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The job execution summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_number ⇒ Integer
A string (consisting of the digits “0” through “9”) which identifies this particular job execution on this particular device.
-
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job execution was last updated.
-
#queued_at ⇒ Time
The time, in seconds since the epoch, when the job execution was queued.
-
#retry_attempt ⇒ Integer
The number that indicates how many retry attempts have been completed for this job on this device.
-
#started_at ⇒ Time
The time, in seconds since the epoch, when the job execution started.
-
#status ⇒ String
The status of the job execution.
Instance Attribute Details
#execution_number ⇒ Integer
A string (consisting of the digits “0” through “9”) which identifies this particular job execution on this particular device. It can be used later in commands which return or update job execution information.
7970 7971 7972 7973 7974 7975 7976 7977 7978 7979 |
# File 'lib/aws-sdk-iot/types.rb', line 7970 class JobExecutionSummary < Struct.new( :status, :queued_at, :started_at, :last_updated_at, :execution_number, :retry_attempt) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time, in seconds since the epoch, when the job execution was last updated.
7970 7971 7972 7973 7974 7975 7976 7977 7978 7979 |
# File 'lib/aws-sdk-iot/types.rb', line 7970 class JobExecutionSummary < Struct.new( :status, :queued_at, :started_at, :last_updated_at, :execution_number, :retry_attempt) SENSITIVE = [] include Aws::Structure end |
#queued_at ⇒ Time
The time, in seconds since the epoch, when the job execution was queued.
7970 7971 7972 7973 7974 7975 7976 7977 7978 7979 |
# File 'lib/aws-sdk-iot/types.rb', line 7970 class JobExecutionSummary < Struct.new( :status, :queued_at, :started_at, :last_updated_at, :execution_number, :retry_attempt) SENSITIVE = [] include Aws::Structure end |
#retry_attempt ⇒ Integer
The number that indicates how many retry attempts have been completed for this job on this device.
7970 7971 7972 7973 7974 7975 7976 7977 7978 7979 |
# File 'lib/aws-sdk-iot/types.rb', line 7970 class JobExecutionSummary < Struct.new( :status, :queued_at, :started_at, :last_updated_at, :execution_number, :retry_attempt) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The time, in seconds since the epoch, when the job execution started.
7970 7971 7972 7973 7974 7975 7976 7977 7978 7979 |
# File 'lib/aws-sdk-iot/types.rb', line 7970 class JobExecutionSummary < Struct.new( :status, :queued_at, :started_at, :last_updated_at, :execution_number, :retry_attempt) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the job execution.
7970 7971 7972 7973 7974 7975 7976 7977 7978 7979 |
# File 'lib/aws-sdk-iot/types.rb', line 7970 class JobExecutionSummary < Struct.new( :status, :queued_at, :started_at, :last_updated_at, :execution_number, :retry_attempt) SENSITIVE = [] include Aws::Structure end |