Class: Aws::IoT::Types::JobProcessDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::JobProcessDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The job process details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#number_of_canceled_things ⇒ Integer
The number of things that cancelled the job.
-
#number_of_failed_things ⇒ Integer
The number of things that failed executing the job.
-
#number_of_in_progress_things ⇒ Integer
The number of things currently executing the job.
-
#number_of_queued_things ⇒ Integer
The number of things that are awaiting execution of the job.
-
#number_of_rejected_things ⇒ Integer
The number of things that rejected the job.
-
#number_of_removed_things ⇒ Integer
The number of things that are no longer scheduled to execute the job because they have been deleted or have been removed from the group that was a target of the job.
-
#number_of_succeeded_things ⇒ Integer
The number of things which successfully completed the job.
-
#number_of_timed_out_things ⇒ Integer
The number of things whose job execution status is ‘TIMED_OUT`.
-
#processing_targets ⇒ Array<String>
The target devices to which the job execution is being rolled out.
Instance Attribute Details
#number_of_canceled_things ⇒ Integer
The number of things that cancelled the job.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#number_of_failed_things ⇒ Integer
The number of things that failed executing the job.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#number_of_in_progress_things ⇒ Integer
The number of things currently executing the job.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#number_of_queued_things ⇒ Integer
The number of things that are awaiting execution of the job.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#number_of_rejected_things ⇒ Integer
The number of things that rejected the job.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#number_of_removed_things ⇒ Integer
The number of things that are no longer scheduled to execute the job because they have been deleted or have been removed from the group that was a target of the job.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#number_of_succeeded_things ⇒ Integer
The number of things which successfully completed the job.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#number_of_timed_out_things ⇒ Integer
The number of things whose job execution status is ‘TIMED_OUT`.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |
#processing_targets ⇒ Array<String>
The target devices to which the job execution is being rolled out. This value will be null after the job execution has finished rolling out to all the target devices.
8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 |
# File 'lib/aws-sdk-iot/types.rb', line 8119 class JobProcessDetails < Struct.new( :processing_targets, :number_of_canceled_things, :number_of_succeeded_things, :number_of_failed_things, :number_of_rejected_things, :number_of_queued_things, :number_of_in_progress_things, :number_of_removed_things, :number_of_timed_out_things) SENSITIVE = [] include Aws::Structure end |