Class: Aws::IoT::Types::JobSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The job summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_atTime

The time, in seconds since the epoch, when the job completed.

Returns:

  • (Time)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time, in seconds since the epoch, when the job was created.

Returns:

  • (Time)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#is_concurrentBoolean

Returns:

  • (Boolean)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The job ARN.

Returns:

  • (String)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier you assigned to this job when it was created.

Returns:

  • (String)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The time, in seconds since the epoch, when the job was last updated.

Returns:

  • (Time)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The job summary status.

Returns:

  • (String)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#target_selectionString

Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a thing when the thing is added to a target group, even after the job was completed by all things originally in the group.

Returns:

  • (String)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end

#thing_group_idString

The ID of the thing group.

Returns:

  • (String)


10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/aws-sdk-iot/types.rb', line 10549

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :thing_group_id,
  :target_selection,
  :status,
  :created_at,
  :last_updated_at,
  :completed_at,
  :is_concurrent)
  SENSITIVE = []
  include Aws::Structure
end