Class: Aws::IoT::Types::KafkaAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass KafkaAction data as a hash:

{
  destination_arn: "AwsArn", # required
  topic: "String", # required
  key: "String",
  partition: "String",
  client_properties: { # required
    "String" => "String",
  },
}

Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_propertiesHash<String,String>

Properties of the Apache Kafka producer client.

Returns:

  • (Hash<String,String>)


10734
10735
10736
10737
10738
10739
10740
10741
10742
# File 'lib/aws-sdk-iot/types.rb', line 10734

class KafkaAction < Struct.new(
  :destination_arn,
  :topic,
  :key,
  :partition,
  :client_properties)
  SENSITIVE = []
  include Aws::Structure
end

#destination_arnString

The ARN of Kafka action's VPC `TopicRuleDestination`.

Returns:

  • (String)


10734
10735
10736
10737
10738
10739
10740
10741
10742
# File 'lib/aws-sdk-iot/types.rb', line 10734

class KafkaAction < Struct.new(
  :destination_arn,
  :topic,
  :key,
  :partition,
  :client_properties)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The Kafka message key.

Returns:

  • (String)


10734
10735
10736
10737
10738
10739
10740
10741
10742
# File 'lib/aws-sdk-iot/types.rb', line 10734

class KafkaAction < Struct.new(
  :destination_arn,
  :topic,
  :key,
  :partition,
  :client_properties)
  SENSITIVE = []
  include Aws::Structure
end

#partitionString

The Kafka message partition.

Returns:

  • (String)


10734
10735
10736
10737
10738
10739
10740
10741
10742
# File 'lib/aws-sdk-iot/types.rb', line 10734

class KafkaAction < Struct.new(
  :destination_arn,
  :topic,
  :key,
  :partition,
  :client_properties)
  SENSITIVE = []
  include Aws::Structure
end

#topicString

The Kafka topic for messages to be sent to the Kafka broker.

Returns:

  • (String)


10734
10735
10736
10737
10738
10739
10740
10741
10742
# File 'lib/aws-sdk-iot/types.rb', line 10734

class KafkaAction < Struct.new(
  :destination_arn,
  :topic,
  :key,
  :partition,
  :client_properties)
  SENSITIVE = []
  include Aws::Structure
end