Class: Aws::IoT::Types::ListCertificateProvidersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListCertificateProvidersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ascending_order ⇒ Boolean
Returns the list of certificate providers in ascending alphabetical order.
-
#next_token ⇒ String
The token for the next set of results, or
nullif there are no more results.
Instance Attribute Details
#ascending_order ⇒ Boolean
Returns the list of certificate providers in ascending alphabetical order.
11057 11058 11059 11060 11061 11062 |
# File 'lib/aws-sdk-iot/types.rb', line 11057 class ListCertificateProvidersRequest < Struct.new( :next_token, :ascending_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no
more results.
11057 11058 11059 11060 11061 11062 |
# File 'lib/aws-sdk-iot/types.rb', line 11057 class ListCertificateProvidersRequest < Struct.new( :next_token, :ascending_order) SENSITIVE = [] include Aws::Structure end |