Class: Aws::IoT::Types::ListCommandExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListCommandExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command_arn ⇒ String
The Amazon Resource Number (ARN) of the command.
-
#completed_time_filter ⇒ Types::TimeFilter
List all command executions that completed any time before or after the date and time that you specify.
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#namespace ⇒ String
The namespace of the command.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwisenullto receive the first set of results. -
#sort_order ⇒ String
Specify whether to list the command executions that were created in the ascending or descending order.
-
#started_time_filter ⇒ Types::TimeFilter
List all command executions that started any time before or after the date and time that you specify.
-
#status ⇒ String
List all command executions for the device that have a particular status.
-
#target_arn ⇒ String
The Amazon Resource Number (ARN) of the target device.
Instance Attribute Details
#command_arn ⇒ String
The Amazon Resource Number (ARN) of the command. You can use this information to list all command executions for a particular command.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#completed_time_filter ⇒ Types::TimeFilter
List all command executions that completed any time before or after
the date and time that you specify. The date and time uses the
format yyyy-MM-dd'T'HH:mm.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in this operation.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the command.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specify whether to list the command executions that were created in
the ascending or descending order. By default, the API returns all
commands in the descending order based on the start time or
completion time of the executions, that are determined by the
startTimeFilter and completeTimeFilter parameters.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#started_time_filter ⇒ Types::TimeFilter
List all command executions that started any time before or after
the date and time that you specify. The date and time uses the
format yyyy-MM-dd'T'HH:mm.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
List all command executions for the device that have a particular status. For example, you can filter the list to display only command executions that have failed or timed out.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Number (ARN) of the target device. You can use this information to list all command executions for a particular device.
11221 11222 11223 11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 |
# File 'lib/aws-sdk-iot/types.rb', line 11221 class ListCommandExecutionsRequest < Struct.new( :max_results, :next_token, :namespace, :status, :sort_order, :started_time_filter, :completed_time_filter, :target_arn, :command_arn) SENSITIVE = [] include Aws::Structure end |