Class: Aws::IoT::Types::ListCommandsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListCommandsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command_parameter_name ⇒ String
A filter that can be used to display the list of commands that have a specific command parameter name.
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#namespace ⇒ String
The namespace of the command.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwisenullto receive the first set of results. -
#sort_order ⇒ String
Specify whether to list the commands that you have created in the ascending or descending order.
Instance Attribute Details
#command_parameter_name ⇒ String
A filter that can be used to display the list of commands that have a specific command parameter name.
10940 10941 10942 10943 10944 10945 10946 10947 10948 |
# File 'lib/aws-sdk-iot/types.rb', line 10940 class ListCommandsRequest < Struct.new( :max_results, :next_token, :namespace, :command_parameter_name, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in this operation. By default, the API returns up to a maximum of 25 results. You can override this default value to return up to a maximum of 100 results for this operation.
10940 10941 10942 10943 10944 10945 10946 10947 10948 |
# File 'lib/aws-sdk-iot/types.rb', line 10940 class ListCommandsRequest < Struct.new( :max_results, :next_token, :namespace, :command_parameter_name, :sort_order) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the command. By default, the API returns all commands that have been created for both AWS-IoT and AWS-IoT-FleetWise namespaces. You can override this default value if you want to return all commands that have been created only for a specific namespace.
10940 10941 10942 10943 10944 10945 10946 10947 10948 |
# File 'lib/aws-sdk-iot/types.rb', line 10940 class ListCommandsRequest < Struct.new( :max_results, :next_token, :namespace, :command_parameter_name, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
10940 10941 10942 10943 10944 10945 10946 10947 10948 |
# File 'lib/aws-sdk-iot/types.rb', line 10940 class ListCommandsRequest < Struct.new( :max_results, :next_token, :namespace, :command_parameter_name, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specify whether to list the commands that you have created in the ascending or descending order. By default, the API returns all commands in the descending order based on the time that they were created.
10940 10941 10942 10943 10944 10945 10946 10947 10948 |
# File 'lib/aws-sdk-iot/types.rb', line 10940 class ListCommandsRequest < Struct.new( :max_results, :next_token, :namespace, :command_parameter_name, :sort_order) SENSITIVE = [] include Aws::Structure end |