Class: Aws::IoT::Types::ListDimensionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListDimensionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimension_names ⇒ Array<String>
A list of the names of the defined dimensions.
-
#next_token ⇒ String
A token that can be used to retrieve the next set of results, or
nullif there are no additional results.
Instance Attribute Details
#dimension_names ⇒ Array<String>
A list of the names of the defined dimensions. Use DescribeDimension to get details for a dimension.
11129 11130 11131 11132 11133 11134 |
# File 'lib/aws-sdk-iot/types.rb', line 11129 class ListDimensionsResponse < Struct.new( :dimension_names, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that can be used to retrieve the next set of results, or null if there are no additional results.
11129 11130 11131 11132 11133 11134 |
# File 'lib/aws-sdk-iot/types.rb', line 11129 class ListDimensionsResponse < Struct.new( :dimension_names, :next_token) SENSITIVE = [] include Aws::Structure end |