Class: Aws::IoT::Types::ListJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per request.
-
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
-
#next_token ⇒ String
The token to retrieve the next set of results.
-
#status ⇒ String
An optional filter that lets you search for jobs that have the specified status.
-
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT).
-
#thing_group_id ⇒ String
A filter that limits the returned jobs to those for the specified group.
-
#thing_group_name ⇒ String
A filter that limits the returned jobs to those for the specified group.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per request.
11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-iot/types.rb', line 11780 class ListJobsRequest < Struct.new( :status, :target_selection, :max_results, :next_token, :thing_group_name, :thing_group_id, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#namespace_id ⇒ String
The namespace used to indicate that a job is a customer-managed job.
When you specify a value for this parameter, Amazon Web Services IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.
$aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/
namespaceId feature is only supported by IoT Greengrass at
this time. For more information, see Setting up IoT Greengrass core
devices.
11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-iot/types.rb', line 11780 class ListJobsRequest < Struct.new( :status, :target_selection, :max_results, :next_token, :thing_group_name, :thing_group_id, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next set of results.
11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-iot/types.rb', line 11780 class ListJobsRequest < Struct.new( :status, :target_selection, :max_results, :next_token, :thing_group_name, :thing_group_id, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
An optional filter that lets you search for jobs that have the specified status.
11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-iot/types.rb', line 11780 class ListJobsRequest < Struct.new( :status, :target_selection, :max_results, :next_token, :thing_group_name, :thing_group_id, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#target_selection ⇒ String
Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a thing when the thing is added to a target group, even after the job was completed by all things originally in the group.
11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-iot/types.rb', line 11780 class ListJobsRequest < Struct.new( :status, :target_selection, :max_results, :next_token, :thing_group_name, :thing_group_id, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#thing_group_id ⇒ String
A filter that limits the returned jobs to those for the specified group.
11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-iot/types.rb', line 11780 class ListJobsRequest < Struct.new( :status, :target_selection, :max_results, :next_token, :thing_group_name, :thing_group_id, :namespace_id) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
A filter that limits the returned jobs to those for the specified group.
11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-iot/types.rb', line 11780 class ListJobsRequest < Struct.new( :status, :target_selection, :max_results, :next_token, :thing_group_name, :thing_group_id, :namespace_id) SENSITIVE = [] include Aws::Structure end |