Class: Aws::IoT::Types::ListThingGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return at one time.

Returns:

  • (Integer)


12517
12518
12519
12520
12521
12522
12523
12524
12525
# File 'lib/aws-sdk-iot/types.rb', line 12517

class ListThingGroupsRequest < Struct.new(
  :next_token,
  :max_results,
  :parent_group,
  :name_prefix_filter,
  :recursive)
  SENSITIVE = []
  include Aws::Structure
end

#name_prefix_filterString

A filter that limits the results to those with the specified name prefix.

Returns:

  • (String)


12517
12518
12519
12520
12521
12522
12523
12524
12525
# File 'lib/aws-sdk-iot/types.rb', line 12517

class ListThingGroupsRequest < Struct.new(
  :next_token,
  :max_results,
  :parent_group,
  :name_prefix_filter,
  :recursive)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


12517
12518
12519
12520
12521
12522
12523
12524
12525
# File 'lib/aws-sdk-iot/types.rb', line 12517

class ListThingGroupsRequest < Struct.new(
  :next_token,
  :max_results,
  :parent_group,
  :name_prefix_filter,
  :recursive)
  SENSITIVE = []
  include Aws::Structure
end

#parent_groupString

A filter that limits the results to those with the specified parent group.

Returns:

  • (String)


12517
12518
12519
12520
12521
12522
12523
12524
12525
# File 'lib/aws-sdk-iot/types.rb', line 12517

class ListThingGroupsRequest < Struct.new(
  :next_token,
  :max_results,
  :parent_group,
  :name_prefix_filter,
  :recursive)
  SENSITIVE = []
  include Aws::Structure
end

#recursiveBoolean

If true, return child groups as well.

Returns:

  • (Boolean)


12517
12518
12519
12520
12521
12522
12523
12524
12525
# File 'lib/aws-sdk-iot/types.rb', line 12517

class ListThingGroupsRequest < Struct.new(
  :next_token,
  :max_results,
  :parent_group,
  :name_prefix_filter,
  :recursive)
  SENSITIVE = []
  include Aws::Structure
end