Class: Aws::IoT::Types::ListThingGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListThingGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#name_prefix_filter ⇒ String
A filter that limits the results to those with the specified name prefix.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#parent_group ⇒ String
A filter that limits the results to those with the specified parent group.
-
#recursive ⇒ Boolean
If true, return child groups as well.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return at one time.
12517 12518 12519 12520 12521 12522 12523 12524 12525 |
# File 'lib/aws-sdk-iot/types.rb', line 12517 class ListThingGroupsRequest < Struct.new( :next_token, :max_results, :parent_group, :name_prefix_filter, :recursive) SENSITIVE = [] include Aws::Structure end |
#name_prefix_filter ⇒ String
A filter that limits the results to those with the specified name prefix.
12517 12518 12519 12520 12521 12522 12523 12524 12525 |
# File 'lib/aws-sdk-iot/types.rb', line 12517 class ListThingGroupsRequest < Struct.new( :next_token, :max_results, :parent_group, :name_prefix_filter, :recursive) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
12517 12518 12519 12520 12521 12522 12523 12524 12525 |
# File 'lib/aws-sdk-iot/types.rb', line 12517 class ListThingGroupsRequest < Struct.new( :next_token, :max_results, :parent_group, :name_prefix_filter, :recursive) SENSITIVE = [] include Aws::Structure end |
#parent_group ⇒ String
A filter that limits the results to those with the specified parent group.
12517 12518 12519 12520 12521 12522 12523 12524 12525 |
# File 'lib/aws-sdk-iot/types.rb', line 12517 class ListThingGroupsRequest < Struct.new( :next_token, :max_results, :parent_group, :name_prefix_filter, :recursive) SENSITIVE = [] include Aws::Structure end |
#recursive ⇒ Boolean
If true, return child groups as well.
12517 12518 12519 12520 12521 12522 12523 12524 12525 |
# File 'lib/aws-sdk-iot/types.rb', line 12517 class ListThingGroupsRequest < Struct.new( :next_token, :max_results, :parent_group, :name_prefix_filter, :recursive) SENSITIVE = [] include Aws::Structure end |