Class: Aws::IoT::Types::ListThingPrincipalsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ListThingPrincipalsV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#thing_name ⇒ String
The name of the thing.
-
#thing_principal_type ⇒ String
The type of the relation you want to filter in the response.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in this operation.
12962 12963 12964 12965 12966 12967 12968 12969 |
# File 'lib/aws-sdk-iot/types.rb', line 12962 class ListThingPrincipalsV2Request < Struct.new( :next_token, :max_results, :thing_name, :thing_principal_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
12962 12963 12964 12965 12966 12967 12968 12969 |
# File 'lib/aws-sdk-iot/types.rb', line 12962 class ListThingPrincipalsV2Request < Struct.new( :next_token, :max_results, :thing_name, :thing_principal_type) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing.
12962 12963 12964 12965 12966 12967 12968 12969 |
# File 'lib/aws-sdk-iot/types.rb', line 12962 class ListThingPrincipalsV2Request < Struct.new( :next_token, :max_results, :thing_name, :thing_principal_type) SENSITIVE = [] include Aws::Structure end |
#thing_principal_type ⇒ String
The type of the relation you want to filter in the response. If no
value is provided in this field, the response will list all
principals, including both the EXCLUSIVE_THING and
NON_EXCLUSIVE_THING attachment types.
EXCLUSIVE_THING- Attaches the specified principal to the specified thing, exclusively. The thing will be the only thing that’s attached to the principal.
^ ^
NON_EXCLUSIVE_THING- Attaches the specified principal to the specified thing. Multiple things can be attached to the principal.
^
12962 12963 12964 12965 12966 12967 12968 12969 |
# File 'lib/aws-sdk-iot/types.rb', line 12962 class ListThingPrincipalsV2Request < Struct.new( :next_token, :max_results, :thing_name, :thing_principal_type) SENSITIVE = [] include Aws::Structure end |