Class: Aws::IoT::Types::ListThingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The input for the ListThings operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_nameString

The attribute name used to search for things.

Returns:

  • (String)


12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
# File 'lib/aws-sdk-iot/types.rb', line 12887

class ListThingsRequest < Struct.new(
  :next_token,
  :max_results,
  :attribute_name,
  :attribute_value,
  :thing_type_name,
  :use_prefix_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end

#attribute_valueString

The attribute value used to search for things.

Returns:

  • (String)


12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
# File 'lib/aws-sdk-iot/types.rb', line 12887

class ListThingsRequest < Struct.new(
  :next_token,
  :max_results,
  :attribute_name,
  :attribute_value,
  :thing_type_name,
  :use_prefix_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in this operation.

Returns:

  • (Integer)


12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
# File 'lib/aws-sdk-iot/types.rb', line 12887

class ListThingsRequest < Struct.new(
  :next_token,
  :max_results,
  :attribute_name,
  :attribute_value,
  :thing_type_name,
  :use_prefix_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
# File 'lib/aws-sdk-iot/types.rb', line 12887

class ListThingsRequest < Struct.new(
  :next_token,
  :max_results,
  :attribute_name,
  :attribute_value,
  :thing_type_name,
  :use_prefix_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end

#thing_type_nameString

The name of the thing type used to search for things.

Returns:

  • (String)


12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
# File 'lib/aws-sdk-iot/types.rb', line 12887

class ListThingsRequest < Struct.new(
  :next_token,
  :max_results,
  :attribute_name,
  :attribute_value,
  :thing_type_name,
  :use_prefix_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end

#use_prefix_attribute_valueBoolean

When true, the action returns the thing resources with attribute values that start with the attributeValue provided.

When false, or not present, the action returns only the thing resources with attribute values that match the entire attributeValue provided.

Returns:

  • (Boolean)


12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
# File 'lib/aws-sdk-iot/types.rb', line 12887

class ListThingsRequest < Struct.new(
  :next_token,
  :max_results,
  :attribute_name,
  :attribute_value,
  :thing_type_name,
  :use_prefix_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end