Class: Aws::IoT::Types::LocationTimestamp

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass LocationTimestamp data as a hash:

{
  value: "String", # required
  unit: "String",
}

Describes how to interpret an application-defined timestamp value from an MQTT message payload and the precision of that value.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unitString

The precision of the timestamp value that results from the expression described in `value`.

Valid values: `SECONDS` | `MILLISECONDS` | `MICROSECONDS` | `NANOSECONDS`. The default is `MILLISECONDS`.

Returns:

  • (String)


14204
14205
14206
14207
14208
14209
# File 'lib/aws-sdk-iot/types.rb', line 14204

class LocationTimestamp < Struct.new(
  :value,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

An expression that returns a long epoch time value.

Returns:

  • (String)


14204
14205
14206
14207
14208
14209
# File 'lib/aws-sdk-iot/types.rb', line 14204

class LocationTimestamp < Struct.new(
  :value,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end