Class: Aws::IoT::Types::MetricsExportConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::MetricsExportConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Set configurations for metrics export.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mqtt_topic ⇒ String
The MQTT topic that Device Defender Detect should publish messages to for metrics export.
-
#role_arn ⇒ String
This role ARN has permission to publish MQTT messages, after which Device Defender Detect can assume the role and publish messages on your behalf.
Instance Attribute Details
#mqtt_topic ⇒ String
The MQTT topic that Device Defender Detect should publish messages to for metrics export.
13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-iot/types.rb', line 13547 class MetricsExportConfig < Struct.new( :mqtt_topic, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
This role ARN has permission to publish MQTT messages, after which Device Defender Detect can assume the role and publish messages on your behalf.
13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-iot/types.rb', line 13547 class MetricsExportConfig < Struct.new( :mqtt_topic, :role_arn) SENSITIVE = [] include Aws::Structure end |