Class: Aws::IoT::Types::MetricsExportConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::MetricsExportConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Set configurations for metrics export.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mqtt_topic ⇒ String
The MQTT topic that Device Defender Detect should publish messages to for metrics export.
-
#role_arn ⇒ String
This role ARN has permission to publish MQTT messages, after which Device Defender Detect can assume the role and publish messages on your behalf.
Instance Attribute Details
#mqtt_topic ⇒ String
The MQTT topic that Device Defender Detect should publish messages to for metrics export.
11623 11624 11625 11626 11627 11628 |
# File 'lib/aws-sdk-iot/types.rb', line 11623 class MetricsExportConfig < Struct.new( :mqtt_topic, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
This role ARN has permission to publish MQTT messages, after which Device Defender Detect can assume the role and publish messages on your behalf.
11623 11624 11625 11626 11627 11628 |
# File 'lib/aws-sdk-iot/types.rb', line 11623 class MetricsExportConfig < Struct.new( :mqtt_topic, :role_arn) SENSITIVE = [] include Aws::Structure end |