Class: Aws::IoT::Types::OTAUpdateFile
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::OTAUpdateFile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes a file to be associated with an OTA update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A list of name/attribute pairs.
-
#code_signing ⇒ Types::CodeSigning
The code signing method of the file.
-
#file_location ⇒ Types::FileLocation
The location of the updated firmware.
-
#file_name ⇒ String
The name of the file.
-
#file_type ⇒ Integer
An integer value you can include in the job document to allow your devices to identify the type of file received from the cloud.
-
#file_version ⇒ String
The file version.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A list of name/attribute pairs.
11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 |
# File 'lib/aws-sdk-iot/types.rb', line 11402 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#code_signing ⇒ Types::CodeSigning
The code signing method of the file.
11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 |
# File 'lib/aws-sdk-iot/types.rb', line 11402 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_location ⇒ Types::FileLocation
The location of the updated firmware.
11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 |
# File 'lib/aws-sdk-iot/types.rb', line 11402 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The name of the file.
11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 |
# File 'lib/aws-sdk-iot/types.rb', line 11402 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_type ⇒ Integer
An integer value you can include in the job document to allow your devices to identify the type of file received from the cloud.
11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 |
# File 'lib/aws-sdk-iot/types.rb', line 11402 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_version ⇒ String
The file version.
11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 |
# File 'lib/aws-sdk-iot/types.rb', line 11402 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |