Class: Aws::IoT::Types::OTAUpdateFile
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::OTAUpdateFile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass OTAUpdateFile data as a hash:
{
file_name: "FileName",
file_type: 1,
file_version: "OTAUpdateFileVersion",
file_location: {
stream: {
stream_id: "StreamId",
file_id: 1,
},
s3_location: {
bucket: "S3Bucket",
key: "S3Key",
version: "S3Version",
},
},
code_signing: {
aws_signer_job_id: "SigningJobId",
start_signing_job_parameter: {
signing_profile_parameter: {
certificate_arn: "CertificateArn",
platform: "Platform",
certificate_path_on_device: "CertificatePathOnDevice",
},
signing_profile_name: "SigningProfileName",
destination: {
s3_destination: {
bucket: "S3Bucket",
prefix: "Prefix",
},
},
},
custom_code_signing: {
signature: {
inline_document: "data",
},
certificate_chain: {
certificate_name: "CertificateName",
inline_document: "InlineDocument",
},
hash_algorithm: "HashAlgorithm",
signature_algorithm: "SignatureAlgorithm",
},
},
attributes: {
"AttributeKey" => "Value",
},
}
Describes a file to be associated with an OTA update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A list of name/attribute pairs.
-
#code_signing ⇒ Types::CodeSigning
The code signing method of the file.
-
#file_location ⇒ Types::FileLocation
The location of the updated firmware.
-
#file_name ⇒ String
The name of the file.
-
#file_type ⇒ Integer
An integer value you can include in the job document to allow your devices to identify the type of file received from the cloud.
-
#file_version ⇒ String
The file version.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A list of name/attribute pairs.
14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 |
# File 'lib/aws-sdk-iot/types.rb', line 14412 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#code_signing ⇒ Types::CodeSigning
The code signing method of the file.
14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 |
# File 'lib/aws-sdk-iot/types.rb', line 14412 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_location ⇒ Types::FileLocation
The location of the updated firmware.
14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 |
# File 'lib/aws-sdk-iot/types.rb', line 14412 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The name of the file.
14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 |
# File 'lib/aws-sdk-iot/types.rb', line 14412 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_type ⇒ Integer
An integer value you can include in the job document to allow your devices to identify the type of file received from the cloud.
14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 |
# File 'lib/aws-sdk-iot/types.rb', line 14412 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |
#file_version ⇒ String
The file version.
14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 |
# File 'lib/aws-sdk-iot/types.rb', line 14412 class OTAUpdateFile < Struct.new( :file_name, :file_type, :file_version, :file_location, :code_signing, :attributes) SENSITIVE = [] include Aws::Structure end |