Class: Aws::IoT::Types::OTAUpdateInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::OTAUpdateInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Information about an OTA update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_parameters ⇒ Hash<String,String>
A collection of name/value pairs.
-
#aws_iot_job_arn ⇒ String
The IoT job ARN associated with the OTA update.
-
#aws_iot_job_id ⇒ String
The IoT job ID associated with the OTA update.
-
#aws_job_executions_rollout_config ⇒ Types::AwsJobExecutionsRolloutConfig
Configuration for the rollout of OTA updates.
-
#aws_job_presigned_url_config ⇒ Types::AwsJobPresignedUrlConfig
Configuration information for pre-signed URLs.
-
#creation_date ⇒ Time
The date when the OTA update was created.
-
#description ⇒ String
A description of the OTA update.
-
#error_info ⇒ Types::ErrorInfo
Error information associated with the OTA update.
-
#last_modified_date ⇒ Time
The date when the OTA update was last updated.
-
#ota_update_arn ⇒ String
The OTA update ARN.
-
#ota_update_files ⇒ Array<Types::OTAUpdateFile>
A list of files associated with the OTA update.
-
#ota_update_id ⇒ String
The OTA update ID.
-
#ota_update_status ⇒ String
The status of the OTA update.
-
#protocols ⇒ Array<String>
The protocol used to transfer the OTA update image.
-
#target_selection ⇒ String
Specifies whether the OTA update will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the OTA update (SNAPSHOT).
-
#targets ⇒ Array<String>
The targets of the OTA update.
Instance Attribute Details
#additional_parameters ⇒ Hash<String,String>
A collection of name/value pairs
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#aws_iot_job_arn ⇒ String
The IoT job ARN associated with the OTA update.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#aws_iot_job_id ⇒ String
The IoT job ID associated with the OTA update.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#aws_job_executions_rollout_config ⇒ Types::AwsJobExecutionsRolloutConfig
Configuration for the rollout of OTA updates.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#aws_job_presigned_url_config ⇒ Types::AwsJobPresignedUrlConfig
Configuration information for pre-signed URLs. Valid when `protocols` contains HTTP.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date when the OTA update was created.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the OTA update.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#error_info ⇒ Types::ErrorInfo
Error information associated with the OTA update.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date when the OTA update was last updated.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#ota_update_arn ⇒ String
The OTA update ARN.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#ota_update_files ⇒ Array<Types::OTAUpdateFile>
A list of files associated with the OTA update.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#ota_update_id ⇒ String
The OTA update ID.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#ota_update_status ⇒ String
The status of the OTA update.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#protocols ⇒ Array<String>
The protocol used to transfer the OTA update image. Valid values are [HTTP], [MQTT], [HTTP, MQTT]. When both HTTP and MQTT are specified, the target device can choose the protocol.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#target_selection ⇒ String
Specifies whether the OTA update will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the OTA update (SNAPSHOT). If continuous, the OTA update may also be run on a thing when a change is detected in a target. For example, an OTA update will run on a thing when the thing is added to a target group, even after the OTA update was completed by all things originally in the group.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<String>
The targets of the OTA update.
14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 |
# File 'lib/aws-sdk-iot/types.rb', line 14498 class OTAUpdateInfo < Struct.new( :ota_update_id, :ota_update_arn, :creation_date, :last_modified_date, :description, :targets, :protocols, :aws_job_executions_rollout_config, :aws_job_presigned_url_config, :target_selection, :ota_update_files, :ota_update_status, :aws_iot_job_id, :aws_iot_job_arn, :error_info, :additional_parameters) SENSITIVE = [] include Aws::Structure end |