Class: Aws::IoT::Types::ProvisioningHook
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ProvisioningHook
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass ProvisioningHook data as a hash:
{
payload_version: "PayloadVersion",
target_arn: "TargetArn", # required
}
Structure that contains `payloadVersion` and `targetArn`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#payload_version ⇒ String
The payload that was sent to the target function.
-
#target_arn ⇒ String
The ARN of the target function.
Instance Attribute Details
#payload_version ⇒ String
The payload that was sent to the target function.
Note: Only Lambda functions are currently supported.
14733 14734 14735 14736 14737 14738 |
# File 'lib/aws-sdk-iot/types.rb', line 14733 class ProvisioningHook < Struct.new( :payload_version, :target_arn) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The ARN of the target function.
Note: Only Lambda functions are currently supported.
14733 14734 14735 14736 14737 14738 |
# File 'lib/aws-sdk-iot/types.rb', line 14733 class ProvisioningHook < Struct.new( :payload_version, :target_arn) SENSITIVE = [] include Aws::Structure end |