Class: Aws::IoT::Types::ProvisioningTemplateVersionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ProvisioningTemplateVersionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
A summary of information about a fleet provision template version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date when the fleet provisioning template version was created.
-
#is_default_version ⇒ Boolean
True if the fleet provisioning template version is the default version, otherwise false.
-
#version_id ⇒ Integer
The ID of the fleet privisioning template version.
Instance Attribute Details
#creation_date ⇒ Time
The date when the fleet provisioning template version was created
14733 14734 14735 14736 14737 14738 14739 |
# File 'lib/aws-sdk-iot/types.rb', line 14733 class ProvisioningTemplateVersionSummary < Struct.new( :version_id, :creation_date, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#is_default_version ⇒ Boolean
True if the fleet provisioning template version is the default version, otherwise false.
14733 14734 14735 14736 14737 14738 14739 |
# File 'lib/aws-sdk-iot/types.rb', line 14733 class ProvisioningTemplateVersionSummary < Struct.new( :version_id, :creation_date, :is_default_version) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ Integer
The ID of the fleet privisioning template version.
14733 14734 14735 14736 14737 14738 14739 |
# File 'lib/aws-sdk-iot/types.rb', line 14733 class ProvisioningTemplateVersionSummary < Struct.new( :version_id, :creation_date, :is_default_version) SENSITIVE = [] include Aws::Structure end |