Class: Aws::IoT::Types::RemoveThingFromBillingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_group_arnString

The ARN of the billing group.

Returns:

  • (String)


12207
12208
12209
12210
12211
12212
12213
12214
# File 'lib/aws-sdk-iot/types.rb', line 12207

class RemoveThingFromBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#billing_group_nameString

The name of the billing group.

Returns:

  • (String)


12207
12208
12209
12210
12211
12212
12213
12214
# File 'lib/aws-sdk-iot/types.rb', line 12207

class RemoveThingFromBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#thing_arnString

The ARN of the thing to be removed from the billing group.

Returns:

  • (String)


12207
12208
12209
12210
12211
12212
12213
12214
# File 'lib/aws-sdk-iot/types.rb', line 12207

class RemoveThingFromBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

The name of the thing to be removed from the billing group.

Returns:

  • (String)


12207
12208
12209
12210
12211
12212
12213
12214
# File 'lib/aws-sdk-iot/types.rb', line 12207

class RemoveThingFromBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end