Class: Aws::IoT::Types::ResourceIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass ResourceIdentifier data as a hash:

{
  device_certificate_id: "CertificateId",
  ca_certificate_id: "CertificateId",
  cognito_identity_pool_id: "CognitoIdentityPoolId",
  client_id: "ClientId",
  policy_version_identifier: {
    policy_name: "PolicyName",
    policy_version_id: "PolicyVersionId",
  },
  account: "AwsAccountId",
  iam_role_arn: "RoleArn",
  role_alias_arn: "RoleAliasArn",
}

Information that identifies the noncompliant resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountString

The account with which the resource is associated.

Returns:

  • (String)


15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end

#ca_certificate_idString

The ID of the CA certificate used to authorize the certificate.

Returns:

  • (String)


15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The client ID.

Returns:

  • (String)


15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end

#cognito_identity_pool_idString

The ID of the Amazon Cognito identity pool.

Returns:

  • (String)


15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end

#device_certificate_idString

The ID of the certificate attached to the resource.

Returns:

  • (String)


15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The ARN of the IAM role that has overly permissive actions.

Returns:

  • (String)


15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end

#policy_version_identifierTypes::PolicyVersionIdentifier

The version of the policy associated with the resource.



15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_alias_arnString

The ARN of the role alias that has overly permissive actions.

Returns:

  • (String)


15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
# File 'lib/aws-sdk-iot/types.rb', line 15971

class ResourceIdentifier < Struct.new(
  :device_certificate_id,
  :ca_certificate_id,
  :cognito_identity_pool_id,
  :client_id,
  :policy_version_identifier,
  :account,
  :iam_role_arn,
  :role_alias_arn)
  SENSITIVE = []
  include Aws::Structure
end