Class: Aws::IoT::Types::RetryCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::RetryCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass RetryCriteria data as a hash:
{
failure_type: "FAILED", # required, accepts FAILED, TIMED_OUT, ALL
number_of_retries: 1, # required
}
The criteria that determines how many retries are allowed for each failure type for a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_type ⇒ String
The type of job execution failures that can initiate a job retry.
-
#number_of_retries ⇒ Integer
The number of retries allowed for a failure type for the job.
Instance Attribute Details
#failure_type ⇒ String
The type of job execution failures that can initiate a job retry.
15688 15689 15690 15691 15692 15693 |
# File 'lib/aws-sdk-iot/types.rb', line 15688 class RetryCriteria < Struct.new( :failure_type, :number_of_retries) SENSITIVE = [] include Aws::Structure end |
#number_of_retries ⇒ Integer
The number of retries allowed for a failure type for the job.
15688 15689 15690 15691 15692 15693 |
# File 'lib/aws-sdk-iot/types.rb', line 15688 class RetryCriteria < Struct.new( :failure_type, :number_of_retries) SENSITIVE = [] include Aws::Structure end |