Class: Aws::IoT::Types::S3Action
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::S3Action
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass S3Action data as a hash:
{
role_arn: "AwsArn", # required
bucket_name: "BucketName", # required
key: "Key", # required
canned_acl: "private", # accepts private, public-read, public-read-write, aws-exec-read, authenticated-read, bucket-owner-read, bucket-owner-full-control, log-delivery-write
}
Describes an action to write data to an Amazon S3 bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The Amazon S3 bucket.
-
#canned_acl ⇒ String
The Amazon S3 canned ACL that controls access to the object identified by the object key.
-
#key ⇒ String
The object key.
-
#role_arn ⇒ String
The ARN of the IAM role that grants access.
Instance Attribute Details
#bucket_name ⇒ String
The Amazon S3 bucket.
15955 15956 15957 15958 15959 15960 15961 15962 |
# File 'lib/aws-sdk-iot/types.rb', line 15955 class S3Action < Struct.new( :role_arn, :bucket_name, :key, :canned_acl) SENSITIVE = [] include Aws::Structure end |
#canned_acl ⇒ String
The Amazon S3 canned ACL that controls access to the object identified by the object key. For more information, see [S3 canned ACLs].
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#canned-acl
15955 15956 15957 15958 15959 15960 15961 15962 |
# File 'lib/aws-sdk-iot/types.rb', line 15955 class S3Action < Struct.new( :role_arn, :bucket_name, :key, :canned_acl) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The object key. For more information, see [Actions, resources, and condition keys for Amazon S3].
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/list_amazons3.html
15955 15956 15957 15958 15959 15960 15961 15962 |
# File 'lib/aws-sdk-iot/types.rb', line 15955 class S3Action < Struct.new( :role_arn, :bucket_name, :key, :canned_acl) SENSITIVE = [] include Aws::Structure end |