Class: Aws::IoT::Types::SalesforceAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SalesforceAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Describes an action to write a message to a Salesforce IoT Cloud Input Stream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#token ⇒ String
The token used to authenticate access to the Salesforce IoT Cloud Input Stream.
-
#url ⇒ String
The URL exposed by the Salesforce IoT Cloud Input Stream.
Instance Attribute Details
#token ⇒ String
The token used to authenticate access to the Salesforce IoT Cloud Input Stream. The token is available from the Salesforce IoT Cloud platform after creation of the Input Stream.
15060 15061 15062 15063 15064 15065 |
# File 'lib/aws-sdk-iot/types.rb', line 15060 class SalesforceAction < Struct.new( :token, :url) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL exposed by the Salesforce IoT Cloud Input Stream. The URL is available from the Salesforce IoT Cloud platform after creation of the Input Stream.
15060 15061 15062 15063 15064 15065 |
# File 'lib/aws-sdk-iot/types.rb', line 15060 class SalesforceAction < Struct.new( :token, :url) SENSITIVE = [] include Aws::Structure end |