Class: Aws::IoT::Types::ScheduledAuditMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ScheduledAuditMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Information about the scheduled audit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#day_of_month ⇒ String
The day of the month on which the scheduled audit is run (if the ‘frequency` is “MONTHLY”).
-
#day_of_week ⇒ String
The day of the week on which the scheduled audit is run (if the ‘frequency` is “WEEKLY” or “BIWEEKLY”).
-
#frequency ⇒ String
How often the scheduled audit occurs.
-
#scheduled_audit_arn ⇒ String
The ARN of the scheduled audit.
-
#scheduled_audit_name ⇒ String
The name of the scheduled audit.
Instance Attribute Details
#day_of_month ⇒ String
The day of the month on which the scheduled audit is run (if the ‘frequency` is “MONTHLY”). If days 29-31 are specified, and the month does not have that many days, the audit takes place on the “LAST” day of the month.
12589 12590 12591 12592 12593 12594 12595 12596 12597 |
# File 'lib/aws-sdk-iot/types.rb', line 12589 class ScheduledAuditMetadata < Struct.new( :scheduled_audit_name, :scheduled_audit_arn, :frequency, :day_of_month, :day_of_week) SENSITIVE = [] include Aws::Structure end |
#day_of_week ⇒ String
The day of the week on which the scheduled audit is run (if the ‘frequency` is “WEEKLY” or “BIWEEKLY”).
12589 12590 12591 12592 12593 12594 12595 12596 12597 |
# File 'lib/aws-sdk-iot/types.rb', line 12589 class ScheduledAuditMetadata < Struct.new( :scheduled_audit_name, :scheduled_audit_arn, :frequency, :day_of_month, :day_of_week) SENSITIVE = [] include Aws::Structure end |
#frequency ⇒ String
How often the scheduled audit occurs.
12589 12590 12591 12592 12593 12594 12595 12596 12597 |
# File 'lib/aws-sdk-iot/types.rb', line 12589 class ScheduledAuditMetadata < Struct.new( :scheduled_audit_name, :scheduled_audit_arn, :frequency, :day_of_month, :day_of_week) SENSITIVE = [] include Aws::Structure end |
#scheduled_audit_arn ⇒ String
The ARN of the scheduled audit.
12589 12590 12591 12592 12593 12594 12595 12596 12597 |
# File 'lib/aws-sdk-iot/types.rb', line 12589 class ScheduledAuditMetadata < Struct.new( :scheduled_audit_name, :scheduled_audit_arn, :frequency, :day_of_month, :day_of_week) SENSITIVE = [] include Aws::Structure end |
#scheduled_audit_name ⇒ String
The name of the scheduled audit.
12589 12590 12591 12592 12593 12594 12595 12596 12597 |
# File 'lib/aws-sdk-iot/types.rb', line 12589 class ScheduledAuditMetadata < Struct.new( :scheduled_audit_name, :scheduled_audit_arn, :frequency, :day_of_month, :day_of_week) SENSITIVE = [] include Aws::Structure end |