Class: Aws::IoT::Types::SchedulingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SchedulingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass SchedulingConfig data as a hash:
{
start_time: "StringDateTime",
end_time: "StringDateTime",
end_behavior: "STOP_ROLLOUT", # accepts STOP_ROLLOUT, CANCEL, FORCE_CANCEL
}
Specifies the date and time that a job will begin the rollout of the job document to all devices in the target group. Additionally, you can specify the end behavior for each job execution when it reaches the scheduled end time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_behavior ⇒ String
Specifies the end behavior for all job executions after a job reaches the selected `endTime`.
-
#end_time ⇒ String
The time a job will stop rollout of the job document to all devices in the target group for a job.
-
#start_time ⇒ String
The time a job will begin rollout of the job document to all devices in the target group for a job.
Instance Attribute Details
#end_behavior ⇒ String
Specifies the end behavior for all job executions after a job reaches the selected `endTime`. If `endTime` is not selected when creating the job, then `endBehavior` does not apply.
16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-iot/types.rb', line 16793 class SchedulingConfig < Struct.new( :start_time, :end_time, :end_behavior) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ String
The time a job will stop rollout of the job document to all devices in the target group for a job. The `endTime` must take place no later than two years from the current time and be scheduled a minimum of thirty minutes from the current time. The minimum duration between `startTime` and `endTime` is thirty minutes. The maximum duration between `startTime` and `endTime` is two years.
16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-iot/types.rb', line 16793 class SchedulingConfig < Struct.new( :start_time, :end_time, :end_behavior) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The time a job will begin rollout of the job document to all devices in the target group for a job. The `startTime` can be scheduled up to a year in advance and must be scheduled a minimum of thirty minutes from the current time.
16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-iot/types.rb', line 16793 class SchedulingConfig < Struct.new( :start_time, :end_time, :end_behavior) SENSITIVE = [] include Aws::Structure end |