Class: Aws::IoT::Types::SearchIndexRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#index_nameString

The search index name.

Returns:

  • (String)


13507
13508
13509
13510
13511
13512
13513
13514
13515
# File 'lib/aws-sdk-iot/types.rb', line 13507

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page at one time. The response might contain fewer results but will never contain more.

Returns:

  • (Integer)


13507
13508
13509
13510
13511
13512
13513
13514
13515
# File 'lib/aws-sdk-iot/types.rb', line 13507

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token used to get the next set of results, or ‘null` if there are no additional results.

Returns:

  • (String)


13507
13508
13509
13510
13511
13512
13513
13514
13515
# File 'lib/aws-sdk-iot/types.rb', line 13507

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The search query string. For more information about the search query syntax, see [Query syntax].

[1]: docs.aws.amazon.com/iot/latest/developerguide/query-syntax.html

Returns:

  • (String)


13507
13508
13509
13510
13511
13512
13513
13514
13515
# File 'lib/aws-sdk-iot/types.rb', line 13507

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#query_versionString

The query version.

Returns:

  • (String)


13507
13508
13509
13510
13511
13512
13513
13514
13515
# File 'lib/aws-sdk-iot/types.rb', line 13507

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end