Class: Aws::IoT::Types::SearchIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SearchIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_name ⇒ String
The search index name.
-
#max_results ⇒ Integer
The maximum number of results to return per page at one time.
-
#next_token ⇒ String
The token used to get the next set of results, or ‘null` if there are no additional results.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The query version.
Instance Attribute Details
#index_name ⇒ String
The search index name.
13507 13508 13509 13510 13511 13512 13513 13514 13515 |
# File 'lib/aws-sdk-iot/types.rb', line 13507 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page at one time. The response might contain fewer results but will never contain more.
13507 13508 13509 13510 13511 13512 13513 13514 13515 |
# File 'lib/aws-sdk-iot/types.rb', line 13507 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token used to get the next set of results, or ‘null` if there are no additional results.
13507 13508 13509 13510 13511 13512 13513 13514 13515 |
# File 'lib/aws-sdk-iot/types.rb', line 13507 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string. For more information about the search query syntax, see [Query syntax].
[1]: docs.aws.amazon.com/iot/latest/developerguide/query-syntax.html
13507 13508 13509 13510 13511 13512 13513 13514 13515 |
# File 'lib/aws-sdk-iot/types.rb', line 13507 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The query version.
13507 13508 13509 13510 13511 13512 13513 13514 13515 |
# File 'lib/aws-sdk-iot/types.rb', line 13507 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |