Class: Aws::IoT::Types::SearchIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SearchIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_name ⇒ String
The search index name.
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The token used to get the next set of results, or ‘null` if there are no additional results.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The query version.
Instance Attribute Details
#index_name ⇒ String
The search index name.
13249 13250 13251 13252 13253 13254 13255 13256 13257 |
# File 'lib/aws-sdk-iot/types.rb', line 13249 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return at one time.
13249 13250 13251 13252 13253 13254 13255 13256 13257 |
# File 'lib/aws-sdk-iot/types.rb', line 13249 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token used to get the next set of results, or ‘null` if there are no additional results.
13249 13250 13251 13252 13253 13254 13255 13256 13257 |
# File 'lib/aws-sdk-iot/types.rb', line 13249 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string. For more information about the search query syntax, see [Query syntax].
[1]: docs.aws.amazon.com/iot/latest/developerguide/query-syntax.html
13249 13250 13251 13252 13253 13254 13255 13256 13257 |
# File 'lib/aws-sdk-iot/types.rb', line 13249 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The query version.
13249 13250 13251 13252 13253 13254 13255 13256 13257 |
# File 'lib/aws-sdk-iot/types.rb', line 13249 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |