Class: Aws::IoT::Types::SearchIndexRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#index_nameString

The search index name.

Returns:

  • (String)


12693
12694
12695
12696
12697
12698
12699
12700
12701
# File 'lib/aws-sdk-iot/types.rb', line 12693

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return at one time.

Returns:

  • (Integer)


12693
12694
12695
12696
12697
12698
12699
12700
12701
# File 'lib/aws-sdk-iot/types.rb', line 12693

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token used to get the next set of results, or ‘null` if there are no additional results.

Returns:

  • (String)


12693
12694
12695
12696
12697
12698
12699
12700
12701
# File 'lib/aws-sdk-iot/types.rb', line 12693

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The search query string. For more information about the search query syntax, see [Query syntax].

[1]: docs.aws.amazon.com/iot/latest/developerguide/query-syntax.html

Returns:

  • (String)


12693
12694
12695
12696
12697
12698
12699
12700
12701
# File 'lib/aws-sdk-iot/types.rb', line 12693

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end

#query_versionString

The query version.

Returns:

  • (String)


12693
12694
12695
12696
12697
12698
12699
12700
12701
# File 'lib/aws-sdk-iot/types.rb', line 12693

class SearchIndexRequest < Struct.new(
  :index_name,
  :query_string,
  :next_token,
  :max_results,
  :query_version)
  SENSITIVE = []
  include Aws::Structure
end