Class: Aws::IoT::Types::SearchIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SearchIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass SearchIndexRequest data as a hash:
{
index_name: "IndexName",
query_string: "QueryString", # required
next_token: "NextToken",
max_results: 1,
query_version: "QueryVersion",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_name ⇒ String
The search index name.
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The token used to get the next set of results, or `null` if there are no additional results.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The query version.
Instance Attribute Details
#index_name ⇒ String
The search index name.
15963 15964 15965 15966 15967 15968 15969 15970 15971 |
# File 'lib/aws-sdk-iot/types.rb', line 15963 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return at one time.
15963 15964 15965 15966 15967 15968 15969 15970 15971 |
# File 'lib/aws-sdk-iot/types.rb', line 15963 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token used to get the next set of results, or `null` if there are no additional results.
15963 15964 15965 15966 15967 15968 15969 15970 15971 |
# File 'lib/aws-sdk-iot/types.rb', line 15963 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string.
15963 15964 15965 15966 15967 15968 15969 15970 15971 |
# File 'lib/aws-sdk-iot/types.rb', line 15963 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The query version.
15963 15964 15965 15966 15967 15968 15969 15970 15971 |
# File 'lib/aws-sdk-iot/types.rb', line 15963 class SearchIndexRequest < Struct.new( :index_name, :query_string, :next_token, :max_results, :query_version) SENSITIVE = [] include Aws::Structure end |