Class: Aws::IoT::Types::SnsAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::SnsAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass SnsAction data as a hash:
{
target_arn: "AwsArn", # required
role_arn: "AwsArn", # required
message_format: "RAW", # accepts RAW, JSON
}
Describes an action to publish to an Amazon SNS topic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message_format ⇒ String
(Optional) The message format of the message to publish.
-
#role_arn ⇒ String
The ARN of the IAM role that grants access.
-
#target_arn ⇒ String
The ARN of the SNS topic.
Instance Attribute Details
#message_format ⇒ String
(Optional) The message format of the message to publish. Accepted values are “JSON” and “RAW”. The default value of the attribute is “RAW”. SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. To read more about SNS message formats, see
- docs.aws.amazon.com/sns/latest/dg/json-formats.html][1
-
refer to their official documentation.
16551 16552 16553 16554 16555 16556 16557 |
# File 'lib/aws-sdk-iot/types.rb', line 16551 class SnsAction < Struct.new( :target_arn, :role_arn, :message_format) SENSITIVE = [] include Aws::Structure end |