Class: Aws::IoT::Types::StartOnDemandAuditTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::StartOnDemandAuditTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_check_names ⇒ Array<String>
Which checks are performed during the audit.
Instance Attribute Details
#target_check_names ⇒ Array<String>
Which checks are performed during the audit. The checks you specify must be enabled for your account or an exception occurs. Use ‘DescribeAccountAuditConfiguration` to see the list of all checks, including those that are enabled or `UpdateAccountAuditConfiguration` to select which checks are enabled.
13639 13640 13641 13642 13643 |
# File 'lib/aws-sdk-iot/types.rb', line 13639 class StartOnDemandAuditTaskRequest < Struct.new( :target_check_names) SENSITIVE = [] include Aws::Structure end |