Class: Aws::IoT::Types::StartOnDemandAuditTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::StartOnDemandAuditTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass StartOnDemandAuditTaskRequest data as a hash:
{
target_check_names: ["AuditCheckName"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_check_names ⇒ Array<String>
Which checks are performed during the audit.
Instance Attribute Details
#target_check_names ⇒ Array<String>
Which checks are performed during the audit. The checks you specify must be enabled for your account or an exception occurs. Use `DescribeAccountAuditConfiguration` to see the list of all checks, including those that are enabled or `UpdateAccountAuditConfiguration` to select which checks are enabled.
16520 16521 16522 16523 16524 |
# File 'lib/aws-sdk-iot/types.rb', line 16520 class StartOnDemandAuditTaskRequest < Struct.new( :target_check_names) SENSITIVE = [] include Aws::Structure end |