Class: Aws::IoT::Types::TestAuthorizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::TestAuthorizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_infos ⇒ Array<Types::AuthInfo>
A list of authorization info objects.
-
#client_id ⇒ String
The MQTT client ID.
-
#cognito_identity_pool_id ⇒ String
The Cognito identity pool ID.
-
#policy_names_to_add ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are attached to the principal being authorized.
-
#policy_names_to_skip ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are not attached to the principal being authorized.
-
#principal ⇒ String
The principal.
Instance Attribute Details
#auth_infos ⇒ Array<Types::AuthInfo>
A list of authorization info objects. Simulating authorization will create a response for each ‘authInfo` object in the list.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 |
# File 'lib/aws-sdk-iot/types.rb', line 14257 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#client_id ⇒ String
The MQTT client ID.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 |
# File 'lib/aws-sdk-iot/types.rb', line 14257 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#cognito_identity_pool_id ⇒ String
The Cognito identity pool ID.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 |
# File 'lib/aws-sdk-iot/types.rb', line 14257 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#policy_names_to_add ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are attached to the principal being authorized.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 |
# File 'lib/aws-sdk-iot/types.rb', line 14257 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#policy_names_to_skip ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are not attached to the principal being authorized.
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 |
# File 'lib/aws-sdk-iot/types.rb', line 14257 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
The principal. Valid principals are CertificateArn (arn:aws:iot:region:accountId:cert/certificateId), thingGroupArn (arn:aws:iot:region:accountId:thinggroup/groupName) and CognitoId (region:id).
14257 14258 14259 14260 14261 14262 14263 14264 14265 14266 |
# File 'lib/aws-sdk-iot/types.rb', line 14257 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |