Class: Aws::IoT::Types::TestAuthorizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::TestAuthorizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass TestAuthorizationRequest data as a hash:
{
principal: "Principal",
cognito_identity_pool_id: "CognitoIdentityPoolId",
auth_infos: [ # required
{
action_type: "PUBLISH", # accepts PUBLISH, SUBSCRIBE, RECEIVE, CONNECT
resources: ["Resource"], # required
},
],
client_id: "ClientId",
policy_names_to_add: ["PolicyName"],
policy_names_to_skip: ["PolicyName"],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_infos ⇒ Array<Types::AuthInfo>
A list of authorization info objects.
-
#client_id ⇒ String
The MQTT client ID.
-
#cognito_identity_pool_id ⇒ String
The Cognito identity pool ID.
-
#policy_names_to_add ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are attached to the principal being authorized.
-
#policy_names_to_skip ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are not attached to the principal being authorized.
-
#principal ⇒ String
The principal.
Instance Attribute Details
#auth_infos ⇒ Array<Types::AuthInfo>
A list of authorization info objects. Simulating authorization will create a response for each `authInfo` object in the list.
17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-iot/types.rb', line 17348 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#client_id ⇒ String
The MQTT client ID.
17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-iot/types.rb', line 17348 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#cognito_identity_pool_id ⇒ String
The Cognito identity pool ID.
17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-iot/types.rb', line 17348 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#policy_names_to_add ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are attached to the principal being authorized.
17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-iot/types.rb', line 17348 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#policy_names_to_skip ⇒ Array<String>
When testing custom authorization, the policies specified here are treated as if they are not attached to the principal being authorized.
17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-iot/types.rb', line 17348 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
The principal. Valid principals are CertificateArn (arn:aws:iot:region:accountId:cert/certificateId), thingGroupArn (arn:aws:iot:region:accountId:thinggroup/groupName) and CognitoId (region:id).
17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-iot/types.rb', line 17348 class TestAuthorizationRequest < Struct.new( :principal, :cognito_identity_pool_id, :auth_infos, :client_id, :policy_names_to_add, :policy_names_to_skip) SENSITIVE = [] include Aws::Structure end |