Class: Aws::IoT::Types::ThingConnectivity
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ThingConnectivity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The connectivity status of the thing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clean_session ⇒ Boolean
Indicates whether the client is using a clean session.
-
#client_id ⇒ String
The unique identifier of the MQTT client.
-
#connected ⇒ Boolean
True if the thing is connected to the Amazon Web Services IoT Core service; false if it is not connected.
-
#disconnect_reason ⇒ String
The reason that the client is disconnected.
-
#keep_alive_duration ⇒ Integer
The keep-alive interval in seconds that the client specified when establishing the connection.
-
#session_expiry ⇒ Integer
The session expiry interval in seconds for the MQTT client connection.
-
#timestamp ⇒ Integer
The epoch time (in milliseconds) when the thing last connected or disconnected.
Instance Attribute Details
#clean_session ⇒ Boolean
Indicates whether the client is using a clean session. Returns ‘true` for clean sessions.
16496 16497 16498 16499 16500 16501 16502 16503 16504 16505 16506 |
# File 'lib/aws-sdk-iot/types.rb', line 16496 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [] include Aws::Structure end |
#client_id ⇒ String
The unique identifier of the MQTT client.
16496 16497 16498 16499 16500 16501 16502 16503 16504 16505 16506 |
# File 'lib/aws-sdk-iot/types.rb', line 16496 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [] include Aws::Structure end |
#connected ⇒ Boolean
True if the thing is connected to the Amazon Web Services IoT Core service; false if it is not connected.
16496 16497 16498 16499 16500 16501 16502 16503 16504 16505 16506 |
# File 'lib/aws-sdk-iot/types.rb', line 16496 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [] include Aws::Structure end |
#disconnect_reason ⇒ String
The reason that the client is disconnected.
16496 16497 16498 16499 16500 16501 16502 16503 16504 16505 16506 |
# File 'lib/aws-sdk-iot/types.rb', line 16496 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [] include Aws::Structure end |
#keep_alive_duration ⇒ Integer
The keep-alive interval in seconds that the client specified when establishing the connection.
16496 16497 16498 16499 16500 16501 16502 16503 16504 16505 16506 |
# File 'lib/aws-sdk-iot/types.rb', line 16496 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [] include Aws::Structure end |
#session_expiry ⇒ Integer
The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.
16496 16497 16498 16499 16500 16501 16502 16503 16504 16505 16506 |
# File 'lib/aws-sdk-iot/types.rb', line 16496 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Integer
The epoch time (in milliseconds) when the thing last connected or disconnected.
16496 16497 16498 16499 16500 16501 16502 16503 16504 16505 16506 |
# File 'lib/aws-sdk-iot/types.rb', line 16496 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason, :keep_alive_duration, :clean_session, :session_expiry, :client_id) SENSITIVE = [] include Aws::Structure end |