Class: Aws::IoT::Types::ThingConnectivity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

The connectivity status of the thing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clean_sessionBoolean

Indicates whether the client is using a clean session. Returns ‘true` for clean sessions.

Returns:

  • (Boolean)


16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/aws-sdk-iot/types.rb', line 16509

class ThingConnectivity < Struct.new(
  :connected,
  :timestamp,
  :disconnect_reason,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The unique identifier of the MQTT client.

Returns:

  • (String)


16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/aws-sdk-iot/types.rb', line 16509

class ThingConnectivity < Struct.new(
  :connected,
  :timestamp,
  :disconnect_reason,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end

#connectedBoolean

True if the thing is connected to the Amazon Web Services IoT Core service; false if it is not connected.

Returns:

  • (Boolean)


16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/aws-sdk-iot/types.rb', line 16509

class ThingConnectivity < Struct.new(
  :connected,
  :timestamp,
  :disconnect_reason,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end

#disconnect_reasonString

The reason why the client is disconnected. When you enable or update the indexing configuration, this value might be missing for devices that have never connected or have been disconnected for more than an hour.

Returns:

  • (String)


16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/aws-sdk-iot/types.rb', line 16509

class ThingConnectivity < Struct.new(
  :connected,
  :timestamp,
  :disconnect_reason,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end

#keep_alive_durationInteger

The keep-alive interval in seconds that the client specified when establishing the connection.

Returns:

  • (Integer)


16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/aws-sdk-iot/types.rb', line 16509

class ThingConnectivity < Struct.new(
  :connected,
  :timestamp,
  :disconnect_reason,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_expiryInteger

The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.

Returns:

  • (Integer)


16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/aws-sdk-iot/types.rb', line 16509

class ThingConnectivity < Struct.new(
  :connected,
  :timestamp,
  :disconnect_reason,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end

#timestampInteger

The epoch time (in milliseconds) when the thing last connected or disconnected. If the thing has been disconnected for approximately an hour, the time value might be missing. When you enable or update the indexing configuration, this value might be ‘0` (the Unix epoch time) for devices that have never connected or have been disconnected for more than an hour.

Returns:

  • (Integer)


16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/aws-sdk-iot/types.rb', line 16509

class ThingConnectivity < Struct.new(
  :connected,
  :timestamp,
  :disconnect_reason,
  :keep_alive_duration,
  :clean_session,
  :session_expiry,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end