Class: Aws::IoT::Types::ThingConnectivity
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ThingConnectivity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The connectivity status of the thing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connected ⇒ Boolean
True if the thing is connected to the Amazon Web Services IoT Core service; false if it is not connected.
-
#disconnect_reason ⇒ String
The reason why the client is disconnected.
-
#timestamp ⇒ Integer
The epoch time (in milliseconds) when the thing last connected or disconnected.
Instance Attribute Details
#connected ⇒ Boolean
True if the thing is connected to the Amazon Web Services IoT Core service; false if it is not connected.
17512 17513 17514 17515 17516 17517 17518 |
# File 'lib/aws-sdk-iot/types.rb', line 17512 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason) SENSITIVE = [] include Aws::Structure end |
#disconnect_reason ⇒ String
The reason why the client is disconnected. If the thing has been disconnected for approximately an hour, the `disconnectReason` value might be missing.
17512 17513 17514 17515 17516 17517 17518 |
# File 'lib/aws-sdk-iot/types.rb', line 17512 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Integer
The epoch time (in milliseconds) when the thing last connected or disconnected. If the thing has been disconnected for approximately an hour, the time value might be missing.
17512 17513 17514 17515 17516 17517 17518 |
# File 'lib/aws-sdk-iot/types.rb', line 17512 class ThingConnectivity < Struct.new( :connected, :timestamp, :disconnect_reason) SENSITIVE = [] include Aws::Structure end |