Class: Aws::IoT::Types::ThingGroupIndexingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ThingGroupIndexingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass ThingGroupIndexingConfiguration data as a hash:
{
thing_group_indexing_mode: "OFF", # required, accepts OFF, ON
managed_fields: [
{
name: "FieldName",
type: "Number", # accepts Number, String, Boolean
},
],
custom_fields: [
{
name: "FieldName",
type: "Number", # accepts Number, String, Boolean
},
],
}
Thing group indexing configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_fields ⇒ Array<Types::Field>
A list of thing group fields to index.
-
#managed_fields ⇒ Array<Types::Field>
Contains fields that are indexed and whose types are already known by the Fleet Indexing service.
-
#thing_group_indexing_mode ⇒ String
Thing group indexing mode.
Instance Attribute Details
#custom_fields ⇒ Array<Types::Field>
A list of thing group fields to index. This list cannot contain any managed fields. Use the GetIndexingConfiguration API to get a list of managed fields.
Contains custom field names and their data type.
17731 17732 17733 17734 17735 17736 17737 |
# File 'lib/aws-sdk-iot/types.rb', line 17731 class ThingGroupIndexingConfiguration < Struct.new( :thing_group_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#managed_fields ⇒ Array<Types::Field>
Contains fields that are indexed and whose types are already known by the Fleet Indexing service.
17731 17732 17733 17734 17735 17736 17737 |
# File 'lib/aws-sdk-iot/types.rb', line 17731 class ThingGroupIndexingConfiguration < Struct.new( :thing_group_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#thing_group_indexing_mode ⇒ String
Thing group indexing mode.
17731 17732 17733 17734 17735 17736 17737 |
# File 'lib/aws-sdk-iot/types.rb', line 17731 class ThingGroupIndexingConfiguration < Struct.new( :thing_group_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |