Class: Aws::IoT::Types::ThingIndexingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ThingIndexingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass ThingIndexingConfiguration data as a hash:
{
thing_indexing_mode: "OFF", # required, accepts OFF, REGISTRY, REGISTRY_AND_SHADOW
thing_connectivity_indexing_mode: "OFF", # accepts OFF, STATUS
device_defender_indexing_mode: "OFF", # accepts OFF, VIOLATIONS
named_shadow_indexing_mode: "OFF", # accepts OFF, ON
managed_fields: [
{
name: "FieldName",
type: "Number", # accepts Number, String, Boolean
},
],
custom_fields: [
{
name: "FieldName",
type: "Number", # accepts Number, String, Boolean
},
],
}
The thing indexing configuration. For more information, see [Managing Thing Indexing].
[1]: docs.aws.amazon.com/iot/latest/developerguide/managing-index.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_fields ⇒ Array<Types::Field>
Contains custom field names and their data type.
-
#device_defender_indexing_mode ⇒ String
Device Defender indexing mode.
-
#managed_fields ⇒ Array<Types::Field>
Contains fields that are indexed and whose types are already known by the Fleet Indexing service.
-
#named_shadow_indexing_mode ⇒ String
Named shadow indexing mode.
-
#thing_connectivity_indexing_mode ⇒ String
Thing connectivity indexing mode.
-
#thing_indexing_mode ⇒ String
Thing indexing mode.
Instance Attribute Details
#custom_fields ⇒ Array<Types::Field>
Contains custom field names and their data type.
17539 17540 17541 17542 17543 17544 17545 17546 17547 17548 |
# File 'lib/aws-sdk-iot/types.rb', line 17539 class ThingIndexingConfiguration < Struct.new( :thing_indexing_mode, :thing_connectivity_indexing_mode, :device_defender_indexing_mode, :named_shadow_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#device_defender_indexing_mode ⇒ String
Device Defender indexing mode. Valid values are:
-
VIOLATIONS – Your thing index contains Device Defender violations. To enable Device Defender indexing, deviceDefenderIndexingMode must not be set to OFF.
-
OFF - Device Defender indexing is disabled.
For more information about Device Defender violations, see [Device Defender Detect.]
[1]: docs.aws.amazon.com/iot/latest/developerguide/device-defender-detect.html
17539 17540 17541 17542 17543 17544 17545 17546 17547 17548 |
# File 'lib/aws-sdk-iot/types.rb', line 17539 class ThingIndexingConfiguration < Struct.new( :thing_indexing_mode, :thing_connectivity_indexing_mode, :device_defender_indexing_mode, :named_shadow_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#managed_fields ⇒ Array<Types::Field>
Contains fields that are indexed and whose types are already known by the Fleet Indexing service.
17539 17540 17541 17542 17543 17544 17545 17546 17547 17548 |
# File 'lib/aws-sdk-iot/types.rb', line 17539 class ThingIndexingConfiguration < Struct.new( :thing_indexing_mode, :thing_connectivity_indexing_mode, :device_defender_indexing_mode, :named_shadow_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#named_shadow_indexing_mode ⇒ String
Named shadow indexing mode. Valid values are:
-
ON – Your thing index contains named shadow. To enable thing named shadow indexing, namedShadowIndexingMode must not be set to OFF.
-
OFF - Named shadow indexing is disabled.
For more information about Shadows, see [IoT Device Shadow service.]
[1]: docs.aws.amazon.com/iot/latest/developerguide/iot-device-shadows.html
17539 17540 17541 17542 17543 17544 17545 17546 17547 17548 |
# File 'lib/aws-sdk-iot/types.rb', line 17539 class ThingIndexingConfiguration < Struct.new( :thing_indexing_mode, :thing_connectivity_indexing_mode, :device_defender_indexing_mode, :named_shadow_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#thing_connectivity_indexing_mode ⇒ String
Thing connectivity indexing mode. Valid values are:
-
STATUS – Your thing index contains connectivity status. To enable thing connectivity indexing, thingIndexMode must not be set to OFF.
-
OFF - Thing connectivity status indexing is disabled.
17539 17540 17541 17542 17543 17544 17545 17546 17547 17548 |
# File 'lib/aws-sdk-iot/types.rb', line 17539 class ThingIndexingConfiguration < Struct.new( :thing_indexing_mode, :thing_connectivity_indexing_mode, :device_defender_indexing_mode, :named_shadow_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |
#thing_indexing_mode ⇒ String
Thing indexing mode. Valid values are:
-
REGISTRY – Your thing index contains registry data only.
-
REGISTRY_AND_SHADOW - Your thing index contains registry and shadow data.
-
OFF - Thing indexing is disabled.
17539 17540 17541 17542 17543 17544 17545 17546 17547 17548 |
# File 'lib/aws-sdk-iot/types.rb', line 17539 class ThingIndexingConfiguration < Struct.new( :thing_indexing_mode, :thing_connectivity_indexing_mode, :device_defender_indexing_mode, :named_shadow_indexing_mode, :managed_fields, :custom_fields) SENSITIVE = [] include Aws::Structure end |