Class: Aws::IoT::Types::TimestreamTimestamp
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::TimestreamTimestamp
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass TimestreamTimestamp data as a hash:
{
value: "TimestreamTimestampValue", # required
unit: "TimestreamTimestampUnit", # required
}
Describes how to interpret an application-defined timestamp value from an MQTT message payload and the precision of that value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unit ⇒ String
The precision of the timestamp value that results from the expression described in `value`.
-
#value ⇒ String
An expression that returns a long epoch time value.
Instance Attribute Details
#unit ⇒ String
The precision of the timestamp value that results from the expression described in `value`.
Valid values: `SECONDS` | `MILLISECONDS` | `MICROSECONDS` | `NANOSECONDS`. The default is `MILLISECONDS`.
17798 17799 17800 17801 17802 17803 |
# File 'lib/aws-sdk-iot/types.rb', line 17798 class TimestreamTimestamp < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
An expression that returns a long epoch time value.
17798 17799 17800 17801 17802 17803 |
# File 'lib/aws-sdk-iot/types.rb', line 17798 class TimestreamTimestamp < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |