Class: Aws::IoT::Types::UpdateAuditSuppressionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateAuditSuppressionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#check_name ⇒ String
An audit check name.
-
#description ⇒ String
The description of the audit suppression.
-
#expiration_date ⇒ Time
The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.
-
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
-
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
Instance Attribute Details
#check_name ⇒ String
An audit check name. Checks must be enabled for your account. (Use
DescribeAccountAuditConfiguration to see the list of all checks,
including those that are enabled or use
UpdateAccountAuditConfiguration to select which checks are
enabled.)
17814 17815 17816 17817 17818 17819 17820 17821 17822 |
# File 'lib/aws-sdk-iot/types.rb', line 17814 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the audit suppression.
17814 17815 17816 17817 17818 17819 17820 17821 17822 |
# File 'lib/aws-sdk-iot/types.rb', line 17814 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#expiration_date ⇒ Time
The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.
17814 17815 17816 17817 17818 17819 17820 17821 17822 |
# File 'lib/aws-sdk-iot/types.rb', line 17814 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
17814 17815 17816 17817 17818 17819 17820 17821 17822 |
# File 'lib/aws-sdk-iot/types.rb', line 17814 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
17814 17815 17816 17817 17818 17819 17820 17821 17822 |
# File 'lib/aws-sdk-iot/types.rb', line 17814 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |