Class: Aws::IoT::Types::UpdateAuditSuppressionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateAuditSuppressionRequest data as a hash:

{
  check_name: "AuditCheckName", # required
  resource_identifier: { # required
    device_certificate_id: "CertificateId",
    ca_certificate_id: "CertificateId",
    cognito_identity_pool_id: "CognitoIdentityPoolId",
    client_id: "ClientId",
    policy_version_identifier: {
      policy_name: "PolicyName",
      policy_version_id: "PolicyVersionId",
    },
    account: "AwsAccountId",
    iam_role_arn: "RoleArn",
    role_alias_arn: "RoleAliasArn",
  },
  expiration_date: Time.now,
  suppress_indefinitely: false,
  description: "AuditDescription",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#check_nameString

An audit check name. Checks must be enabled for your account. (Use `DescribeAccountAuditConfiguration` to see the list of all checks, including those that are enabled or use `UpdateAccountAuditConfiguration` to select which checks are enabled.)

Returns:

  • (String)


18991
18992
18993
18994
18995
18996
18997
18998
18999
# File 'lib/aws-sdk-iot/types.rb', line 18991

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the audit suppression.

Returns:

  • (String)


18991
18992
18993
18994
18995
18996
18997
18998
18999
# File 'lib/aws-sdk-iot/types.rb', line 18991

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_dateTime

The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.

Returns:

  • (Time)


18991
18992
18993
18994
18995
18996
18997
18998
18999
# File 'lib/aws-sdk-iot/types.rb', line 18991

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifierTypes::ResourceIdentifier

Information that identifies the noncompliant resource.



18991
18992
18993
18994
18995
18996
18997
18998
18999
# File 'lib/aws-sdk-iot/types.rb', line 18991

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#suppress_indefinitelyBoolean

Indicates whether a suppression should exist indefinitely or not.

Returns:

  • (Boolean)


18991
18992
18993
18994
18995
18996
18997
18998
18999
# File 'lib/aws-sdk-iot/types.rb', line 18991

class UpdateAuditSuppressionRequest < Struct.new(
  :check_name,
  :resource_identifier,
  :expiration_date,
  :suppress_indefinitely,
  :description)
  SENSITIVE = []
  include Aws::Structure
end