Class: Aws::IoT::Types::UpdateAuditSuppressionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateAuditSuppressionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass UpdateAuditSuppressionRequest data as a hash:
{
check_name: "AuditCheckName", # required
resource_identifier: { # required
device_certificate_id: "CertificateId",
ca_certificate_id: "CertificateId",
cognito_identity_pool_id: "CognitoIdentityPoolId",
client_id: "ClientId",
policy_version_identifier: {
policy_name: "PolicyName",
policy_version_id: "PolicyVersionId",
},
account: "AwsAccountId",
iam_role_arn: "RoleArn",
role_alias_arn: "RoleAliasArn",
},
expiration_date: Time.now,
suppress_indefinitely: false,
description: "AuditDescription",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#check_name ⇒ String
An audit check name.
-
#description ⇒ String
The description of the audit suppression.
-
#expiration_date ⇒ Time
The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.
-
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
-
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
Instance Attribute Details
#check_name ⇒ String
An audit check name. Checks must be enabled for your account. (Use `DescribeAccountAuditConfiguration` to see the list of all checks, including those that are enabled or use `UpdateAccountAuditConfiguration` to select which checks are enabled.)
18843 18844 18845 18846 18847 18848 18849 18850 18851 |
# File 'lib/aws-sdk-iot/types.rb', line 18843 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the audit suppression.
18843 18844 18845 18846 18847 18848 18849 18850 18851 |
# File 'lib/aws-sdk-iot/types.rb', line 18843 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#expiration_date ⇒ Time
The expiration date (epoch timestamp in seconds) that you want the suppression to adhere to.
18843 18844 18845 18846 18847 18848 18849 18850 18851 |
# File 'lib/aws-sdk-iot/types.rb', line 18843 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ Types::ResourceIdentifier
Information that identifies the noncompliant resource.
18843 18844 18845 18846 18847 18848 18849 18850 18851 |
# File 'lib/aws-sdk-iot/types.rb', line 18843 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |
#suppress_indefinitely ⇒ Boolean
Indicates whether a suppression should exist indefinitely or not.
18843 18844 18845 18846 18847 18848 18849 18850 18851 |
# File 'lib/aws-sdk-iot/types.rb', line 18843 class UpdateAuditSuppressionRequest < Struct.new( :check_name, :resource_identifier, :expiration_date, :suppress_indefinitely, :description) SENSITIVE = [] include Aws::Structure end |