Class: Aws::IoT::Types::UpdateAuthorizerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizer_function_arnString

The ARN of the authorizer's Lambda function.

Returns:

  • (String)


17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
# File 'lib/aws-sdk-iot/types.rb', line 17593

class UpdateAuthorizerRequest < Struct.new(
  :authorizer_name,
  :authorizer_function_arn,
  :token_key_name,
  :token_signing_public_keys,
  :status,
  :enable_caching_for_http)
  SENSITIVE = []
  include Aws::Structure
end

#authorizer_nameString

The authorizer name.

Returns:

  • (String)


17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
# File 'lib/aws-sdk-iot/types.rb', line 17593

class UpdateAuthorizerRequest < Struct.new(
  :authorizer_name,
  :authorizer_function_arn,
  :token_key_name,
  :token_signing_public_keys,
  :status,
  :enable_caching_for_http)
  SENSITIVE = []
  include Aws::Structure
end

#enable_caching_for_httpBoolean

When true, the result from the authorizer’s Lambda function is cached for the time specified in refreshAfterInSeconds. The cached result is used while the device reuses the same HTTP connection.

Returns:

  • (Boolean)


17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
# File 'lib/aws-sdk-iot/types.rb', line 17593

class UpdateAuthorizerRequest < Struct.new(
  :authorizer_name,
  :authorizer_function_arn,
  :token_key_name,
  :token_signing_public_keys,
  :status,
  :enable_caching_for_http)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the update authorizer request.

Returns:

  • (String)


17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
# File 'lib/aws-sdk-iot/types.rb', line 17593

class UpdateAuthorizerRequest < Struct.new(
  :authorizer_name,
  :authorizer_function_arn,
  :token_key_name,
  :token_signing_public_keys,
  :status,
  :enable_caching_for_http)
  SENSITIVE = []
  include Aws::Structure
end

#token_key_nameString

The key used to extract the token from the HTTP headers.

Returns:

  • (String)


17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
# File 'lib/aws-sdk-iot/types.rb', line 17593

class UpdateAuthorizerRequest < Struct.new(
  :authorizer_name,
  :authorizer_function_arn,
  :token_key_name,
  :token_signing_public_keys,
  :status,
  :enable_caching_for_http)
  SENSITIVE = []
  include Aws::Structure
end

#token_signing_public_keysHash<String,String>

The public keys used to verify the token signature.

Returns:

  • (Hash<String,String>)


17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
# File 'lib/aws-sdk-iot/types.rb', line 17593

class UpdateAuthorizerRequest < Struct.new(
  :authorizer_name,
  :authorizer_function_arn,
  :token_key_name,
  :token_signing_public_keys,
  :status,
  :enable_caching_for_http)
  SENSITIVE = []
  include Aws::Structure
end