Class: Aws::IoT::Types::UpdateAuthorizerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateAuthorizerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_function_arn ⇒ String
The ARN of the authorizer’s Lambda function.
-
#authorizer_name ⇒ String
The authorizer name.
-
#enable_caching_for_http ⇒ Boolean
When
true, the result from the authorizer’s Lambda function is cached for the time specified inrefreshAfterInSeconds. -
#status ⇒ String
The status of the update authorizer request.
-
#token_key_name ⇒ String
The key used to extract the token from the HTTP headers.
-
#token_signing_public_keys ⇒ Hash<String,String>
The public keys used to verify the token signature.
Instance Attribute Details
#authorizer_function_arn ⇒ String
The ARN of the authorizer’s Lambda function.
17469 17470 17471 17472 17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-iot/types.rb', line 17469 class UpdateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#authorizer_name ⇒ String
The authorizer name.
17469 17470 17471 17472 17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-iot/types.rb', line 17469 class UpdateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#enable_caching_for_http ⇒ Boolean
When true, the result from the authorizer’s Lambda function is cached for the time specified in refreshAfterInSeconds. The cached result is used while the device reuses the same HTTP connection.
17469 17470 17471 17472 17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-iot/types.rb', line 17469 class UpdateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the update authorizer request.
17469 17470 17471 17472 17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-iot/types.rb', line 17469 class UpdateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#token_key_name ⇒ String
The key used to extract the token from the HTTP headers.
17469 17470 17471 17472 17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-iot/types.rb', line 17469 class UpdateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |
#token_signing_public_keys ⇒ Hash<String,String>
The public keys used to verify the token signature.
17469 17470 17471 17472 17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-iot/types.rb', line 17469 class UpdateAuthorizerRequest < Struct.new( :authorizer_name, :authorizer_function_arn, :token_key_name, :token_signing_public_keys, :status, :enable_caching_for_http) SENSITIVE = [] include Aws::Structure end |