Class: Aws::IoT::Types::UpdateBillingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_group_nameString

The name of the billing group.

Returns:

  • (String)


14682
14683
14684
14685
14686
14687
14688
# File 'lib/aws-sdk-iot/types.rb', line 14682

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#billing_group_propertiesTypes::BillingGroupProperties

The properties of the billing group.



14682
14683
14684
14685
14686
14687
14688
# File 'lib/aws-sdk-iot/types.rb', line 14682

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#expected_versionInteger

The expected version of the billing group. If the version of the billing group does not match the expected version specified in the request, the `UpdateBillingGroup` request is rejected with a `VersionConflictException`.

Returns:

  • (Integer)


14682
14683
14684
14685
14686
14687
14688
# File 'lib/aws-sdk-iot/types.rb', line 14682

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end