Class: Aws::IoT::Types::UpdateBillingGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateBillingGroupRequest data as a hash:

{
  billing_group_name: "BillingGroupName", # required
  billing_group_properties: { # required
    billing_group_description: "BillingGroupDescription",
  },
  expected_version: 1,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_group_nameString

The name of the billing group.

Returns:

  • (String)


19137
19138
19139
19140
19141
19142
19143
# File 'lib/aws-sdk-iot/types.rb', line 19137

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#billing_group_propertiesTypes::BillingGroupProperties

The properties of the billing group.



19137
19138
19139
19140
19141
19142
19143
# File 'lib/aws-sdk-iot/types.rb', line 19137

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end

#expected_versionInteger

The expected version of the billing group. If the version of the billing group does not match the expected version specified in the request, the `UpdateBillingGroup` request is rejected with a `VersionConflictException`.

Returns:

  • (Integer)


19137
19138
19139
19140
19141
19142
19143
# File 'lib/aws-sdk-iot/types.rb', line 19137

class UpdateBillingGroupRequest < Struct.new(
  :billing_group_name,
  :billing_group_properties,
  :expected_version)
  SENSITIVE = []
  include Aws::Structure
end