Class: Aws::IoT::Types::UpdateBillingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateBillingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateBillingGroupRequest data as a hash:
{
billing_group_name: "BillingGroupName", # required
billing_group_properties: { # required
billing_group_description: "BillingGroupDescription",
},
expected_version: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_group_name ⇒ String
The name of the billing group.
-
#billing_group_properties ⇒ Types::BillingGroupProperties
The properties of the billing group.
-
#expected_version ⇒ Integer
The expected version of the billing group.
Instance Attribute Details
#billing_group_name ⇒ String
The name of the billing group.
18947 18948 18949 18950 18951 18952 18953 |
# File 'lib/aws-sdk-iot/types.rb', line 18947 class UpdateBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#billing_group_properties ⇒ Types::BillingGroupProperties
The properties of the billing group.
18947 18948 18949 18950 18951 18952 18953 |
# File 'lib/aws-sdk-iot/types.rb', line 18947 class UpdateBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#expected_version ⇒ Integer
The expected version of the billing group. If the version of the billing group does not match the expected version specified in the request, the `UpdateBillingGroup` request is rejected with a `VersionConflictException`.
18947 18948 18949 18950 18951 18952 18953 |
# File 'lib/aws-sdk-iot/types.rb', line 18947 class UpdateBillingGroupRequest < Struct.new( :billing_group_name, :billing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |