Class: Aws::IoT::Types::UpdateCACertificateParams
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateCACertificateParams
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateCACertificateParams data as a hash:
{
action: "DEACTIVATE", # required, accepts DEACTIVATE
}
Parameters to define a mitigation action that changes the state of the CA certificate to inactive.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action that you want to apply to the CA certificate.
Instance Attribute Details
#action ⇒ String
The action that you want to apply to the CA certificate. The only supported value is `DEACTIVATE`.
19525 19526 19527 19528 19529 |
# File 'lib/aws-sdk-iot/types.rb', line 19525 class UpdateCACertificateParams < Struct.new( :action) SENSITIVE = [] include Aws::Structure end |