Class: Aws::IoT::Types::UpdateCACertificateParams

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateCACertificateParams data as a hash:

{
  action: "DEACTIVATE", # required, accepts DEACTIVATE
}

Parameters to define a mitigation action that changes the state of the CA certificate to inactive.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action that you want to apply to the CA certificate. The only supported value is `DEACTIVATE`.

Returns:

  • (String)


19042
19043
19044
19045
19046
# File 'lib/aws-sdk-iot/types.rb', line 19042

class UpdateCACertificateParams < Struct.new(
  :action)
  SENSITIVE = []
  include Aws::Structure
end