Class: Aws::IoT::Types::UpdateCustomMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateCustomMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
Field represents a friendly name in the console for the custom metric, it doesn’t have to be unique.
-
#metric_name ⇒ String
The name of the custom metric.
Instance Attribute Details
#display_name ⇒ String
Field represents a friendly name in the console for the custom metric, it doesn’t have to be unique. Don’t use this name as the metric identifier in the device metric report. Can be updated.
15511 15512 15513 15514 15515 15516 |
# File 'lib/aws-sdk-iot/types.rb', line 15511 class UpdateCustomMetricRequest < Struct.new( :metric_name, :display_name) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the custom metric. Cannot be updated.
15511 15512 15513 15514 15515 15516 |
# File 'lib/aws-sdk-iot/types.rb', line 15511 class UpdateCustomMetricRequest < Struct.new( :metric_name, :display_name) SENSITIVE = [] include Aws::Structure end |