Class: Aws::IoT::Types::UpdateCustomMetricRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

Field represents a friendly name in the console for the custom metric, it doesn’t have to be unique. Don’t use this name as the metric identifier in the device metric report. Can be updated.

Returns:

  • (String)


15451
15452
15453
15454
15455
15456
# File 'lib/aws-sdk-iot/types.rb', line 15451

class UpdateCustomMetricRequest < Struct.new(
  :metric_name,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the custom metric. Cannot be updated.

Returns:

  • (String)


15451
15452
15453
15454
15455
15456
# File 'lib/aws-sdk-iot/types.rb', line 15451

class UpdateCustomMetricRequest < Struct.new(
  :metric_name,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end