Class: Aws::IoT::Types::UpdateDeviceCertificateParams
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateDeviceCertificateParams
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateDeviceCertificateParams data as a hash:
{
action: "DEACTIVATE", # required, accepts DEACTIVATE
}
Parameters to define a mitigation action that changes the state of the device certificate to inactive.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action that you want to apply to the device certificate.
Instance Attribute Details
#action ⇒ String
The action that you want to apply to the device certificate. The only supported value is `DEACTIVATE`.
19150 19151 19152 19153 19154 |
# File 'lib/aws-sdk-iot/types.rb', line 19150 class UpdateDeviceCertificateParams < Struct.new( :action) SENSITIVE = [] include Aws::Structure end |