Class: Aws::IoT::Types::UpdateDeviceCertificateParams

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateDeviceCertificateParams data as a hash:

{
  action: "DEACTIVATE", # required, accepts DEACTIVATE
}

Parameters to define a mitigation action that changes the state of the device certificate to inactive.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action that you want to apply to the device certificate. The only supported value is `DEACTIVATE`.

Returns:

  • (String)


19030
19031
19032
19033
19034
# File 'lib/aws-sdk-iot/types.rb', line 19030

class UpdateDeviceCertificateParams < Struct.new(
  :action)
  SENSITIVE = []
  include Aws::Structure
end