Class: Aws::IoT::Types::UpdateDimensionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateDimensionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN)of the created dimension.
-
#creation_date ⇒ Time
The date and time, in milliseconds since epoch, when the dimension was initially created.
-
#last_modified_date ⇒ Time
The date and time, in milliseconds since epoch, when the dimension was most recently updated.
-
#name ⇒ String
A unique identifier for the dimension.
-
#string_values ⇒ Array<String>
The value or list of values used to scope the dimension.
-
#type ⇒ String
The type of the dimension.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN)of the created dimension.
14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 |
# File 'lib/aws-sdk-iot/types.rb', line 14992 class UpdateDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time, in milliseconds since epoch, when the dimension was initially created.
14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 |
# File 'lib/aws-sdk-iot/types.rb', line 14992 class UpdateDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time, in milliseconds since epoch, when the dimension was most recently updated.
14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 |
# File 'lib/aws-sdk-iot/types.rb', line 14992 class UpdateDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique identifier for the dimension.
14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 |
# File 'lib/aws-sdk-iot/types.rb', line 14992 class UpdateDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#string_values ⇒ Array<String>
The value or list of values used to scope the dimension. For example, for topic filters, this is the pattern used to match the MQTT topic name.
14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 |
# File 'lib/aws-sdk-iot/types.rb', line 14992 class UpdateDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the dimension.
14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 |
# File 'lib/aws-sdk-iot/types.rb', line 14992 class UpdateDimensionResponse < Struct.new( :name, :arn, :type, :string_values, :creation_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |