Class: Aws::IoT::Types::UpdateDomainConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateDomainConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
-
#domain_configuration_name ⇒ String
The name of the domain configuration to be updated.
-
#domain_configuration_status ⇒ String
The status to which the domain configuration should be updated.
-
#remove_authorizer_config ⇒ Boolean
Removes the authorization configuration from a domain.
-
#tls_config ⇒ Types::TlsConfig
An object that specifies the TLS configuration for a domain.
Instance Attribute Details
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
15650 15651 15652 15653 15654 15655 15656 15657 15658 |
# File 'lib/aws-sdk-iot/types.rb', line 15650 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config, :tls_config) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_name ⇒ String
The name of the domain configuration to be updated.
15650 15651 15652 15653 15654 15655 15656 15657 15658 |
# File 'lib/aws-sdk-iot/types.rb', line 15650 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config, :tls_config) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_status ⇒ String
The status to which the domain configuration should be updated.
15650 15651 15652 15653 15654 15655 15656 15657 15658 |
# File 'lib/aws-sdk-iot/types.rb', line 15650 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config, :tls_config) SENSITIVE = [] include Aws::Structure end |
#remove_authorizer_config ⇒ Boolean
Removes the authorization configuration from a domain.
15650 15651 15652 15653 15654 15655 15656 15657 15658 |
# File 'lib/aws-sdk-iot/types.rb', line 15650 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config, :tls_config) SENSITIVE = [] include Aws::Structure end |
#tls_config ⇒ Types::TlsConfig
An object that specifies the TLS configuration for a domain.
15650 15651 15652 15653 15654 15655 15656 15657 15658 |
# File 'lib/aws-sdk-iot/types.rb', line 15650 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config, :tls_config) SENSITIVE = [] include Aws::Structure end |