Class: Aws::IoT::Types::UpdateDomainConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateDomainConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateDomainConfigurationRequest data as a hash:
{
domain_configuration_name: "ReservedDomainConfigurationName", # required
authorizer_config: {
default_authorizer_name: "AuthorizerName",
allow_authorizer_override: false,
},
domain_configuration_status: "ENABLED", # accepts ENABLED, DISABLED
remove_authorizer_config: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
-
#domain_configuration_name ⇒ String
The name of the domain configuration to be updated.
-
#domain_configuration_status ⇒ String
The status to which the domain configuration should be updated.
-
#remove_authorizer_config ⇒ Boolean
Removes the authorization configuration from a domain.
Instance Attribute Details
#authorizer_config ⇒ Types::AuthorizerConfig
An object that specifies the authorization service for a domain.
19668 19669 19670 19671 19672 19673 19674 19675 |
# File 'lib/aws-sdk-iot/types.rb', line 19668 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_name ⇒ String
The name of the domain configuration to be updated.
19668 19669 19670 19671 19672 19673 19674 19675 |
# File 'lib/aws-sdk-iot/types.rb', line 19668 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config) SENSITIVE = [] include Aws::Structure end |
#domain_configuration_status ⇒ String
The status to which the domain configuration should be updated.
19668 19669 19670 19671 19672 19673 19674 19675 |
# File 'lib/aws-sdk-iot/types.rb', line 19668 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config) SENSITIVE = [] include Aws::Structure end |
#remove_authorizer_config ⇒ Boolean
Removes the authorization configuration from a domain.
19668 19669 19670 19671 19672 19673 19674 19675 |
# File 'lib/aws-sdk-iot/types.rb', line 19668 class UpdateDomainConfigurationRequest < Struct.new( :domain_configuration_name, :authorizer_config, :domain_configuration_status, :remove_authorizer_config) SENSITIVE = [] include Aws::Structure end |