Class: Aws::IoT::Types::UpdateFleetMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateFleetMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass UpdateFleetMetricRequest data as a hash:
{
metric_name: "FleetMetricName", # required
query_string: "QueryString",
aggregation_type: {
name: "Statistics", # required, accepts Statistics, Percentiles, Cardinality
values: ["AggregationTypeValue"],
},
period: 1,
aggregation_field: "AggregationField",
description: "FleetMetricDescription",
query_version: "QueryVersion",
index_name: "IndexName", # required
unit: "Seconds", # accepts Seconds, Microseconds, Milliseconds, Bytes, Kilobytes, Megabytes, Gigabytes, Terabytes, Bits, Kilobits, Megabits, Gigabits, Terabits, Percent, Count, Bytes/Second, Kilobytes/Second, Megabytes/Second, Gigabytes/Second, Terabytes/Second, Bits/Second, Kilobits/Second, Megabits/Second, Gigabits/Second, Terabits/Second, Count/Second, None
expected_version: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_field ⇒ String
The field to aggregate.
-
#aggregation_type ⇒ Types::AggregationType
The type of the aggregation query.
-
#description ⇒ String
The description of the fleet metric.
-
#expected_version ⇒ Integer
The expected version of the fleet metric record in the registry.
-
#index_name ⇒ String
The name of the index to search.
-
#metric_name ⇒ String
The name of the fleet metric to update.
-
#period ⇒ Integer
The time in seconds between fleet metric emissions.
-
#query_string ⇒ String
The search query string.
-
#query_version ⇒ String
The version of the query.
-
#unit ⇒ String
Used to support unit transformation such as milliseconds to seconds.
Instance Attribute Details
#aggregation_field ⇒ String
The field to aggregate.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#aggregation_type ⇒ Types::AggregationType
The type of the aggregation query.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the fleet metric.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#expected_version ⇒ Integer
The expected version of the fleet metric record in the registry.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index to search.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the fleet metric to update.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The time in seconds between fleet metric emissions. Range [60(1 min), 86400(1 day)] and must be multiple of 60.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The search query string.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#query_version ⇒ String
The version of the query.
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
Used to support unit transformation such as milliseconds to seconds. The unit must be supported by [CW metric].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html
19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 |
# File 'lib/aws-sdk-iot/types.rb', line 19627 class UpdateFleetMetricRequest < Struct.new( :metric_name, :query_string, :aggregation_type, :period, :aggregation_field, :description, :query_version, :index_name, :unit, :expected_version) SENSITIVE = [] include Aws::Structure end |