Class: Aws::IoT::Types::UpdateMitigationActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateMitigationActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateMitigationActionRequest data as a hash:
{
action_name: "MitigationActionName", # required
role_arn: "RoleArn",
action_params: {
update_device_certificate_params: {
action: "DEACTIVATE", # required, accepts DEACTIVATE
},
update_ca_certificate_params: {
action: "DEACTIVATE", # required, accepts DEACTIVATE
},
add_things_to_thing_group_params: {
thing_group_names: ["ThingGroupName"], # required
override_dynamic_groups: false,
},
replace_default_policy_version_params: {
template_name: "BLANK_POLICY", # required, accepts BLANK_POLICY
},
enable_io_t_logging_params: {
role_arn_for_logging: "RoleArn", # required
log_level: "DEBUG", # required, accepts DEBUG, INFO, ERROR, WARN, DISABLED
},
publish_finding_to_sns_params: {
topic_arn: "SnsTopicArn", # required
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_name ⇒ String
The friendly name for the mitigation action.
-
#action_params ⇒ Types::MitigationActionParams
Defines the type of action and the parameters for that action.
-
#role_arn ⇒ String
The ARN of the IAM role that is used to apply the mitigation action.
Instance Attribute Details
#action_name ⇒ String
The friendly name for the mitigation action. You cannot change the name by using `UpdateMitigationAction`. Instead, you must delete and recreate the mitigation action with the new name.
20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-iot/types.rb', line 20205 class UpdateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params) SENSITIVE = [] include Aws::Structure end |
#action_params ⇒ Types::MitigationActionParams
Defines the type of action and the parameters for that action.
20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-iot/types.rb', line 20205 class UpdateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that is used to apply the mitigation action.
20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-iot/types.rb', line 20205 class UpdateMitigationActionRequest < Struct.new( :action_name, :role_arn, :action_params) SENSITIVE = [] include Aws::Structure end |