Class: Aws::IoT::Types::UpdateProvisioningTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateProvisioningTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass UpdateProvisioningTemplateRequest data as a hash:
{
template_name: "TemplateName", # required
description: "TemplateDescription",
enabled: false,
default_version_id: 1,
provisioning_role_arn: "RoleArn",
pre_provisioning_hook: {
payload_version: "PayloadVersion",
target_arn: "TargetArn", # required
},
remove_pre_provisioning_hook: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_version_id ⇒ Integer
The ID of the default provisioning template version.
-
#description ⇒ String
The description of the provisioning template.
-
#enabled ⇒ Boolean
True to enable the provisioning template, otherwise false.
-
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Updates the pre-provisioning hook template.
-
#provisioning_role_arn ⇒ String
The ARN of the role associated with the provisioning template.
-
#remove_pre_provisioning_hook ⇒ Boolean
Removes pre-provisioning hook template.
-
#template_name ⇒ String
The name of the provisioning template.
Instance Attribute Details
#default_version_id ⇒ Integer
The ID of the default provisioning template version.
20150 20151 20152 20153 20154 20155 20156 20157 20158 20159 20160 |
# File 'lib/aws-sdk-iot/types.rb', line 20150 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the provisioning template.
20150 20151 20152 20153 20154 20155 20156 20157 20158 20159 20160 |
# File 'lib/aws-sdk-iot/types.rb', line 20150 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
True to enable the provisioning template, otherwise false.
20150 20151 20152 20153 20154 20155 20156 20157 20158 20159 20160 |
# File 'lib/aws-sdk-iot/types.rb', line 20150 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Updates the pre-provisioning hook template. Only supports template of type `FLEET_PROVISIONING`. For more information about provisioning template types, see [type].
20150 20151 20152 20153 20154 20155 20156 20157 20158 20159 20160 |
# File 'lib/aws-sdk-iot/types.rb', line 20150 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#provisioning_role_arn ⇒ String
The ARN of the role associated with the provisioning template. This IoT role grants permission to provision a device.
20150 20151 20152 20153 20154 20155 20156 20157 20158 20159 20160 |
# File 'lib/aws-sdk-iot/types.rb', line 20150 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#remove_pre_provisioning_hook ⇒ Boolean
Removes pre-provisioning hook template.
20150 20151 20152 20153 20154 20155 20156 20157 20158 20159 20160 |
# File 'lib/aws-sdk-iot/types.rb', line 20150 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the provisioning template.
20150 20151 20152 20153 20154 20155 20156 20157 20158 20159 20160 |
# File 'lib/aws-sdk-iot/types.rb', line 20150 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |