Class: Aws::IoT::Types::UpdateProvisioningTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateProvisioningTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
When making an API call, you may pass UpdateProvisioningTemplateRequest data as a hash:
{
template_name: "TemplateName", # required
description: "TemplateDescription",
enabled: false,
default_version_id: 1,
provisioning_role_arn: "RoleArn",
pre_provisioning_hook: {
payload_version: "PayloadVersion",
target_arn: "TargetArn", # required
},
remove_pre_provisioning_hook: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_version_id ⇒ Integer
The ID of the default provisioning template version.
-
#description ⇒ String
The description of the fleet provisioning template.
-
#enabled ⇒ Boolean
True to enable the fleet provisioning template, otherwise false.
-
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Updates the pre-provisioning hook template.
-
#provisioning_role_arn ⇒ String
The ARN of the role associated with the provisioning template.
-
#remove_pre_provisioning_hook ⇒ Boolean
Removes pre-provisioning hook template.
-
#template_name ⇒ String
The name of the fleet provisioning template.
Instance Attribute Details
#default_version_id ⇒ Integer
The ID of the default provisioning template version.
19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/aws-sdk-iot/types.rb', line 19872 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the fleet provisioning template.
19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/aws-sdk-iot/types.rb', line 19872 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
True to enable the fleet provisioning template, otherwise false.
19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/aws-sdk-iot/types.rb', line 19872 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#pre_provisioning_hook ⇒ Types::ProvisioningHook
Updates the pre-provisioning hook template.
19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/aws-sdk-iot/types.rb', line 19872 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#provisioning_role_arn ⇒ String
The ARN of the role associated with the provisioning template. This IoT role grants permission to provision a device.
19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/aws-sdk-iot/types.rb', line 19872 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#remove_pre_provisioning_hook ⇒ Boolean
Removes pre-provisioning hook template.
19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/aws-sdk-iot/types.rb', line 19872 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the fleet provisioning template.
19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/aws-sdk-iot/types.rb', line 19872 class UpdateProvisioningTemplateRequest < Struct.new( :template_name, :description, :enabled, :default_version_id, :provisioning_role_arn, :pre_provisioning_hook, :remove_pre_provisioning_hook) SENSITIVE = [] include Aws::Structure end |