Class: Aws::IoT::Types::UpdateRoleAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#credential_duration_secondsInteger

The number of seconds the credential will be valid.

This value must be less than or equal to the maximum session duration of the IAM role that the role alias references.

Returns:

  • (Integer)


18549
18550
18551
18552
18553
18554
18555
# File 'lib/aws-sdk-iot/types.rb', line 18549

class UpdateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#role_aliasString

The role alias to update.

Returns:

  • (String)


18549
18550
18551
18552
18553
18554
18555
# File 'lib/aws-sdk-iot/types.rb', line 18549

class UpdateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The role ARN.

Returns:

  • (String)


18549
18550
18551
18552
18553
18554
18555
# File 'lib/aws-sdk-iot/types.rb', line 18549

class UpdateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end