Class: Aws::IoT::Types::UpdateRoleAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateRoleAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credential_duration_seconds ⇒ Integer
The number of seconds the credential will be valid.
-
#role_alias ⇒ String
The role alias to update.
-
#role_arn ⇒ String
The role ARN.
Instance Attribute Details
#credential_duration_seconds ⇒ Integer
The number of seconds the credential will be valid.
This value must be less than or equal to the maximum session duration of the IAM role that the role alias references.
18432 18433 18434 18435 18436 18437 18438 |
# File 'lib/aws-sdk-iot/types.rb', line 18432 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#role_alias ⇒ String
The role alias to update.
18432 18433 18434 18435 18436 18437 18438 |
# File 'lib/aws-sdk-iot/types.rb', line 18432 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role ARN.
18432 18433 18434 18435 18436 18437 18438 |
# File 'lib/aws-sdk-iot/types.rb', line 18432 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |