Class: Aws::IoT::Types::UpdateRoleAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateRoleAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credential_duration_seconds ⇒ Integer
The number of seconds the credential will be valid.
-
#role_alias ⇒ String
The role alias to update.
-
#role_arn ⇒ String
The role ARN.
Instance Attribute Details
#credential_duration_seconds ⇒ Integer
The number of seconds the credential will be valid.
This value must be less than or equal to the maximum session duration of the IAM role that the role alias references.
15249 15250 15251 15252 15253 15254 15255 |
# File 'lib/aws-sdk-iot/types.rb', line 15249 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#role_alias ⇒ String
The role alias to update.
15249 15250 15251 15252 15253 15254 15255 |
# File 'lib/aws-sdk-iot/types.rb', line 15249 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role ARN.
15249 15250 15251 15252 15253 15254 15255 |
# File 'lib/aws-sdk-iot/types.rb', line 15249 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |