Class: Aws::IoT::Types::UpdateRoleAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Overview

Note:

When making an API call, you may pass UpdateRoleAliasRequest data as a hash:

{
  role_alias: "RoleAlias", # required
  role_arn: "RoleArn",
  credential_duration_seconds: 1,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#credential_duration_secondsInteger

The number of seconds the credential will be valid.

This value must be less than or equal to the maximum session duration of the IAM role that the role alias references.

Returns:

  • (Integer)


19824
19825
19826
19827
19828
19829
19830
# File 'lib/aws-sdk-iot/types.rb', line 19824

class UpdateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#role_aliasString

The role alias to update.

Returns:

  • (String)


19824
19825
19826
19827
19828
19829
19830
# File 'lib/aws-sdk-iot/types.rb', line 19824

class UpdateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The role ARN.

Returns:

  • (String)


19824
19825
19826
19827
19828
19829
19830
# File 'lib/aws-sdk-iot/types.rb', line 19824

class UpdateRoleAliasRequest < Struct.new(
  :role_alias,
  :role_arn,
  :credential_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end