Class: Aws::IoT::Types::UpdateRoleAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateRoleAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateRoleAliasRequest data as a hash:
{
role_alias: "RoleAlias", # required
role_arn: "RoleArn",
credential_duration_seconds: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credential_duration_seconds ⇒ Integer
The number of seconds the credential will be valid.
-
#role_alias ⇒ String
The role alias to update.
-
#role_arn ⇒ String
The role ARN.
Instance Attribute Details
#credential_duration_seconds ⇒ Integer
The number of seconds the credential will be valid.
This value must be less than or equal to the maximum session duration of the IAM role that the role alias references.
19754 19755 19756 19757 19758 19759 19760 |
# File 'lib/aws-sdk-iot/types.rb', line 19754 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#role_alias ⇒ String
The role alias to update.
19754 19755 19756 19757 19758 19759 19760 |
# File 'lib/aws-sdk-iot/types.rb', line 19754 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role ARN.
19754 19755 19756 19757 19758 19759 19760 |
# File 'lib/aws-sdk-iot/types.rb', line 19754 class UpdateRoleAliasRequest < Struct.new( :role_alias, :role_arn, :credential_duration_seconds) SENSITIVE = [] include Aws::Structure end |