Class: Aws::IoT::Types::UpdateSecurityProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateSecurityProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_metrics_to_retain ⇒ Array<String>
*Please use UpdateSecurityProfileResponse$additionalMetricsToRetainV2 instead.*.
-
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored).
-
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Where the alerts are sent.
-
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
-
#creation_date ⇒ Time
The time the security profile was created.
-
#last_modified_date ⇒ Time
The time the security profile was last modified.
-
#metrics_export_config ⇒ Types::MetricsExportConfig
Specifies the MQTT topic and role ARN required for metric export.
-
#security_profile_arn ⇒ String
The ARN of the security profile that was updated.
-
#security_profile_description ⇒ String
The description of the security profile.
-
#security_profile_name ⇒ String
The name of the security profile that was updated.
-
#version ⇒ Integer
The updated version of the security profile.
Instance Attribute Details
#additional_metrics_to_retain ⇒ Array<String>
*Please use UpdateSecurityProfileResponse$additionalMetricsToRetainV2 instead.*
A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the security profile’s ‘behaviors`, but it is also retained for any metric specified here.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#additional_metrics_to_retain_v2 ⇒ Array<Types::MetricToRetain>
A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile’s behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#alert_targets ⇒ Hash<String,Types::AlertTarget>
Where the alerts are sent. (Alerts are always sent to the console.)
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#behaviors ⇒ Array<Types::Behavior>
Specifies the behaviors that, when violated by a device (thing), cause an alert.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The time the security profile was created.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The time the security profile was last modified.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#metrics_export_config ⇒ Types::MetricsExportConfig
Specifies the MQTT topic and role ARN required for metric export.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_arn ⇒ String
The ARN of the security profile that was updated.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_description ⇒ String
The description of the security profile.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#security_profile_name ⇒ String
The name of the security profile that was updated.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The updated version of the security profile.
16385 16386 16387 16388 16389 16390 16391 16392 16393 16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-iot/types.rb', line 16385 class UpdateSecurityProfileResponse < Struct.new( :security_profile_name, :security_profile_arn, :security_profile_description, :behaviors, :alert_targets, :additional_metrics_to_retain, :additional_metrics_to_retain_v2, :version, :creation_date, :last_modified_date, :metrics_export_config) SENSITIVE = [] include Aws::Structure end |