Class: Aws::IoT::Types::UpdateSecurityProfileResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_metrics_to_retainArray<String>

*Please use UpdateSecurityProfileResponse$additionalMetricsToRetainV2 instead.*

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the security profile's `behaviors`, but it is also retained for any metric specified here.

Returns:

  • (Array<String>)


20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#additional_metrics_to_retain_v2Array<Types::MetricToRetain>

A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions.

Returns:



20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#alert_targetsHash<String,Types::AlertTarget>

Where the alerts are sent. (Alerts are always sent to the console.)

Returns:



20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#behaviorsArray<Types::Behavior>

Specifies the behaviors that, when violated by a device (thing), cause an alert.

Returns:



20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The time the security profile was created.

Returns:

  • (Time)


20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The time the security profile was last modified.

Returns:

  • (Time)


20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_arnString

The ARN of the security profile that was updated.

Returns:

  • (String)


20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_descriptionString

The description of the security profile.

Returns:

  • (String)


20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_nameString

The name of the security profile that was updated.

Returns:

  • (String)


20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The updated version of the security profile.

Returns:

  • (Integer)


20032
20033
20034
20035
20036
20037
20038
20039
20040
20041
20042
20043
20044
20045
# File 'lib/aws-sdk-iot/types.rb', line 20032

class UpdateSecurityProfileResponse < Struct.new(
  :security_profile_name,
  :security_profile_arn,
  :security_profile_description,
  :behaviors,
  :alert_targets,
  :additional_metrics_to_retain,
  :additional_metrics_to_retain_v2,
  :version,
  :creation_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end