Class: Aws::IoT::Types::UpdateThingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateThingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_version ⇒ Integer
The expected version of the thing group.
-
#thing_group_name ⇒ String
The thing group to update.
-
#thing_group_properties ⇒ Types::ThingGroupProperties
The thing group properties.
Instance Attribute Details
#expected_version ⇒ Integer
The expected version of the thing group. If this does not match the version of the thing group being updated, the update will fail.
16397 16398 16399 16400 16401 16402 16403 |
# File 'lib/aws-sdk-iot/types.rb', line 16397 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
The thing group to update.
16397 16398 16399 16400 16401 16402 16403 |
# File 'lib/aws-sdk-iot/types.rb', line 16397 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_properties ⇒ Types::ThingGroupProperties
The thing group properties.
16397 16398 16399 16400 16401 16402 16403 |
# File 'lib/aws-sdk-iot/types.rb', line 16397 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |