Class: Aws::IoT::Types::UpdateThingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateThingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateThingGroupRequest data as a hash:
{
thing_group_name: "ThingGroupName", # required
thing_group_properties: { # required
thing_group_description: "ThingGroupDescription",
attribute_payload: {
attributes: {
"AttributeName" => "AttributeValue",
},
merge: false,
},
},
expected_version: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_version ⇒ Integer
The expected version of the thing group.
-
#thing_group_name ⇒ String
The thing group to update.
-
#thing_group_properties ⇒ Types::ThingGroupProperties
The thing group properties.
Instance Attribute Details
#expected_version ⇒ Integer
The expected version of the thing group. If this does not match the version of the thing group being updated, the update will fail.
21011 21012 21013 21014 21015 21016 21017 |
# File 'lib/aws-sdk-iot/types.rb', line 21011 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
The thing group to update.
21011 21012 21013 21014 21015 21016 21017 |
# File 'lib/aws-sdk-iot/types.rb', line 21011 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_properties ⇒ Types::ThingGroupProperties
The thing group properties.
21011 21012 21013 21014 21015 21016 21017 |
# File 'lib/aws-sdk-iot/types.rb', line 21011 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |