Class: Aws::IoT::Types::UpdateThingGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateThingGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass UpdateThingGroupRequest data as a hash:
{
thing_group_name: "ThingGroupName", # required
thing_group_properties: { # required
thing_group_description: "ThingGroupDescription",
attribute_payload: {
attributes: {
"AttributeName" => "AttributeValue",
},
merge: false,
},
},
expected_version: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_version ⇒ Integer
The expected version of the thing group.
-
#thing_group_name ⇒ String
The thing group to update.
-
#thing_group_properties ⇒ Types::ThingGroupProperties
The thing group properties.
Instance Attribute Details
#expected_version ⇒ Integer
The expected version of the thing group. If this does not match the version of the thing group being updated, the update will fail.
20139 20140 20141 20142 20143 20144 20145 |
# File 'lib/aws-sdk-iot/types.rb', line 20139 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_name ⇒ String
The thing group to update.
20139 20140 20141 20142 20143 20144 20145 |
# File 'lib/aws-sdk-iot/types.rb', line 20139 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |
#thing_group_properties ⇒ Types::ThingGroupProperties
The thing group properties.
20139 20140 20141 20142 20143 20144 20145 |
# File 'lib/aws-sdk-iot/types.rb', line 20139 class UpdateThingGroupRequest < Struct.new( :thing_group_name, :thing_group_properties, :expected_version) SENSITIVE = [] include Aws::Structure end |