Class: Aws::IoT::Types::UpdateThingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::UpdateThingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
The input for the UpdateThing operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_payload ⇒ Types::AttributePayload
A list of thing attributes, a JSON string containing name-value pairs.
-
#expected_version ⇒ Integer
The expected version of the thing record in the registry.
-
#remove_thing_type ⇒ Boolean
Remove a thing type association.
-
#thing_name ⇒ String
The name of the thing to update.
-
#thing_type_name ⇒ String
The name of the thing type.
Instance Attribute Details
#attribute_payload ⇒ Types::AttributePayload
A list of thing attributes, a JSON string containing name-value pairs. For example:
‘“attributes”:{“name1”:“value2”}`
This data is used to add new attributes or update existing attributes.
16815 16816 16817 16818 16819 16820 16821 16822 16823 |
# File 'lib/aws-sdk-iot/types.rb', line 16815 class UpdateThingRequest < Struct.new( :thing_name, :thing_type_name, :attribute_payload, :expected_version, :remove_thing_type) SENSITIVE = [] include Aws::Structure end |
#expected_version ⇒ Integer
The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the ‘UpdateThing` request is rejected with a `VersionConflictException`.
16815 16816 16817 16818 16819 16820 16821 16822 16823 |
# File 'lib/aws-sdk-iot/types.rb', line 16815 class UpdateThingRequest < Struct.new( :thing_name, :thing_type_name, :attribute_payload, :expected_version, :remove_thing_type) SENSITIVE = [] include Aws::Structure end |
#remove_thing_type ⇒ Boolean
Remove a thing type association. If true, the association is removed.
16815 16816 16817 16818 16819 16820 16821 16822 16823 |
# File 'lib/aws-sdk-iot/types.rb', line 16815 class UpdateThingRequest < Struct.new( :thing_name, :thing_type_name, :attribute_payload, :expected_version, :remove_thing_type) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing to update.
You can’t change a thing’s name. To change a thing’s name, you must create a new thing, give it the new name, and then delete the old thing.
16815 16816 16817 16818 16819 16820 16821 16822 16823 |
# File 'lib/aws-sdk-iot/types.rb', line 16815 class UpdateThingRequest < Struct.new( :thing_name, :thing_type_name, :attribute_payload, :expected_version, :remove_thing_type) SENSITIVE = [] include Aws::Structure end |
#thing_type_name ⇒ String
The name of the thing type.
16815 16816 16817 16818 16819 16820 16821 16822 16823 |
# File 'lib/aws-sdk-iot/types.rb', line 16815 class UpdateThingRequest < Struct.new( :thing_name, :thing_type_name, :attribute_payload, :expected_version, :remove_thing_type) SENSITIVE = [] include Aws::Structure end |