Class: Aws::IoT::Types::ViolationEventOccurrenceRange
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::ViolationEventOccurrenceRange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass ViolationEventOccurrenceRange data as a hash:
{
start_time: Time.now, # required
end_time: Time.now, # required
}
Specifies the time period of which violation events occurred between.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The end date and time of a time period in which violation events occurred.
-
#start_time ⇒ Time
The start date and time of a time period in which violation events occurred.
Instance Attribute Details
#end_time ⇒ Time
The end date and time of a time period in which violation events occurred.
20509 20510 20511 20512 20513 20514 |
# File 'lib/aws-sdk-iot/types.rb', line 20509 class ViolationEventOccurrenceRange < Struct.new( :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start date and time of a time period in which violation events occurred.
20509 20510 20511 20512 20513 20514 |
# File 'lib/aws-sdk-iot/types.rb', line 20509 class ViolationEventOccurrenceRange < Struct.new( :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |