Class: Aws::IoT::Types::VpcDestinationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoT::Types::VpcDestinationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iot/types.rb
Overview
Note:
When making an API call, you may pass VpcDestinationConfiguration data as a hash:
{
subnet_ids: ["SubnetId"], # required
security_groups: ["SecurityGroupId"],
vpc_id: "VpcId", # required
role_arn: "AwsArn", # required
}
The configuration information for a virtual private cloud (VPC) destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role_arn ⇒ String
The ARN of a role that has permission to create and attach to elastic network interfaces (ENIs).
-
#security_groups ⇒ Array<String>
The security groups of the VPC destination.
-
#subnet_ids ⇒ Array<String>
The subnet IDs of the VPC destination.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#role_arn ⇒ String
The ARN of a role that has permission to create and attach to elastic network interfaces (ENIs).
20980 20981 20982 20983 20984 20985 20986 20987 |
# File 'lib/aws-sdk-iot/types.rb', line 20980 class VpcDestinationConfiguration < Struct.new( :subnet_ids, :security_groups, :vpc_id, :role_arn) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The security groups of the VPC destination.
20980 20981 20982 20983 20984 20985 20986 20987 |
# File 'lib/aws-sdk-iot/types.rb', line 20980 class VpcDestinationConfiguration < Struct.new( :subnet_ids, :security_groups, :vpc_id, :role_arn) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The subnet IDs of the VPC destination.
20980 20981 20982 20983 20984 20985 20986 20987 |
# File 'lib/aws-sdk-iot/types.rb', line 20980 class VpcDestinationConfiguration < Struct.new( :subnet_ids, :security_groups, :vpc_id, :role_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
20980 20981 20982 20983 20984 20985 20986 20987 |
# File 'lib/aws-sdk-iot/types.rb', line 20980 class VpcDestinationConfiguration < Struct.new( :subnet_ids, :security_groups, :vpc_id, :role_arn) SENSITIVE = [] include Aws::Structure end |